(* ::Package:: *)

(* ::Title:: *)
(*SUSYHD v1.0*)


(* ::Text:: *)
(*This package computes the pole mass of the Higgs boson in the MSSM using the effective field theory technique. *)
(*For the details of the calculation and conventions please refer to the file of documentation and examples SUSYHD_Examples.nb or the paper arXiv:1504.05200*)


(* ::Section::Closed:: *)
(*Preambula*)


BeginPackage["SUSYHD`"]


(*uncomment this cell if you need the values of the MSSM bottom and tau Yukawa couplings in the Overscript[DR, _] scheme*)
(*gbMSSM::usage="gbMSSM[Q,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]";
gtauMSSM::usage="gtauMSSM[Q,mL3,mE3,M2,M1,\[Mu],tan\[Beta]]";*)


Print["----------------------------------
SUSYHD v1.0 (2015)
Javier Pardo Vega and Giovanni Villadoro
http://www.ictp.it/~susyhd
----------------------------------"];
MHiggs::usage="MHiggs[parameterslist] computes the pole mass of the Higgs boson (in units of GeV) as a function of the supersymmetric parameters in the \!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme evaluated at the scale Q=\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", SubscriptBox[\"U\", \"3\"]]}]],\nFontSize->10]\). 

The input \!\(\*
StyleBox[\"parameterslist\",\nFontSlant->\"Italic\"]\) should be a list of the following form:
	{tan\[Beta],\!\(\*SubscriptBox[\(M\), \(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \(3\)]\),\[Mu],\!\(\*SubscriptBox[\(A\), \(t\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\)}.

It also accepts shorter lists and assign suitable values for the parameters that are not input:
	{tan\[Beta],m0}: assumes degenerate SUSY masses m0 and \!\(\*SubscriptBox[\(A\), \(t\)]\)=0
	{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\)}: like before but with generic \!\(\*SubscriptBox[\(A\), \(t\)]\)
	{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\),m12}: like before but with generic fermion masses \!\(\*SubscriptBox[\(M\), \(1\)]\)=\!\(\*SubscriptBox[\(M\), \(2\)]\)=\!\(\*SubscriptBox[\(M\), \(3\)]\)=\[Mu]=m12 
	{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but with generic \[Mu]
	{tan\[Beta],\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but with \!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\)\[NotEqual]\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\), the other scalar masses are m0=\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", SubscriptBox[\"U\", \"3\"]]}]],\nFontSize->10]\)
	{tan\[Beta],\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),\!\(\*SubscriptBox[\(M\), \(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \(3\)]\),\[Mu]}: like before but with generic gaugino masses.";
MHiggs::warning="We recommend to choose the renormalization scale \!\(\*SubscriptBox[\(m\), \(SUSY\)]\) near the stop average mass (\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\)\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\)\!\(\*SuperscriptBox[\()\), \(1/2\)]\).";
MHiggs::warningsplit="The Split-SUSY calculation is suitable when the scalars are heavier than the gauginos and higgsinos. High-Scale calculation will be used.";
MHiggs::variables="One of the variables is not well-defined.";
MHiggs::negative="The Higgs mass squared is negative. The value 0 is returned.";
MHiggs::bottomYukawa="Bottom Yukawa is non-perturbative.";
MHiggs::tauYukawa="Tau Yukawa is non-perturbative.";
split::usage="split is an option for MHiggs. When activated (split\[Rule]True), the code uses the Split-SUSY effective theory to resum the logs between the fermion scale \!\(\*SubscriptBox[\(Q\), \(split\)]\)=max(\[Mu],\!\(\*SubscriptBox[\(M\), \(2\)]\)) and the SUSY scale. In this case the RGE are integrated numerically and the code is sensibly slower. In the whole range relevant for the Higgs mass the effect of this resummation is very small.
Default value: split\[Rule]False";
numerical::usage="\!\(\*
StyleBox[\"numerical\",\nFontSlant->\"Italic\"]\) is an option for MHiggs and \[CapitalDelta]MHiggs. When activated (numerical\[Rule]True) the program integrates the RGE numerically and is much slower. 
Default value: numerical\[Rule] False (recommended)";
hiOrd::usage="hiOrd is an option for MHiggs and \[CapitalDelta]MHiggs which controls what two-loop SUSY thresholds are included. It also determines if the \!\(\*OverscriptBox[\(MS\), \(_\)]\) running top Yukawa coupling is calculated at two or three loops from the pole mass of the top quark. This option has the form hiOrd->{t1,t2,t3,t4} where each component take values 0 (correction excluded) or 1 (correction included). Each component controls the following corrections:
t1: two-loop O(\!\(\*SubscriptBox[\(\[Alpha]\), \(t\)]\)\!\(\*SubscriptBox[\(\[Alpha]\), \(S\)]\)) SUSY threshold
t2: two-loop O(\!\(\*SubsuperscriptBox[\(\[Alpha]\), \(t\), \(2\)]\)) SUSY threshold
t3: one-loop O(\!\(\*SubscriptBox[\(\[Alpha]\), \(b, \[Tau]\)]\)) including tan\[Beta]-enhanced corrections.
t4: three-loop O(\!\(\*SubsuperscriptBox[\(\[Alpha]\), \(S\), \(3\)]\)) correction to the determination of the \!\(\*OverscriptBox[\(MS\), \(_\)]\) top Yukawa coupling
By default all corrections are included, i.e. hiOrd\[Rule]{1,1,1,1}.";
Rscale::usage="Rscale is an option for MHiggs and \[CapitalDelta]MHiggs that allows to change the scale at which the MSSM parameters are given as input. The program does not perform any RGE resummation of the soft parameters, it is thus recommended to use a scale close to the default one.
Default value: Rscale\[Rule]\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", SubscriptBox[\"U\", \"3\"]]}]],\nFontSize->10]\)";
RscaleSplit::usage="\!\(\*
StyleBox[\"RscaleSplit\",\nFontSlant->\"Italic\"]\) is an option for MHiggs which allows to change the scale of the Split-SUSY effective theory. 
Default value: Rscale\[Rule]max(\[Mu],\!\(\*SubscriptBox[\(M\), \(2\)]\))";
scheme::usage="\!\(\*
StyleBox[\"scheme\",\nFontSlant->\"Italic\"]\) is an option for MHiggs and \[CapitalDelta]MHiggs which allows to input the MSSM parameters in the on-shell scheme (scheme\[Rule]\"OS\").
Default value: scheme\[Rule]\"DRbar\" ";
SetSMparameters::usage="SetSMparameters[\!\(\*SubscriptBox[\(m\), \(t\)]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*SubscriptBox[\(\[Alpha]\), \(S\)]\)(\!\(\*SubscriptBox[\(m\), \(Z\)]\))] sets the input values for the OS top mass \!\(\*SubscriptBox[\(m\), \(t\)]\) and the strong coupling at the scale of the mass of the Z-boson \!\(\*SubscriptBox[\(\[Alpha]\), \(S\)]\)(\!\(\*SubscriptBox[\(M\), \(Z\)]\)). The default values are \!\(\*SubscriptBox[\(m\), \(t\)]\)=173.34 GeV and \!\(\*SubscriptBox[\(\[Alpha]\), \(S\)]\)(\!\(\*SubscriptBox[\(m\), \(Z\)]\))=0.1185.";
useMStopYukawa::usage="useMStopYukawa is an option for SetSMparameters which allows to input the \!\(\*OverscriptBox[\(MS\), \(_\)]\) top Yukawa coupling \!\(\*SubsuperscriptBox[\(y\), \(t\), OverscriptBox[\(MS\), \(_\)]]\)(\!\(\*SubscriptBox[\(m\), \(t\)]\)) in place of the pole mass of the top quark (useMStopYukawa\[Rule]True).
Default value: useMStopYukawa\[Rule]False.";
\[CapitalDelta]MHiggs::usage="\!\(\*
StyleBox[\"\[CapitalDelta]MHiggs\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)parameterslist\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)estimates the theoretical uncertainty in the calculation of the Higgs mass (in units of GeV). 

The input \!\(\*
StyleBox[\"parameterslist\",\nFontSlant->\"Italic\"]\) should be a list of the following form:
	{tan\[Beta],\!\(\*SubscriptBox[\(M\), \(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \(3\)]\),\[Mu],\!\(\*SubscriptBox[\(A\), \(t\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\)}.

It also accepts shorter lists and assign suitable values for the parameters that are not input:
	{tan\[Beta],m0}: assumes degenerate SUSY masses m0 and \!\(\*SubscriptBox[\(A\), \(t\)]\)=0
	{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\)}: like before but with generic \!\(\*SubscriptBox[\(A\), \(t\)]\)
	{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\),m12}: like before but with generic fermion masses \!\(\*SubscriptBox[\(M\), \(1\)]\)=\!\(\*SubscriptBox[\(M\), \(2\)]\)=\!\(\*SubscriptBox[\(M\), \(3\)]\)=\[Mu]=m12 
	{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but with generic \[Mu]
	{tan\[Beta],\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but with \!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\)\[NotEqual]\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\), the other scalar masses are m0=\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", SubscriptBox[\"U\", \"3\"]]}]],\nFontSize->10]\)
	{tan\[Beta],\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),\!\(\*SubscriptBox[\(M\), \(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \(3\)]\),\[Mu]}: like before but with generic gaugino masses.";
\[CapitalDelta]MHiggs::tachyon="The stops become tachyonic when varying the renormalization scale. A large uncertainty in the Higgs mass using the effective field theory in the \!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme is expected.";
sources::usage="\!\(\*
StyleBox[\"sources\",\nFontSlant->\"Italic\"]\) is an option for \[CapitalDelta]MHiggs. It selects which sources of theoretical uncertainties of the Higgs mass calculation are included.This option has the form sources\[Rule]{t1,t2,t3} where each component take values 0 (source excluded) or 1 (source included). Each component controls the following source of uncertainty:
t1: SM: from higher-order corrections in the SM thresholds and RGE
t2: SUSY: from missing threshold corrections at the SUSY scale
t3: EFT: from higher order correction in the effective field theory expansion.
By default all sources are included: sources\[Rule]{1,1,1}.
The total is taken as the linear sum.";
solutionSMRGEs::usage="solution of the three-loop SM renormalization group equations.";
(********)
(********)
(*MhpoleHSS::usage="MhpoleHSS[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] computes the pole mass of the Higgs in High-Scale-SUSY as a function of the supersymmetric parameters in the Overscript[DR, _] scheme.";
(*MhpoleHSS::warning="We recommend to choose the renormalization scale Overscript[m, ~] near the stop average mass (Subscript[m, Subscript[Q, 3]]Subscript[m, Subscript[U, 3]])^(1/2).";*)
MhpoleHSSfast::usage="MhpoleHSSfast[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] computes the pole mass of the Higgs in High-Scale-SUSY as a function of the supersymmetric parameters in the Overscript[DR, _] scheme. It is an optimized version of MhpoleHSS.";
(*MhpoleHSSfast::warning="We recommend to choose the renormalization scale Overscript[m, ~] near the stop average mass (Subscript[m, Subscript[Q, 3]]Subscript[m, Subscript[U, 3]])^(1/2).";*)
MhpoleSplit::usage="MhpoleSplit[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] computes the pole mass of the Higgs in Split Supersymmetry as a function of the supersymmetric parameters in the Overscript[DR, _] scheme.";
\[CapitalDelta]MhpoleHSSmom::usage="\[CapitalDelta]MhpoleHSSmom[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] estimates the uncertainty in the Higgs mass due to effects v^2/Overscript[m, ~]^2-suppressed.";
\[CapitalDelta]MhpoleHSSSM::usage="\[CapitalDelta]MhpoleHSSSM[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] estimates the uncertainty in the Higgs mass due to missing SM corrections in the the RGEs and the matching at the EW scale.";
\[CapitalDelta]MhpoleHSSQ::usage="\[CapitalDelta]MhpoleHSSQ[n,Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] calculates the shift in the Higgs mass induced by changing the renormalization scale by a factor n around the SUSY scale. It depends on the two-loop threshold corrections that are included in the calculation through the option hiOrd->{t1,t2,t3,t4}.";
\[CapitalDelta]MhpoleHSSbottom::usage="\[CapitalDelta]MhpoleHSSbottom[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] calculates the shift in the Higgs mass produced by the resummation of the tan\[Beta]-enhanced contributions.";
MhpoleHSSUnc::usage="\[CapitalDelta]MhpoleHSSUnc[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] estimates the total uncertainty in the calculation of the Higgs mass.";
\[CapitalDelta]MhpoleHSSmomfast::usage="\[CapitalDelta]MhpoleHSSmomfast[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] estimates the uncertainty in the Higgs mass due to effects v^2/Overscript[m, ~]^2-suppressed.(fast version)";
\[CapitalDelta]MhpoleHSSSMfast::usage="\[CapitalDelta]MhpoleHSSSMfast[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] estimates the uncertainty in the Higgs mass due to missing SM corrections in the the RGEs and the matching at the EW scale.(fast version)";
\[CapitalDelta]MhpoleHSSQfast::usage="\[CapitalDelta]MhpoleHSSQfast[n,Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] calculates the shift in the Higgs mass induced by changing the renormalization scale by a factor n around the SUSY scale. It depends on the two-loop threshold corrections that are included in the calculation thorugh the option hiOrd->{t1,t2,t3,t4}.(fast version)";
\[CapitalDelta]MhpoleHSSbottomfast::usage="\[CapitalDelta]MhpoleHSSbottomfast[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] calculates the shift in the Higgs mass produced by the resummation of the tan\[Beta]-enhanced contributions.(fast version)";
MhpoleHSSUncfast::usage="\[CapitalDelta]MhpoleHSSUncfast[Overscript[m, ~],Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],tan\[Beta],Subscript[X, t]] estimates the total uncertainty in the calculation of the Higgs mass.(fast version)";*)


Begin["Private`"]


(* ::Title::Closed:: *)
(*SM RGEs*)


(* ::Text:: *)
(*This sub-package solves the renormalization group equations of the Standard Model up to the three loop order. *)


(* ::Section::Closed:: *)
(*Preambula*)


(*SM\[Beta]::usage="SM\[Beta][loops,coupling] gives the SM \[Beta]-function of a coupling up to a given order specified by loops";
SMrun::usage="SMrun[variables,initialconds,tmin,tmax,opts] solves the coupled RGEs of the variables with the initial coditions given by initialconds between tmin and tmax. 
 It accepts the options of NDSolve. For time saving we recommend the optsrun";
optsSMrun::usage="Default options for the function SMrun. It selects the numerical method used by NDSolve and the precision goal";
{Subscript[g, 1],g1,Subscript[g, 2],g2,Subscript[g, 3],g3,Subscript[g, t],gt,Subscript[g, \[Tau]],g\[Tau],Subscript[g, b],gb,\[Lambda]};(*The names of the couplings are not encapsulated.*)*)


(* ::Section::Closed:: *)
(*Manipuation : rationalization of the three loop beta functions*)


(* ::Input:: *)
(*(*Here we rationalize the numbers in the three loop beta functions*)*)
(*SM\[Beta]aux[3,\[Lambda]]:=(\[Lambda]^3 (6011.35` \[Lambda]+873 Subscript[g, t]^2-387.452` Subscript[g, 2]^2-77.49` Subscript[g, 1]^2)+\[Lambda]^2 Subscript[g, t]^2 (1768.26` Subscript[g, t]^2+160.77` Subscript[g, 3]^2-359.539` Subscript[g, 2]^2-63.869` Subscript[g, 1]^2)+\[Lambda]^2 (-790.28` Subscript[g, 2]^4-185.532` Subscript[g, 1]^4-316.64` Subscript[g, 2]^2 Subscript[g, 1]^2)+\[Lambda] Subscript[g, t]^4 (-223.382` Subscript[g, t]^2-662.866` Subscript[g, 3]^2-5.47` Subscript[g, 2]^2-21.015` Subscript[g, 1]^2)+\[Lambda] +Subscript[g, t]^2 (356.968` Subscript[g, 3]^4-319.664` Subscript[g, 2]^4-74.8599` Subscript[g, 1]^4+15.1443` Subscript[g, 3]^2 Subscript[g, 2]^2+17.454` Subscript[g, 3]^2 Subscript[g, 1]^2+5.615` Subscript[g, 2]^2 Subscript[g, 1]^2)+\[Lambda] Subscript[g, 2]^4 (-57.144` Subscript[g, 3]^2+865.483` Subscript[g, 2]^2+79.638` Subscript[g, 1]^2)+\[Lambda] Subscript[g, 1]^4 (-8.381` Subscript[g, 3]^2+61.753` Subscript[g, 2]^2+28.168` Subscript[g, 1]^2)+Subscript[g, t]^6 (-243.149` Subscript[g, t]^2+250.494` Subscript[g, 3]^2+74.138` Subscript[g, 2]^2+33.93` Subscript[g, 1]^2)+Subscript[g, t]^4 (-50.201` Subscript[g, 3]^4+15.884` Subscript[g, 2]^4+15.948` Subscript[g, 1]^4+13.349` Subscript[g, 3]^2 Subscript[g, 2]^2+17.57` Subscript[g, 3]^2 Subscript[g, 1]^2-70.356` Subscript[g, 2]^2 Subscript[g, 1]^2)+Subscript[g, t]^2 Subscript[g, 3]^2 (16.464` Subscript[g, 2]^4+1.016` Subscript[g, 1]^4+11.386` Subscript[g, 2]^2 Subscript[g, 1]^2)+Subscript[g, t]^2 Subscript[g, 2]^4 (62.5` Subscript[g, 2]^2+13.041` Subscript[g, 1]^2)+Subscript[g, t]^2 Subscript[g, 1]^4 (10.627` Subscript[g, 2]^2+11.117` Subscript[g, 1]^2)+Subscript[g, 3]^2 (7.536` Subscript[g, 2]^6+0.663` Subscript[g, 1]^6+1.507` Subscript[g, 2]^4 Subscript[g, 1]^2+1.105` Subscript[g, 2]^2 Subscript[g, 1]^4)-114.091` Subscript[g, 2]^8-1.508` Subscript[g, 1]^8-37.889` Subscript[g, 2]^6 Subscript[g, 1]^2+6.5` Subscript[g, 2]^4 Subscript[g, 1]^4-1.543` Subscript[g, 2]^2 Subscript[g, 1]^6);*)
(*SM\[Beta]aux[3,Subscript[g, t]]:=Subscript[g, t]^2 (Subscript[g, t]^4 (58.6028` Subscript[g, t]^2+198 \[Lambda]-157 Subscript[g, 3]^2-1593/16 Subscript[g, 2]^2-2437/80 Subscript[g, 1]^2)+\[Lambda] Subscript[g, t]^2 ((15 \[Lambda])/4+16 Subscript[g, 3]^2-135/2 Subscript[g, 2]^2-127/10 Subscript[g, 1]^2)+Subscript[g, t]^2 (363.764` Subscript[g, 3]^4+16.99` Subscript[g, 2]^4-24.422` Subscript[g, 1]^4+48.37` Subscript[g, 3]^2 Subscript[g, 2]^2+18.074` Subscript[g, 3]^2 Subscript[g, 1]^2+34.829` Subscript[g, 2]^2 Subscript[g, 1]^2)+\[Lambda]^2 (-36 \[Lambda]+45 Subscript[g, 2]^2+9 Subscript[g, 1]^2)+\[Lambda] (-(1/16) (171 Subscript[g, 2]^4)-1089/400 Subscript[g, 1]^4+117/40 Subscript[g, 2]^2 Subscript[g, 1]^2)-619.35` Subscript[g, 3]^6+169.829` Subscript[g, 2]^6+16.099` Subscript[g, 1]^6+73.654` Subscript[g, 3]^4 Subscript[g, 2]^2-15.096` Subscript[g, 3]^4 Subscript[g, 1]^2-21.072` Subscript[g, 3]^2 Subscript[g, 2]^4-22.319` Subscript[g, 3]^2 Subscript[g, 1]^4-321/20 Subscript[g, 3]^2 Subscript[g, 2]^2 Subscript[g, 1]^2-4.743` Subscript[g, 2]^4 Subscript[g, 1]^2-4.442` Subscript[g, 2]^2 Subscript[g, 1]^4);*)
(*Rationalize[ -2472.28]*)
(*Rationalize[SM\[Beta]aux[3,\[Lambda]]]*)
(*Rationalize[SM\[Beta]aux[3,Subscript[g, t]]]*)


(* ::Section::Closed:: *)
(*Beta functions*)


With[{\[Kappa]=1/(4\[Pi])^2},
SM\[Beta][1,Subscript[g, 1]]:=\[Kappa] Subscript[g, 1]^4 (41/10);
SM\[Beta][2,Subscript[g, 1]]:=SM\[Beta][1,Subscript[g, 1]]+\[Kappa]^2 Subscript[g, 1]^4 (44/5 Subscript[g, 3]^2+27/10 Subscript[g, 2]^2+199/50 Subscript[g, 1]^2-17/10 Subscript[g, t]^2-1/2 Subscript[g, b]^2-3/2 Subscript[g, \[Tau]]^2);
SM\[Beta][3,Subscript[g, 1]]:=SM\[Beta][2,Subscript[g, 1]]+\[Kappa]^3 Subscript[g, 1]^4 (Subscript[g, t]^2 (189/16 Subscript[g, t]^2-29/5 Subscript[g, 3]^2-471/32 Subscript[g, 2]^2-2827/800 Subscript[g, 1]^2)+\[Lambda] (-(1/5) (36 \[Lambda])+9/5 Subscript[g, 2]^2+27/25 Subscript[g, 1]^2)+(297/5 Subscript[g, 3]^4)+789/64 Subscript[g, 2]^4-(388613 Subscript[g, 1]^4)/24000-3/5 Subscript[g, 3]^2 Subscript[g, 2]^2-137/75 Subscript[g, 3]^2 Subscript[g, 1]^2+123/160 Subscript[g, 2]^2 Subscript[g, 1]^2);
(*********************)
SM\[Beta][1,Subscript[g, 2]]:=\[Kappa] Subscript[g, 2]^4 (-(19/6));
SM\[Beta][2,Subscript[g, 2]]:=SM\[Beta][1,Subscript[g, 2]]+\[Kappa]^2 Subscript[g, 2]^4 (12 Subscript[g, 3]^2+35/6 Subscript[g, 2]^2+9/10 Subscript[g, 1]^2-3/2 Subscript[g, t]^2-3/2 Subscript[g, b]^2-1/2 Subscript[g, \[Tau]]^2);
SM\[Beta][3,Subscript[g, 2]]:=SM\[Beta][2,Subscript[g, 2]]+\[Kappa]^3 Subscript[g, 2]^4 (Subscript[g, t]^2 (147/16 Subscript[g, t]^2-7 Subscript[g, 3]^2-729/32 Subscript[g, 2]^2-593/160 Subscript[g, 1]^2)+\[Lambda] (-3 \[Lambda]+3/2 Subscript[g, 2]^2+3/10 Subscript[g, 1]^2)+81 Subscript[g, 3]^4+(324953 Subscript[g, 2]^4)/1728-(5597 Subscript[g, 1]^4)/1600+39 Subscript[g, 3]^2 Subscript[g, 2]^2-1/5 Subscript[g, 3]^2 Subscript[g, 1]^2+873/160 Subscript[g, 2]^2 Subscript[g, 1]^2);
(**********************)
SM\[Beta][1,Subscript[g, 3]]:=\[Kappa] Subscript[g, 3]^4 (-7);
SM\[Beta][2,Subscript[g, 3]]:=SM\[Beta][1,Subscript[g, 3]]+\[Kappa]^2 Subscript[g, 3]^4 (-26 Subscript[g, 3]^2+9/2 Subscript[g, 2]^2+11/10 Subscript[g, 1]^2-2 Subscript[g, t]^2-2 Subscript[g, b]^2);
SM\[Beta][3,Subscript[g, 3]]:=SM\[Beta][2,Subscript[g, 3]]+\[Kappa]^3 Subscript[g, 3]^4 (Subscript[g, t]^2 (15 Subscript[g, t]^2-40 Subscript[g, 3]^2-93/8 Subscript[g, 2]^2-101/40 Subscript[g, 1]^2)+65/2 Subscript[g, 3]^4+109/8 Subscript[g, 2]^4-523/120 Subscript[g, 1]^4+21 Subscript[g, 3]^2 Subscript[g, 2]^2+77/15 Subscript[g, 3]^2 Subscript[g, 1]^2-3/40 Subscript[g, 2]^2 Subscript[g, 1]^2)+0 1/(4 \[Pi])^8 Subscript[g, 3]^10 (-(61807/25));
(**We multiplied by 2\[Lambda] to have all the RGEs in the form ((dg^2)/(d Log[\[Mu]^2]))=Subscript[\[Beta], g]**)
SM\[Beta][1,\[Lambda]]:=(\[Kappa] 2\[Lambda])(\[Lambda] (12 \[Lambda]+6 Subscript[g, t]^2+6 Subscript[g, b]^2+2 Subscript[g, \[Tau]]^2-9/2 Subscript[g, 2]^2-9/10 Subscript[g, 1]^2)-3 Subscript[g, t]^4-3 Subscript[g, b]^4-Subscript[g, \[Tau]]^4+9/16 Subscript[g, 2]^4+27/400 Subscript[g, 1]^4+9/40 Subscript[g, 2]^2 Subscript[g, 1]^2);
SM\[Beta][2,\[Lambda]]:=SM\[Beta][1,\[Lambda]]+(\[Kappa]^2 2\[Lambda])(\[Lambda]^2 (-156 \[Lambda]-72 Subscript[g, t]^2-72 Subscript[g, b]^2-24 Subscript[g, \[Tau]]^2+54 Subscript[g, 2]^2+54/5 Subscript[g, 1]^2)+\[Lambda] Subscript[g, t]^2 (-(1/2) (3 Subscript[g, t]^2)-21 Subscript[g, b]^2+40 Subscript[g, 3]^2+45/4 Subscript[g, 2]^2+17/4 Subscript[g, 1]^2)+\[Lambda] Subscript[g, b]^2 (-(1/2) (3 Subscript[g, b]^2)+40 Subscript[g, 3]^2+45/4 Subscript[g, 2]^2+5/4 Subscript[g, 1]^2)+\[Lambda] Subscript[g, \[Tau]]^2 (-(1/2) Subscript[g, \[Tau]]^2+15/4 Subscript[g, 2]^2+15/4 Subscript[g, 1]^2)+\[Lambda] (-(1/16) (73 Subscript[g, 2]^4)+1887/400 Subscript[g, 1]^4+117/40 Subscript[g, 2]^2 Subscript[g, 1]^2)+Subscript[g, t]^4 (15 Subscript[g, t]^2-3 Subscript[g, b]^2-16 Subscript[g, 3]^2-4/5 Subscript[g, 1]^2)+Subscript[g, t]^2 (-(1/8) (9 Subscript[g, 2]^4)-171/200 Subscript[g, 1]^4+63/20 Subscript[g, 2]^2 Subscript[g, 1]^2)+Subscript[g, b]^4 (-3 Subscript[g, t]^2+15 Subscript[g, b]^2-16 Subscript[g, 3]^2+2/5 Subscript[g, 1]^2)+Subscript[g, b]^2 (-(1/8) (9 Subscript[g, 2]^4)+9/40 Subscript[g, 1]^4+27/20 Subscript[g, 2]^2 Subscript[g, 1]^2)+Subscript[g, \[Tau]]^4 (5 Subscript[g, \[Tau]]^2-6/5 Subscript[g, 1]^2)+Subscript[g, \[Tau]]^2 (-(1/8) (3 Subscript[g, 2]^4)-9/8 Subscript[g, 1]^4+33/20 Subscript[g, 2]^2 Subscript[g, 1]^2)+305/32 Subscript[g, 2]^6-(3411 Subscript[g, 1]^6)/4000-289/160 Subscript[g, 2]^4 Subscript[g, 1]^2-1677/800 Subscript[g, 2]^2 Subscript[g, 1]^4);
SM\[Beta][3,\[Lambda]]:=SM\[Beta][2,\[Lambda]]+(\[Kappa]^3 2\[Lambda])(\[Lambda]-(377 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(8\)]\))/250-(1543 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(6\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/1000+13/2 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\)-(37889 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(6\)]\))/1000-(114091 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(8\)]\))/1000+\[Lambda]^2 (-((46383 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\))/250)-7916/25 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)-(19757 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/25)+((663 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(6\)]\))/1000+221/200 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+(1507 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/1000+(942 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(6\)]\))/125) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)+\[Lambda] 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\) ((39819 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/500+(865483 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/1000-(7143 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\))/125)+\[Lambda] 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) ((3521 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/125+(61753 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/1000-(8381 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\))/1000)+\!\(
\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\ \((
\*FractionBox[\(11117\ 
\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\), \(1000\)] + 
\*FractionBox[\(10627\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\), \(1000\)])\)\ 
\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\)+\!\(
\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\ \((
\*FractionBox[\(13041\ 
\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\), \(1000\)] + 
\*FractionBox[\(125\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\), \(2\)])\)\ 
\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\)+((127 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\))/125+5693/500 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+(2058 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/125) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\)+(-((748599 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\))/10000)+1123/200 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)-(39958 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/125+8727/500 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)+(151443 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\))/10000+(44621 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(4\)]\))/125) 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\)+((3987 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\))/250-17589/250 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+(3971 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/250+1757/100 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)+(13349 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\))/1000-(50201 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(4\)]\))/1000) 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\)+\!\(
\*SubsuperscriptBox[\(g\), \(t\), \(6\)]\ \((
\*FractionBox[\(3393\ 
\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\), \(100\)] + 
\*FractionBox[\(37069\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\), \(500\)] + 
\*FractionBox[\(125247\ 
\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\), \(500\)] - 
\*FractionBox[\(243149\ 
\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\), \(1000\)])\)\)+\[Lambda] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\) (-((4203 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/200)-(547 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/100-(331433 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\))/500-(111691 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))/500)+\[Lambda]^3 ((120227 \[Lambda])/20-(7749 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/100-(96863 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/250+873 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))+\[Lambda]^2 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (-((63869 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/1000)-(359539 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/1000+(16077 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\))/100+(88413 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))/50));
(***************)
SM\[Beta][1,Subscript[g, t]]:=\[Kappa] Subscript[g, t]^2 (9/2 Subscript[g, t]^2+3/2 Subscript[g, b]^2+Subscript[g, \[Tau]]^2-8 Subscript[g, 3]^2-9/4 Subscript[g, 2]^2-17/20 Subscript[g, 1]^2);
SM\[Beta][2,Subscript[g, t]]:=SM\[Beta][1,Subscript[g, t]]+\[Kappa]^2 Subscript[g, t]^2 (Subscript[g, t]^2 (-12 Subscript[g, t]^2-11/4 Subscript[g, b]^2-9/4 Subscript[g, \[Tau]]^2-12 \[Lambda]+36 Subscript[g, 3]^2+225/16 Subscript[g, 2]^2+393/80 Subscript[g, 1]^2)+Subscript[g, b]^2 (-(1/4) Subscript[g, b]^2+5/4 Subscript[g, \[Tau]]^2+4 Subscript[g, 3]^2+99/16 Subscript[g, 2]^2+7/80 Subscript[g, 1]^2)+Subscript[g, \[Tau]]^2 (-(1/4) (9 Subscript[g, \[Tau]]^2)+15/8 Subscript[g, 2]^2+15/8 Subscript[g, 1]^2)+6 \[Lambda]^2-108 Subscript[g, 3]^4-23/4 Subscript[g, 2]^4+1187/600 Subscript[g, 1]^4+9 Subscript[g, 3]^2 Subscript[g, 2]^2+19/15 Subscript[g, 3]^2 Subscript[g, 1]^2-9/20 Subscript[g, 2]^2 Subscript[g, 1]^2);
SM\[Beta][3,Subscript[g, t]]:=SM\[Beta][2,Subscript[g, t]]+\[Kappa]^3 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) ((16099 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(6\)]\))/1000-2221/500 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)-(4743 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/1000+(169829 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(6\)]\))/1000+\[Lambda]^2 (-36 \[Lambda]+9 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+45 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))+\[Lambda] (-((1089 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\))/400)+117/40 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)-(171 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/16)-(22319 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\))/1000-321/20 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)-2634/125 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)-1887/125 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(4\)]\)+36827/500 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(4\)]\)-(12387 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(6\)]\))/20+\[Lambda] ((15 \[Lambda])/4-(127 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/10-(135 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/2+16 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)) 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\)+(-((12211 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\))/500)+(34829 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))/1000+(1699 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))/100+9037/500 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)+4837/100 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)+(90941 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(4\)]\))/250) 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\)+\!\(
\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\ \((198\ \[Lambda] - 
\*FractionBox[\(2437\ 
\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\), \(80\)] - 
\*FractionBox[\(1593\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\), \(16\)] - 157\ 
\*SubsuperscriptBox[\(g\), \(3\), \(2\)] + 
\*FractionBox[\(146507\ 
\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\), \(2500\)])\)\));
(*************************)
SM\[Beta][1,Subscript[g, b]]:=\[Kappa] Subscript[g, b]^2 (3/2 Subscript[g, t]^2+9/2 Subscript[g, b]^2+Subscript[g, \[Tau]]^2-8 Subscript[g, 3]^2-9/4 Subscript[g, 2]^2-1/4 Subscript[g, 1]^2);
SM\[Beta][2,Subscript[g, b]]:=SM\[Beta][1,Subscript[g, b]]+\[Kappa]^2 Subscript[g, b]^2 (Subscript[g, t]^2 (-(1/4) Subscript[g, t]^2-11/4 Subscript[g, b]^2+5/4 Subscript[g, \[Tau]]^2+4 Subscript[g, 3]^2+99/16 Subscript[g, 2]^2+91/80 Subscript[g, 1]^2)+Subscript[g, b]^2 (-12 Subscript[g, b]^2-9/4 Subscript[g, \[Tau]]^2-12 \[Lambda]+36 Subscript[g, 3]^2+225/16 Subscript[g, 2]^2+237/80 Subscript[g, 1]^2)+Subscript[g, \[Tau]]^2 (-(1/4) (9 Subscript[g, \[Tau]]^2)+15/8 Subscript[g, 2]^2+15/8 Subscript[g, 1]^2)+6 \[Lambda]^2-108 Subscript[g, 3]^4-23/4 Subscript[g, 2]^4-127/600 Subscript[g, 1]^4+9 Subscript[g, 3]^2 Subscript[g, 2]^2+31/15 Subscript[g, 3]^2 Subscript[g, 1]^2-27/20 Subscript[g, 2]^2 Subscript[g, 1]^2);
SM\[Beta][3,Subscript[g, b]]:=SM\[Beta][2,Subscript[g, b]];(*defined for convenience*)
(******************)
SM\[Beta][1,Subscript[g, \[Tau]]]:=\[Kappa] Subscript[g, \[Tau]]^2 (3 Subscript[g, t]^2+3 Subscript[g, b]^2+5/2 Subscript[g, \[Tau]]^2-9/4 Subscript[g, 2]^2-9/4 Subscript[g, 1]^2);
SM\[Beta][2,Subscript[g, \[Tau]]]:=SM\[Beta][1,Subscript[g, \[Tau]]]+\[Kappa]^2 Subscript[g, \[Tau]]^2 (6 \[Lambda]^2-23/4 Subscript[g, 2]^4+1371/200 Subscript[g, 1]^4+27/20 Subscript[g, 2]^2 Subscript[g, 1]^2+Subscript[g, t]^2 (-(1/4) (27 Subscript[g, t]^2)+3/2 Subscript[g, b]^2-27/4 Subscript[g, \[Tau]]^2+20 Subscript[g, 3]^2+45/8 Subscript[g, 2]^2+17/8 Subscript[g, 1]^2)+Subscript[g, b]^2 (-(1/4) (27 Subscript[g, b]^2)-27/4 Subscript[g, \[Tau]]^2+20 Subscript[g, 3]^2+45/8 Subscript[g, 2]^2+5/8 Subscript[g, 1]^2)+Subscript[g, \[Tau]]^2 (-3 Subscript[g, \[Tau]]^2-12 \[Lambda]+165/16 Subscript[g, 2]^2+537/80 Subscript[g, 1]^2));
SM\[Beta][3,Subscript[g, \[Tau]]]:=SM\[Beta][2,Subscript[g, \[Tau]]] (*defined for convenience*)
]


(* ::Section::Closed:: *)
(*Running*)


SMrun[variables_,init_,tmin_,tmax_,opts:OptionsPattern[]]:=Block[{equations,vars,reps},
reps={Subscript[g, 1]->g1,Subscript[g, 2]->g2,Subscript[g, 3]->g3,Subscript[g, t]->gt,Subscript[g, \[Tau]]->g\[Tau],Subscript[g, b]->gb};
equations=Join[#[t]#'[t]==(SM\[Beta][3,#] /.(#->#[t]&/@variables))&/@variables,init]/.reps;
vars=variables/.reps;
First[NDSolve[equations,vars,{t,tmin,tmax},FilterRules[{opts},Options[NDSolve]]]] ]
optsSMrun={AccuracyGoal->5,PrecisionGoal->5,MaxSteps->350,If[$VersionNumber>=10,Method->{"Shooting","StartingInitialConditions"->{\[Lambda][35]==0.15}},Method->Automatic]};


(* ::Title::Closed:: *)
(*Split RGEs*)


(* ::Text:: *)
(*This sub-package solves the renormalization group equations of Split Supersymmetry. *)


(* ::Section::Closed:: *)
(*Preambula*)


(*Split\[Beta]::usage="Split\[Beta][loops,coupling] gives the Split \[Beta]-function of a coupling up to a given order specified by loops";
Splitrun::usage="run[variables,initialconds,tmin,tmax,opts] solves the coupled RGEs of the variables with the initial coditions given by initialconds between tmin and tmax. 
 It accepts the options of NDSolve. For time saving we recommend the optsrun";
optsSplitrun::usage="Default options for the function run. It selects the numerical method used by NDSolve and the precision goal";
{(*\[Lambda],Subscript[g, 3],Subscript[g, 2],Subscript[g, 1],Subscript[g, t],Subscript[g, \[Tau]],Subscript[g, b],g3,g2,g1,gt,g\[Tau],gb,*)Subscript[Overscript[g, ~], 1 u],Subscript[Overscript[g, ~], 2 u],Subscript[Overscript[g, ~], 1 d],Subscript[Overscript[g, ~], 2 d],gtildeu,gtilde2u,gtilded,gtilde2d};
(*The names of the couplings are not encapsulated.*)*)


(* ::Section::Closed:: *)
(*Beta Functions*)


Split\[Beta][1,coupling_]:=1/(4\[Pi])^2 Subscript[\[Beta], 1][coupling]
Split\[Beta][2,coupling_]:=1/(4\[Pi])^2 Subscript[\[Beta], 1][coupling]+1/(4\[Pi])^4 Subscript[\[Beta], 2][coupling]


(* ::Subsubsection::Closed:: *)
(*eqs. (26) : \[Beta] tilde*)


Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), t]:=1/2 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2); Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), \[Lambda]]:=2 \[Lambda](Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-2 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2) (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2);


(* ::Subsubsection::Closed:: *)
(*eq.  (35)-(36) : Subscript[\[Beta], 1] *)


Subscript[\[Beta], 1][Subscript[g, 1]]:=9/2 Subscript[g, 1]^3;Subscript[\[Beta], 1][Subscript[g, 2]]:=-(7/6) Subscript[g, 2]^3 ;Subscript[\[Beta], 1][Subscript[g, 3]]:=-5 Subscript[g, 3]^3;
Subscript[\[Beta], 1][Subscript[g, t]]:=Subscript[g, t] (Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), t]+3/2 Subscript[g, b]^2+Subscript[g, \[Tau]]^2+9/2 Subscript[g, t]^2-17/20 Subscript[g, 1]^2-9/4 Subscript[g, 2]^2-8 Subscript[g, 3]^2);Subscript[\[Beta], 1][Subscript[g, b]]:=Subscript[g, b] (Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), t]+3/2 Subscript[g, t]^2+Subscript[g, \[Tau]]^2+9/2 Subscript[g, b]^2-1/4 Subscript[g, 1]^2-9/4 Subscript[g, 2]^2-8 Subscript[g, 3]^2);Subscript[\[Beta], 1][Subscript[g, \[Tau]]]:=Subscript[g, \[Tau]] (Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), t]+3 Subscript[g, b]^2+3 Subscript[g, t]^2+5/2 Subscript[g, \[Tau]]^2-9/4 Subscript[g, 1]^2-9/4 Subscript[g, 2]^2);Subscript[\[Beta], 1][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]]:=Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u] (3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+1/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+11/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[g, b]^2+3 Subscript[g, t]^2+Subscript[g, \[Tau]]^2-9/20 Subscript[g, 1]^2-33/4 Subscript[g, 2]^2);Subscript[\[Beta], 1][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]]:=Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] (3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+1/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+11/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+3 Subscript[g, b]^2+3 Subscript[g, t]^2+Subscript[g, \[Tau]]^2-9/20 Subscript[g, 1]^2-33/4 Subscript[g, 2]^2);Subscript[\[Beta], 1][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]]:=3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] (2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+5/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+3 Subscript[g, b]^2+3 Subscript[g, t]^2+Subscript[g, \[Tau]]^2-9/20 Subscript[g, 1]^2-9/4 Subscript[g, 2]^2);Subscript[\[Beta], 1][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]]:=3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] (2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+5/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+3/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[g, b]^2+3 Subscript[g, t]^2+Subscript[g, \[Tau]]^2-9/20 Subscript[g, 1]^2-9/4 Subscript[g, 2]^2);Subscript[\[Beta], 1][\[Lambda]]:=4 \[Lambda] (3 Subscript[g, t]^2+3 Subscript[g, b]^2+Subscript[g, \[Tau]]^2)-9 \[Lambda] (1/5 Subscript[g, 1]^2+Subscript[g, 2]^2)-4 (3 Subscript[g, t]^4+3 Subscript[g, b]^4+Subscript[g, \[Tau]]^4)+27/100 Subscript[g, 1]^4+9/10 Subscript[g, 2]^2 Subscript[g, 1]^2+9/4 Subscript[g, 2]^4+12 \[Lambda]^2+Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), \[Lambda]];


(* ::Subsubsection::Closed:: *)
(*eq. (37) - (39) : Subscript[\[Beta], 2] of the gauge couplings*)


Subscript[\[Beta], 2][Subscript[g, 1]]:=Subscript[g, 1]^3 (1/20 (-3) (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)-9/20 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-1/2 Subscript[g, b]^2-17/10 Subscript[g, t]^2-3/2 Subscript[g, \[Tau]]^2+104/25 Subscript[g, 1]^2+18/5 Subscript[g, 2]^2+44/5 Subscript[g, 3]^2);
Subscript[\[Beta], 2][Subscript[g, 2]]:=Subscript[g, 2]^3 (-(1/4) (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)-11/4 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-1/2 (3 Subscript[g, b]^2+3 Subscript[g, t]^2+Subscript[g, \[Tau]]^2)+6/5 Subscript[g, 1]^2+106/3 Subscript[g, 2]^2+12 Subscript[g, 3]^2);
Subscript[\[Beta], 2][Subscript[g, 3]]:=Subscript[g, 3]^3 (-2 (Subscript[g, b]^2+Subscript[g, t]^2)+11/10 Subscript[g, 1]^2+9/2 Subscript[g, 2]^2+22 Subscript[g, 3]^2)


(* ::Subsubsection::Closed:: *)
(*eqs. (40) - (47): Subscript[\[Beta], 2] of the rest of the couplings*)


Subscript[\[Beta], 2][Subscript[g, t]]:=-12 Subscript[g, t]^5+Subscript[g, t] (Subscript[g, b]^2 (5/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+5/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+15/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+15/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+5/4 Subscript[g, \[Tau]]^2+7/80 Subscript[g, 1]^2+99/16 Subscript[g, 2]^2+4 Subscript[g, 3]^2)+Subscript[g, 1]^2 (3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-9/20 Subscript[g, 2]^2+19/15 Subscript[g, 3]^2)-3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[g, 2]^2 (15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+9 Subscript[g, 3]^2)-5/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-1/4 Subscript[g, b]^4-9/4 Subscript[g, \[Tau]]^4+(15/8 Subscript[g, 1]^2+15/8 Subscript[g, 2]^2) Subscript[g, \[Tau]]^2+1303/600 Subscript[g, 1]^4-17/4 Subscript[g, 2]^4-284/3 Subscript[g, 3]^4+(3 \[Lambda]^2)/2)+Subscript[g, t]^3 (-(1/8) (9 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-11/4 Subscript[g, b]^2-9/4 Subscript[g, \[Tau]]^2+393/80 Subscript[g, 1]^2+225/16 Subscript[g, 2]^2+36 Subscript[g, 3]^2-6 \[Lambda]) ;
Subscript[\[Beta], 2][Subscript[g, b]]:=-12 Subscript[g, b]^5+Subscript[g, b] (Subscript[g, t]^2 (5/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+5/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+15/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+15/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+5/4 Subscript[g, \[Tau]]^2+91/80 Subscript[g, 1]^2+99/16 Subscript[g, 2]^2+4 Subscript[g, 3]^2)+Subscript[g, 1]^2 (3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-27/20 Subscript[g, 2]^2+31/15 Subscript[g, 3]^2)-3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[g, 2]^2 (15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+9 Subscript[g, 3]^2)-5/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-1/4 Subscript[g, t]^4-9/4 Subscript[g, \[Tau]]^4+(15/8 Subscript[g, 1]^2+15/8 Subscript[g, 2]^2) Subscript[g, \[Tau]]^2-131/600 Subscript[g, 1]^4-17/4 Subscript[g, 2]^4-284/3 Subscript[g, 3]^4+(3 \[Lambda]^2)/2)+Subscript[g, b]^3 (-(1/8) (9 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-11/4 Subscript[g, t]^2-9/4 Subscript[g, \[Tau]]^2+237/80 Subscript[g, 1]^2+225/16 Subscript[g, 2]^2+36 Subscript[g, 3]^2-6 \[Lambda]) ;
Subscript[\[Beta], 2][Subscript[g, \[Tau]]]:=-3 Subscript[g, \[Tau]]^5+Subscript[g, \[Tau]] (Subscript[g, 1]^2 (3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+27/20 Subscript[g, 2]^2)-3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[g, 2]^2 (15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-5/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4+(3/2 Subscript[g, b]^2+17/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2) Subscript[g, t]^2-27/4 Subscript[g, b]^4+(5/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2) Subscript[g, b]^2-27/4 Subscript[g, t]^4+1503/200 Subscript[g, 1]^4-17/4 Subscript[g, 2]^4+(3 \[Lambda]^2)/2)+Subscript[g, \[Tau]]^3 (-(1/8) (9 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-27/4 Subscript[g, b]^2-27/4 Subscript[g, t]^2+537/80 Subscript[g, 1]^2+165/16 Subscript[g, 2]^2-6 \[Lambda]) ;
Subscript[\[Beta], 2][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]]:=Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u] (Subscript[g, 1]^2 (3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+63/160 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3/20 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+9/20 Subscript[g, 2]^2)+Subscript[g, 2]^2 (15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+111/32 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+17/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2)-3/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-13/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4+Subscript[g, t]^2 (-(1/8) (9 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)+3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3/2 Subscript[g, b]^2+17/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)+Subscript[g, b]^2 (-(1/8) (9 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)+3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+5/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)-\[Lambda] (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2)+Subscript[g, \[Tau]]^2 (-(1/8) (3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)+1/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+15/8 Subscript[g, 1]^2+15/8 Subscript[g, 2]^2)-31/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-5/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-11/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-27/4 Subscript[g, b]^4-27/4 Subscript[g, t]^4-9/4 Subscript[g, \[Tau]]^4+117/200 Subscript[g, 1]^4-409/12 Subscript[g, 2]^4+(3 \[Lambda]^2)/2)+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^3 (-(1/16) (15 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-59/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-45/8 Subscript[g, b]^2-45/8 Subscript[g, t]^2-15/8 Subscript[g, \[Tau]]^2+87/32 Subscript[g, 1]^2+875/32 Subscript[g, 2]^2-5 \[Lambda])-4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-3 Subscript[g, b]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]-\[Lambda] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]-3 Subscript[g, t]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]-Subscript[g, \[Tau]]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]-9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^3-3/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]-5/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]+3/20 Subscript[g, 1]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]+9/4 Subscript[g, 2]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]-1/2 (7 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^5) ;
Subscript[\[Beta], 2][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]]:=Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] (Subscript[g, 1]^2 (63/160 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+3/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3/20 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+9/20 Subscript[g, 2]^2)+Subscript[g, 2]^2 (111/32 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+17/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-3/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+Subscript[g, t]^2 (-(1/8) (9 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)+3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+3/2 Subscript[g, b]^2+17/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)+Subscript[g, b]^2 (-(1/8) (9 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)+3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+5/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)-\[Lambda] (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)+Subscript[g, \[Tau]]^2 (-(1/8) (3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)+1/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+15/8 Subscript[g, 1]^2+15/8 Subscript[g, 2]^2)-31/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-5/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-13/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-11/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-27/4 Subscript[g, b]^4-27/4 Subscript[g, t]^4-9/4 Subscript[g, \[Tau]]^4+117/200 Subscript[g, 1]^4-409/12 Subscript[g, 2]^4+(3 \[Lambda]^2)/2)+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^3 (-(1/16) (59 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-15/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-45/8 Subscript[g, b]^2-45/8 Subscript[g, t]^2-15/8 Subscript[g, \[Tau]]^2+87/32 Subscript[g, 1]^2+875/32 Subscript[g, 2]^2-5 \[Lambda])-4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3 Subscript[g, b]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-\[Lambda] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3 Subscript[g, t]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-Subscript[g, \[Tau]]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^3-5/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+3/20 Subscript[g, 1]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+9/4 Subscript[g, 2]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-1/2 (7 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^5) ;
Subscript[\[Beta], 2][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]]:=Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] (Subscript[g, 1]^2 (3/40 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+189/160 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-27/20 Subscript[g, 2]^2)+Subscript[g, 2]^2 (39/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+549/32 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-75/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+Subscript[g, t]^2 (-(1/4) (21 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+3/2 Subscript[g, b]^2+17/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)+Subscript[g, b]^2 (-(1/4) (21 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+5/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)-3 \[Lambda] (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)+Subscript[g, \[Tau]]^2 (-(1/4) (7 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+15/8 Subscript[g, 1]^2+15/8 Subscript[g, 2]^2)-75/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-21/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-99/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-27/4 Subscript[g, b]^4-27/4 Subscript[g, t]^4-9/4 Subscript[g, \[Tau]]^4+117/200 Subscript[g, 1]^4-17/4 Subscript[g, 2]^4+(3 \[Lambda]^2)/2)+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^3 (-(1/4) (15 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2)-27/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-27/8 Subscript[g, b]^2-27/8 Subscript[g, t]^2-9/8 Subscript[g, \[Tau]]^2+309/160 Subscript[g, 1]^2+165/32 Subscript[g, 2]^2-3 \[Lambda])-6 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-9 Subscript[g, b]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3 \[Lambda] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-9 Subscript[g, t]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3 Subscript[g, \[Tau]]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-9/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^3-33/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+9/20 Subscript[g, 1]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+51/4 Subscript[g, 2]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-1/4 (3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^5) ;
Subscript[\[Beta], 2][Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]]:=Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] (Subscript[g, 1]^2 (3/40 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+189/160 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-27/20 Subscript[g, 2]^2)+Subscript[g, 2]^2 (39/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+549/32 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+165/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)+Subscript[g, t]^2 (-(1/4) (21 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3/2 Subscript[g, b]^2+17/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)+Subscript[g, b]^2 (-(1/4) (21 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)-27/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+5/8 Subscript[g, 1]^2+45/8 Subscript[g, 2]^2+20 Subscript[g, 3]^2)-3 \[Lambda] (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2)+Subscript[g, \[Tau]]^2 (-(1/4) (7 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)-9/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+15/8 Subscript[g, 1]^2+15/8 Subscript[g, 2]^2)-75/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-75/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-21/8 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-99/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-45/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-27/4 Subscript[g, b]^4-27/4 Subscript[g, t]^4-9/4 Subscript[g, \[Tau]]^4+117/200 Subscript[g, 1]^4-17/4 Subscript[g, 2]^4+(3 \[Lambda]^2)/2)+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^3 (-(1/4) (15 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)-9/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-27/16 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-27/8 Subscript[g, b]^2-27/8 Subscript[g, t]^2-9/8 Subscript[g, \[Tau]]^2+309/160 Subscript[g, 1]^2+165/32 Subscript[g, 2]^2-3 \[Lambda])-6 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^5-9 Subscript[g, b]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3 \[Lambda] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-9 Subscript[g, t]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-3 Subscript[g, \[Tau]]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-33/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^3-9/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-9/4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+9/20 Subscript[g, 1]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+51/4 Subscript[g, 2]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u] ;
Subscript[\[Beta], 2][\[Lambda]]:=-78 \[Lambda]^3-(3699 Subscript[g, 1]^6)/1000+(9/10 Subscript[g, b]^2-171/50 Subscript[g, t]^2-9/2 Subscript[g, \[Tau]]^2-9/100 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)) Subscript[g, 1]^4+(8/5 Subscript[g, b]^4-16/5 Subscript[g, t]^4-24/5 Subscript[g, \[Tau]]^4) Subscript[g, 1]^2+209/8 Subscript[g, 2]^6+20 (3 Subscript[g, b]^6+3 Subscript[g, t]^6+Subscript[g, \[Tau]]^6)-64 Subscript[g, 3]^2 Subscript[g, b]^4-(64 Subscript[g, 3]^2+12 Subscript[g, b]^2) Subscript[g, t]^4-12 Subscript[g, b]^4 Subscript[g, t]^2+\[Lambda]^2 (54/5 Subscript[g, 1]^2+54 Subscript[g, 2]^2-72 Subscript[g, b]^2-72 Subscript[g, t]^2-24 Subscript[g, \[Tau]]^2-12 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2))+Subscript[g, 2]^4 (-(1/8) (77 Subscript[g, 1]^2)-9/2 Subscript[g, b]^2-9/2 Subscript[g, t]^2-3/2 Subscript[g, \[Tau]]^2-3/4 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+51 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+51 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2))+Subscript[g, 2]^2 (-(1/200) (1773 Subscript[g, 1]^4)+(27/5 Subscript[g, b]^2+63/5 Subscript[g, t]^2+33/5 Subscript[g, \[Tau]]^2-3/10 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2-21 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-21 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)) Subscript[g, 1]^2-4 (5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]+5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2))+\[Lambda] (2007/200 Subscript[g, 1]^4+(5/2 Subscript[g, b]^2+17/2 Subscript[g, t]^2+15/2 Subscript[g, \[Tau]]^2+3/4 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)) Subscript[g, 1]^2+47/8 Subscript[g, 2]^4-3 Subscript[g, b]^4-3 Subscript[g, t]^4-Subscript[g, \[Tau]]^4+80 Subscript[g, 3]^2 Subscript[g, b]^2+(80 Subscript[g, 3]^2-42 Subscript[g, b]^2) Subscript[g, t]^2+1/4 (-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-2 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2-6 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2) Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+80 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2-44 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)+Subscript[g, 2]^2 (117/20 Subscript[g, 1]^2+45/2 Subscript[g, b]^2+45/2 Subscript[g, t]^2+15/2 Subscript[g, \[Tau]]^2+15/4 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+11 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+11 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)))+1/2 (47 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^6+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^6)+5 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^6+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^6)+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u](42 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+42 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+38 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+38 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2)+19 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)+21 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u](Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2)+17 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2)+11 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4)+7 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2));


(* ::Input:: *)
(*(************************************************************************)*)


(* ::Section:: *)
(*Running*)


Splitrun[variables_,init_,tmin_,tmax_,opts:OptionsPattern[]]:=Block[{equations,vars,reps},
reps={Subscript[g, 1]->g1,Subscript[g, 2]->g2,Subscript[g, 3]->g3,Subscript[g, t]->gt,Subscript[g, \[Tau]]->g\[Tau],Subscript[g, b]->gb,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]->gtildeu,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]->gtilde2u,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]->gtilded,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]->gtilde2d};
equations=Join[#'[t]==(Split\[Beta][2,#] /.(#->#[t]&/@variables))&/@variables,init]/.reps;
vars=variables/.reps;
First[NDSolve[equations,vars,{t,tmin,tmax},FilterRules[{opts},Options[NDSolve]]]] 
]
optsSplitrun={AccuracyGoal->5,PrecisionGoal->5,MaxSteps->200};


(* ::Title:: *)
(*SUSY Thresholds*)


(* ::Text:: *)
(*This sub-package contains the threshold corrections to the quartic coupling of the Higgs in High Scale Supersymmetry and Split Supersymmetry. *)


(* ::Section::Closed:: *)
(*Preambula*)


(*\[Lambda]HSS::usage="\[Lambda]HSS[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],\[Beta],Subscript[X, t]] computes the thresholds to the quartic coupling at scale of the scalar masses in High Scale Supersymmetry.";
hiOrd::usage="controls the inclusion of higher-order corrections";
scheme::usage="chooses the renormalization scheme";
suppressedCorrections::usage="v^2/Overscript[m, ~]^2-suppressed corrections";
\[Lambda]Splitscalars::usage="\[Lambda]Splitscalars[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],\[Beta],Subscript[X, t]] computes the thresholds to the quartic coupling at the mass of the scalars in Split Supersymmetry.";
\[Lambda]SMsplit::usage="\[Lambda]SMsplit[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],\[Beta],Subscript[X, t]] computes the quartic coupling of the Standard Model at the scale of the fermions obtained after integrating out all the supersymmetric particles.";
gtSplitsplit::usage="gtSplitsplit[\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3]] computes the top Yukawa coupling just above the scale of the fermion masses in Split Supersymmetry.";
g1umtilde::usage="g1umtilde[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],\[Beta],Subscript[X, t]] computes the Higgs-higgsino-gaugino coupling at the mass of the scalar masses including the one-loop thresholds corrections.";
g2umtilde::usage="g2umtilde[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],\[Beta],Subscript[X, t]] computes the Higgs-higgsino-gaugino coupling at the mass of the scalar masses including the one-loop thresholds corrections.";g1dmtilde::usage="g1dmtilde[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],\[Beta],Subscript[X, t]] computes the Higgs-higgsino-gaugino coupling at the mass of the scalar masses including the one-loop thresholds corrections.";g2dmtilde::usage="g2dmtilde[Subscript[m, Subscript[Q, 1]],Subscript[m, Subscript[Q, 2]],Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 1]],Subscript[m, Subscript[U, 2]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 1]],Subscript[m, Subscript[D, 2]],Subscript[m, Subscript[D, 3]],Subscript[m, Subscript[E, 1]],Subscript[m, Subscript[E, 2]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[L, 1]],Subscript[m, Subscript[L, 2]],Subscript[m, Subscript[L, 3]],Subscript[m, A],\[Mu],Subscript[M, 1],Subscript[M, 2],Subscript[M, 3],\[Beta],Subscript[X, t]] computes the Higgs-higgsino-gaugino coupling at the mass of the scalar masses including the one-loop thresholds corrections.";
gbDR::usage="gbDR[Subscript[m, Subscript[Q, 3]],Subscript[m, Subscript[U, 3]],Subscript[m, Subscript[D, 3]],Subscript[M, 3],\[Mu],tan\[Beta],Subscript[X, t]] computes the Overscript[DR, _] bottom Yukawa.";
gtauDR::usage="gtauDR[Subscript[m, Subscript[L, 3]],Subscript[m, Subscript[E, 3]],Subscript[m, Subscript[N, 3]],Subscript[M, 2],Subscript[M, 1],\[Mu],tan\[Beta]] computes the Overscript[DR, _] bottom Yukawa.";
\[Lambda]HSS1lsuppressed::usage="It is used to estimate the v^2/Subscript[m, SUSY]^2-suppressed corrections."*)


(* ::Section:: *)
(*Thresholds MSSM*)


(* ::Subsection:: *)
(*One Loop*)


(* ::Subsubsection::Closed:: *)
(*Expressions one-loop*)


\[Lambda]HSS1laux:=\[Lambda]tree+\[CapitalDelta]\[Lambda]1lreg+\[CapitalDelta]\[Lambda]1l\[Phi]+\[CapitalDelta]\[Lambda]1l\[Chi]1HSS+\[CapitalDelta]\[Lambda]1l\[Chi]2
\[Lambda]HSS1lsuppressedaux:=factorscalars \[CapitalDelta]\[Lambda]1l\[Phi]+factorfermions (\[CapitalDelta]\[Lambda]1l\[Chi]1HSS+\[CapitalDelta]\[Lambda]1l\[Chi]2)
\[Lambda]Splitscalarsaux:=\[Lambda]tree+\[CapitalDelta]\[Lambda]1lreg+\[CapitalDelta]\[Lambda]1l\[Phi]
\[Lambda]SMsplitaux:=\[Lambda]+\[CapitalDelta]\[Lambda]1l\[Chi]1Split
gtSplitsplitaux:=Subscript[g, t](1+\[CapitalDelta]gt\[Chi])


\[Lambda]tree:=1/4 (Subscript[g, 2]^2+3/5 Subscript[g, 1]^2)Cos[2\[Beta]]^2
\[CapitalDelta]\[Lambda]1lreg:=1/(4\[Pi])^2 (-(9/100)  
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)-3/10 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)-(3/4-1/6 Cos[2 \[Beta]]^2) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\));(*eq. 9*)
\[CapitalDelta]\[Lambda]1l\[Phi]:=1/((4 \[Pi])^2)  (3 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (\!\(
\*SubsuperscriptBox[\(g\), \(t\), \(2\)] + \(
\*FractionBox[\(1\), \(2\)]\ \((
\*SubsuperscriptBox[\(g\), \(2\), \(2\)] - 
\*FractionBox[
SubsuperscriptBox[\(g\), \(1\), \(2\)], \(5\)])\)\ Cos[2\ \[Beta]]\)\)) Log[
\!\(\*SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(3\)], \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+3 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (\!\(
\*SubsuperscriptBox[\(g\), \(t\), \(2\)] + \(
\*FractionBox[\(2\), \(5\)]\ 
\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\ Cos[2\ \[Beta]]\)\)) Log[
\!\(\*SubsuperscriptBox[\(m\), 
SubscriptBox[\(U\), \(3\)], \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+1/300 (Cos[2 \[Beta]]^2) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\((3 \((
\*SubsuperscriptBox[\(g\), \(1\), \(4\)] + 25\ 
\*SubsuperscriptBox[\(g\), \(2\), \(4\)])\)\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 24\ 
\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(U\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 6\ 
\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(D\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + \((9\ 
\*SubsuperscriptBox[\(g\), \(1\), \(4\)] + 25\ 
\*SubsuperscriptBox[\(g\), \(2\), \(4\)])\)\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(L\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 18\ 
\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(E\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]])\)\)+1/4800 (261 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)+630 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+1325 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\)-4 Cos[4 \[Beta]] (9 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)+90 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+175 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))-9 Cos[8 \[Beta]] (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+5 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))^2) Log[Subscript[m, A]^2/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]-3/16 ((3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/5+
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))^2 Sin[4 \[Beta]]^2+6 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\) Subscript[
\!\(\*OverscriptBox[\(X\), \(~\)]\), t] (Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 1][Subscript[x, QU]]-1/12 Subscript[
\!\(\*OverscriptBox[\(X\), \(~\)]\), t] Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 2][Subscript[x, QU]])+3/4 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(X\), \(~\)]\), t] Cos[2 \[Beta] ](3/5 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 3][Subscript[x, QU]]+\!\(
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\ \(
\(\*SubscriptBox[
OverscriptBox[\(F\), \(~\)], \(4\)]\)[
\*SubscriptBox[\(x\), \(QU\)]]\)\))-1/4 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(X\), \(~\)]\), t] Cos[2 \[Beta]]^2 ((3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/5+
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 5][Subscript[x, QU]]) (*eq. 10*)
Subscript[
\!\(\*OverscriptBox[\(X\), \(~\)]\), t]:=Subscript[X, t]^2/(Subscript[m, Subscript[Q, 3]] Subscript[m, Subscript[U, 3]]);Subscript[x, QU]:=Subscript[m, Subscript[Q, 3]]/Subscript[m, Subscript[U, 3]];


\[CapitalDelta]\[Lambda]1l\[Chi]1Split:=Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), \[Lambda]] /((4 \[Pi])^2)  1/2 Log[\[Mu]^2/msplit^2]+1/(4 \[Pi])^2 (1/12 (-7) Subscript[f, 1][Subscript[r, 1]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(4\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(4\)]\))-9/4 Subscript[f, 2][Subscript[r, 2]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(4\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(4\)]\))-3/2 Subscript[f, 3][Subscript[r, 1]] 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)]\) 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\)-7/2 Subscript[f, 4][Subscript[r, 2]] 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)]\) 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)-8/3 Subscript[f, 5][Subscript[r, 1],Subscript[r, 2]] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-7/6 Subscript[f, 6][Subscript[r, 1],Subscript[r, 2]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)]\)+\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\))-1/6 Subscript[f, 7][Subscript[r, 1],Subscript[r, 2]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)+\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)]\))-4/3 Subscript[f, 8][Subscript[r, 1],Subscript[r, 2]] (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]) (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u])+2/3 f[Subscript[r, 1]] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u](\[Lambda]-2 (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\)))+2 f[Subscript[r, 2]] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u](\[Lambda]-2 (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)))+1/3 gg[Subscript[r, 1]] \[Lambda](\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\))+gg[Subscript[r, 2]] \[Lambda](\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)));(*eq. 11*)
Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), \[Lambda]]:=2 \[Lambda](Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-2 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2) (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2); (*eq. 12*)
Subscript[r, 1]:=Subscript[M, 1]/\[Mu];Subscript[r, 2]:=Subscript[M, 2]/\[Mu];


(* ::Input:: *)
(*\[CapitalDelta]\[Lambda]1l\[Chi]1Split/.{msplit->*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\),Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]->(Subscript[g, 2] Sin[\[Beta]]),Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]->(Subscript[g, 2] Cos[\[Beta]]),Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]->(Sqrt[3/5] Subscript[g, 1] Sin[\[Beta]]),Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]->(Sqrt[3/5] Subscript[g, 1] Cos[\[Beta]]),\[Lambda]->\[Lambda]tree}//Simplify*)


(* ::Input:: *)
(*\[CapitalDelta]\[Lambda]1l\[Chi]1HSS:=1/(6400 \[Pi]^2) (4 Cos[2 \[Beta]]^2 gg[Subscript[M, 1]/\[Mu]] *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) (3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+5 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))+3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) (-18 Log[\[Mu]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+6 Cos[4 \[Beta]] Log[\[Mu]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+f[Subscript[M, 1]/\[Mu]] (-31 Sin[2 \[Beta]]+Sin[6 \[Beta]])-7 (3+Cos[4 \[Beta]]) Subscript[f, 1][Subscript[M, 1]/\[Mu]]-9 Subscript[f, 3][Subscript[M, 1]/\[Mu]]+9 Cos[4 \[Beta]] Subscript[f, 3][Subscript[M, 1]/\[Mu]])+25 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\) (4 Cos[2 \[Beta]]^2 gg[Subscript[M, 2]/\[Mu]]-26 Log[\[Mu]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]-2 Cos[4 \[Beta]] Log[\[Mu]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+f[Subscript[M, 2]/\[Mu]] (-31 Sin[2 \[Beta]]+Sin[6 \[Beta]])-27 Subscript[f, 2][Subscript[M, 2]/\[Mu]]-9 Cos[4 \[Beta]] Subscript[f, 2][Subscript[M, 2]/\[Mu]]-7 Subscript[f, 4][Subscript[M, 2]/\[Mu]]+7 Cos[4 \[Beta]] Subscript[f, 4][Subscript[M, 2]/\[Mu]])+5 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) (6 (1+Cos[4 \[Beta]]) gg[Subscript[M, 2]/\[Mu]]-24 Log[\[Mu]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+24 Cos[4 \[Beta]] Log[\[Mu]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+3 f[Subscript[M, 2]/\[Mu]] Sin[2 \[Beta]]+3 f[Subscript[M, 2]/\[Mu]] Sin[6 \[Beta]]+f[Subscript[M, 1]/\[Mu]] (Sin[2 \[Beta]]+Sin[6 \[Beta]])-16 Subscript[f, 5][Subscript[M, 1]/\[Mu],Subscript[M, 2]/\[Mu]]+16 Cos[4 \[Beta]] Subscript[f, 5][Subscript[M, 1]/\[Mu],Subscript[M, 2]/\[Mu]]-42 Subscript[f, 6][Subscript[M, 1]/\[Mu],Subscript[M, 2]/\[Mu]]-14 Cos[4 \[Beta]] Subscript[f, 6][Subscript[M, 1]/\[Mu],Subscript[M, 2]/\[Mu]]-2 Subscript[f, 7][Subscript[M, 1]/\[Mu],Subscript[M, 2]/\[Mu]]+2 Cos[4 \[Beta]] Subscript[f, 7][Subscript[M, 1]/\[Mu],Subscript[M, 2]/\[Mu]]-64 Sin[2 \[Beta]] Subscript[f, 8][Subscript[M, 1]/\[Mu],Subscript[M, 2]/\[Mu]]));*)
(*\[CapitalDelta]\[Lambda]1l\[Chi]2:=1/(4\[Pi])^2 (-(1/6) Cos[2\[Beta]]^2 (2Subscript[g, 2]^4 Log[Subscript[M, 2]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+(9/25 Subscript[g, 1]^4+Subscript[g, 2]^4)Log[\[Mu]^2/*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)^2])); (*eq. 13*)*)
(**)


\[CapitalDelta]\[Lambda]1l\[Chi]1Split:=Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), \[Lambda]] /((4 \[Pi])^2)  1/2 Log[\[Mu]^2/msplit^2]+1/(4 \[Pi])^2 (1/12 (-7) Subscript[f, 1][Subscript[r, 1]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(4\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(4\)]\))-9/4 Subscript[f, 2][Subscript[r, 2]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(4\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(4\)]\))-3/2 Subscript[f, 3][Subscript[r, 1]] 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)]\) 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\)-7/2 Subscript[f, 4][Subscript[r, 2]] 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)]\) 
\!\(\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)-8/3 Subscript[f, 5][Subscript[r, 1],Subscript[r, 2]] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-7/6 Subscript[f, 6][Subscript[r, 1],Subscript[r, 2]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)]\)+\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\))-1/6 Subscript[f, 7][Subscript[r, 1],Subscript[r, 2]] (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)+\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\ 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)]\))-4/3 Subscript[f, 8][Subscript[r, 1],Subscript[r, 2]] (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]) (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u])+2/3 f[Subscript[r, 1]] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u](\[Lambda]-2 (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\)))+2 f[Subscript[r, 2]] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u](\[Lambda]-2 (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)))+1/3 gg[Subscript[r, 1]] \[Lambda](\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)]\))+gg[Subscript[r, 2]] \[Lambda](\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)]\)));(*eq. 11*)
Subscript[
\!\(\*OverscriptBox[\(\[Beta]\), \(~\)]\), \[Lambda]]:=2 \[Lambda](Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2+3 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2)-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^4-Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^4-5 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^4-4 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]-2 (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]^2) (Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]^2+Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]^2); (*eq. 12*)
Subscript[r, 1]:=Subscript[M, 1]/\[Mu];Subscript[r, 2]:=Subscript[M, 2]/\[Mu];


g2umtildeaux:=Subscript[g, 2] Sin[\[Beta]](1+1/(4 \[Pi])^2 (-
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)(2/3+(11 Cos[\[Beta]]^2)/16)+1/80 (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)) (-2+7 Cos[\[Beta]]^2)+(9 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))/(4 Sin[\[Beta]]^2)+(20 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+3 (-9 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+35 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))Cos[\[Beta]]^2)/120 Log[Subscript[m, A]^2/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+1/6 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\(Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(L\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]]\)\)+1/2 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\(Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]]\)\)-(3 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) )/(4 (Sin[\[Beta]]^2)) (3 Log[
\!\(\*SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(3\)], \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]-Log[
\!\(\*SubsuperscriptBox[\(m\), 
SubscriptBox[\(U\), \(3\)], \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]))) ;
g2dmtildeaux:=Subscript[g, 2]Cos[\[Beta]](1+1/(4 \[Pi])^2 (-
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)(2/3+(11 Sin[\[Beta]]^2)/16)+1/80 (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)) (-2+7 Sin[\[Beta]]^2)+1/2 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\(Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]]\)\)+1/120 (20 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+3 (-9 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+35 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)) Sin[\[Beta]]^2) Log[
\!\(\*SubsuperscriptBox[\(m\), \(A\), \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+1/6 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\(Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(L\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]]\)\)) );
g1umtildeaux:=Sqrt[3/5] Subscript[g, 1] Sin[\[Beta]](1+1/(4 \[Pi])^2 (1/16 (3 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)) (-2+7 Cos[\[Beta]]^2)+1/80 (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)) (-44+7 Cos[\[Beta]]^2)+(9 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))/(4 Sin[\[Beta]]^2)+1/40 (4 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)-9 (\!\(
\*SubsuperscriptBox[\(g\), \(1\), \(2\)] + \(5\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)\)) Cos[\[Beta]]^2) Log[
\!\(\*SubsuperscriptBox[\(m\), \(A\), \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+1/10 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\((Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(L\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 2\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(E\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]])\)\)+1/30 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\((Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 8\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(U\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 2\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(D\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]])\)\)+\!\(
\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\(\ \)\)/(4 Sin[\[Beta]]^2) (7 Log[
\!\(\*SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(3\)], \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]-13 Log[
\!\(\*SubsuperscriptBox[\(m\), 
SubscriptBox[\(U\), \(3\)], \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]))) ;
g1dmtildeaux:=Sqrt[3/5] Subscript[g, 1] Cos[\[Beta]](1+1/(4 \[Pi])^2 (1/16 (3 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)) (-2+7 Sin[\[Beta]]^2)+1/80 (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)) (-44+7 Sin[\[Beta]]^2)+1/40 (4 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)-9 (\!\(
\*SubsuperscriptBox[\(g\), \(1\), \(2\)] + \(5\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)\)) Sin[\[Beta]]^2) Log[
\!\(\*SubsuperscriptBox[\(m\), \(A\), \(2\)]\)/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]+1/10 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\((Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(L\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 2\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(E\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]])\)\)+1/30 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\((Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(Q\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 8\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(U\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]] + 2\ Log[
\*FractionBox[
SubsuperscriptBox[\(m\), 
SubscriptBox[\(D\), \(i\)], \(2\)], 
SuperscriptBox[
OverscriptBox[\(m\), \(~\)], \(2\)]]])\)\))) ;
 \[CapitalDelta]gt\[Chi]:=1/(4 \[Pi])^2 (-(1/6) Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d] f[Subscript[M, 1]/\[Mu]]-1/12 (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ u\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(1\ d\), \(2\)]\)) (gg[Subscript[M, 1]/\[Mu]]+3 Log[\[Mu]^2/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2])-1/2 Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u] Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d] f[Subscript[M, 2]/\[Mu]]-1/4 (\!\(
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ u\), \(2\)] + 
\*SubsuperscriptBox[
OverscriptBox[\(g\), \(~\)], \(2\ d\), \(2\)]\)) (gg[Subscript[M, 2]/\[Mu]]+3 Log[\[Mu]^2/
\!\(\*OverscriptBox[\(m\), \(~\)]\)^2]))/.{
\!\(\*OverscriptBox[\(m\), \(~\)]\)->msplit};


(* ::Subsubsection::Closed:: *)
(*Loop Functions*)


(* ::Text:: *)
(*When evaluating the loop functions, the limit values need to be treated carefully to avoid indeterminate expressions.*)


(* ::Input::Closed:: *)
(*(*Commented*)*)


(* ::Input:: *)
(*(*With[{\[Delta]=10^-7},Subscript[Overscript[F, ~], 1][x_]:=Piecewise[{{1,Abs[x-1]<\[Delta]}},(x Log[x^2])/(x^2-1)];Subscript[Overscript[F, ~], 2][x_]:=Piecewise[{{1,Abs[x-1]<\[Delta]}},(6 x^2 (2-2 x^2+(1+x^2) Log[x^2]))/(x^2-1)^3];Subscript[Overscript[F, ~], 3][x_]:=Piecewise[{{1,Abs[x-1]<\[Delta]}},(2 x (5 (1-x^2)+(1+4 x^2) Log[x^2]))/(3 (x^2-1)^2)];Subscript[Overscript[F, ~], 4][x_]:=Piecewise[{{1,Abs[x-1]<\[Delta]}},(2 x (x^2-1-Log[x^2]))/(x^2-1)^2];Subscript[Overscript[F, ~], 5][x_]:=Piecewise[{{1,Abs[x-1]<\[Delta]}},(3 x (1-x^4+2 x^2 Log[x^2]))/(1-x^2)^3];Subscript[Overscript[F, ~], 6][x_]:=Piecewise[{{0,Abs[x-1]<\[Delta]}},(x^2-3)/(4 (1-x^2))+((x^2 (x^2-2)) Log[x^2])/(2 (1-x^2)^2)];Subscript[Overscript[F, ~], 7][x_]:=Piecewise[{{1,Abs[x-1]<\[Delta]}},-((3 (x^4-6 x^2+1))/(2 (x^2-1)^2))+((3 x^4 (x^2-3)) Log[x^2])/(x^2-1)^3];Subscript[Overscript[F, ~], 8][x1_,x2_]:=Piecewise[{{1,(Abs[x1-1]+Abs[x2-1])<\[Delta]}},-2+2 /(x1^2-x2^2)((x1^4 Log[x1^2])/(x1^2-1)-(x2^4 Log[x2^2])/(x2^2-1))];Subscript[Overscript[F, ~], 9][x1_,x2_]:=Piecewise[{{1,(Abs[x1-1]+Abs[x2-1])<\[Delta]}},(2 ((x1^2 Log[x1^2])/(x1^2-1)-(x2^2 Log[x2^2])/(x2^2-1)))/(x1^2-x2^2)];*)
(*f[r_]:=Subscript[Overscript[F, ~], 5][r];*)
(*gg[r_]:=Subscript[Overscript[F, ~], 7][r];(*define gg to avoid conflict*)*)
(*Subscript[f, 1][r_]:=Piecewise[{{1,Abs[r-1]<\[Delta]}},(6 (r^2+3) r^2)/(7 (r^2-1)^2)+(6 (r^2-5) r^4 Log[r^2])/(7 (r^2-1)^3)];*)
(*Subscript[f, 2][r_]:=Piecewise[{{1,Abs[r-1]<\[Delta]}},(2 (r^2+11) r^2)/(9 (r^2-1)^2)+(2 (5 r^2-17) r^4 Log[r^2])/(9 (r^2-1)^3)];Subscript[f, 3][r_]:=Piecewise[{{1,Abs[r-1]<\[Delta]}},(2 (r^4+9 r^2+2))/(3 (r^2-1)^2)+(2 (r^4-7 r^2-6) r^2 Log[r^2])/(3 (r^2-1)^3)];Subscript[f, 4][r_]:=Piecewise[{{1,Abs[r-1]<\[Delta]}},(2 (5 r^4+25 r^2+6))/(7 (r^2-1)^2)+(2 (r^4-19 r^2-18) r^2 Log[r^2])/(7 (r^2-1)^3)];Subscript[f, 5][r1_,r2_]:=Piecewise[{{1,(Abs[r1-1]+Abs[r2-1])<\[Delta]}},3/4 ((1+(r1+r2)^2-r1^2 r2^2)/((r1^2-1) (r2^2-1))+(r1^3 (r1^2+1) Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^3(r2^2+1) Log[r2^2])/((r1-r2) (r2^2-1)^2))];Subscript[f, 6][r1_,r2_]:=Piecewise[{{1,(Abs[r1-1]+Abs[r2-1])<\[Delta]}},6/7 ((r1^2+r2^2+r1 r2-r1^2 r2^2)/((r1^2-1) (r2^2-1))+(r1^5 Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^5 Log[r2^2])/((r1-r2) (r2^2-1)^2))];Subscript[f, 7][r1_,r2_]:=Piecewise[{{1,(Abs[r1-1]+Abs[r2-1])<\[Delta]}},6 ((1+r1 r2)/((r1^2-1) (r2^2-1))+(r1^3 Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^3 Log[r2^2])/((r1-r2) (r2^2-1)^2))];Subscript[f, 8][r1_,r2_]:=Piecewise[{{1,(Abs[r1-1]+Abs[r2-1])<\[Delta]}},3/2 ((r1+r2)/((r1^2-1) (r2^2-1))+(r1^4 Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^4 Log[r2^2])/((r1-r2) (r2^2-1)^2))];]*)*)


With[{\[Delta]=1.3564 10^-4,\[Delta]2=2.36547 10^-4},Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 1][Qx_]:=Block[{x=(1.+\[Delta])Qx},(x Log[x^2])/(x^2-1)];
Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 2][Qx_]:=Block[{x=(1.+\[Delta])Qx},(6 x^2 (2-2 x^2+(1+x^2) Log[x^2]))/(x^2-1)^3];Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 3][Qx_]:=Block[{x=(1.+\[Delta])Qx},(2 x (5 (1-x^2)+(1+4 x^2) Log[x^2]))/(3 (x^2-1)^2)];Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 4][Qx_]:=Block[{x=(1.+\[Delta])Qx},(2 x (x^2-1-Log[x^2]))/(x^2-1)^2];Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 5][Qx_]:=Block[{x=(1.+\[Delta])Qx},(3 x (1-x^4+2 x^2 Log[x^2]))/(1-x^2)^3];Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 6][Qx_]:=Block[{x=(1.+\[Delta])Qx},(x^2-3)/(4 (1-x^2))+((x^2 (x^2-2)) Log[x^2])/(2 (1-x^2)^2)];Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 7][Qx_]:=Block[{x=(1.+\[Delta])Qx},-((3 (x^4-6 x^2+1))/(2 (x^2-1)^2))+((3 x^4 (x^2-3)) Log[x^2])/(x^2-1)^3];Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 8][Qx1_,Qx2_]:=Block[{x1=(1.+\[Delta])Qx1,x2=(1.+\[Delta]2)Qx2},-2+2 /(x1^2-x2^2) ((x1^4 Log[x1^2])/(x1^2-1)-(x2^4 Log[x2^2])/(x2^2-1))];
Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 9][Qx1_,Qx2_]:=Block[{x1=(1.+\[Delta])Qx1,x2=(1.+\[Delta]2)Qx2},(2 ((x1^2 Log[x1^2])/(x1^2-1)-(x2^2 Log[x2^2])/(x2^2-1)))/(x1^2-x2^2)];
f[r_]:=Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 5][r];
gg[r_]:=Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 7][r];(*define gg to avoid conflict*)
Subscript[f, 1][Qr_]:=Block[{r=(1.+\[Delta])Qr},(6 (r^2+3) r^2)/(7 (r^2-1)^2)+(6 (r^2-5) r^4 Log[r^2])/(7 (r^2-1)^3)];
Subscript[f, 2][Qr_]:=Block[{r=(1.+\[Delta])Qr},(2 (r^2+11) r^2)/(9 (r^2-1)^2)+(2 (5 r^2-17) r^4 Log[r^2])/(9 (r^2-1)^3)];Subscript[f, 3][Qr_]:=Block[{r=(1.+\[Delta])Qr},(2 (r^4+9 r^2+2))/(3 (r^2-1)^2)+(2 (r^4-7 r^2-6) r^2 Log[r^2])/(3 (r^2-1)^3)];Subscript[f, 4][Qr_]:=Block[{r=(1.+\[Delta])Qr},(2 (5 r^4+25 r^2+6))/(7 (r^2-1)^2)+(2 (r^4-19 r^2-18) r^2 Log[r^2])/(7 (r^2-1)^3)];Subscript[f, 5][Qr1_,Qr2_]:=Block[{r1=(1.+\[Delta])Qr1,r2=(1.+\[Delta]2)Qr2},3/4 ((1+(r1+r2)^2-r1^2 r2^2)/((r1^2-1) (r2^2-1))+(r1^3 (r1^2+1) Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^3 (r2^2+1) Log[r2^2])/((r1-r2) (r2^2-1)^2))];Subscript[f, 6][Qr1_,Qr2_]:=Block[{r1=(1.+\[Delta])Qr1,r2=(1.+\[Delta]2)Qr2},6/7 ((r1^2+r2^2+r1 r2-r1^2 r2^2)/((r1^2-1) (r2^2-1))+(r1^5 Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^5 Log[r2^2])/((r1-r2) (r2^2-1)^2))];Subscript[f, 7][Qr1_,Qr2_]:=Block[{r1=(1.+\[Delta])Qr1,r2=(1.+\[Delta]2)Qr2},6 ((1+r1 r2)/((r1^2-1) (r2^2-1))+(r1^3 Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^3 Log[r2^2])/((r1-r2) (r2^2-1)^2))];Subscript[f, 8][Qr1_,Qr2_]:=Block[{r1=(1.+\[Delta])Qr1,r2=(1.+\[Delta]2)Qr2},3/2 ((r1+r2)/((r1^2-1) (r2^2-1))+(r1^4 Log[r1^2])/((r1^2-1)^2 (r1-r2))-(r2^4 Log[r2^2])/((r1-r2) (r2^2-1)^2))]]


(* ::Subsubsection::Closed:: *)
(*One loop function HSS*)


(* ::Input:: *)
(*\[Lambda]HSS1laux/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt,*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}//Simplify*)


(* ::Input:: *)
(*\[Lambda]HSS1lsuppressedaux/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt,*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}//Simplify*)


\[Lambda]HSS1l[mtilde_,mQ1_,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=1./19200 (960 Cos[2 ArcTan[tan\[Beta]]]^2 (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+5 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))+(4 (-27 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)-90 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+25 (-8+Cos[4 ArcTan[tan\[Beta]]]) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\)))/\[Pi]^2-(200 Cos[2 ArcTan[tan\[Beta]]]^2 (2 Log[M2^2/mtilde^2] 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\)+Log[Q\[Mu]^2/mtilde^2] ((9 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\))/25+
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))))/\[Pi]^2+1/\[Pi]^2 3 (4 Cos[2 ArcTan[tan\[Beta]]]^2 gg[M1/Q\[Mu]] 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+5 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))+3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) (-18 Log[Q\[Mu]^2/mtilde^2]+6 Cos[4 ArcTan[tan\[Beta]]] Log[Q\[Mu]^2/mtilde^2]+f[M1/Q\[Mu]] (-31 Sin[2 ArcTan[tan\[Beta]]]+Sin[6 ArcTan[tan\[Beta]]])-7 (3+Cos[4 ArcTan[tan\[Beta]]]) Subscript[f, 1][M1/Q\[Mu]]-9 Subscript[f, 3][M1/Q\[Mu]]+9 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 3][M1/Q\[Mu]])+25 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\) (4 Cos[2 ArcTan[tan\[Beta]]]^2 gg[M2/Q\[Mu]]-26 Log[Q\[Mu]^2/mtilde^2]-2 Cos[4 ArcTan[tan\[Beta]]] Log[Q\[Mu]^2/mtilde^2]+f[M2/Q\[Mu]] (-31 Sin[2 ArcTan[tan\[Beta]]]+Sin[6 ArcTan[tan\[Beta]]])-27 Subscript[f, 2][M2/Q\[Mu]]-9 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 2][M2/Q\[Mu]]-7 Subscript[f, 4][M2/Q\[Mu]]+7 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 4][M2/Q\[Mu]])+5 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) (6 (1+Cos[4 ArcTan[tan\[Beta]]]) gg[M2/Q\[Mu]]-24 Log[Q\[Mu]^2/mtilde^2]+24 Cos[4 ArcTan[tan\[Beta]]] Log[Q\[Mu]^2/mtilde^2]+3 f[M2/Q\[Mu]] Sin[2 ArcTan[tan\[Beta]]]+3 f[M2/Q\[Mu]] Sin[6 ArcTan[tan\[Beta]]]+f[M1/Q\[Mu]] (Sin[2 ArcTan[tan\[Beta]]]+Sin[6 ArcTan[tan\[Beta]]])-16 Subscript[f, 5][M1/Q\[Mu],M2/Q\[Mu]]+16 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 5][M1/Q\[Mu],M2/Q\[Mu]]-42 Subscript[f, 6][M1/Q\[Mu],M2/Q\[Mu]]-14 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 6][M1/Q\[Mu],M2/Q\[Mu]]-2 Subscript[f, 7][M1/Q\[Mu],M2/Q\[Mu]]+2 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 7][M1/Q\[Mu],M2/Q\[Mu]]-64 Sin[2 ArcTan[tan\[Beta]]] Subscript[f, 8][M1/Q\[Mu],M2/Q\[Mu]]))+1/\[Pi]^2 1200 (-(3/16) Sin[4 ArcTan[tan\[Beta]]]^2 ((3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/5+
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))^2-1/4800 Log[mA^2/mtilde^2] (9 (-29+4 Cos[4 ArcTan[tan\[Beta]]]+9 Cos[8 ArcTan[tan\[Beta]]]) 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)-360 (5+3 Cos[4 ArcTan[tan\[Beta]]]) Sin[2 ArcTan[tan\[Beta]]]^2 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+25 (-53+28 Cos[4 ArcTan[tan\[Beta]]]+9 Cos[8 ArcTan[tan\[Beta]]]) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))+1/300 Cos[2 ArcTan[tan\[Beta]]]^2 (3 (2 Log[mD1^2/mtilde^2]+2 Log[mD2^2/mtilde^2]+2 Log[mD3^2/mtilde^2]+6 Log[mE1^2/mtilde^2]+6 Log[mE2^2/mtilde^2]+6 Log[mE3^2/mtilde^2]+3 Log[mL1^2/mtilde^2]+3 Log[mL2^2/mtilde^2]+3 Log[mL3^2/mtilde^2]+Log[mQ1^2/mtilde^2]+Log[mQ2^2/mtilde^2]+Log[mQ3^2/mtilde^2]+8 Log[mU1^2/mtilde^2]+8 Log[mU2^2/mtilde^2]+8 Log[mU3^2/mtilde^2]) 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)+25 (Log[mL1^2/mtilde^2]+Log[mL2^2/mtilde^2]+Log[mL3^2/mtilde^2]+3 Log[mQ1^2/mtilde^2]+3 Log[mQ2^2/mtilde^2]+3 Log[mQ3^2/mtilde^2]) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))+3 Log[mU3^2/mtilde^2] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (2/5 Cos[2 ArcTan[tan\[Beta]]] 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))+3 Log[mQ3^2/mtilde^2] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (-(1/10) Cos[2 ArcTan[tan\[Beta]]] (\!\(
\*SubsuperscriptBox[\(g\), \(1\), \(2\)] - \(5\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)\))+
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))+(Xt^2 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\) (12 mQ3 mU3 Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 1][mQ3/mU3]-Xt^2 Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 2][mQ3/mU3]))/(2 mQ3^2 mU3^2)+(3 Xt^2 Cos[2 ArcTan[tan\[Beta]]] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 3][mQ3/mU3]+5 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 4][mQ3/mU3]))/(20 mQ3 mU3)-(Xt^2 Cos[2 ArcTan[tan\[Beta]]]^2 ((3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/5+
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)) 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 5][mQ3/mU3])/(4 mQ3 mU3)))


\[Lambda]HSS1lsuppressed[mtilde_,mQ1_,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=With[{factorfermions=91^2/Min[Abs@Q\[Mu],Abs@M2]^2,factorscalars=246^2/(mQ3 mU3)},1/4 91^2/mA^2 1/4 (3/5 Subscript[g, 1]^2+Subscript[g, 2]^2)Sin[4ArcTan[tan\[Beta]]]^2+1/(19200 \[Pi]^2) (factorfermions Abs@ (12 Cos[2 ArcTan[tan\[Beta]]]^2 gg[M1/Q\[Mu]] 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+5 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))+9 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\) (-22 Log[Q\[Mu]^2/mtilde^2]+2 Cos[4 ArcTan[tan\[Beta]]] Log[Q\[Mu]^2/mtilde^2]+f[M1/Q\[Mu]] (-31 Sin[2 ArcTan[tan\[Beta]]]+Sin[6 ArcTan[tan\[Beta]]])-7 (3+Cos[4 ArcTan[tan\[Beta]]]) Subscript[f, 1][M1/Q\[Mu]]-9 Subscript[f, 3][M1/Q\[Mu]]+9 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 3][M1/Q\[Mu]])+25 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\) (6 (1+Cos[4 ArcTan[tan\[Beta]]]) gg[M2/Q\[Mu]]-8 Log[M2^2/mtilde^2]-8 Cos[4 ArcTan[tan\[Beta]]] Log[M2^2/mtilde^2]-82 Log[Q\[Mu]^2/mtilde^2]-10 Cos[4 ArcTan[tan\[Beta]]] Log[Q\[Mu]^2/mtilde^2]+3 f[M2/Q\[Mu]] (-31 Sin[2 ArcTan[tan\[Beta]]]+Sin[6 ArcTan[tan\[Beta]]])-81 Subscript[f, 2][M2/Q\[Mu]]-27 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 2][M2/Q\[Mu]]-21 Subscript[f, 4][M2/Q\[Mu]]+21 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 4][M2/Q\[Mu]])+15 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) (6 (1+Cos[4 ArcTan[tan\[Beta]]]) gg[M2/Q\[Mu]]-24 Log[Q\[Mu]^2/mtilde^2]+24 Cos[4 ArcTan[tan\[Beta]]] Log[Q\[Mu]^2/mtilde^2]+3 f[M2/Q\[Mu]] Sin[2 ArcTan[tan\[Beta]]]+3 f[M2/Q\[Mu]] Sin[6 ArcTan[tan\[Beta]]]+f[M1/Q\[Mu]] (Sin[2 ArcTan[tan\[Beta]]]+Sin[6 ArcTan[tan\[Beta]]])-16 Subscript[f, 5][M1/Q\[Mu],M2/Q\[Mu]]+16 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 5][M1/Q\[Mu],M2/Q\[Mu]]-42 Subscript[f, 6][M1/Q\[Mu],M2/Q\[Mu]]-14 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 6][M1/Q\[Mu],M2/Q\[Mu]]-2 Subscript[f, 7][M1/Q\[Mu],M2/Q\[Mu]]+2 Cos[4 ArcTan[tan\[Beta]]] Subscript[f, 7][M1/Q\[Mu],M2/Q\[Mu]]-64 Sin[2 ArcTan[tan\[Beta]]] Subscript[f, 8][M1/Q\[Mu],M2/Q\[Mu]]))+1200 factorscalars Abs@(-(3/16) Sin[4 ArcTan[tan\[Beta]]]^2 ((3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/5+
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\))^2-1/4800 Log[mA^2/mtilde^2] (9 (-29+4 Cos[4 ArcTan[tan\[Beta]]]+9 Cos[8 ArcTan[tan\[Beta]]]) 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)-360 (5+3 Cos[4 ArcTan[tan\[Beta]]]) Sin[2 ArcTan[tan\[Beta]]]^2 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)+25 (-53+28 Cos[4 ArcTan[tan\[Beta]]]+9 Cos[8 ArcTan[tan\[Beta]]]) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))+1/300 Cos[2 ArcTan[tan\[Beta]]]^2 (3 (2 Log[mD1^2/mtilde^2]+2 Log[mD2^2/mtilde^2]+2 Log[mD3^2/mtilde^2]+6 Log[mE1^2/mtilde^2]+6 Log[mE2^2/mtilde^2]+6 Log[mE3^2/mtilde^2]+3 Log[mL1^2/mtilde^2]+3 Log[mL2^2/mtilde^2]+3 Log[mL3^2/mtilde^2]+Log[mQ1^2/mtilde^2]+Log[mQ2^2/mtilde^2]+Log[mQ3^2/mtilde^2]+8 Log[mU1^2/mtilde^2]+8 Log[mU2^2/mtilde^2]+8 Log[mU3^2/mtilde^2]) 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(4\)]\)+25 (Log[mL1^2/mtilde^2]+Log[mL2^2/mtilde^2]+Log[mL3^2/mtilde^2]+3 Log[mQ1^2/mtilde^2]+3 Log[mQ2^2/mtilde^2]+3 Log[mQ3^2/mtilde^2]) 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(4\)]\))+3 Log[mU3^2/mtilde^2] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (2/5 Cos[2 ArcTan[tan\[Beta]]] 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\)+
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))+3 Log[mQ3^2/mtilde^2] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (-(1/10) Cos[2 ArcTan[tan\[Beta]]] (\!\(
\*SubsuperscriptBox[\(g\), \(1\), \(2\)] - \(5\ 
\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)\))+
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))+(Xt^2 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\) (12 mQ3 mU3 Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 1][mQ3/mU3]-Xt^2 Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 2][mQ3/mU3]))/(2 mQ3^2 mU3^2)+(3 Xt^2 Cos[2 ArcTan[tan\[Beta]]] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) (3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 3][mQ3/mU3]+5 
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 4][mQ3/mU3]))/(20 mQ3 mU3)-(Xt^2 Cos[2 ArcTan[tan\[Beta]]]^2 ((3 
\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\))/5+
\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\)) 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\) Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 5][mQ3/mU3])/(4 mQ3 mU3)))]


(* ::Subsubsection::Closed:: *)
(*One loop O(Subscript[\[Alpha], b]) including tan\[Beta]-enhanced corrections*)


(* ::Text:: *)
(*The one-loop tan\[Beta]-enhanced SUSY threshold contribution to \[Lambda] from the sbottom is in \[Lambda]2lbottom[ ]. The factor Subscript[r, b] used in the Appendix of the paper is defined as gbDR[ ] cos\[Beta] / Subscript[g, b].*)


(* ::Text::Closed:: *)
(*Auxiliar*)


(* ::Input:: *)
(*\[Lambda]2lbottomaux:=1/(4\[Pi])^2 (6Subscript[g, b]^4) Subscript[X, b]^2/(mQ3 mD3) (Subscript[*)
(*\!\(\*OverscriptBox[\(F\), \(~\)]\), 1][mQ3/mD3]-1/12 Subscript[X, b]^2/(mQ3 mD3) Subscript[*)
(*\!\(\*OverscriptBox[\(F\), \(~\)]\), 2][mQ3/mD3])(1/(1-(4\[Pi])^-2 Subscript[\[CapitalDelta]h, b]))^4;*)
(*Subscript[\[CapitalDelta]h, b]:=8/3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)M3 Subscript[X, b] II[mQ3,mD3,M3]-Subscript[g, t]^2/Sin[ArcTan[tan\[Beta]]]^2 \[Mu] tan\[Beta] Subscript[X, t] II[mQ3,mU3,\[Mu]];*)


(* ::Input:: *)
(*\[Lambda]2lbottomaux/.{Subscript[X, b]->-\[Mu] tan\[Beta],Subscript[X, t]->Xt}*)


\[Lambda]2lbottom[mQ3_,mU3_,mD3_,M3_,\[Mu]_,tan\[Beta]_,Xt_]:=6/(16\[Pi]^2) (gbDR[mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt] Cos[ArcTan[tan\[Beta]]])^4 (tan\[Beta]^2 \[Mu]^2)/( mD3 mQ3 )  (Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 1][mQ3/mD3]-(tan\[Beta]^2 \[Mu]^2 Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 2][mQ3/mD3])/(12 mD3 mQ3));
gbDR[mQ3_,mU3_,mD3_,M3_,\[Mu]_,tan\[Beta]_,Xt_]:=Subscript[g, b]/Cos[ArcTan[tan\[Beta]]] (1-(-(8/3) M3 tan\[Beta] \[Mu] II[mQ3,mD3,M3] 
\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\)-((1+tan\[Beta]^2) Xt \[Mu] II[mQ3,mU3,\[Mu]] 
\!\(\*SubsuperscriptBox[\(g\), \(t\), \(2\)]\))/tan\[Beta])/(16 \[Pi]^2))^-1;II[a_,b_,c_]:=Piecewise[{{1/(2a^2),Abs[a-b]<10^-2&&Abs[a-Abs[c]]<10^-2},{1/a^2 1/(1-(c/a)^2) (1+((c/a)^2 Log[(c/a)^2])/(1-(c/a)^2)),Abs[a-b]<10^-2},{-(1/a^2) 1/(1-(c/a)^2) (1+Log[(c/a)^2]/(1-(c/a)^2)),Abs[b-Abs[c]]<10^-2},{-(1/b^2) 1/(1-(c/b)^2) (1+Log[(c/b)^2]/(1-(c/b)^2)),Abs[a-Abs[c]]<10^-2}},(a^2 b^2 Log[a^2/b^2]+b^2 c^2 Log[b^2/c^2]+a^2 c^2 Log[c^2/a^2])/((a^2-b^2) (b^2-c^2) (a^2-c^2))]


(* ::Subsubsection::Closed:: *)
(*One loop O(Subscript[\[Alpha], \[Tau]]) including tan\[Beta]-enhanced corrections*)


(* ::Text:: *)
(*The one-loop tan\[Beta]-enhanced SUSY threshold contribution to \[Lambda] from the sbottom is in \[Lambda]2ltau[ ]. The factor Subscript[r, \[Tau]] used in the Appendix of the paper is defined as gtauDR[ ] cos\[Beta] / Subscript[g, \[Tau]].*)


\[Lambda]2ltau[mL3_,mE3_,M2_,M1_,\[Mu]_,tan\[Beta]_]:=(2/(16\[Pi]^2))(gtauDR[mL3,mE3,M2,M1,\[Mu],tan\[Beta]] Cos[ArcTan[tan\[Beta]]])^4 (tan\[Beta]^2 \[Mu]^2)/( mL3 mE3 )  (Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 1][mL3/mE3]-(tan\[Beta]^2 \[Mu]^2 Subscript[
\!\(\*OverscriptBox[\(F\), \(~\)]\), 2][mL3/mE3])/(12 mL3 mE3));
gtauDR[mL3_,mE3_,M2_,M1_,\[Mu]_,tan\[Beta]_]:=Subscript[g, \[Tau]]/Cos[ArcTan[tan\[Beta]]] (1-1/(4\[Pi])^2 tan\[Beta](Subscript[g, 2]^2 M2 \[Mu](II[mL3,M2,\[Mu]]+1/2 II[mL3,M2,\[Mu]])-3/5 Subscript[g, 1]^2 M1 (-\[Mu] II[mL3,mE3,M1]+1/2 \[Mu] II[mL3,M1,\[Mu]]-\[Mu] II[mE3,M1,\[Mu]])))^-1;


(* ::Subsection:: *)
(*Two - Loops*)


(* ::Subsubsection::Closed:: *)
(*Two - Loop O(Subscript[\[Alpha], t] Subscript[\[Alpha], S]) auxiliar manipulation*)


(* ::Input:: *)
(*\[CapitalDelta]\[Lambda]2lstrongdegenerateaux:=1/(96 \[Pi]^4) g3^2 gt^4 (-Xth^5+Xth (-12-24 Log[Q^2/M3^2])+Xth^4 (1/2-Log[Q^2/M3^2])-18 Log[Q^2/M3^2]^2+Xth^3 (14+4 Log[Q^2/M3^2])+Xth^2 (-6+24 Log[Q^2/M3^2]))*)


(* ::Input:: *)
(*\[CapitalDelta]\[Lambda]2lstrongaux:=1/(96 \[Pi]^4 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2 (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2) *)
(*\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\) (-9 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)-12 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)-18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)+6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)-6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)+6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)-6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)-6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\)+27 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+30 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-15 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-15 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+27 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+30 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-15 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-15 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-24 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-2 \[Pi]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-24 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+9 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+18 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-3 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-9 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/(\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-72 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-72 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-72 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+36 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+72 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-24 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+36 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+72 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-24 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-24 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-24 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-2 \[Pi]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-24 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+18 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-9 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+9 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-3 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)-6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/(\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\)+6 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+6 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+57 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+4 \[Pi]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+54 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-21 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-39 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+18 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-24 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/(\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+57 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+4 \[Pi]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+54 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-39 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+18 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-21 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+6 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-24 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/(\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+6 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)+6 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(6\)]\)-12 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-12 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-39 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-4 \[Pi]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-36 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)+21 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-9 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)+21 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)+18 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-9 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]^2 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)/(\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)+12 Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] Log[*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)/(\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-12 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)-12 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(8\)]\)+6 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(10\)]\)+6 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(10\)]\)+6 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(10\)]\)+6 Log[Q^2/*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(10\)]\)+12 PolyLog[2,*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\) (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2+12 PolyLog[2,*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)/*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)] *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(4\)]\) (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2)+(\!\( *)
(*\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\ *)
(*\*SubscriptBox[\(M\), \(3\)]\ \((\(-6\)\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 2\ *)
(*\*SuperscriptBox[\(\[Pi]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 3\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 6\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 12\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 2\ *)
(*\*SuperscriptBox[\(\[Pi]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 3\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 6\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 12\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 12\ PolyLog[2, *)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)], *)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]]]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)])\) - 12\ PolyLog[2, *)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)], *)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]]]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)])\))\)\ *)
(*\*SubscriptBox[\(X\), \(t\)]\))/(24 \[Pi]^4 (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)) (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)) (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)))-(\!\( *)
(*\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\ \(( *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SuperscriptBox[\((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\), \(2\)]\ \((4\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)] - 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + \((\(-8\)\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)] + 4\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + \((3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)])\) + \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((2\ \((1 + Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]])\)\ *)
(*\*SuperscriptBox[\(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ *)
(*\*SuperscriptBox[\((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\), \(2\)] + *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ \((2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\) + \((\(-4\)\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 6\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 4\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - 3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)])\) - Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 2\ \((3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 7\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\))\))\) + Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ \((Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ \((\(-2\)\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\) + 4\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SuperscriptBox[\(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 3\ *)
(*\*SuperscriptBox[\(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\), \(3\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ \((3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)] + 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 2\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)])\) - \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 2\ \((2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + 3\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 7\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\))\))\))\)\ *)
(*\*SubsuperscriptBox[\(X\), \(t\), \(2\)]\))/(16 \[Pi]^4 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\))^2 (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2 (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2)+(\!\( *)
(*\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\ *)
(*\*SubscriptBox[\(M\), \(3\)]\ \((\(-8\)\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] - 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] - *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 6\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 6\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 3\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 2\ PolyLog[2, *)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)], *)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]]]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 2\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\) + 2\ PolyLog[2, *)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)], *)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]]]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\)\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + 2\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\))\)\ *)
(*\*SubsuperscriptBox[\(X\), \(t\), \(3\)]\))/(8 \[Pi]^4 (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\))^3 (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)) (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)))+(\!\( *)
(*\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\ \((10\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] - 15\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] + 5\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] + 3\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] - *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)] - 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)] - 24\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)] + 10\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] + 3\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] - *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] - 15\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] + 5\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)] - 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 22\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 31\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 10\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 7\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 22\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 3\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 16\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 27\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 24\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 22\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 27\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 3\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 24\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 16\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 22\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 7\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 31\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 10\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)] + 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 5\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 5\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 24\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 24\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 44\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 20\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 24\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 64\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 64\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 38\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 19\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 38\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 38\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 19\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 24\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 24\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 44\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 24\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 20\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 8\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 6\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 5\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 5\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(4\)] + 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 18\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 29\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 8\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 9\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 10\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 18\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 7\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 10\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 13\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 22\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 12\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 18\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 13\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 12\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 7\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 22\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 10\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 18\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 9\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 29\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 10\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 8\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(10\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(6\)] - 4\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 14\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 7\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 10\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 10\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 20\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 16\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 8\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 14\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 12\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 4\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 7\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 10\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 10\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 4\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(8\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(8\)] + 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 2\ *)
(*\*SuperscriptBox[\(Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 4\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], \( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] + 2\ Log[*)
(*\*FractionBox[*)
(*SuperscriptBox[\(Q\), \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(6\)]\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(10\)] - 2\ PolyLog[2, *)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)], *)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SuperscriptBox[\((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\), \(2\)]\ *)
(*\*SuperscriptBox[\((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\), \(2\)]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 2\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\) + 2\ PolyLog[2, *)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)], *)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ *)
(*\*SuperscriptBox[\((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\), \(2\)]\ *)
(*\*SuperscriptBox[\((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\), \(2\)]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(4\)]\) + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(4\)] + 2\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\)\ *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\))\)\ *)
(*\*SubsuperscriptBox[\(X\), \(t\), \(4\)]\))/(32 \[Pi]^4 *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\))^4 (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2 (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\))^2)+(\!\( *)
(*\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\ *)
(*\*SubsuperscriptBox[\(g\), \(t\), \(4\)]\ \((\(-2\)\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)] + Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\) - Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)])\))\)\ *)
(*\*SubscriptBox[\(M\), \(3\)]\ \((Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\ \(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\) + Log[*)
(*\*FractionBox[*)
(*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*SubsuperscriptBox[\(M\), \(3\), \(2\)]]]\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\ \((\(-*)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\) + *)
(*\*SubsuperscriptBox[\(M\), \(3\), \(2\)])\))\)\ *)
(*\*SubsuperscriptBox[\(X\), \(t\), \(5\)]\))/(8 \[Pi]^4 (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\))^4 (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)) (-*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)]\)+*)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)))*)


(* ::Subsubsection::Closed:: *)
(*Two - Loop O(Subscript[\[Alpha], t] Subscript[\[Alpha], S])*)


(* ::Text:: *)
(*The complete analytical expression for the two-loop O(Subscript[\[Alpha], t] Subscript[\[Alpha], s]) correction in the *)
(*\!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme can be found in the definition of the function \[CapitalDelta]\[Lambda]2lstronggeneral[ ]. In the on-shell scheme one needs to add the shift contribution given in the function shiftDROS\[Alpha]t\[Alpha]Sgeneral[ ].*)


\[CapitalDelta]\[Lambda]2lstrong[mtilde_,mQ3_,mU3_,Xt_,M3_]:=Subscript[g, 3]^2 Subscript[g, t]^4 With[{\[Delta]=8 10^-2,\[Delta]2=1 10^-2},Piecewise[{{\[CapitalDelta]\[Lambda]2lstrongdegenerate[mtilde,mQ3,Xt],Abs[mQ3/mU3-1]<\[Delta]2&&Abs[M3/mU3-1]<\[Delta]2&&Abs[M3/mQ3-1]<\[Delta]2},{Re[\[CapitalDelta]\[Lambda]2lstronggeneral[1.mtilde,mU3(1+\[Delta]),mU3,Xt ,M3]] (mQ3-mU3(1-\[Delta]))/(2mU3 \[Delta])+Re[\[CapitalDelta]\[Lambda]2lstronggeneral[1.mtilde,mU3(1-\[Delta]),mU3,Xt ,M3]](1-(mQ3-mU3(1-\[Delta]))/(2 mU3 \[Delta])),Abs[mQ3/mU3-1]<= \[Delta]},
{Re[\[CapitalDelta]\[Lambda]2lstronggeneral[1.mtilde,mQ3,mU3,Xt ,mQ3(1+\[Delta])]] (M3-mQ3(1-\[Delta]))/(2mQ3 \[Delta])+Re[\[CapitalDelta]\[Lambda]2lstronggeneral[1.mtilde,mQ3,mU3,Xt ,mQ3(1-\[Delta])]](1-(M3-mQ3(1-\[Delta]))/(2mQ3 \[Delta])),Abs[mQ3/M3-1]<=\[Delta]},
{Re[\[CapitalDelta]\[Lambda]2lstronggeneral[1.mtilde,mQ3,mU3,Xt ,mU3(1+\[Delta])]] (M3-mU3(1-\[Delta]))/(2mU3 \[Delta])+Re[\[CapitalDelta]\[Lambda]2lstronggeneral[1.mtilde,mQ3,mU3,Xt ,mU3(1-\[Delta])]](1-(M3-mU3(1-\[Delta]))/(2mU3 \[Delta])),Abs[mU3/M3-1]<= \[Delta]}},Re[\[CapitalDelta]\[Lambda]2lstronggeneral[mtilde,1.mQ3,mU3,Xt ,M3]]]]
(*The two loop corrections has singularities for mQ3\[Rule]mU3, mU3\[Rule]M3 and mQ3\[Rule]mU3. We avoid evaluating the function at the singular points by using a linear interpolation near the singular point, i.e. for |x-Subscript[x, 0]|<\[Delta].*)


(* ::Input::Closed:: *)
(*(*commented:old definition*)*)


(* ::Input:: *)
(*(*\[CapitalDelta]\[Lambda]2lstrong[mtilde_,mQ3_,mU3_,Xt_,M3_]:=Subscript[g, 3]^2Subscript[g, t]^4Piecewise[{{\[CapitalDelta]\[Lambda]2lstrongdegenerate[mtilde,M3,Xt],Abs[mQ3/mU3-1]<3. 10^-2&&Abs[M3/mU3-1]<3. 10^-2&&Abs[M3/mQ3-1]<3. 10^-2},{Re[\[CapitalDelta]\[Lambda]2lstronggeneral[mtilde,1.01mQ3,mU3,Xt ,M3]],Abs[mQ3/mU3-1]< 10^-2},*)
(*{Re[\[CapitalDelta]\[Lambda]2lstronggeneral[mtilde,1.01mQ3,mU3,Xt ,M3]],Abs[mQ3/M3-1]< 10^-2},*)
(*{Re[\[CapitalDelta]\[Lambda]2lstronggeneral[mtilde,mQ3,1.01mU3,Xt ,M3]],Abs[mU3/M3-1]< 10^-2}},Re[\[CapitalDelta]\[Lambda]2lstronggeneral[mtilde,1.mQ3,mU3,Xt ,M3]]]*)*)


(* ::Input:: *)
(*(*\[CapitalDelta]\[Lambda]2lstrong[mtilde_,mQ3_,mU3_,Xt_,M3_]:=*)
(*Subscript[g, 3]^2Subscript[g, t]^4If[Abs[mQ3/mU3-1]<10^-2&&Abs[M3/mU3-1]<10^-2&&Abs[M3/mQ3-1]<10^-2,*)
(*\[CapitalDelta]\[Lambda]2lstrongdegenerate[mtilde,M3,Xt],*)
(*If[Abs[mQ3/mU3-1]<10^-2||Abs[M3/mU3-1]<10^-2||Abs[M3/mQ3-1]<10^-2,*)
(*	Re[\[CapitalDelta]\[Lambda]2lstronggeneral[1.013mtilde,mQ3,1.011mU3,Xt ,1.012M3]],*)
(*	Re[\[CapitalDelta]\[Lambda]2lstronggeneral[mtilde,1.mQ3,mU3,Xt ,M3]]]*)
(*]*)*)


(* ::Input:: *)
(*\[CapitalDelta]\[Lambda]2lstrongdegenerateaux/.{Xth->Xt/M3,g3->1,gt->1}*)


\[CapitalDelta]\[Lambda]2lstrongdegenerate[Q_,M3_,Xt_]:=1/(96 \[Pi]^4) (-(Xt^5/M3^5)+(Xt (-12-24 Log[Q^2/M3^2]))/M3+(Xt^4 (1/2-Log[Q^2/M3^2]))/M3^4-18 Log[Q^2/M3^2]^2+(Xt^3 (14+4 Log[Q^2/M3^2]))/M3^3+(Xt^2 (-6+24 Log[Q^2/M3^2]))/M3^2)


(* ::Input:: *)
(*\[CapitalDelta]\[Lambda]2lstrongaux/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt,*)
(*\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}/.{Subscript[g, 3]->1,Subscript[g, t]->1}*)


\[CapitalDelta]\[Lambda]2lstronggeneral[Q_,mQ3_,mU3_,Xt_,M3_]:=(M3 Xt^5 (mQ3^2 (M3^2-mU3^2) Log[mQ3^2/M3^2]+(-M3^2+mQ3^2) mU3^2 Log[mU3^2/M3^2]) (-2 mQ3^2+2 mU3^2+(mQ3^2+mU3^2) Log[mQ3^2/M3^2]-(mQ3^2+mU3^2) Log[mU3^2/M3^2]))/(8 (M3^2-mQ3^2) (M3^2-mU3^2) (mQ3^2-mU3^2)^4 \[Pi]^4)-(Xt^2 (mQ3^2 mU3^2 (M3^2-mU3^2)^2 (4 mQ3^6-2 mQ3^4 mU3^2+M3^4 (3 mQ3^2-mU3^2)+M3^2 (-8 mQ3^4+4 mQ3^2 mU3^2)) Log[mQ3^2/M3^2]^2+(M3^2-mQ3^2) (mQ3^2 mU3^2 (-M3^6 (mQ3^2-3 mU3^2)+2 mQ3^2 mU3^4 (mQ3^2-2 mU3^2)+M3^4 (mQ3^4+mQ3^2 mU3^2-8 mU3^4)+M3^2 (-4 mQ3^4 mU3^2+6 mQ3^2 mU3^4+4 mU3^6)) Log[mU3^2/M3^2]^2+2 M3^2 (M3^2-mQ3^2) (M3^2-mU3^2)^2 (mQ3^2-mU3^2)^2 (1+Log[Q^2/M3^2])-mQ3^2 mU3^2 (mQ3^2-mU3^2) (-M3^2+mU3^2) Log[mU3^2/M3^2] (7 M3^4+3 mQ3^2 mU3^2-2 M3^2 (3 mQ3^2+2 mU3^2)+6 (M3^2-mQ3^2) (M3^2-mU3^2) Log[Q^2/M3^2]))+mQ3^2 mU3^2 Log[mQ3^2/M3^2] ((-2 M3^8 (mQ3^2+mU3^2)-2 mQ3^4 mU3^4 (mQ3^2+mU3^2)+4 M3^2 mQ3^2 mU3^2 (mQ3^2+mU3^2)^2-3 M3^4 (mQ3^2+mU3^2)^3+2 M3^6 (3 mQ3^4+2 mQ3^2 mU3^2+3 mU3^4)) Log[mU3^2/M3^2]-(M3^2-mQ3^2) (M3^2-mU3^2) (mQ3^2-mU3^2) (7 M3^4+3 mQ3^2 mU3^2-2 M3^2 (2 mQ3^2+3 mU3^2)+6 (M3^2-mQ3^2) (M3^2-mU3^2) Log[Q^2/M3^2]))))/(16 mQ3^2 (M3^2-mQ3^2)^2 mU3^2 (M3^2-mU3^2)^2 (mQ3^2-mU3^2)^2 \[Pi]^4)+(M3 Xt (2 M3^2 mQ3^2 \[Pi]^2-2 M3^2 mU3^2 \[Pi]^2-6 M3^4 Log[mQ3^2/M3^2]+6 M3^2 mQ3^2 Log[mQ3^2/M3^2]+6 M3^2 mU3^2 Log[mQ3^2/M3^2]-6 mQ3^2 mU3^2 Log[mQ3^2/M3^2]+6 M3^4 Log[mQ3^2/M3^2]^2-3 M3^2 mQ3^2 Log[mQ3^2/M3^2]^2-6 M3^2 mU3^2 Log[mQ3^2/M3^2]^2+3 mQ3^2 mU3^2 Log[mQ3^2/M3^2]^2-12 M3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+12 M3^2 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+6 M3^4 Log[mU3^2/M3^2]-6 M3^2 mQ3^2 Log[mU3^2/M3^2]-6 M3^2 mU3^2 Log[mU3^2/M3^2]+6 mQ3^2 mU3^2 Log[mU3^2/M3^2]-3 M3^2 mQ3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+3 M3^2 mU3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-6 M3^4 Log[mU3^2/M3^2]^2+6 M3^2 mQ3^2 Log[mU3^2/M3^2]^2+3 M3^2 mU3^2 Log[mU3^2/M3^2]^2-3 mQ3^2 mU3^2 Log[mU3^2/M3^2]^2+12 M3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-12 M3^2 mQ3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-6 M3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+6 M3^2 mQ3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+6 M3^2 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-6 mQ3^2 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+6 M3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]-6 M3^2 mQ3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-6 M3^2 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]+6 mQ3^2 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-12 (M3^4-M3^2 mU3^2) PolyLog[2,M3^2/mQ3^2]+12 (M3^4-M3^2 mQ3^2) PolyLog[2,M3^2/mU3^2]))/(24 (M3^2-mQ3^2) (M3^2-mU3^2) (mQ3^2-mU3^2) \[Pi]^4)+(6 M3^10 mQ3^2-12 M3^8 mQ3^4+6 M3^6 mQ3^6+6 M3^10 mU3^2-39 M3^8 mQ3^2 mU3^2+57 M3^6 mQ3^4 mU3^2-24 M3^4 mQ3^6 mU3^2-12 M3^8 mU3^4+57 M3^6 mQ3^2 mU3^4-72 M3^4 mQ3^4 mU3^4+27 M3^2 mQ3^6 mU3^4+6 M3^6 mU3^6-24 M3^4 mQ3^2 mU3^6+27 M3^2 mQ3^4 mU3^6-9 mQ3^6 mU3^6-4 M3^8 mQ3^2 mU3^2 \[Pi]^2+4 M3^6 mQ3^4 mU3^2 \[Pi]^2-2 M3^4 mQ3^6 mU3^2 \[Pi]^2+4 M3^6 mQ3^2 mU3^4 \[Pi]^2-2 M3^4 mQ3^2 mU3^6 \[Pi]^2+21 M3^8 mQ3^2 mU3^2 Log[mQ3^2/M3^2]-21 M3^6 mQ3^4 mU3^2 Log[mQ3^2/M3^2]+9 M3^4 mQ3^6 mU3^2 Log[mQ3^2/M3^2]-39 M3^6 mQ3^2 mU3^4 Log[mQ3^2/M3^2]+36 M3^4 mQ3^4 mU3^4 Log[mQ3^2/M3^2]-15 M3^2 mQ3^6 mU3^4 Log[mQ3^2/M3^2]+18 M3^4 mQ3^2 mU3^6 Log[mQ3^2/M3^2]-15 M3^2 mQ3^4 mU3^6 Log[mQ3^2/M3^2]+6 mQ3^6 mU3^6 Log[mQ3^2/M3^2]-9 M3^8 mQ3^2 mU3^2 Log[mQ3^2/M3^2]^2+12 M3^6 mQ3^4 mU3^2 Log[mQ3^2/M3^2]^2-6 M3^4 mQ3^6 mU3^2 Log[mQ3^2/M3^2]^2+18 M3^6 mQ3^2 mU3^4 Log[mQ3^2/M3^2]^2-24 M3^4 mQ3^4 mU3^4 Log[mQ3^2/M3^2]^2+12 M3^2 mQ3^6 mU3^4 Log[mQ3^2/M3^2]^2-9 M3^4 mQ3^2 mU3^6 Log[mQ3^2/M3^2]^2+12 M3^2 mQ3^4 mU3^6 Log[mQ3^2/M3^2]^2-6 mQ3^6 mU3^6 Log[mQ3^2/M3^2]^2+12 M3^8 mQ3^2 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-24 M3^6 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+12 M3^4 mQ3^2 mU3^6 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+21 M3^8 mQ3^2 mU3^2 Log[mU3^2/M3^2]-39 M3^6 mQ3^4 mU3^2 Log[mU3^2/M3^2]+18 M3^4 mQ3^6 mU3^2 Log[mU3^2/M3^2]-21 M3^6 mQ3^2 mU3^4 Log[mU3^2/M3^2]+36 M3^4 mQ3^4 mU3^4 Log[mU3^2/M3^2]-15 M3^2 mQ3^6 mU3^4 Log[mU3^2/M3^2]+9 M3^4 mQ3^2 mU3^6 Log[mU3^2/M3^2]-15 M3^2 mQ3^4 mU3^6 Log[mU3^2/M3^2]+6 mQ3^6 mU3^6 Log[mU3^2/M3^2]+6 M3^6 mQ3^4 mU3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-3 M3^4 mQ3^6 mU3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+6 M3^6 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-24 M3^4 mQ3^4 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+12 M3^2 mQ3^6 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-3 M3^4 mQ3^2 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+12 M3^2 mQ3^4 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-6 mQ3^6 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-9 M3^8 mQ3^2 mU3^2 Log[mU3^2/M3^2]^2+18 M3^6 mQ3^4 mU3^2 Log[mU3^2/M3^2]^2-9 M3^4 mQ3^6 mU3^2 Log[mU3^2/M3^2]^2+12 M3^6 mQ3^2 mU3^4 Log[mU3^2/M3^2]^2-24 M3^4 mQ3^4 mU3^4 Log[mU3^2/M3^2]^2+12 M3^2 mQ3^6 mU3^4 Log[mU3^2/M3^2]^2-6 M3^4 mQ3^2 mU3^6 Log[mU3^2/M3^2]^2+12 M3^2 mQ3^4 mU3^6 Log[mU3^2/M3^2]^2-6 mQ3^6 mU3^6 Log[mU3^2/M3^2]^2+12 M3^8 mQ3^2 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-24 M3^6 mQ3^4 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+12 M3^4 mQ3^6 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+6 M3^10 mQ3^2 Log[Q^2/M3^2]-12 M3^8 mQ3^4 Log[Q^2/M3^2]+6 M3^6 mQ3^6 Log[Q^2/M3^2]+6 M3^10 mU3^2 Log[Q^2/M3^2]-36 M3^8 mQ3^2 mU3^2 Log[Q^2/M3^2]+54 M3^6 mQ3^4 mU3^2 Log[Q^2/M3^2]-24 M3^4 mQ3^6 mU3^2 Log[Q^2/M3^2]-12 M3^8 mU3^4 Log[Q^2/M3^2]+54 M3^6 mQ3^2 mU3^4 Log[Q^2/M3^2]-72 M3^4 mQ3^4 mU3^4 Log[Q^2/M3^2]+30 M3^2 mQ3^6 mU3^4 Log[Q^2/M3^2]+6 M3^6 mU3^6 Log[Q^2/M3^2]-24 M3^4 mQ3^2 mU3^6 Log[Q^2/M3^2]+30 M3^2 mQ3^4 mU3^6 Log[Q^2/M3^2]-12 mQ3^6 mU3^6 Log[Q^2/M3^2]+18 M3^8 mQ3^2 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-36 M3^6 mQ3^4 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+18 M3^4 mQ3^6 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-36 M3^6 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+72 M3^4 mQ3^4 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-36 M3^2 mQ3^6 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+18 M3^4 mQ3^2 mU3^6 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-36 M3^2 mQ3^4 mU3^6 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+18 mQ3^6 mU3^6 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+18 M3^8 mQ3^2 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-36 M3^6 mQ3^4 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]+18 M3^4 mQ3^6 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-36 M3^6 mQ3^2 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]+72 M3^4 mQ3^4 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]-36 M3^2 mQ3^6 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]+18 M3^4 mQ3^2 mU3^6 Log[mU3^2/M3^2] Log[Q^2/M3^2]-36 M3^2 mQ3^4 mU3^6 Log[mU3^2/M3^2] Log[Q^2/M3^2]+18 mQ3^6 mU3^6 Log[mU3^2/M3^2] Log[Q^2/M3^2]-18 M3^8 mQ3^2 mU3^2 Log[Q^2/M3^2]^2+36 M3^6 mQ3^4 mU3^2 Log[Q^2/M3^2]^2-18 M3^4 mQ3^6 mU3^2 Log[Q^2/M3^2]^2+36 M3^6 mQ3^2 mU3^4 Log[Q^2/M3^2]^2-72 M3^4 mQ3^4 mU3^4 Log[Q^2/M3^2]^2+36 M3^2 mQ3^6 mU3^4 Log[Q^2/M3^2]^2-18 M3^4 mQ3^2 mU3^6 Log[Q^2/M3^2]^2+36 M3^2 mQ3^4 mU3^6 Log[Q^2/M3^2]^2-18 mQ3^6 mU3^6 Log[Q^2/M3^2]^2+12 M3^4 mQ3^2 mU3^2 (M3^2-mU3^2)^2 PolyLog[2,M3^2/mQ3^2]+12 M3^4 mQ3^2 (M3^2-mQ3^2)^2 mU3^2 PolyLog[2,M3^2/mU3^2])/(96 mQ3^2 (M3^2-mQ3^2)^2 mU3^2 (M3^2-mU3^2)^2 \[Pi]^4)+(M3 Xt^3 (-8 M3^4 mQ3^2+8 M3^2 mQ3^4+8 M3^4 mU3^2-8 mQ3^4 mU3^2-8 M3^2 mU3^4+8 mQ3^2 mU3^4+6 M3^4 mQ3^2 Log[mQ3^2/M3^2]-6 M3^2 mQ3^4 Log[mQ3^2/M3^2]+2 M3^4 mU3^2 Log[mQ3^2/M3^2]-8 M3^2 mQ3^2 mU3^2 Log[mQ3^2/M3^2]+6 mQ3^4 mU3^2 Log[mQ3^2/M3^2]-2 M3^2 mU3^4 Log[mQ3^2/M3^2]+2 mQ3^2 mU3^4 Log[mQ3^2/M3^2]+2 M3^6 Log[mQ3^2/M3^2]^2-3 M3^4 mQ3^2 Log[mQ3^2/M3^2]^2-M3^2 mQ3^4 Log[mQ3^2/M3^2]^2-3 M3^4 mU3^2 Log[mQ3^2/M3^2]^2+6 M3^2 mQ3^2 mU3^2 Log[mQ3^2/M3^2]^2+mQ3^4 mU3^2 Log[mQ3^2/M3^2]^2+M3^2 mU3^4 Log[mQ3^2/M3^2]^2-3 mQ3^2 mU3^4 Log[mQ3^2/M3^2]^2-4 M3^6 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+6 M3^4 mQ3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-2 M3^2 mQ3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+6 M3^4 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-8 M3^2 mQ3^2 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+2 mQ3^4 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-2 M3^2 mU3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+2 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-2 M3^4 mQ3^2 Log[mU3^2/M3^2]+2 M3^2 mQ3^4 Log[mU3^2/M3^2]-6 M3^4 mU3^2 Log[mU3^2/M3^2]+8 M3^2 mQ3^2 mU3^2 Log[mU3^2/M3^2]-2 mQ3^4 mU3^2 Log[mU3^2/M3^2]+6 M3^2 mU3^4 Log[mU3^2/M3^2]-6 mQ3^2 mU3^4 Log[mU3^2/M3^2]+2 M3^2 mQ3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-4 mQ3^4 mU3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-2 M3^2 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+4 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-2 M3^6 Log[mU3^2/M3^2]^2+3 M3^4 mQ3^2 Log[mU3^2/M3^2]^2-M3^2 mQ3^4 Log[mU3^2/M3^2]^2+3 M3^4 mU3^2 Log[mU3^2/M3^2]^2-6 M3^2 mQ3^2 mU3^2 Log[mU3^2/M3^2]^2+3 mQ3^4 mU3^2 Log[mU3^2/M3^2]^2+M3^2 mU3^4 Log[mU3^2/M3^2]^2-mQ3^2 mU3^4 Log[mU3^2/M3^2]^2+4 M3^6 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-6 M3^4 mQ3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+2 M3^2 mQ3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-6 M3^4 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+8 M3^2 mQ3^2 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-2 mQ3^4 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+2 M3^2 mU3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-2 mQ3^2 mU3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-4 M3^4 mQ3^2 Log[Q^2/M3^2]+4 M3^2 mQ3^4 Log[Q^2/M3^2]+4 M3^4 mU3^2 Log[Q^2/M3^2]-4 mQ3^4 mU3^2 Log[Q^2/M3^2]-4 M3^2 mU3^4 Log[Q^2/M3^2]+4 mQ3^2 mU3^4 Log[Q^2/M3^2]+2 M3^4 mQ3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-2 M3^2 mQ3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+2 M3^4 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-4 M3^2 mQ3^2 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+2 mQ3^4 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-2 M3^2 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+2 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-2 M3^4 mQ3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]+2 M3^2 mQ3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]-2 M3^4 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]+4 M3^2 mQ3^2 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-2 mQ3^4 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]+2 M3^2 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]-2 mQ3^2 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]-2 (M3^2-mQ3^2) (M3^2-mU3^2) (2 M3^2-mQ3^2-mU3^2) PolyLog[2,M3^2/mQ3^2]+2 (M3^2-mQ3^2) (M3^2-mU3^2) (2 M3^2-mQ3^2-mU3^2) PolyLog[2,M3^2/mU3^2]))/(8 (M3^2-mQ3^2) (M3^2-mU3^2) (mQ3^2-mU3^2)^3 \[Pi]^4)+(Xt^4 (2 M3^10 mQ3^6-4 M3^8 mQ3^8+2 M3^6 mQ3^10-2 M3^10 mQ3^4 mU3^2+14 M3^8 mQ3^6 mU3^2-20 M3^6 mQ3^8 mU3^2+8 M3^4 mQ3^10 mU3^2-2 M3^10 mQ3^2 mU3^4-20 M3^8 mQ3^4 mU3^4+18 M3^6 mQ3^6 mU3^4+24 M3^4 mQ3^8 mU3^4-20 M3^2 mQ3^10 mU3^4+2 M3^10 mU3^6+14 M3^8 mQ3^2 mU3^6+18 M3^6 mQ3^4 mU3^6-64 M3^4 mQ3^6 mU3^6+20 M3^2 mQ3^8 mU3^6+10 mQ3^10 mU3^6-4 M3^8 mU3^8-20 M3^6 mQ3^2 mU3^8+24 M3^4 mQ3^4 mU3^8+20 M3^2 mQ3^6 mU3^8-20 mQ3^8 mU3^8+2 M3^6 mU3^10+8 M3^4 mQ3^2 mU3^10-20 M3^2 mQ3^4 mU3^10+10 mQ3^6 mU3^10-4 M3^10 mQ3^4 mU3^2 Log[mQ3^2/M3^2]-7 M3^8 mQ3^6 mU3^2 Log[mQ3^2/M3^2]+29 M3^6 mQ3^8 mU3^2 Log[mQ3^2/M3^2]-16 M3^4 mQ3^10 mU3^2 Log[mQ3^2/M3^2]+4 M3^10 mQ3^2 mU3^4 Log[mQ3^2/M3^2]+8 M3^8 mQ3^4 mU3^4 Log[mQ3^2/M3^2]-7 M3^6 mQ3^6 mU3^4 Log[mQ3^2/M3^2]-44 M3^4 mQ3^8 mU3^4 Log[mQ3^2/M3^2]+31 M3^2 mQ3^10 mU3^4 Log[mQ3^2/M3^2]-M3^8 mQ3^2 mU3^6 Log[mQ3^2/M3^2]-13 M3^6 mQ3^4 mU3^6 Log[mQ3^2/M3^2]+38 M3^4 mQ3^6 mU3^6 Log[mQ3^2/M3^2]+3 M3^2 mQ3^8 mU3^6 Log[mQ3^2/M3^2]-15 mQ3^10 mU3^6 Log[mQ3^2/M3^2]-9 M3^6 mQ3^2 mU3^8 Log[mQ3^2/M3^2]+16 M3^4 mQ3^4 mU3^8 Log[mQ3^2/M3^2]-27 M3^2 mQ3^6 mU3^8 Log[mQ3^2/M3^2]+12 mQ3^8 mU3^8 Log[mQ3^2/M3^2]+6 M3^4 mQ3^2 mU3^10 Log[mQ3^2/M3^2]-7 M3^2 mQ3^4 mU3^10 Log[mQ3^2/M3^2]+3 mQ3^6 mU3^10 Log[mQ3^2/M3^2]+2 M3^10 mQ3^4 mU3^2 Log[mQ3^2/M3^2]^2-8 M3^6 mQ3^8 mU3^2 Log[mQ3^2/M3^2]^2+5 M3^4 mQ3^10 mU3^2 Log[mQ3^2/M3^2]^2-2 M3^10 mQ3^2 mU3^4 Log[mQ3^2/M3^2]^2+4 M3^8 mQ3^4 mU3^4 Log[mQ3^2/M3^2]^2-10 M3^6 mQ3^6 mU3^4 Log[mQ3^2/M3^2]^2+20 M3^4 mQ3^8 mU3^4 Log[mQ3^2/M3^2]^2-10 M3^2 mQ3^10 mU3^4 Log[mQ3^2/M3^2]^2+4 M3^8 mQ3^2 mU3^6 Log[mQ3^2/M3^2]^2-12 M3^6 mQ3^4 mU3^6 Log[mQ3^2/M3^2]^2+19 M3^4 mQ3^6 mU3^6 Log[mQ3^2/M3^2]^2-16 M3^2 mQ3^8 mU3^6 Log[mQ3^2/M3^2]^2+5 mQ3^10 mU3^6 Log[mQ3^2/M3^2]^2-2 M3^6 mQ3^2 mU3^8 Log[mQ3^2/M3^2]^2+4 M3^4 mQ3^4 mU3^8 Log[mQ3^2/M3^2]^2-8 M3^2 mQ3^6 mU3^8 Log[mQ3^2/M3^2]^2+4 mQ3^8 mU3^8 Log[mQ3^2/M3^2]^2+2 M3^2 mQ3^4 mU3^10 Log[mQ3^2/M3^2]^2-mQ3^6 mU3^10 Log[mQ3^2/M3^2]^2-4 M3^10 mQ3^4 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+10 M3^8 mQ3^6 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-8 M3^6 mQ3^8 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+2 M3^4 mQ3^10 mU3^2 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+4 M3^10 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-16 M3^6 mQ3^6 mU3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+16 M3^4 mQ3^8 mU3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-4 M3^2 mQ3^10 mU3^4 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-10 M3^8 mQ3^2 mU3^6 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+16 M3^6 mQ3^4 mU3^6 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-8 M3^2 mQ3^8 mU3^6 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+2 mQ3^10 mU3^6 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+8 M3^6 mQ3^2 mU3^8 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-16 M3^4 mQ3^4 mU3^8 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+8 M3^2 mQ3^6 mU3^8 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-2 M3^4 mQ3^2 mU3^10 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+4 M3^2 mQ3^4 mU3^10 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]-2 mQ3^6 mU3^10 Log[mQ3^2/M3^2] Log[mQ3^2/(-M3^2+mQ3^2)]+4 M3^10 mQ3^4 mU3^2 Log[mU3^2/M3^2]-M3^8 mQ3^6 mU3^2 Log[mU3^2/M3^2]-9 M3^6 mQ3^8 mU3^2 Log[mU3^2/M3^2]+6 M3^4 mQ3^10 mU3^2 Log[mU3^2/M3^2]-4 M3^10 mQ3^2 mU3^4 Log[mU3^2/M3^2]+8 M3^8 mQ3^4 mU3^4 Log[mU3^2/M3^2]-13 M3^6 mQ3^6 mU3^4 Log[mU3^2/M3^2]+16 M3^4 mQ3^8 mU3^4 Log[mU3^2/M3^2]-7 M3^2 mQ3^10 mU3^4 Log[mU3^2/M3^2]-7 M3^8 mQ3^2 mU3^6 Log[mU3^2/M3^2]-7 M3^6 mQ3^4 mU3^6 Log[mU3^2/M3^2]+38 M3^4 mQ3^6 mU3^6 Log[mU3^2/M3^2]-27 M3^2 mQ3^8 mU3^6 Log[mU3^2/M3^2]+3 mQ3^10 mU3^6 Log[mU3^2/M3^2]+29 M3^6 mQ3^2 mU3^8 Log[mU3^2/M3^2]-44 M3^4 mQ3^4 mU3^8 Log[mU3^2/M3^2]+3 M3^2 mQ3^6 mU3^8 Log[mU3^2/M3^2]+12 mQ3^8 mU3^8 Log[mU3^2/M3^2]-16 M3^4 mQ3^2 mU3^10 Log[mU3^2/M3^2]+31 M3^2 mQ3^4 mU3^10 Log[mU3^2/M3^2]-15 mQ3^6 mU3^10 Log[mU3^2/M3^2]-4 M3^8 mQ3^6 mU3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+10 M3^6 mQ3^8 mU3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-5 M3^4 mQ3^10 mU3^2 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-8 M3^8 mQ3^4 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+22 M3^6 mQ3^6 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-24 M3^4 mQ3^8 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+8 M3^2 mQ3^10 mU3^4 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-4 M3^8 mQ3^2 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+22 M3^6 mQ3^4 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-38 M3^4 mQ3^6 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+24 M3^2 mQ3^8 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-4 mQ3^10 mU3^6 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+10 M3^6 mQ3^2 mU3^8 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-24 M3^4 mQ3^4 mU3^8 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+24 M3^2 mQ3^6 mU3^8 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-8 mQ3^8 mU3^8 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-5 M3^4 mQ3^2 mU3^10 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]+8 M3^2 mQ3^4 mU3^10 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-4 mQ3^6 mU3^10 Log[mQ3^2/M3^2] Log[mU3^2/M3^2]-2 M3^10 mQ3^4 mU3^2 Log[mU3^2/M3^2]^2+4 M3^8 mQ3^6 mU3^2 Log[mU3^2/M3^2]^2-2 M3^6 mQ3^8 mU3^2 Log[mU3^2/M3^2]^2+2 M3^10 mQ3^2 mU3^4 Log[mU3^2/M3^2]^2+4 M3^8 mQ3^4 mU3^4 Log[mU3^2/M3^2]^2-12 M3^6 mQ3^6 mU3^4 Log[mU3^2/M3^2]^2+4 M3^4 mQ3^8 mU3^4 Log[mU3^2/M3^2]^2+2 M3^2 mQ3^10 mU3^4 Log[mU3^2/M3^2]^2-10 M3^6 mQ3^4 mU3^6 Log[mU3^2/M3^2]^2+19 M3^4 mQ3^6 mU3^6 Log[mU3^2/M3^2]^2-8 M3^2 mQ3^8 mU3^6 Log[mU3^2/M3^2]^2-mQ3^10 mU3^6 Log[mU3^2/M3^2]^2-8 M3^6 mQ3^2 mU3^8 Log[mU3^2/M3^2]^2+20 M3^4 mQ3^4 mU3^8 Log[mU3^2/M3^2]^2-16 M3^2 mQ3^6 mU3^8 Log[mU3^2/M3^2]^2+4 mQ3^8 mU3^8 Log[mU3^2/M3^2]^2+5 M3^4 mQ3^2 mU3^10 Log[mU3^2/M3^2]^2-10 M3^2 mQ3^4 mU3^10 Log[mU3^2/M3^2]^2+5 mQ3^6 mU3^10 Log[mU3^2/M3^2]^2+4 M3^10 mQ3^4 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-10 M3^8 mQ3^6 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+8 M3^6 mQ3^8 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-2 M3^4 mQ3^10 mU3^2 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-4 M3^10 mQ3^2 mU3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+16 M3^6 mQ3^6 mU3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-16 M3^4 mQ3^8 mU3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+4 M3^2 mQ3^10 mU3^4 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+10 M3^8 mQ3^2 mU3^6 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-16 M3^6 mQ3^4 mU3^6 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+8 M3^2 mQ3^8 mU3^6 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-2 mQ3^10 mU3^6 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-8 M3^6 mQ3^2 mU3^8 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+16 M3^4 mQ3^4 mU3^8 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-8 M3^2 mQ3^6 mU3^8 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+2 M3^4 mQ3^2 mU3^10 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]-4 M3^2 mQ3^4 mU3^10 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+2 mQ3^6 mU3^10 Log[mU3^2/M3^2] Log[mU3^2/(-M3^2+mU3^2)]+2 M3^10 mQ3^6 Log[Q^2/M3^2]-4 M3^8 mQ3^8 Log[Q^2/M3^2]+2 M3^6 mQ3^10 Log[Q^2/M3^2]-2 M3^10 mQ3^4 mU3^2 Log[Q^2/M3^2]+12 M3^8 mQ3^6 mU3^2 Log[Q^2/M3^2]-18 M3^6 mQ3^8 mU3^2 Log[Q^2/M3^2]+8 M3^4 mQ3^10 mU3^2 Log[Q^2/M3^2]-2 M3^10 mQ3^2 mU3^4 Log[Q^2/M3^2]-16 M3^8 mQ3^4 mU3^4 Log[Q^2/M3^2]+16 M3^6 mQ3^6 mU3^4 Log[Q^2/M3^2]+24 M3^4 mQ3^8 mU3^4 Log[Q^2/M3^2]-22 M3^2 mQ3^10 mU3^4 Log[Q^2/M3^2]+2 M3^10 mU3^6 Log[Q^2/M3^2]+12 M3^8 mQ3^2 mU3^6 Log[Q^2/M3^2]+16 M3^6 mQ3^4 mU3^6 Log[Q^2/M3^2]-64 M3^4 mQ3^6 mU3^6 Log[Q^2/M3^2]+22 M3^2 mQ3^8 mU3^6 Log[Q^2/M3^2]+12 mQ3^10 mU3^6 Log[Q^2/M3^2]-4 M3^8 mU3^8 Log[Q^2/M3^2]-18 M3^6 mQ3^2 mU3^8 Log[Q^2/M3^2]+24 M3^4 mQ3^4 mU3^8 Log[Q^2/M3^2]+22 M3^2 mQ3^6 mU3^8 Log[Q^2/M3^2]-24 mQ3^8 mU3^8 Log[Q^2/M3^2]+2 M3^6 mU3^10 Log[Q^2/M3^2]+8 M3^4 mQ3^2 mU3^10 Log[Q^2/M3^2]-22 M3^2 mQ3^4 mU3^10 Log[Q^2/M3^2]+12 mQ3^6 mU3^10 Log[Q^2/M3^2]-4 M3^10 mQ3^4 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+2 M3^8 mQ3^6 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+8 M3^6 mQ3^8 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-6 M3^4 mQ3^10 mU3^2 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+4 M3^10 mQ3^2 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-16 M3^4 mQ3^8 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+12 M3^2 mQ3^10 mU3^4 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-2 M3^8 mQ3^2 mU3^6 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+8 M3^2 mQ3^8 mU3^6 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-6 mQ3^10 mU3^6 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-8 M3^6 mQ3^2 mU3^8 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+16 M3^4 mQ3^4 mU3^8 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-8 M3^2 mQ3^6 mU3^8 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+6 M3^4 mQ3^2 mU3^10 Log[mQ3^2/M3^2] Log[Q^2/M3^2]-12 M3^2 mQ3^4 mU3^10 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+6 mQ3^6 mU3^10 Log[mQ3^2/M3^2] Log[Q^2/M3^2]+4 M3^10 mQ3^4 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-2 M3^8 mQ3^6 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-8 M3^6 mQ3^8 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]+6 M3^4 mQ3^10 mU3^2 Log[mU3^2/M3^2] Log[Q^2/M3^2]-4 M3^10 mQ3^2 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]+16 M3^4 mQ3^8 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]-12 M3^2 mQ3^10 mU3^4 Log[mU3^2/M3^2] Log[Q^2/M3^2]+2 M3^8 mQ3^2 mU3^6 Log[mU3^2/M3^2] Log[Q^2/M3^2]-8 M3^2 mQ3^8 mU3^6 Log[mU3^2/M3^2] Log[Q^2/M3^2]+6 mQ3^10 mU3^6 Log[mU3^2/M3^2] Log[Q^2/M3^2]+8 M3^6 mQ3^2 mU3^8 Log[mU3^2/M3^2] Log[Q^2/M3^2]-16 M3^4 mQ3^4 mU3^8 Log[mU3^2/M3^2] Log[Q^2/M3^2]+8 M3^2 mQ3^6 mU3^8 Log[mU3^2/M3^2] Log[Q^2/M3^2]-6 M3^4 mQ3^2 mU3^10 Log[mU3^2/M3^2] Log[Q^2/M3^2]+12 M3^2 mQ3^4 mU3^10 Log[mU3^2/M3^2] Log[Q^2/M3^2]-6 mQ3^6 mU3^10 Log[mU3^2/M3^2] Log[Q^2/M3^2]-2 mQ3^2 (M3^2-mQ3^2)^2 mU3^2 (M3^2-mU3^2)^2 (-mQ3^4+mU3^4+2 M3^2 (mQ3^2-mU3^2)) PolyLog[2,M3^2/mQ3^2]+2 mQ3^2 (M3^2-mQ3^2)^2 mU3^2 (M3^2-mU3^2)^2 (-mQ3^4+mU3^4+2 M3^2 (mQ3^2-mU3^2)) PolyLog[2,M3^2/mU3^2]))/(32 mQ3^2 (M3^2-mQ3^2)^2 mU3^2 (M3^2-mU3^2)^2 (mQ3^2-mU3^2)^4 \[Pi]^4)


(* ::Input:: *)
(*(*Shift DR to OS*)*)


(*sing[f_,x_,x0_,\[Delta]_]:={f[x0(1+\[Delta])](x-x0(1-\[Delta]))/(2x0 \[Delta])+f[x0(1-\[Delta])](1-1/(2x0 \[Delta])(x-x0(1-\[Delta]))),Abs[x/x0-1]<\[Delta]}*)
shiftDROS\[Alpha]t\[Alpha]S[mtilde_,mQ3_,mU3_,Xt_,M3_]:=Subscript[g, 3]^2 Subscript[g, t]^4 With[{\[Delta]=8.5 10^-2,\[Delta]2=1 10^-2},Piecewise[{{shiftDROS\[Alpha]t\[Alpha]Sdegenerate[mtilde,mQ3,Xt],Abs[mQ3/mU3-1]<\[Delta]2&&Abs[M3/mU3-1]<\[Delta]2&&Abs[M3/mQ3-1]<\[Delta]2},{Re[shiftDROS\[Alpha]t\[Alpha]Sgeneral[1.mtilde,mU3(1+\[Delta]),mU3,Xt ,M3]] (mQ3-mU3(1-\[Delta]))/(2mU3 \[Delta])+Re[shiftDROS\[Alpha]t\[Alpha]Sgeneral[1.mtilde,mU3(1-\[Delta]),mU3,Xt ,M3]](1-(mQ3-mU3(1-\[Delta]))/(2 mU3 \[Delta])),Abs[mQ3/mU3-1]< \[Delta]},
{Re[shiftDROS\[Alpha]t\[Alpha]Sgeneral[1.mtilde,mQ3,mU3,Xt ,mQ3(1+\[Delta])]] (M3-mQ3(1-\[Delta]))/(2mQ3 \[Delta])+Re[shiftDROS\[Alpha]t\[Alpha]Sgeneral[1.mtilde,mQ3,mU3,Xt ,mQ3(1-\[Delta])]](1-(M3-mQ3(1-\[Delta]))/(2mQ3 \[Delta])),Abs[mQ3/M3-1]<\[Delta]},
{Re[shiftDROS\[Alpha]t\[Alpha]Sgeneral[1.mtilde,mQ3,mU3,Xt ,mU3(1+\[Delta])]] (M3-mU3(1-\[Delta]))/(2mU3 \[Delta])+Re[shiftDROS\[Alpha]t\[Alpha]Sgeneral[1.mtilde,mQ3,mU3,Xt ,mU3(1-\[Delta])]](1-(M3-mU3(1-\[Delta]))/(2mU3 \[Delta])),Abs[mU3/M3-1]< \[Delta]}},Re[shiftDROS\[Alpha]t\[Alpha]Sgeneral[mtilde,1.mQ3,mU3,Xt ,M3]]]]


shiftDROS\[Alpha]t\[Alpha]Sgeneral[mtilde_,mQ3_,mU3_,QXt_,M3_]:=Re@ Block[{x1=(mQ3)^2/M3^2,x2=(mU3)^2/M3^2,xt=QXt/M3,xs=mtilde^2/M3^2},1/(64 \[Pi]^4) (-((2 ((-1+x1)^2 Log[1-x1]+x1 (3+x1-(-2+x1) Log[x1]+2 Log[xs/x1])))/x1^2)-(2 ((-1+x2)^2 Log[1-x2]+x2 (3+x2-(-2+x2) Log[x2]+2 Log[xs/x2])))/x2^2+1/(x1^2 x2^2) xt (1/(x1-x2)^3 x1^2 x2^2 (2 (x1-x2) xt^2+(2 x1^2+x2 (2 x2-xt^2)-x1 (4 x2+xt^2)) Log[x1/x2]) (-((4 xt^2 (x1 (-1+x2) Log[x1]-(-1+x1) x2 Log[x2]))/((-1+x1) (x1-x2) (-1+x2)))+1/(x1-x2) xt (-7 x1+x1/(-1+x1)+x1/(-1+x2)+7 x2+x2/(1-x1)+x2/(1-x2)-(4 (-1+x1)^2 Log[1-x1])/x1+((-x1+x2) Log[x1])/(-1+x1)^2-8 Log[1-x2]+(4 Log[1-x2])/x2+4 x2 Log[1-x2]-(x1 Log[x2])/(-1+x2)^2+(x2 Log[x2])/(-1+x2)^2+9 x1 Log[x1/xs]-x2 Log[x1/xs]+x1 Log[x2/xs]-9 x2 Log[x2/xs]+4 x1 Log[xs]-4 x2 Log[xs])-(4 ((-1+x1) x2 Log[1-x1]+x1 ((-1+x2) Log[1-x2]-2 x2 (2+Log[xs]))))/(x1 x2)+(xt ((-1+x1)^2 Log[1-x1]+x1 (3+x1-(-2+x1) Log[x1]+2 Log[xs/x1])))/x1^2+(xt ((-1+x2)^2 Log[1-x2]+x2 (3+x2-(-2+x2) Log[x2]+2 Log[xs/x2])))/x2^2)+xt (1/(x1-x2)^2 2 (-2 x1+2 x2+(x1+x2) Log[x1/x2]) ((-1+x1)^2 x2^2 Log[1-x1]-x1 ((-2+x1) x2^2 Log[x1]+x1 (-1+x2)^2 Log[1-x2]+x2 (3 x1-3 x2-x1 (-2+x2) Log[x2]-2 x2 Log[xs/x1]+2 x1 Log[xs/x2])))+x1^2 xt (1/(x1^2 (x1-x2)^3) 2 xt (-x1+x2+x1 Log[x1/x2]) ((-1+x1)^2 x2^2 Log[1-x1]-x1 ((-2+x1) x2^2 Log[x1]+x1 (-1+x2)^2 Log[1-x2]+x2 (3 x1-3 x2-x1 (-2+x2) Log[x2]-2 x2 Log[xs/x1]+2 x1 Log[xs/x2])))-1/((-1+x1/x2)^4 x2) (-2 x1+2 x2+(x1+x2) Log[x1/x2]) ((-1+x1/x2) (-((4 xt^2 (x1 (-1+x2) Log[x1]-(-1+x1) x2 Log[x2]))/((-1+x1) (x1-x2) (-1+x2)))+1/(x1-x2) xt (-7 x1+x1/(-1+x1)+x1/(-1+x2)+7 x2+x2/(1-x1)+x2/(1-x2)-(4 (-1+x1)^2 Log[1-x1])/x1+((-x1+x2) Log[x1])/(-1+x1)^2-8 Log[1-x2]+(4 Log[1-x2])/x2+4 x2 Log[1-x2]-(x1 Log[x2])/(-1+x2)^2+(x2 Log[x2])/(-1+x2)^2+9 x1 Log[x1/xs]-x2 Log[x1/xs]+x1 Log[x2/xs]-9 x2 Log[x2/xs]+4 x1 Log[xs]-4 x2 Log[xs])-(4 ((-1+x1) x2 Log[1-x1]+x1 ((-1+x2) Log[1-x2]-2 x2 (2+Log[xs]))))/(x1 x2)-(xt ((-1+x1)^2 Log[1-x1]+x1 (3+x1-(-2+x1) Log[x1]+2 Log[xs/x1])))/x1^2+(3 xt ((-1+x2)^2 Log[1-x2]+x2 (3+x2-(-2+x2) Log[x2]+2 Log[xs/x2])))/x2^2)+1/(x1 x2^3) 6 xt ((-1+x1)^2 x2^2 Log[1-x1]-x1 ((-2+x1) x2^2 Log[x1]+x1 (-1+x2)^2 Log[1-x2]+x2 (3 x1-3 x2-x1 (-2+x2) Log[x2]-2 x2 Log[xs/x1]+2 x1 Log[xs/x2]))))))))];
shiftDROS\[Alpha]t\[Alpha]Sdegenerate[mtilde_,M3_,Xt_]:=Re@ Block[{xt=Xt/M3,xs=mtilde^2/M3^2},((2+xt)^2 (-6+18 xt-9 xt^2+xt^3)+(-12+24 xt-6 xt^2-4 xt^3+xt^4) Log[xs])/(96 \[Pi]^4)];


(* ::Subsubsection::Closed:: *)
(*Two - Loop O((Subscript[\[Alpha], t]^2))*)


(* ::Text:: *)
(*The analytical expression for the two-loop O(Subscript[\[Alpha], t] Subscript[\[Alpha], s]) correction for degenerate scalars in the *)
(*\!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme can be found in the definition of the function \[CapitalDelta]\[Lambda]2lalphat2[]. In the on-shell scheme one needs to add the shift contribution given in the function shiftDROS\[Alpha]t2[ ].*)


(* ::Text::Closed:: *)
(*Auxiliar*)


(* ::Input:: *)
(*\[CapitalDelta]\[Lambda]2lalphat2aux:=(3 ht^6 Sin[\[Beta]]^4)/(4\[Pi])^4 (1/2+6 \[Mu]h^2-(13 Cos[\[Beta]]^2)/2+60 K Cos[\[Beta]]^2+\[Pi]^2 Cos[\[Beta]]^2-8 f1[\[Mu]h]-2 \[Mu]h^2 f1[\[Mu]h]+3 \[Mu]h^2 f2[\[Mu]h]+4 f3[\[Mu]h]+Xth^6 (-(1/2)+Cos[\[Beta]]^2 (1/2-1/2 Log[mst^2/Q^2])+1/2 Log[mst^2/Q^2])-4 Log[mst^2/Q^2]-6 \[Mu]h^2 Log[mst^2/Q^2]+13 Cos[\[Beta]]^2 Log[mst^2/Q^2]+3 Log[mst^2/Q^2]^2-3 Cos[\[Beta]]^2 Log[mst^2/Q^2]^2+Xth^3 Yth (4 Cos[\[Beta]]^2+16 K Cos[\[Beta]]^2-2 Cos[\[Beta]]^2 Log[mst^2/Q^2])+Yth^2 (-3 Cos[\[Beta]]^2-16 K Cos[\[Beta]]^2+3 Cos[\[Beta]]^2 Log[mst^2/Q^2])+Xth Yth (-12 Cos[\[Beta]]^2-64 K Cos[\[Beta]]^2+12 Cos[\[Beta]]^2 Log[mst^2/Q^2])+Xth^2 (-7-6 \[Mu]h^2+15 Cos[\[Beta]]^2-24 K Cos[\[Beta]]^2+4 f1[\[Mu]h]-6 \[Mu]h^2 f1[\[Mu]h]-4 f2[\[Mu]h]-6 \[Mu]h^2 f2[\[Mu]h]+27 Log[mst^2/Q^2]+6 \[Mu]h^2 Log[mst^2/Q^2]-24 Cos[\[Beta]]^2 Log[mst^2/Q^2]+Yth^2 ((14 Cos[\[Beta]]^2)/3+24 K Cos[\[Beta]]^2-3 Cos[\[Beta]]^2 Log[mst^2/Q^2]))+Xth^4 (11/2+\[Mu]h^2-(25 Cos[\[Beta]]^2)/4-f1[\[Mu]h]/2+\[Mu]h^2 f1[\[Mu]h]+f2[\[Mu]h]/2+1/2 \[Mu]h^2 f2[\[Mu]h]-13/2 Log[mst^2/Q^2]-\[Mu]h^2 Log[mst^2/Q^2]+6 Cos[\[Beta]]^2 Log[mst^2/Q^2]+Yth^2 (-(19/12) Cos[\[Beta]]^2-8 K Cos[\[Beta]]^2+1/2 Cos[\[Beta]]^2 Log[mst^2/Q^2])));*)
(*\[CapitalDelta]\[Lambda]2lalphat2aux/.Log[1-\[Mu]h^2]->log[1-\[Mu]h^2]/.{\[Mu]h->\[Mu]/mst,Xth->Xt/mst,Yth->Xt/mst+(2\[Mu])/(mst Sin[2\[Beta]]),ht->Subscript[g, t]/Sin[\[Beta]]}/.{\[Beta]->ArcTan[tan\[Beta]]}*)


Module[{f1,f2,f3,\[Kappa]=1/(4\[Pi])^2,K=-0.1953256,\[Delta]=10^-5},
f1[\[Mu]_]:=Piecewise[{{-1,Abs[\[Mu]^2-1]<\[Delta]}},\[Mu]^2/(1-\[Mu]^2) Log[\[Mu]^2]];
f2[\[Mu]_]:=Piecewise[{{1/2,Abs[\[Mu]^2-1]<\[Delta]}},1/(1-\[Mu]^2) (1+\[Mu]^2/(1-\[Mu]^2) Log[\[Mu]^2])];
f3[\[Mu]_]:=Piecewise[{{-9/4,Abs[\[Mu]^2-1]<\[Delta]}},Re[(-1+2\[Mu]^2+2\[Mu]^4)/(1-\[Mu]^2)^2 (Log[\[Mu]^2]Log[1-\[Mu]^2]+PolyLog[2,\[Mu]^2]-\[Pi]^2/6-\[Mu]^2 Log[\[Mu]^2])]];
\[CapitalDelta]\[Lambda]2lalphat2[Q_,mst_,\[Mu]_,tan\[Beta]_,Xt_]:= \!\(
\*SubsuperscriptBox[\(g\), \(t\), \(6\)] 
\*FractionBox[\(1\), \(256\ 
\*SuperscriptBox[\(\[Pi]\), \(4\)]\ 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] 3\ \((1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)])\)\ \((
\*FractionBox[\(1\), \(2\)] - 
\*FractionBox[\(13\), \(2\ \((1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)])\)\)] + 
\*FractionBox[\(60\ K\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[
SuperscriptBox[\(\[Pi]\), \(2\)], \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(6\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\), 
SuperscriptBox[\(mst\), \(2\)]] - 8\ f1[
\*FractionBox[\(\[Mu]\), \(mst\)]] - 
\*FractionBox[\(2\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ f1[
\*FractionBox[\(\[Mu]\), \(mst\)]]\), 
SuperscriptBox[\(mst\), \(2\)]] + 
\*FractionBox[\(3\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ f2[
\*FractionBox[\(\[Mu]\), \(mst\)]]\), 
SuperscriptBox[\(mst\), \(2\)]] + 4\ f3[
\*FractionBox[\(\[Mu]\), \(mst\)]] + 
\*FractionBox[\(
\*SuperscriptBox[\(Xt\), \(6\)]\ \((\(-
\*FractionBox[\(1\), \(2\)]\) + 
\*FractionBox[\(
\*FractionBox[\(1\), \(2\)] - 
\*FractionBox[\(1\), \(2\)]\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(1\), \(2\)]\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]])\)\), 
SuperscriptBox[\(mst\), \(6\)]] - 4\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]] + 
\*FractionBox[\(13\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] - 
\*FractionBox[\(6\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), 
SuperscriptBox[\(mst\), \(2\)]] + 3\ 
\*SuperscriptBox[\(Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(2\)] - 
\*FractionBox[\(3\ 
\*SuperscriptBox[\(Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(2\)]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(1\), 
SuperscriptBox[\(mst\), \(3\)]] \(
\*SuperscriptBox[\(Xt\), \(3\)]\ \((
\*FractionBox[\(Xt\), \(mst\)] + 
\*FractionBox[\(2\ \[Mu]\ Csc[2\ ArcTan[tan\[Beta]]]\), \(mst\)])\)\ \((
\*FractionBox[\(4\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(16\ K\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] - 
\*FractionBox[\(2\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)])\)\) + 
\*SuperscriptBox[\((
\*FractionBox[\(Xt\), \(mst\)] + 
\*FractionBox[\(2\ \[Mu]\ Csc[2\ ArcTan[tan\[Beta]]]\), \(mst\)])\), \(2\)]\ \((\(-
\*FractionBox[\(3\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)]\) - 
\*FractionBox[\(16\ K\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(3\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)])\) + 
\*FractionBox[\(1\), \(mst\)] \(Xt\ \((
\*FractionBox[\(Xt\), \(mst\)] + 
\*FractionBox[\(2\ \[Mu]\ Csc[2\ ArcTan[tan\[Beta]]]\), \(mst\)])\)\ \((\(-
\*FractionBox[\(12\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)]\) - 
\*FractionBox[\(64\ K\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(12\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)])\)\) + 
\*FractionBox[\(1\), 
SuperscriptBox[\(mst\), \(2\)]] 
\*SuperscriptBox[\(Xt\), \(2\)]\ \((\(-7\) + 
\*FractionBox[\(15\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] - 
\*FractionBox[\(24\ K\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] - 
\*FractionBox[\(6\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\), 
SuperscriptBox[\(mst\), \(2\)]] + 4\ f1[
\*FractionBox[\(\[Mu]\), \(mst\)]] - 
\*FractionBox[\(6\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ f1[
\*FractionBox[\(\[Mu]\), \(mst\)]]\), 
SuperscriptBox[\(mst\), \(2\)]] - 4\ f2[
\*FractionBox[\(\[Mu]\), \(mst\)]] - 
\*FractionBox[\(6\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ f2[
\*FractionBox[\(\[Mu]\), \(mst\)]]\), 
SuperscriptBox[\(mst\), \(2\)]] + 27\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]] - 
\*FractionBox[\(24\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(6\ 
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), 
SuperscriptBox[\(mst\), \(2\)]] + 
\*SuperscriptBox[\((
\*FractionBox[\(Xt\), \(mst\)] + 
\*FractionBox[\(2\ \[Mu]\ Csc[2\ ArcTan[tan\[Beta]]]\), \(mst\)])\), \(2\)]\ \((
\*FractionBox[\(14\), \(3\ \((1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)])\)\)] + 
\*FractionBox[\(24\ K\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] - 
\*FractionBox[\(3\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)])\))\) + 
\*FractionBox[\(1\), 
SuperscriptBox[\(mst\), \(4\)]] 
\*SuperscriptBox[\(Xt\), \(4\)]\ \((
\*FractionBox[\(11\), \(2\)] - 
\*FractionBox[\(25\), \(4\ \((1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)])\)\)] + 
\*FractionBox[
SuperscriptBox[\(\[Mu]\), \(2\)], 
SuperscriptBox[\(mst\), \(2\)]] - 
\*FractionBox[\(1\), \(2\)]\ f1[
\*FractionBox[\(\[Mu]\), \(mst\)]] + 
\*FractionBox[\(
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ f1[
\*FractionBox[\(\[Mu]\), \(mst\)]]\), 
SuperscriptBox[\(mst\), \(2\)]] + 
\*FractionBox[\(1\), \(2\)]\ f2[
\*FractionBox[\(\[Mu]\), \(mst\)]] + 
\*FractionBox[\(
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ f2[
\*FractionBox[\(\[Mu]\), \(mst\)]]\), \(2\ 
\*SuperscriptBox[\(mst\), \(2\)]\)] - 
\*FractionBox[\(13\), \(2\)]\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]] + 
\*FractionBox[\(6\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] - 
\*FractionBox[\(
\*SuperscriptBox[\(\[Mu]\), \(2\)]\ Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), 
SuperscriptBox[\(mst\), \(2\)]] + 
\*SuperscriptBox[\((
\*FractionBox[\(Xt\), \(mst\)] + 
\*FractionBox[\(2\ \[Mu]\ Csc[2\ ArcTan[tan\[Beta]]]\), \(mst\)])\), \(2\)]\ \((\(-
\*FractionBox[\(19\), \(12\ \((1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)])\)\)]\) - 
\*FractionBox[\(8\ K\), \(1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)]\)] + 
\*FractionBox[\(Log[
\*FractionBox[
SuperscriptBox[\(mst\), \(2\)], 
SuperscriptBox[\(Q\), \(2\)]]]\), \(2\ \((1 + 
\*SuperscriptBox[\(tan\[Beta]\), \(2\)])\)\)])\))\))\)\);
(*shift DRbar to OS*)
log[y_]:=Piecewise[{{0, Abs[y]<0.5 10^-2}},Log[Abs[y]]] ;(*defined to avoid numerical problems*)
shiftDROS\[Alpha]t2[Q_,mst_,\[Mu]_,tan\[Beta]_,Xt_]:=Subscript[g, t]^6 Re@Block[{\[Beta]=ArcTan[tan\[Beta]],xt=Xt/mst,yt=Xt/mst+(2 \[Mu])/(mst Sin[2ArcTan[tan\[Beta]]]),x\[Mu]=(\[Mu])^2/mst^2,xq=Q^2/mst^2},
Sin[\[Beta]]^-2 (1/(1024 \[Pi]^4) (-36-36 xt^2+6 xt^4+72 x\[Mu]-72 xt^2 x\[Mu]+12 xt^4 x\[Mu]-36 x\[Mu]^2+108 xt^2 x\[Mu]^2-18 xt^4 x\[Mu]^2) log[1-x\[Mu]]+1/(1024 \[Pi]^4) (108-54 xt^2+9 xt^4-108 x\[Mu]+180 xt^2 x\[Mu]-30 xt^4 x\[Mu]-6 xt^2 (-6+xt^2) x\[Mu] f2[Sqrt[x\[Mu]]]+3 (-24 (-1+x\[Mu])+12 xt^2 (3+2 x\[Mu])-2 xt^4 (3+2 x\[Mu])) Log[xq]+Cos[\[Beta]]^2 (36-48 (-6+Sqrt[3] \[Pi]) xt yt+8 (-6+Sqrt[3] \[Pi]) xt^3 yt+72 yt^2-12 Sqrt[3] \[Pi] yt^2+xt^4 (9-2 (-6+Sqrt[3] \[Pi]) yt^2)+6 xt^2 (-9+2 (-6+Sqrt[3] \[Pi]) yt^2)+6 (24 xt yt-4 xt^3 yt+6 (1+yt^2)-6 xt^2 (2+yt^2)+xt^4 (2+yt^2)) Log[xq])+36 x\[Mu]^2 Log[x\[Mu]]-108 xt^2 x\[Mu]^2 Log[x\[Mu]]+18 xt^4 x\[Mu]^2 Log[x\[Mu]]+6 xt^2 (30-10 xt^2+xt^4) (2+Log[xq]) Sin[\[Beta]]^2))]
]


(* ::Subsection::Closed:: *)
(*Global Functions*)


Options[\[Lambda]HSS]={hiOrd->{1,1,1},suppressedCorrections->False,scheme->"DRbar"};
\[Lambda]HSS[mtilde_?NumericQ,mQ1_?NumericQ,mQ2_?NumericQ,mQ3_?NumericQ,mU1_?NumericQ,mU2_?NumericQ,mU3_?NumericQ,mD1_?NumericQ,mD2_?NumericQ,mD3_?NumericQ,mE1_?NumericQ,mE2_?NumericQ,mE3_?NumericQ,mL1_?NumericQ,mL2_?NumericQ,mL3_?NumericQ,mA_?NumericQ,\[Mu]_?NumericQ,M1_?NumericQ,M2_?NumericQ,M3_?NumericQ,tan\[Beta]_?NumericQ,Xt_?NumericQ,OptionsPattern[]]:=(\[Lambda]HSS1l[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt]+
If[OptionValue[hiOrd][[1]]==1,(\[CapitalDelta]\[Lambda]2lstrong[mtilde,mQ3,mU3,Xt,M3]+If[OptionValue[scheme]=="OS",shiftDROS\[Alpha]t\[Alpha]S[mtilde,mQ3,mU3,Xt,M3],0]),0]+If[OptionValue[hiOrd][[2]]==1,(\[CapitalDelta]\[Lambda]2lalphat2[mtilde,Sqrt[mQ3 mU3],\[Mu],tan\[Beta],Xt]+If[OptionValue[scheme]=="OS",shiftDROS\[Alpha]t2[mtilde,Sqrt[mQ3 mU3],\[Mu],tan\[Beta],Xt],0]),0]+
If[OptionValue[hiOrd][[3]]==1,(\[Lambda]2lbottom[mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]+\[Lambda]2ltau[mL3,mE3,M2,M1,\[Mu],tan\[Beta]]),0]+If[OptionValue[suppressedCorrections],\[Lambda]HSS1lsuppressed[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt],0])


\[Lambda]Splitscalars[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Simplify[\[Lambda]Splitscalarsaux/.{
\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt}]
\[Lambda]SMsplit[Qmsplit_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Simplify[\[Lambda]SMsplitaux/.{msplit->Qmsplit}/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt}]
gtSplitsplit[Qmsplit_,Q\[Mu]_?NumericQ,M1_,M2_,M3_]:=Simplify[gtSplitsplitaux/.{msplit->Qmsplit}/.{\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3}]


g1umtilde[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Simplify[g1umtildeaux/.{
\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt}];
g2umtilde[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Simplify[g2umtildeaux/.{
\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt}];
g1dmtilde[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Simplify[g1dmtildeaux/.{
\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt}];
g2dmtilde[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Simplify[g2dmtildeaux/.{
\!\(\*OverscriptBox[\(m\), \(~\)]\)->mtilde}/.{Subscript[m, Subscript[Q, 1]]->mQ1,Subscript[m, Subscript[Q, 2]]->mQ2,Subscript[m, Subscript[Q, 3]]->mQ3,Subscript[m, Subscript[U, 1]]->mU1,Subscript[m, Subscript[U, 2]]->mU2,Subscript[m, Subscript[U, 3]]->mU3,Subscript[m, Subscript[D, 1]]->mD1,Subscript[m, Subscript[D, 2]]->mD2,Subscript[m, Subscript[D, 3]]->mD3,Subscript[m, Subscript[E, 1]]->mE1,Subscript[m, Subscript[E, 2]]->mE2,Subscript[m, Subscript[E, 3]]->mE3,Subscript[m, Subscript[L, 1]]->mL1,Subscript[m, Subscript[L, 2]]->mL2,Subscript[m, Subscript[L, 3]]->mL3,Subscript[m, A]->mA,\[Mu]->Q\[Mu],Subscript[M, 1]->M1,Subscript[M, 2]->M2,Subscript[M, 3]->M3,\[Beta]->ArcTan[tan\[Beta]],Subscript[X, t]->Xt}]


(* ::Title::Closed:: *)
(*Higgs Mass*)


(* ::Text:: *)
(*This is the actual package for the calcualtion of the Higgs mass in the MSSM. It depends on the other previously defined sub-packages: SM RGEs, Split RGEs and Thresholds.*)


(* ::Section::Closed:: *)
(*Matching at the electroweak scale (at the top mass)*)


Mhpole::usage="Mhpole[\[Lambda]atMT] computes the pole mass of the Higgs from the value of the quartic coupling \!\(\*
StyleBox[\"\[Lambda]atMT\",\nFontSlant->\"Italic\"]\) at the pole mass of the top in the \!\(\*OverscriptBox[\(MS\), \(_\)]\) scheme.";


MW=80.384; MZ=91.1876;
Mh=125.09;
\[Alpha]3MZ=0.1185;
MT=173.34;vev=246.21971;
g3MT=  1.1666+ 0 1.15;
g2MT= 0.64779+0 0.64822;
gyMT= 0.35830+0 0.35760;g1MT=Sqrt[5/3]gyMT;
gtMT2l=0.94018;(*NNLO*);
gtMT3l=0.93690;(*NNNLO*)
gbMT=0.0156; 
g\[Tau]MT=0.0100; 
\[Lambda]MT=2 0.12604;


Options[SetSMparameters]={useMStopYukawa->False};
SetSMparameters[QMTorgt_,Q\[Alpha]3MZ_,opts:OptionsPattern[]]:=(If[!OptionValue[useMStopYukawa],
	g3MT=1.1666+0.00314 (Q\[Alpha]3MZ-0.1184)/0.0007-0.00046(QMTorgt-173.34);
	gtMT3l=0.93690+0.00556(QMTorgt-173.34)-0.00042 (Q\[Alpha]3MZ-0.1184)/0.0007;
	gtMT2l=gtMT3l-0.93690+0.94018,
	gtMT3l=QMTorgt;
	gtMT2l=gtMT3l-0.93690+0.94018;
	MT=173.34+1/0.00556 (gtMT3l-0.93690+0.00042 (Q\[Alpha]3MZ-0.1184)/0.0007);
	g3MT=1.1666+0.00314 (Q\[Alpha]3MZ-0.1184)/0.0007-0.00046(MT-173.34);];solSM3l=SMrun[{Subscript[g, 1],Subscript[g, 2],Subscript[g, 3],Subscript[g, t],\[Lambda],Subscript[g, \[Tau]],Subscript[g, b]},{Subscript[g, 1][0]==g1MT,Subscript[g, 2][0]==g2MT,Subscript[g, 3][0]==g3MT,Subscript[g, t][0]==gtMT3l,\[Lambda][0]==1/2 \[Lambda]MT,Subscript[g, b][0]==gbMT,Subscript[g, \[Tau]][0]==g\[Tau]MT},0,40,optsSMrun];
solSM2l=SMrun[{Subscript[g, 1],Subscript[g, 2],Subscript[g, 3],Subscript[g, t],\[Lambda],Subscript[g, \[Tau]],Subscript[g, b]},{Subscript[g, 1][0]==g1MT,Subscript[g, 2][0]==g2MT,Subscript[g, 3][0]==g3MT,Subscript[g, t][0]==gtMT2l,\[Lambda][0]==1/2 \[Lambda]MT,Subscript[g, b][0]==gbMT,Subscript[g, \[Tau]][0]==g\[Tau]MT},0,40,optsSMrun];)


\[Delta]\[Lambda]2lMT=Module[{\[Delta]\[Lambda]2QCD,\[Delta]\[Lambda]2EW},
\[Delta]\[Lambda]2QCD=g3MT^2/(4\[Pi])^4 (-23.88+0.12(Mh-125)-0.64 (MT-173));
\[Delta]\[Lambda]2EW=1/(4\[Pi])^4 (-9.45-0.12 (Mh-125)-0.21(MT-173));
-2\[Delta]\[Lambda]2QCD-2 \[Delta]\[Lambda]2EW];


Mhpole[\[Lambda]mt_]:=Sqrt[vev^2 (\[Lambda]mt+0.0075\[Lambda]mt+\[Delta]\[Lambda]2lMT)]


(* ::Section::Closed:: *)
(*Pole mass of the Higgs in the MSSM*)


(* ::Subsection::Closed:: *)
(*Interpolated Solution of the RGEs*)


(* ::Input:: *)
(*(*SetDirectory[NotebookDirectory[]]*)
(*ToExpression[ToString[Flatten@Import[Directory[]<>"/RGsolution.txt","Data"]]]*)*)


(* ::Text::Closed:: *)
(*Table for interpolation (tableint)*)


tableint={{{-0.03`,0.4`,0.94018`,1.1666`},-0.008068195410301826`},{{-0.03`,0.4`,0.94018`,1.1711`},-0.008068195410301826`},{{-0.03`,0.4`,0.94018`,1.1621000000000001`},-0.008068195410301826`},{{-0.03`,0.4`,0.94368`,1.1666`},-0.007723856547999131`},{{-0.03`,0.4`,0.94368`,1.1711`},-0.007723856547999131`},{{-0.03`,0.4`,0.94368`,1.1621000000000001`},-0.007723856547999131`},{{-0.03`,0.4`,0.93668`,1.1666`},-0.008408817954970574`},{{-0.03`,0.4`,0.93668`,1.1711`},-0.008408817954970574`},{{-0.03`,0.4`,0.93668`,1.1621000000000001`},-0.008408817954970574`},{{-0.03`,0.6`,0.94018`,1.1666`},0.0020352851002791864`},{{-0.03`,0.6`,0.94018`,1.1711`},0.0020352851002791864`},{{-0.03`,0.6`,0.94018`,1.1621000000000001`},0.0020352851002791864`},{{-0.03`,0.6`,0.94368`,1.1666`},0.0025396953252873025`},{{-0.03`,0.6`,0.94368`,1.1711`},0.0025396953252873025`},{{-0.03`,0.6`,0.94368`,1.1621000000000001`},0.0025396953252873025`},{{-0.03`,0.6`,0.93668`,1.1666`},0.0015363315640612172`},{{-0.03`,0.6`,0.93668`,1.1711`},0.0015363315640612172`},{{-0.03`,0.6`,0.93668`,1.1621000000000001`},0.0015363315640612172`},{{-0.03`,0.8`,0.94018`,1.1666`},0.011617521654989279`},{{-0.03`,0.8`,0.94018`,1.1711`},0.011617521654989279`},{{-0.03`,0.8`,0.94018`,1.1621000000000001`},0.011617521654989279`},{{-0.03`,0.8`,0.94368`,1.1666`},0.012274599315169435`},{{-0.03`,0.8`,0.94368`,1.1711`},0.012274599315169435`},{{-0.03`,0.8`,0.94368`,1.1621000000000001`},0.012274599315169435`},{{-0.03`,0.8`,0.93668`,1.1666`},0.010967566590489957`},{{-0.03`,0.8`,0.93668`,1.1711`},0.010967566590489957`},{{-0.03`,0.8`,0.93668`,1.1621000000000001`},0.010967566590489957`},{{-0.03`,1.`,0.94018`,1.1666`},0.020714379793588485`},{{-0.03`,1.`,0.94018`,1.1711`},0.020714379793588485`},{{-0.03`,1.`,0.94018`,1.1621000000000001`},0.020714379793588485`},{{-0.03`,1.`,0.94368`,1.1666`},0.021517172221571786`},{{-0.03`,1.`,0.94368`,1.1711`},0.021517172221571786`},{{-0.03`,1.`,0.94368`,1.1621000000000001`},0.021517172221571786`},{{-0.03`,1.`,0.93668`,1.1666`},0.01992030444258303`},{{-0.03`,1.`,0.93668`,1.1711`},0.01992030444258303`},{{-0.03`,1.`,0.93668`,1.1621000000000001`},0.01992030444258303`},{{-0.03`,1.2`,0.94018`,1.1666`},0.029358637368335234`},{{-0.03`,1.2`,0.94018`,1.1711`},0.029358637368335234`},{{-0.03`,1.2`,0.94018`,1.1621000000000001`},0.029358637368335234`},{{-0.03`,1.2`,0.94368`,1.1666`},0.030300610665449507`},{{-0.03`,1.2`,0.94368`,1.1711`},0.030300610665449507`},{{-0.03`,1.2`,0.94368`,1.1621000000000001`},0.030300610665449507`},{{-0.03`,1.2`,0.93668`,1.1666`},0.028426907201590114`},{{-0.03`,1.2`,0.93668`,1.1711`},0.028426907201590114`},{{-0.03`,1.2`,0.93668`,1.1621000000000001`},0.028426907201590114`},{{-0.03`,1.4`,0.94018`,1.1666`},0.03758030136374664`},{{-0.03`,1.4`,0.94018`,1.1711`},0.03758030136374664`},{{-0.03`,1.4`,0.94018`,1.1621000000000001`},0.03758030136374664`},{{-0.03`,1.4`,0.94368`,1.1666`},0.038655310474637966`},{{-0.03`,1.4`,0.94368`,1.1711`},0.038655310474637966`},{{-0.03`,1.4`,0.94368`,1.1621000000000001`},0.038655310474637966`},{{-0.03`,1.4`,0.93668`,1.1666`},0.036516995944489386`},{{-0.03`,1.4`,0.93668`,1.1711`},0.036516995944489386`},{{-0.03`,1.4`,0.93668`,1.1621000000000001`},0.036516995944489386`},{{-0.03`,1.6`,0.94018`,1.1666`},0.045406887246077596`},{{-0.03`,1.6`,0.94018`,1.1711`},0.045406887246077596`},{{-0.03`,1.6`,0.94018`,1.1621000000000001`},0.045406887246077596`},{{-0.03`,1.6`,0.94368`,1.1666`},0.04660914840025003`},{{-0.03`,1.6`,0.94368`,1.1711`},0.04660914840025003`},{{-0.03`,1.6`,0.94368`,1.1621000000000001`},0.04660914840025003`},{{-0.03`,1.6`,0.93668`,1.1666`},0.044217727711245325`},{{-0.03`,1.6`,0.93668`,1.1711`},0.044217727711245325`},{{-0.03`,1.6`,0.93668`,1.1621000000000001`},0.044217727711245325`},{{-0.03`,1.8`,0.94018`,1.1666`},0.05286366582630709`},{{-0.03`,1.8`,0.94018`,1.1711`},0.05286366582630709`},{{-0.03`,1.8`,0.94018`,1.1621000000000001`},0.05286366582630709`},{{-0.03`,1.8`,0.94368`,1.1666`},0.054187731158079906`},{{-0.03`,1.8`,0.94368`,1.1711`},0.054187731158079906`},{{-0.03`,1.8`,0.94368`,1.1621000000000001`},0.054187731158079906`},{{-0.03`,1.8`,0.93668`,1.1666`},0.05155404017851422`},{{-0.03`,1.8`,0.93668`,1.1711`},0.05155404017851422`},{{-0.03`,1.8`,0.93668`,1.1621000000000001`},0.05155404017851422`},{{-0.03`,2.`,0.94018`,1.1666`},0.05997388188898019`},{{-0.03`,2.`,0.94018`,1.1711`},0.05997388188898019`},{{-0.03`,2.`,0.94018`,1.1621000000000001`},0.05997388188898019`},{{-0.03`,2.`,0.94368`,1.1666`},0.06141461605912326`},{{-0.03`,2.`,0.94368`,1.1711`},0.06141461605912326`},{{-0.03`,2.`,0.94368`,1.1621000000000001`},0.06141461605912326`},{{-0.03`,2.`,0.93668`,1.1666`},0.058548868279443965`},{{-0.03`,2.`,0.93668`,1.1711`},0.058548868279443965`},{{-0.03`,2.`,0.93668`,1.1621000000000001`},0.058548868279443965`},{{-0.03`,2.2`,0.94018`,1.1666`},0.06675894822445971`},{{-0.03`,2.2`,0.94018`,1.1711`},0.06675894822445971`},{{-0.03`,2.2`,0.94018`,1.1621000000000001`},0.06675894822445971`},{{-0.03`,2.2`,0.94368`,1.1666`},0.06831150687895543`},{{-0.03`,2.2`,0.94368`,1.1711`},0.06831150687895543`},{{-0.03`,2.2`,0.94368`,1.1621000000000001`},0.06831150687895543`},{{-0.03`,2.2`,0.93668`,1.1666`},0.06522333639418082`},{{-0.03`,2.2`,0.93668`,1.1711`},0.06522333639418082`},{{-0.03`,2.2`,0.93668`,1.1621000000000001`},0.06522333639418082`},{{-0.03`,2.6`,0.94018`,1.1666`},0.07942927364807735`},{{-0.03`,2.6`,0.94018`,1.1711`},0.07942927364807735`},{{-0.03`,2.6`,0.94018`,1.1621000000000001`},0.07942927364807735`},{{-0.03`,2.6`,0.94368`,1.1666`},0.08119201928957345`},{{-0.03`,2.6`,0.94368`,1.1711`},0.08119201928957345`},{{-0.03`,2.6`,0.94368`,1.1621000000000001`},0.08119201928957345`},{{-0.03`,2.6`,0.93668`,1.1666`},0.07768577403562371`},{{-0.03`,2.6`,0.93668`,1.1711`},0.07768577403562371`},{{-0.03`,2.6`,0.93668`,1.1621000000000001`},0.07768577403562371`},{{-0.03`,3.`,0.94018`,1.1666`},0.09101661499306041`},{{-0.03`,3.`,0.94018`,1.1711`},0.09101661499306041`},{{-0.03`,3.`,0.94018`,1.1621000000000001`},0.09101661499306041`},{{-0.03`,3.`,0.94368`,1.1666`},0.09297320899134034`},{{-0.03`,3.`,0.94368`,1.1711`},0.09297320899134034`},{{-0.03`,3.`,0.94368`,1.1621000000000001`},0.09297320899134034`},{{-0.03`,3.`,0.93668`,1.1666`},0.08908137634045968`},{{-0.03`,3.`,0.93668`,1.1711`},0.08908137634045968`},{{-0.03`,3.`,0.93668`,1.1621000000000001`},0.08908137634045968`},{{-0.03`,3.4`,0.94018`,1.1666`},0.10164215182210926`},{{-0.03`,3.4`,0.94018`,1.1711`},0.10164215182210926`},{{-0.03`,3.4`,0.94018`,1.1621000000000001`},0.10164215182210926`},{{-0.03`,3.4`,0.94368`,1.1666`},0.10377795563067146`},{{-0.03`,3.4`,0.94368`,1.1711`},0.10377795563067146`},{{-0.03`,3.4`,0.94368`,1.1621000000000001`},0.10377795563067146`},{{-0.03`,3.4`,0.93668`,1.1666`},0.09952963965610256`},{{-0.03`,3.4`,0.93668`,1.1711`},0.09952963965610256`},{{-0.03`,3.4`,0.93668`,1.1621000000000001`},0.09952963965610256`},{{-0.03`,3.8`,0.94018`,1.1666`},0.11140993810418444`},{{-0.03`,3.8`,0.94018`,1.1711`},0.11140993810418444`},{{-0.03`,3.8`,0.94018`,1.1621000000000001`},0.11140993810418444`},{{-0.03`,3.8`,0.94368`,1.1666`},0.11371180683942174`},{{-0.03`,3.8`,0.94368`,1.1711`},0.11371180683942174`},{{-0.03`,3.8`,0.94368`,1.1621000000000001`},0.11371180683942174`},{{-0.03`,3.8`,0.93668`,1.1666`},0.10913313967208373`},{{-0.03`,3.8`,0.93668`,1.1711`},0.10913313967208373`},{{-0.03`,3.8`,0.93668`,1.1621000000000001`},0.10913313967208373`},{{-0.03`,4.2`,0.94018`,1.1666`},0.12041013930864689`},{{-0.03`,4.2`,0.94018`,1.1711`},0.12041013930864689`},{{-0.03`,4.2`,0.94018`,1.1621000000000001`},0.12041013930864689`},{{-0.03`,4.2`,0.94368`,1.1666`},0.12286623894226334`},{{-0.03`,4.2`,0.94368`,1.1711`},0.12286623894226334`},{{-0.03`,4.2`,0.94368`,1.1621000000000001`},0.12286623894226334`},{{-0.03`,4.2`,0.93668`,1.1666`},0.11798074493811958`},{{-0.03`,4.2`,0.93668`,1.1711`},0.11798074493811958`},{{-0.03`,4.2`,0.93668`,1.1621000000000001`},0.11798074493811958`},{{-0.03`,4.6`,0.94018`,1.1666`},0.12872170948853226`},{{-0.03`,4.6`,0.94018`,1.1711`},0.12872170948853226`},{{-0.03`,4.6`,0.94018`,1.1621000000000001`},0.12872170948853226`},{{-0.03`,4.6`,0.94368`,1.1666`},0.13132135834777664`},{{-0.03`,4.6`,0.94368`,1.1711`},0.13132135834777664`},{{-0.03`,4.6`,0.94368`,1.1621000000000001`},0.13132135834777664`},{{-0.03`,4.6`,0.93668`,1.1666`},0.12615026954834704`},{{-0.03`,4.6`,0.93668`,1.1711`},0.12615026954834704`},{{-0.03`,4.6`,0.93668`,1.1621000000000001`},0.12615026954834704`},{{-0.03`,5.`,0.94018`,1.1666`},0.13641303749197392`},{{-0.03`,5.`,0.94018`,1.1711`},0.13641303749197392`},{{-0.03`,5.`,0.94018`,1.1621000000000001`},0.13641303749197392`},{{-0.03`,5.`,0.94368`,1.1666`},0.13914656374604728`},{{-0.03`,5.`,0.94368`,1.1711`},0.13914656374604728`},{{-0.03`,5.`,0.94368`,1.1621000000000001`},0.13914656374604728`},{{-0.03`,5.`,0.93668`,1.1666`},0.13370910407993009`},{{-0.03`,5.`,0.93668`,1.1711`},0.13370910407993009`},{{-0.03`,5.`,0.93668`,1.1621000000000001`},0.13370910407993009`},{{-0.03`,5.4`,0.94018`,1.1666`},0.14354368961368963`},{{-0.03`,5.4`,0.94018`,1.1711`},0.14354368961368963`},{{-0.03`,5.4`,0.94018`,1.1621000000000001`},0.14354368961368963`},{{-0.03`,5.4`,0.94368`,1.1666`},0.14640232829486563`},{{-0.03`,5.4`,0.94368`,1.1711`},0.14640232829486563`},{{-0.03`,5.4`,0.94368`,1.1621000000000001`},0.14640232829486563`},{{-0.03`,5.4`,0.93668`,1.1666`},0.14071591827047497`},{{-0.03`,5.4`,0.93668`,1.1711`},0.14071591827047497`},{{-0.03`,5.4`,0.93668`,1.1621000000000001`},0.14071591827047497`},{{-0.03`,5.8`,0.94018`,1.1666`},0.15016651371358625`},{{-0.03`,5.8`,0.94018`,1.1711`},0.15016651371358625`},{{-0.03`,5.8`,0.94018`,1.1621000000000001`},0.15016651371358625`},{{-0.03`,5.8`,0.94368`,1.1666`},0.15314229847028782`},{{-0.03`,5.8`,0.94368`,1.1711`},0.15314229847028782`},{{-0.03`,5.8`,0.94368`,1.1621000000000001`},0.15314229847028782`},{{-0.03`,5.8`,0.93668`,1.1666`},0.1472227706576161`},{{-0.03`,5.8`,0.93668`,1.1711`},0.1472227706576161`},{{-0.03`,5.8`,0.93668`,1.1621000000000001`},0.1472227706576161`},{{-0.03`,6.2`,0.94018`,1.1666`},0.15632816491784976`},{{-0.03`,6.2`,0.94018`,1.1711`},0.15632816491784976`},{{-0.03`,6.2`,0.94018`,1.1621000000000001`},0.15632816491784976`},{{-0.03`,6.2`,0.94368`,1.1666`},0.15941383993917219`},{{-0.03`,6.2`,0.94368`,1.1711`},0.15941383993917219`},{{-0.03`,6.2`,0.94368`,1.1621000000000001`},0.15941383993917219`},{{-0.03`,6.2`,0.93668`,1.1666`},0.1532756142234446`},{{-0.03`,6.2`,0.93668`,1.1711`},0.1532756142234446`},{{-0.03`,6.2`,0.93668`,1.1621000000000001`},0.1532756142234446`},{{-0.03`,6.8`,0.94018`,1.1666`},0.16479471265162768`},{{-0.03`,6.8`,0.94018`,1.1711`},0.16479471265162768`},{{-0.03`,6.8`,0.94018`,1.1621000000000001`},0.16479471265162768`},{{-0.03`,6.8`,0.94368`,1.1666`},0.16803298545684306`},{{-0.03`,6.8`,0.94368`,1.1711`},0.16803298545684306`},{{-0.03`,6.8`,0.94368`,1.1621000000000001`},0.16803298545684306`},{{-0.03`,6.8`,0.93668`,1.1666`},0.16159103254065402`},{{-0.03`,6.8`,0.93668`,1.1711`},0.16159103254065402`},{{-0.03`,6.8`,0.93668`,1.1621000000000001`},0.16159103254065402`},{{-0.03`,7.4`,0.94018`,1.1666`},0.1724357458975667`},{{-0.03`,7.4`,0.94018`,1.1711`},0.1724357458975667`},{{-0.03`,7.4`,0.94018`,1.1621000000000001`},0.1724357458975667`},{{-0.03`,7.4`,0.94368`,1.1666`},0.17581356801496342`},{{-0.03`,7.4`,0.94368`,1.1711`},0.17581356801496342`},{{-0.03`,7.4`,0.94368`,1.1621000000000001`},0.17581356801496342`},{{-0.03`,7.4`,0.93668`,1.1666`},0.16909381804477594`},{{-0.03`,7.4`,0.93668`,1.1711`},0.16909381804477594`},{{-0.03`,7.4`,0.93668`,1.1621000000000001`},0.16909381804477594`},{{-0.03`,8.`,0.94018`,1.1666`},0.17935280579098176`},{{-0.03`,8.`,0.94018`,1.1711`},0.17935280579098176`},{{-0.03`,8.`,0.94018`,1.1621000000000001`},0.17935280579098176`},{{-0.03`,8.`,0.94368`,1.1666`},0.18285871190075867`},{{-0.03`,8.`,0.94368`,1.1711`},0.18285871190075867`},{{-0.03`,8.`,0.94368`,1.1621000000000001`},0.18285871190075867`},{{-0.03`,8.`,0.93668`,1.1666`},0.1758839482278346`},{{-0.03`,8.`,0.93668`,1.1711`},0.1758839482278346`},{{-0.03`,8.`,0.93668`,1.1621000000000001`},0.1758839482278346`},{{-0.03`,8.6`,0.94018`,1.1666`},0.18563254733203358`},{{-0.03`,8.6`,0.94018`,1.1711`},0.18563254733203358`},{{-0.03`,8.6`,0.94018`,1.1621000000000001`},0.18563254733203358`},{{-0.03`,8.6`,0.94368`,1.1666`},0.18925642529646072`},{{-0.03`,8.6`,0.94368`,1.1711`},0.18925642529646072`},{{-0.03`,8.6`,0.94368`,1.1621000000000001`},0.18925642529646072`},{{-0.03`,8.6`,0.93668`,1.1666`},0.18204674175593316`},{{-0.03`,8.6`,0.93668`,1.1711`},0.18204674175593316`},{{-0.03`,8.6`,0.93668`,1.1621000000000001`},0.18204674175593316`},{{-0.03`,9.2`,0.94018`,1.1666`},0.19134831892933887`},{{-0.03`,9.2`,0.94018`,1.1711`},0.19134831892933887`},{{-0.03`,9.2`,0.94018`,1.1621000000000001`},0.19134831892933887`},{{-0.03`,9.2`,0.94368`,1.1666`},0.19508121903284703`},{{-0.03`,9.2`,0.94368`,1.1711`},0.19508121903284703`},{{-0.03`,9.2`,0.94368`,1.1621000000000001`},0.19508121903284703`},{{-0.03`,9.2`,0.93668`,1.1666`},0.18765439922564658`},{{-0.03`,9.2`,0.93668`,1.1711`},0.18765439922564658`},{{-0.03`,9.2`,0.93668`,1.1621000000000001`},0.18765439922564658`},{{-0.03`,9.8`,0.94018`,1.1666`},0.19656335021756566`},{{-0.03`,9.8`,0.94018`,1.1711`},0.19656335021756566`},{{-0.03`,9.8`,0.94018`,1.1621000000000001`},0.19656335021756566`},{{-0.03`,9.8`,0.94368`,1.1666`},0.20039732250805303`},{{-0.03`,9.8`,0.94368`,1.1711`},0.20039732250805303`},{{-0.03`,9.8`,0.94368`,1.1621000000000001`},0.20039732250805303`},{{-0.03`,9.8`,0.93668`,1.1666`},0.19276916318569842`},{{-0.03`,9.8`,0.93668`,1.1711`},0.19276916318569842`},{{-0.03`,9.8`,0.93668`,1.1621000000000001`},0.19276916318569842`},{{-0.03`,10.4`,0.94018`,1.1666`},0.20133142032999338`},{{-0.03`,10.4`,0.94018`,1.1711`},0.20133142032999338`},{{-0.03`,10.4`,0.94018`,1.1621000000000001`},0.20133142032999338`},{{-0.03`,10.4`,0.94368`,1.1666`},0.20525938155300924`},{{-0.03`,10.4`,0.94368`,1.1711`},0.20525938155300924`},{{-0.03`,10.4`,0.94368`,1.1621000000000001`},0.20525938155300924`},{{-0.03`,10.4`,0.93668`,1.1666`},0.197443957199082`},{{-0.03`,10.4`,0.93668`,1.1711`},0.197443957199082`},{{-0.03`,10.4`,0.93668`,1.1621000000000001`},0.197443957199082`},{{-0.03`,11.`,0.94018`,1.1666`},0.20570003714507215`},{{-0.03`,11.`,0.94018`,1.1711`},0.20570003714507215`},{{-0.03`,11.`,0.94018`,1.1621000000000001`},0.20570003714507215`},{{-0.03`,11.`,0.94368`,1.1666`},0.20971565910077988`},{{-0.03`,11.`,0.94368`,1.1711`},0.20971565910077988`},{{-0.03`,11.`,0.94368`,1.1621000000000001`},0.20971565910077988`},{{-0.03`,11.`,0.93668`,1.1666`},0.20172554361550735`},{{-0.03`,11.`,0.93668`,1.1711`},0.20172554361550735`},{{-0.03`,11.`,0.93668`,1.1621000000000001`},0.20172554361550735`},{{-0.03`,11.6`,0.94018`,1.1666`},0.20970999034830623`},{{-0.03`,11.6`,0.94018`,1.1711`},0.20970999034830623`},{{-0.03`,11.6`,0.94018`,1.1621000000000001`},0.20970999034830623`},{{-0.03`,11.6`,0.94368`,1.1666`},0.2138076005953994`},{{-0.03`,11.6`,0.94368`,1.1711`},0.2138076005953994`},{{-0.03`,11.6`,0.94368`,1.1621000000000001`},0.2138076005953994`},{{-0.03`,11.6`,0.93668`,1.1666`},0.20565406485272272`},{{-0.03`,11.6`,0.93668`,1.1711`},0.20565406485272272`},{{-0.03`,11.6`,0.93668`,1.1621000000000001`},0.20565406485272272`},{{-0.03`,12.2`,0.94018`,1.1666`},0.213396113508952`},{{-0.03`,12.2`,0.94018`,1.1711`},0.213396113508952`},{{-0.03`,12.2`,0.94018`,1.1621000000000001`},0.213396113508952`},{{-0.03`,12.2`,0.94368`,1.1666`},0.21757062121829904`},{{-0.03`,12.2`,0.94368`,1.1711`},0.21757062121829904`},{{-0.03`,12.2`,0.94368`,1.1621000000000001`},0.21757062121829904`},{{-0.03`,12.2`,0.93668`,1.1666`},0.2092637803127908`},{{-0.03`,12.2`,0.93668`,1.1711`},0.2092637803127908`},{{-0.03`,12.2`,0.93668`,1.1621000000000001`},0.2092637803127908`},{{-0.03`,12.8`,0.94018`,1.1666`},0.21679054550108645`},{{-0.03`,12.8`,0.94018`,1.1711`},0.21679054550108645`},{{-0.03`,12.8`,0.94018`,1.1621000000000001`},0.21679054550108645`},{{-0.03`,12.8`,0.94368`,1.1666`},0.22103736427226064`},{{-0.03`,12.8`,0.94368`,1.1711`},0.22103736427226064`},{{-0.03`,12.8`,0.94368`,1.1621000000000001`},0.22103736427226064`},{{-0.03`,12.8`,0.93668`,1.1666`},0.2125863307512784`},{{-0.03`,12.8`,0.93668`,1.1711`},0.2125863307512784`},{{-0.03`,12.8`,0.93668`,1.1621000000000001`},0.2125863307512784`},{{-0.03`,13.4`,0.94018`,1.1666`},0.21992022202405306`},{{-0.03`,13.4`,0.94018`,1.1711`},0.21992022202405306`},{{-0.03`,13.4`,0.94018`,1.1621000000000001`},0.21992022202405306`},{{-0.03`,13.4`,0.94368`,1.1666`},0.2242352115538363`},{{-0.03`,13.4`,0.94368`,1.1711`},0.2242352115538363`},{{-0.03`,13.4`,0.94368`,1.1621000000000001`},0.2242352115538363`},{{-0.03`,13.4`,0.93668`,1.1666`},0.21564821169389928`},{{-0.03`,13.4`,0.93668`,1.1711`},0.21564821169389928`},{{-0.03`,13.4`,0.93668`,1.1621000000000001`},0.21564821169389928`},{{-0.03`,14.`,0.94018`,1.1666`},0.2228098212987354`},{{-0.03`,14.`,0.94018`,1.1711`},0.2228098212987354`},{{-0.03`,14.`,0.94018`,1.1621000000000001`},0.2228098212987354`},{{-0.03`,14.`,0.94368`,1.1666`},0.2271892374008025`},{{-0.03`,14.`,0.94368`,1.1711`},0.2271892374008025`},{{-0.03`,14.`,0.94368`,1.1621000000000001`},0.2271892374008025`},{{-0.03`,14.`,0.93668`,1.1666`},0.21847371010074101`},{{-0.03`,14.`,0.93668`,1.1711`},0.21847371010074101`},{{-0.03`,14.`,0.93668`,1.1621000000000001`},0.21847371010074101`},{{-0.03`,14.6`,0.94018`,1.1666`},0.22548085414293081`},{{-0.03`,14.6`,0.94018`,1.1711`},0.22548085414293081`},{{-0.03`,14.6`,0.94018`,1.1621000000000001`},0.22548085414293081`},{{-0.03`,14.6`,0.94368`,1.1666`},0.22992130107985867`},{{-0.03`,14.6`,0.94368`,1.1711`},0.22992130107985867`},{{-0.03`,14.6`,0.94368`,1.1621000000000001`},0.22992130107985867`},{{-0.03`,14.6`,0.93668`,1.1666`},0.2210839928495895`},{{-0.03`,14.6`,0.93668`,1.1711`},0.2210839928495895`},{{-0.03`,14.6`,0.93668`,1.1621000000000001`},0.2210839928495895`},{{-0.03`,15.2`,0.94018`,1.1666`},0.22795155002590584`},{{-0.03`,15.2`,0.94018`,1.1711`},0.22795155002590584`},{{-0.03`,15.2`,0.94018`,1.1621000000000001`},0.22795155002590584`},{{-0.03`,15.2`,0.94368`,1.1666`},0.23244994915851755`},{{-0.03`,15.2`,0.94368`,1.1711`},0.23244994915851755`},{{-0.03`,15.2`,0.94368`,1.1621000000000001`},0.23244994915851755`},{{-0.03`,15.2`,0.93668`,1.1666`},0.22349697649537956`},{{-0.03`,15.2`,0.93668`,1.1711`},0.22349697649537956`},{{-0.03`,15.2`,0.93668`,1.1621000000000001`},0.22349697649537956`},{{-0.03`,15.8`,0.94018`,1.1666`},0.23023964134259467`},{{-0.03`,15.8`,0.94018`,1.1711`},0.23023964134259467`},{{-0.03`,15.8`,0.94018`,1.1621000000000001`},0.23023964134259467`},{{-0.03`,15.8`,0.94368`,1.1666`},0.23479319151241343`},{{-0.03`,15.8`,0.94368`,1.1711`},0.23479319151241343`},{{-0.03`,15.8`,0.94368`,1.1621000000000001`},0.23479319151241343`},{{-0.03`,15.8`,0.93668`,1.1666`},0.22573011912966293`},{{-0.03`,15.8`,0.93668`,1.1711`},0.22573011912966293`},{{-0.03`,15.8`,0.93668`,1.1621000000000001`},0.22573011912966293`},{{-0.03`,16.4`,0.94018`,1.1666`},0.23236015790156064`},{{-0.03`,16.4`,0.94018`,1.1711`},0.23236015790156064`},{{-0.03`,16.4`,0.94018`,1.1621000000000001`},0.23236015790156064`},{{-0.03`,16.4`,0.94368`,1.1666`},0.23696630614511605`},{{-0.03`,16.4`,0.94368`,1.1711`},0.23696630614511605`},{{-0.03`,16.4`,0.94368`,1.1621000000000001`},0.23696630614511605`},{{-0.03`,16.4`,0.93668`,1.1666`},0.22779820559350866`},{{-0.03`,16.4`,0.93668`,1.1711`},0.22779820559350866`},{{-0.03`,16.4`,0.93668`,1.1621000000000001`},0.22779820559350866`},{{-0.03`,17.`,0.94018`,1.1666`},0.2343262458308546`},{{-0.03`,17.`,0.94018`,1.1711`},0.2343262458308546`},{{-0.03`,17.`,0.94018`,1.1621000000000001`},0.2343262458308546`},{{-0.03`,17.`,0.94368`,1.1666`},0.2389826654424973`},{{-0.03`,17.`,0.94368`,1.1711`},0.2389826654424973`},{{-0.03`,17.`,0.94368`,1.1621000000000001`},0.2389826654424973`},{{-0.03`,17.`,0.93668`,1.1666`},0.22971415873278145`},{{-0.03`,17.`,0.93668`,1.1711`},0.22971415873278145`},{{-0.03`,17.`,0.93668`,1.1621000000000001`},0.22971415873278145`},{{-0.03`,17.6`,0.94018`,1.1666`},0.23615022616554202`},{{-0.03`,17.6`,0.94018`,1.1711`},0.23615022616554202`},{{-0.03`,17.6`,0.94018`,1.1621000000000001`},0.23615022616554202`},{{-0.03`,17.6`,0.94368`,1.1666`},0.24085479594603942`},{{-0.03`,17.6`,0.94368`,1.1711`},0.24085479594603942`},{{-0.03`,17.6`,0.94368`,1.1621000000000001`},0.24085479594603942`},{{-0.03`,17.6`,0.93668`,1.1666`},0.23149009626503497`},{{-0.03`,17.6`,0.93668`,1.1711`},0.23149009626503497`},{{-0.03`,17.6`,0.93668`,1.1621000000000001`},0.23149009626503497`},{{-0.03`,18.2`,0.94018`,1.1666`},0.2378434226012271`},{{-0.03`,18.2`,0.94018`,1.1711`},0.2378434226012271`},{{-0.03`,18.2`,0.94018`,1.1621000000000001`},0.2378434226012271`},{{-0.03`,18.2`,0.94368`,1.1666`},0.24259419040579652`},{{-0.03`,18.2`,0.94368`,1.1711`},0.24259419040579652`},{{-0.03`,18.2`,0.94368`,1.1621000000000001`},0.24259419040579652`},{{-0.03`,18.2`,0.93668`,1.1666`},0.23313717469648587`},{{-0.03`,18.2`,0.93668`,1.1711`},0.23313717469648587`},{{-0.03`,18.2`,0.93668`,1.1621000000000001`},0.23313717469648587`},{{-0.03`,18.8`,0.94018`,1.1666`},0.23941500636051313`},{{-0.03`,18.8`,0.94018`,1.1711`},0.23941500636051313`},{{-0.03`,18.8`,0.94018`,1.1621000000000001`},0.23941500636051313`},{{-0.03`,18.8`,0.94368`,1.1666`},0.24421020443272476`},{{-0.03`,18.8`,0.94368`,1.1711`},0.24421020443272476`},{{-0.03`,18.8`,0.94368`,1.1621000000000001`},0.24421020443272476`},{{-0.03`,18.8`,0.93668`,1.1666`},0.23466438359245903`},{{-0.03`,18.8`,0.93668`,1.1711`},0.23466438359245903`},{{-0.03`,18.8`,0.93668`,1.1621000000000001`},0.23466438359245903`},{{-0.03`,19.4`,0.94018`,1.1666`},0.24087363212898916`},{{-0.03`,19.4`,0.94018`,1.1711`},0.24087363212898916`},{{-0.03`,19.4`,0.94018`,1.1621000000000001`},0.24087363212898916`},{{-0.03`,19.4`,0.94368`,1.1666`},0.2457116404858613`},{{-0.03`,19.4`,0.94368`,1.1711`},0.2457116404858613`},{{-0.03`,19.4`,0.94368`,1.1621000000000001`},0.2457116404858613`},{{-0.03`,19.4`,0.93668`,1.1666`},0.23608023154585872`},{{-0.03`,19.4`,0.93668`,1.1711`},0.23608023154585872`},{{-0.03`,19.4`,0.93668`,1.1621000000000001`},0.23608023154585872`},{{-0.03`,20.`,0.94018`,1.1666`},0.2422280190426217`},{{-0.03`,20.`,0.94018`,1.1711`},0.2422280190426217`},{{-0.03`,20.`,0.94018`,1.1621000000000001`},0.2422280190426217`},{{-0.03`,20.`,0.94368`,1.1666`},0.24710734775003831`},{{-0.03`,20.`,0.94368`,1.1711`},0.24710734775003831`},{{-0.03`,20.`,0.94368`,1.1621000000000001`},0.24710734775003831`},{{-0.03`,20.`,0.93668`,1.1666`},0.23739330881131043`},{{-0.03`,20.`,0.93668`,1.1711`},0.23739330881131043`},{{-0.03`,20.`,0.93668`,1.1621000000000001`},0.23739330881131043`},{{-0.03`,20.6`,0.94018`,1.1666`},0.2434853416939051`},{{-0.03`,20.6`,0.94018`,1.1711`},0.2434853416939051`},{{-0.03`,20.6`,0.94018`,1.1621000000000001`},0.2434853416939051`},{{-0.03`,20.6`,0.94368`,1.1666`},0.2484046249022876`},{{-0.03`,20.6`,0.94368`,1.1711`},0.2484046249022876`},{{-0.03`,20.6`,0.94368`,1.1621000000000001`},0.2484046249022876`},{{-0.03`,20.6`,0.93668`,1.1666`},0.23861066744828893`},{{-0.03`,20.6`,0.93668`,1.1711`},0.23861066744828893`},{{-0.03`,20.6`,0.93668`,1.1621000000000001`},0.23861066744828893`},{{-0.03`,21.2`,0.94018`,1.1666`},0.24465161650849332`},{{-0.03`,21.2`,0.94018`,1.1711`},0.24465161650849332`},{{-0.03`,21.2`,0.94018`,1.1621000000000001`},0.24465161650849332`},{{-0.03`,21.2`,0.94368`,1.1666`},0.24960961005057739`},{{-0.03`,21.2`,0.94368`,1.1711`},0.24960961005057739`},{{-0.03`,21.2`,0.94368`,1.1621000000000001`},0.24960961005057739`},{{-0.03`,21.2`,0.93668`,1.1666`},0.23973820371045784`},{{-0.03`,21.2`,0.93668`,1.1711`},0.23973820371045784`},{{-0.03`,21.2`,0.93668`,1.1621000000000001`},0.23973820371045784`},{{-0.03`,21.8`,0.94018`,1.1666`},0.24573354136019485`},{{-0.03`,21.8`,0.94018`,1.1711`},0.24573354136019485`},{{-0.03`,21.8`,0.94018`,1.1621000000000001`},0.24573354136019485`},{{-0.03`,21.8`,0.94368`,1.1666`},0.25072909702442236`},{{-0.03`,21.8`,0.94368`,1.1711`},0.25072909702442236`},{{-0.03`,21.8`,0.94368`,1.1621000000000001`},0.25072909702442236`},{{-0.03`,21.8`,0.93668`,1.1666`},0.24078252025125754`},{{-0.03`,21.8`,0.93668`,1.1711`},0.24078252025125754`},{{-0.03`,21.8`,0.93668`,1.1621000000000001`},0.24078252025125754`},{{-0.03`,22.4`,0.94018`,1.1666`},0.24673642684215202`},{{-0.03`,22.4`,0.94018`,1.1711`},0.24673642684215202`},{{-0.03`,22.4`,0.94018`,1.1621000000000001`},0.24673642684215202`},{{-0.03`,22.4`,0.94368`,1.1666`},0.25176849292483683`},{{-0.03`,22.4`,0.94368`,1.1711`},0.25176849292483683`},{{-0.03`,22.4`,0.94368`,1.1621000000000001`},0.25176849292483683`},{{-0.03`,22.4`,0.93668`,1.1666`},0.24174883230504712`},{{-0.03`,22.4`,0.93668`,1.1711`},0.24174883230504712`},{{-0.03`,22.4`,0.93668`,1.1621000000000001`},0.24174883230504712`},{{-0.03`,23.`,0.94018`,1.1666`},0.2476653110910348`},{{-0.03`,23.`,0.94018`,1.1711`},0.2476653110910348`},{{-0.03`,23.`,0.94018`,1.1621000000000001`},0.2476653110910348`},{{-0.03`,23.`,0.94368`,1.1666`},0.25273292260943503`},{{-0.03`,23.`,0.94368`,1.1711`},0.25273292260943503`},{{-0.03`,23.`,0.94368`,1.1621000000000001`},0.25273292260943503`},{{-0.03`,23.`,0.93668`,1.1666`},0.24264209218060506`},{{-0.03`,23.`,0.93668`,1.1711`},0.24264209218060506`},{{-0.03`,23.`,0.93668`,1.1621000000000001`},0.24264209218060506`},{{-0.03`,23.6`,0.94018`,1.1666`},0.248524809215811`},{{-0.03`,23.6`,0.94018`,1.1711`},0.248524809215811`},{{-0.03`,23.6`,0.94018`,1.1621000000000001`},0.248524809215811`},{{-0.03`,23.6`,0.94368`,1.1666`},0.2536270806636988`},{{-0.03`,23.6`,0.94368`,1.1711`},0.2536270806636988`},{{-0.03`,23.6`,0.94368`,1.1621000000000001`},0.2536270806636988`},{{-0.03`,23.6`,0.93668`,1.1666`},0.2434668363098368`},{{-0.03`,23.6`,0.93668`,1.1711`},0.2434668363098368`},{{-0.03`,23.6`,0.93668`,1.1621000000000001`},0.2434668363098368`},{{-0.03`,24.2`,0.94018`,1.1666`},0.24931768494105258`},{{-0.03`,24.2`,0.94018`,1.1711`},0.24931768494105258`},{{-0.03`,24.2`,0.94018`,1.1621000000000001`},0.24931768494105258`},{{-0.03`,24.2`,0.94368`,1.1666`},0.2544538336420677`},{{-0.03`,24.2`,0.94368`,1.1711`},0.2544538336420677`},{{-0.03`,24.2`,0.94368`,1.1621000000000001`},0.2544538336420677`},{{-0.03`,24.2`,0.93668`,1.1666`},0.2442257268390955`},{{-0.03`,24.2`,0.93668`,1.1711`},0.2442257268390955`},{{-0.03`,24.2`,0.93668`,1.1621000000000001`},0.2442257268390955`},{{-0.03`,24.8`,0.94018`,1.1666`},0.25004953231849825`},{{-0.03`,24.8`,0.94018`,1.1711`},0.25004953231849825`},{{-0.03`,24.8`,0.94018`,1.1621000000000001`},0.25004953231849825`},{{-0.03`,24.8`,0.94368`,1.1666`},0.25521881265440594`},{{-0.03`,24.8`,0.94368`,1.1711`},0.25521881265440594`},{{-0.03`,24.8`,0.94368`,1.1621000000000001`},0.25521881265440594`},{{-0.03`,24.8`,0.93668`,1.1666`},0.24492432047850757`},{{-0.03`,24.8`,0.93668`,1.1711`},0.24492432047850757`},{{-0.03`,24.8`,0.93668`,1.1621000000000001`},0.24492432047850757`},{{-0.03`,25.4`,0.94018`,1.1666`},0.2507232776862925`},{{-0.03`,25.4`,0.94018`,1.1711`},0.2507232776862925`},{{-0.03`,25.4`,0.94018`,1.1621000000000001`},0.2507232776862925`},{{-0.03`,25.4`,0.94368`,1.1666`},0.2559250179886538`},{{-0.03`,25.4`,0.94368`,1.1711`},0.2559250179886538`},{{-0.03`,25.4`,0.94368`,1.1621000000000001`},0.2559250179886538`},{{-0.03`,25.4`,0.93668`,1.1666`},0.24556547055163327`},{{-0.03`,25.4`,0.93668`,1.1711`},0.24556547055163327`},{{-0.03`,25.4`,0.93668`,1.1621000000000001`},0.24556547055163327`},{{-0.03`,26.`,0.94018`,1.1666`},0.25134214858858356`},{{-0.03`,26.`,0.94018`,1.1711`},0.25134214858858356`},{{-0.03`,26.`,0.94018`,1.1621000000000001`},0.25134214858858356`},{{-0.03`,26.`,0.94368`,1.1666`},0.25657573631075137`},{{-0.03`,26.`,0.94368`,1.1711`},0.25657573631075137`},{{-0.03`,26.`,0.94368`,1.1621000000000001`},0.25657573631075137`},{{-0.03`,26.`,0.93668`,1.1666`},0.24615234598951957`},{{-0.03`,26.`,0.93668`,1.1711`},0.24615234598951957`},{{-0.03`,26.`,0.93668`,1.1621000000000001`},0.24615234598951957`},{{-0.03`,26.6`,0.94018`,1.1666`},0.2519091151133099`},{{-0.03`,26.6`,0.94018`,1.1711`},0.2519091151133099`},{{-0.03`,26.6`,0.94018`,1.1621000000000001`},0.2519091151133099`},{{-0.03`,26.6`,0.94368`,1.1666`},0.2571739940764933`},{{-0.03`,26.6`,0.94368`,1.1711`},0.2571739940764933`},{{-0.03`,26.6`,0.94368`,1.1621000000000001`},0.2571739940764933`},{{-0.03`,26.6`,0.93668`,1.1666`},0.24668786085336783`},{{-0.03`,26.6`,0.93668`,1.1711`},0.24668786085336783`},{{-0.03`,26.6`,0.93668`,1.1621000000000001`},0.24668786085336783`},{{-0.03`,27.2`,0.94018`,1.1666`},0.25242559785189406`},{{-0.03`,27.2`,0.94018`,1.1711`},0.25242559785189406`},{{-0.03`,27.2`,0.94018`,1.1621000000000001`},0.25242559785189406`},{{-0.03`,27.2`,0.94368`,1.1666`},0.25772129349550277`},{{-0.03`,27.2`,0.94368`,1.1711`},0.25772129349550277`},{{-0.03`,27.2`,0.94368`,1.1621000000000001`},0.25772129349550277`},{{-0.03`,27.2`,0.93668`,1.1666`},0.2471733551885399`},{{-0.03`,27.2`,0.93668`,1.1711`},0.2471733551885399`},{{-0.03`,27.2`,0.93668`,1.1621000000000001`},0.2471733551885399`},{{-0.03`,27.8`,0.94018`,1.1666`},0.25289568210539987`},{{-0.03`,27.8`,0.94018`,1.1711`},0.25289568210539987`},{{-0.03`,27.8`,0.94018`,1.1621000000000001`},0.25289568210539987`},{{-0.03`,27.8`,0.94368`,1.1666`},0.2582217362722559`},{{-0.03`,27.8`,0.94368`,1.1711`},0.2582217362722559`},{{-0.03`,27.8`,0.94368`,1.1621000000000001`},0.2582217362722559`},{{-0.03`,27.8`,0.93668`,1.1666`},0.24761289705538858`},{{-0.03`,27.8`,0.93668`,1.1711`},0.24761289705538858`},{{-0.03`,27.8`,0.93668`,1.1621000000000001`},0.24761289705538858`},{{-0.03`,28.4`,0.94018`,1.1666`},0.25332119425026434`},{{-0.03`,28.4`,0.94018`,1.1711`},0.25332119425026434`},{{-0.03`,28.4`,0.94018`,1.1621000000000001`},0.25332119425026434`},{{-0.03`,28.4`,0.94368`,1.1666`},0.2586772028919377`},{{-0.03`,28.4`,0.94368`,1.1711`},0.2586772028919377`},{{-0.03`,28.4`,0.94368`,1.1621000000000001`},0.2586772028919377`},{{-0.03`,28.4`,0.93668`,1.1666`},0.24800825947553876`},{{-0.03`,28.4`,0.93668`,1.1711`},0.24800825947553876`},{{-0.03`,28.4`,0.93668`,1.1621000000000001`},0.24800825947553876`},{{-0.03`,29.`,0.94018`,1.1666`},0.2537042541231769`},{{-0.03`,29.`,0.94018`,1.1711`},0.2537042541231769`},{{-0.03`,29.`,0.94018`,1.1621000000000001`},0.2537042541231769`},{{-0.03`,29.`,0.94368`,1.1666`},0.2590898563289232`},{{-0.03`,29.`,0.94368`,1.1711`},0.2590898563289232`},{{-0.03`,29.`,0.94368`,1.1621000000000001`},0.2590898563289232`},{{-0.03`,29.`,0.93668`,1.1666`},0.24836151936482884`},{{-0.03`,29.`,0.93668`,1.1711`},0.24836151936482884`},{{-0.03`,29.`,0.93668`,1.1621000000000001`},0.24836151936482884`},{{-0.03`,29.6`,0.94018`,1.1666`},0.2540460815530479`},{{-0.03`,29.6`,0.94018`,1.1711`},0.2540460815530479`},{{-0.03`,29.6`,0.94018`,1.1621000000000001`},0.2540460815530479`},{{-0.03`,29.6`,0.94368`,1.1666`},0.25946097482245073`},{{-0.03`,29.6`,0.94368`,1.1711`},0.25946097482245073`},{{-0.03`,29.6`,0.94368`,1.1621000000000001`},0.25946097482245073`},{{-0.03`,29.6`,0.93668`,1.1666`},0.2486738388214369`},{{-0.03`,29.6`,0.93668`,1.1711`},0.2486738388214369`},{{-0.03`,29.6`,0.93668`,1.1621000000000001`},0.2486738388214369`},{{-0.03`,30.2`,0.94018`,1.1666`},0.25434918841251936`},{{-0.03`,30.2`,0.94018`,1.1711`},0.25434918841251936`},{{-0.03`,30.2`,0.94018`,1.1621000000000001`},0.25434918841251936`},{{-0.03`,30.2`,0.94368`,1.1666`},0.25979309627863467`},{{-0.03`,30.2`,0.94368`,1.1711`},0.25979309627863467`},{{-0.03`,30.2`,0.94368`,1.1621000000000001`},0.25979309627863467`},{{-0.03`,30.2`,0.93668`,1.1666`},0.24894770295572374`},{{-0.03`,30.2`,0.93668`,1.1711`},0.24894770295572374`},{{-0.03`,30.2`,0.93668`,1.1621000000000001`},0.24894770295572374`},{{-0.03`,30.8`,0.94018`,1.1666`},0.254615021436433`},{{-0.03`,30.8`,0.94018`,1.1711`},0.254615021436433`},{{-0.03`,30.8`,0.94018`,1.1621000000000001`},0.254615021436433`},{{-0.03`,30.8`,0.94368`,1.1666`},0.26008770687029864`},{{-0.03`,30.8`,0.94368`,1.1711`},0.26008770687029864`},{{-0.03`,30.8`,0.94368`,1.1621000000000001`},0.26008770687029864`},{{-0.03`,30.8`,0.93668`,1.1666`},0.24918451949947154`},{{-0.03`,30.8`,0.93668`,1.1711`},0.24918451949947154`},{{-0.03`,30.8`,0.93668`,1.1621000000000001`},0.24918451949947154`},{{-0.03`,31.4`,0.94018`,1.1666`},0.254845081950059`},{{-0.03`,31.4`,0.94018`,1.1711`},0.254845081950059`},{{-0.03`,31.4`,0.94018`,1.1621000000000001`},0.254845081950059`},{{-0.03`,31.4`,0.94368`,1.1666`},0.2603463438051243`},{{-0.03`,31.4`,0.94368`,1.1711`},0.2603463438051243`},{{-0.03`,31.4`,0.94368`,1.1621000000000001`},0.2603463438051243`},{{-0.03`,31.4`,0.93668`,1.1666`},0.24938575395097998`},{{-0.03`,31.4`,0.93668`,1.1711`},0.24938575395097998`},{{-0.03`,31.4`,0.93668`,1.1621000000000001`},0.24938575395097998`},{{-0.03`,32.`,0.94018`,1.1666`},0.25504037796058604`},{{-0.03`,32.`,0.94018`,1.1711`},0.25504037796058604`},{{-0.03`,32.`,0.94018`,1.1621000000000001`},0.25504037796058604`},{{-0.03`,32.`,0.94368`,1.1666`},0.26057005817520357`},{{-0.03`,32.`,0.94368`,1.1711`},0.26057005817520357`},{{-0.03`,32.`,0.94368`,1.1621000000000001`},0.26057005817520357`},{{-0.03`,32.`,0.93668`,1.1666`},0.2495523716290419`},{{-0.03`,32.`,0.93668`,1.1711`},0.2495523716290419`},{{-0.03`,32.`,0.93668`,1.1621000000000001`},0.2495523716290419`},{{-0.03`,32.6`,0.94018`,1.1666`},0.25520243345905336`},{{-0.03`,32.6`,0.94018`,1.1711`},0.25520243345905336`},{{-0.03`,32.6`,0.94018`,1.1621000000000001`},0.25520243345905336`},{{-0.03`,32.6`,0.94368`,1.1666`},0.26076040481817464`},{{-0.03`,32.6`,0.94368`,1.1711`},0.26076040481817464`},{{-0.03`,32.6`,0.94368`,1.1621000000000001`},0.26076040481817464`},{{-0.03`,32.6`,0.93668`,1.1666`},0.24968586504210308`},{{-0.03`,32.6`,0.93668`,1.1711`},0.24968586504210308`},{{-0.03`,32.6`,0.93668`,1.1621000000000001`},0.24968586504210308`},{{-0.03`,33.2`,0.94018`,1.1666`},0.25533236430460643`},{{-0.03`,33.2`,0.94018`,1.1711`},0.25533236430460643`},{{-0.03`,33.2`,0.94018`,1.1621000000000001`},0.25533236430460643`},{{-0.03`,33.2`,0.94368`,1.1666`},0.2609185305820485`},{{-0.03`,33.2`,0.94368`,1.1711`},0.2609185305820485`},{{-0.03`,33.2`,0.94368`,1.1621000000000001`},0.2609185305820485`},{{-0.03`,33.2`,0.93668`,1.1666`},0.2497873192455216`},{{-0.03`,33.2`,0.93668`,1.1711`},0.2497873192455216`},{{-0.03`,33.2`,0.93668`,1.1621000000000001`},0.2497873192455216`},{{-0.03`,33.8`,0.94018`,1.1666`},0.2554312137806776`},{{-0.03`,33.8`,0.94018`,1.1711`},0.2554312137806776`},{{-0.03`,33.8`,0.94018`,1.1621000000000001`},0.2554312137806776`},{{-0.03`,33.8`,0.94368`,1.1666`},0.261045510354574`},{{-0.03`,33.8`,0.94368`,1.1711`},0.261045510354574`},{{-0.03`,33.8`,0.94368`,1.1621000000000001`},0.261045510354574`},{{-0.03`,33.8`,0.93668`,1.1666`},0.24985774582215933`},{{-0.03`,33.8`,0.93668`,1.1711`},0.24985774582215933`},{{-0.03`,33.8`,0.93668`,1.1621000000000001`},0.24985774582215933`},{{-0.03`,34.4`,0.94018`,1.1666`},0.2554999342723821`},{{-0.03`,34.4`,0.94018`,1.1711`},0.2554999342723821`},{{-0.03`,34.4`,0.94018`,1.1621000000000001`},0.2554999342723821`},{{-0.03`,34.4`,0.94368`,1.1666`},0.2611423271714842`},{{-0.03`,34.4`,0.94368`,1.1711`},0.2611423271714842`},{{-0.03`,34.4`,0.94368`,1.1621000000000001`},0.2611423271714842`},{{-0.03`,34.4`,0.93668`,1.1666`},0.24989806637671655`},{{-0.03`,34.4`,0.93668`,1.1711`},0.24989806637671655`},{{-0.03`,34.4`,0.93668`,1.1621000000000001`},0.24989806637671655`},{{-0.03`,35.`,0.94018`,1.1666`},0.25553947288240664`},{{-0.03`,35.`,0.94018`,1.1711`},0.25553947288240664`},{{-0.03`,35.`,0.94018`,1.1621000000000001`},0.25553947288240664`},{{-0.03`,35.`,0.94368`,1.1666`},0.26120995755455506`},{{-0.03`,35.`,0.94368`,1.1711`},0.26120995755455506`},{{-0.03`,35.`,0.94368`,1.1621000000000001`},0.26120995755455506`},{{-0.03`,35.`,0.93668`,1.1666`},0.24990919827887847`},{{-0.03`,35.`,0.93668`,1.1711`},0.24990919827887847`},{{-0.03`,35.`,0.93668`,1.1621000000000001`},0.24990919827887847`},{{-0.03`,35.6`,0.94018`,1.1666`},0.25554942377471745`},{{-0.03`,35.6`,0.94018`,1.1711`},0.25554942377471745`},{{-0.03`,35.6`,0.94018`,1.1621000000000001`},0.25554942377471745`},{{-0.03`,35.6`,0.94368`,1.1666`},0.2612480559521686`},{{-0.03`,35.6`,0.94368`,1.1711`},0.2612480559521686`},{{-0.03`,35.6`,0.94368`,1.1621000000000001`},0.2612480559521686`},{{-0.03`,35.6`,0.93668`,1.1666`},0.24989067623472438`},{{-0.03`,35.6`,0.93668`,1.1711`},0.24989067623472438`},{{-0.03`,35.6`,0.93668`,1.1621000000000001`},0.24989067623472438`},{{-0.03`,36.2`,0.94018`,1.1666`},0.25553204792856915`},{{-0.03`,36.2`,0.94018`,1.1711`},0.25553204792856915`},{{-0.03`,36.2`,0.94018`,1.1621000000000001`},0.25553204792856915`},{{-0.03`,36.2`,0.94368`,1.1666`},0.2612588721351748`},{{-0.03`,36.2`,0.94368`,1.1711`},0.2612588721351748`},{{-0.03`,36.2`,0.94368`,1.1621000000000001`},0.2612588721351748`},{{-0.03`,36.2`,0.93668`,1.1666`},0.24984477077917974`},{{-0.03`,36.2`,0.93668`,1.1711`},0.24984477077917974`},{{-0.03`,36.2`,0.93668`,1.1621000000000001`},0.24984477077917974`},{{-0.03`,36.8`,0.94018`,1.1666`},0.2554873754670647`},{{-0.03`,36.8`,0.94018`,1.1711`},0.2554873754670647`},{{-0.03`,36.8`,0.94018`,1.1621000000000001`},0.2554873754670647`},{{-0.03`,36.8`,0.94368`,1.1666`},0.26124248036631137`},{{-0.03`,36.8`,0.94368`,1.1711`},0.26124248036631137`},{{-0.03`,36.8`,0.94368`,1.1621000000000001`},0.26124248036631137`},{{-0.03`,36.8`,0.93668`,1.1666`},0.2497714681885969`},{{-0.03`,36.8`,0.93668`,1.1711`},0.2497714681885969`},{{-0.03`,36.8`,0.93668`,1.1621000000000001`},0.2497714681885969`},{{-0.03`,37.4`,0.94018`,1.1666`},0.2554159510633286`},{{-0.03`,37.4`,0.94018`,1.1711`},0.2554159510633286`},{{-0.03`,37.4`,0.94018`,1.1621000000000001`},0.2554159510633286`},{{-0.03`,37.4`,0.94368`,1.1666`},0.26119945431894365`},{{-0.03`,37.4`,0.94368`,1.1711`},0.26119945431894365`},{{-0.03`,37.4`,0.94368`,1.1621000000000001`},0.26119945431894365`},{{-0.03`,37.4`,0.93668`,1.1666`},0.24967128382846615`},{{-0.03`,37.4`,0.93668`,1.1711`},0.24967128382846615`},{{-0.03`,37.4`,0.93668`,1.1621000000000001`},0.24967128382846615`},{{-0.03`,38.`,0.94018`,1.1666`},0.25531825247843853`},{{-0.03`,38.`,0.94018`,1.1711`},0.25531825247843853`},{{-0.03`,38.`,0.94018`,1.1621000000000001`},0.25531825247843853`},{{-0.03`,38.`,0.94368`,1.1666`},0.2611303005940003`},{{-0.03`,38.`,0.94368`,1.1711`},0.2611303005940003`},{{-0.03`,38.`,0.94368`,1.1621000000000001`},0.2611303005940003`},{{-0.03`,38.`,0.93668`,1.1666`},0.24954466627544686`},{{-0.03`,38.`,0.93668`,1.1711`},0.24954466627544686`},{{-0.03`,38.`,0.93668`,1.1621000000000001`},0.24954466627544686`},{{-0.03`,38.6`,0.94018`,1.1666`},0.2551946930453707`},{{-0.03`,38.6`,0.94018`,1.1711`},0.2551946930453707`},{{-0.03`,38.6`,0.94018`,1.1621000000000001`},0.2551946930453707`},{{-0.03`,38.6`,0.94368`,1.1666`},0.26103546130971533`},{{-0.03`,38.6`,0.94368`,1.1711`},0.26103546130971533`},{{-0.03`,38.6`,0.94368`,1.1621000000000001`},0.26103546130971533`},{{-0.03`,38.6`,0.93668`,1.1666`},0.24939199969447895`},{{-0.03`,38.6`,0.93668`,1.1711`},0.24939199969447895`},{{-0.03`,38.6`,0.93668`,1.1621000000000001`},0.24939199969447895`},{{-0.03`,39.2`,0.94018`,1.1666`},0.25504562372467204`},{{-0.03`,39.2`,0.94018`,1.1711`},0.25504562372467204`},{{-0.03`,39.2`,0.94018`,1.1621000000000001`},0.25504562372467204`},{{-0.03`,39.2`,0.94368`,1.1666`},0.26091531626354325`},{{-0.03`,39.2`,0.94368`,1.1711`},0.26091531626354325`},{{-0.03`,39.2`,0.94368`,1.1621000000000001`},0.26091531626354325`},{{-0.03`,39.2`,0.93668`,1.1666`},0.24921360578693166`},{{-0.03`,39.2`,0.93668`,1.1711`},0.24921360578693166`},{{-0.03`,39.2`,0.93668`,1.1621000000000001`},0.24921360578693166`},{{-0.03`,39.8`,0.94018`,1.1666`},0.2548713347502262`},{{-0.03`,39.8`,0.94018`,1.1711`},0.2548713347502262`},{{-0.03`,39.8`,0.94018`,1.1621000000000001`},0.2548713347502262`},{{-0.03`,39.8`,0.94368`,1.1666`},0.26077018468561713`},{{-0.03`,39.8`,0.94368`,1.1711`},0.26077018468561713`},{{-0.03`,39.8`,0.94368`,1.1621000000000001`},0.26077018468561713`},{{-0.03`,39.8`,0.93668`,1.1666`},0.24900974532716486`},{{-0.03`,39.8`,0.93668`,1.1711`},0.24900974532716486`},{{-0.03`,39.8`,0.93668`,1.1621000000000001`},0.24900974532716486`},{{0.`,0.4`,0.94018`,1.1666`},0.02142782702809648`},{{0.`,0.4`,0.94018`,1.1711`},0.02142782702809648`},{{0.`,0.4`,0.94018`,1.1621000000000001`},0.02142782702809648`},{{0.`,0.4`,0.94368`,1.1666`},0.02176575678899757`},{{0.`,0.4`,0.94368`,1.1711`},0.02176575678899757`},{{0.`,0.4`,0.94368`,1.1621000000000001`},0.02176575678899757`},{{0.`,0.4`,0.93668`,1.1666`},0.02109358899756884`},{{0.`,0.4`,0.93668`,1.1711`},0.02109358899756884`},{{0.`,0.4`,0.93668`,1.1621000000000001`},0.02109358899756884`},{{0.`,0.6`,0.94018`,1.1666`},0.03128290529204494`},{{0.`,0.6`,0.94018`,1.1711`},0.03128290529204494`},{{0.`,0.6`,0.94018`,1.1621000000000001`},0.03128290529204494`},{{0.`,0.6`,0.94368`,1.1666`},0.03177763578422278`},{{0.`,0.6`,0.94368`,1.1711`},0.03177763578422278`},{{0.`,0.6`,0.94368`,1.1621000000000001`},0.03177763578422278`},{{0.`,0.6`,0.93668`,1.1666`},0.030793593316440042`},{{0.`,0.6`,0.93668`,1.1711`},0.030793593316440042`},{{0.`,0.6`,0.93668`,1.1621000000000001`},0.030793593316440042`},{{0.`,0.8`,0.94018`,1.1666`},0.04061963653935648`},{{0.`,0.8`,0.94018`,1.1711`},0.04061963653935648`},{{0.`,0.8`,0.94018`,1.1621000000000001`},0.04061963653935648`},{{0.`,0.8`,0.94368`,1.1666`},0.041263734419688676`},{{0.`,0.8`,0.94368`,1.1711`},0.041263734419688676`},{{0.`,0.8`,0.94368`,1.1621000000000001`},0.041263734419688676`},{{0.`,0.8`,0.93668`,1.1666`},0.03998260887576226`},{{0.`,0.8`,0.93668`,1.1711`},0.03998260887576226`},{{0.`,0.8`,0.93668`,1.1621000000000001`},0.03998260887576226`},{{0.`,1.`,0.94018`,1.1666`},0.04947418028397216`},{{0.`,1.`,0.94018`,1.1711`},0.04947418028397216`},{{0.`,1.`,0.94018`,1.1621000000000001`},0.04947418028397216`},{{0.`,1.`,0.94368`,1.1666`},0.05026067264684195`},{{0.`,1.`,0.94368`,1.1711`},0.05026067264684195`},{{0.`,1.`,0.94368`,1.1621000000000001`},0.05026067264684195`},{{0.`,1.`,0.93668`,1.1666`},0.048696337945435514`},{{0.`,1.`,0.93668`,1.1711`},0.048696337945435514`},{{0.`,1.`,0.93668`,1.1621000000000001`},0.048696337945435514`},{{0.`,1.2`,0.94018`,1.1666`},0.05787955208304953`},{{0.`,1.2`,0.94018`,1.1711`},0.05787955208304953`},{{0.`,1.2`,0.94018`,1.1621000000000001`},0.05787955208304953`},{{0.`,1.2`,0.94368`,1.1666`},0.05880189274194298`},{{0.`,1.2`,0.94368`,1.1711`},0.05880189274194298`},{{0.`,1.2`,0.94368`,1.1621000000000001`},0.05880189274194298`},{{0.`,1.2`,0.93668`,1.1666`},0.05696737249857386`},{{0.`,1.2`,0.93668`,1.1711`},0.05696737249857386`},{{0.`,1.2`,0.93668`,1.1621000000000001`},0.05696737249857386`},{{0.`,1.4`,0.94018`,1.1666`},0.0658659486795997`},{{0.`,1.4`,0.94018`,1.1711`},0.0658659486795997`},{{0.`,1.4`,0.94018`,1.1621000000000001`},0.0658659486795997`},{{0.`,1.4`,0.94368`,1.1666`},0.06691798716700277`},{{0.`,1.4`,0.94368`,1.1711`},0.06691798716700277`},{{0.`,1.4`,0.94368`,1.1621000000000001`},0.06691798716700277`},{{0.`,1.4`,0.93668`,1.1666`},0.06482551661661758`},{{0.`,1.4`,0.93668`,1.1711`},0.06482551661661758`},{{0.`,1.4`,0.93668`,1.1621000000000001`},0.06482551661661758`},{{0.`,1.6`,0.94018`,1.1666`},0.07346103443789069`},{{0.`,1.6`,0.94018`,1.1711`},0.07346103443789069`},{{0.`,1.6`,0.94018`,1.1621000000000001`},0.07346103443789069`},{{0.`,1.6`,0.94368`,1.1666`},0.07463698750511326`},{{0.`,1.6`,0.94368`,1.1711`},0.07463698750511326`},{{0.`,1.6`,0.94368`,1.1621000000000001`},0.07463698750511326`},{{0.`,1.6`,0.93668`,1.1666`},0.0722980704110702`},{{0.`,1.6`,0.93668`,1.1711`},0.0722980704110702`},{{0.`,1.6`,0.93668`,1.1621000000000001`},0.0722980704110702`},{{0.`,1.8`,0.94018`,1.1666`},0.08069019424900427`},{{0.`,1.8`,0.94018`,1.1711`},0.08069019424900427`},{{0.`,1.8`,0.94018`,1.1621000000000001`},0.08069019424900427`},{{0.`,1.8`,0.94368`,1.1666`},0.08198461966070375`},{{0.`,1.8`,0.94368`,1.1711`},0.08198461966070375`},{{0.`,1.8`,0.94368`,1.1621000000000001`},0.08198461966070375`},{{0.`,1.8`,0.93668`,1.1666`},0.0794100806249283`},{{0.`,1.8`,0.93668`,1.1711`},0.0794100806249283`},{{0.`,1.8`,0.93668`,1.1621000000000001`},0.0794100806249283`},{{0.`,2.`,0.94018`,1.1666`},0.08757675732029443`},{{0.`,2.`,0.94018`,1.1711`},0.08757675732029443`},{{0.`,2.`,0.94018`,1.1621000000000001`},0.08757675732029443`},{{0.`,2.`,0.94368`,1.1666`},0.08898452975238688`},{{0.`,2.`,0.94368`,1.1711`},0.08898452975238688`},{{0.`,2.`,0.94368`,1.1621000000000001`},0.08898452975238688`},{{0.`,2.`,0.93668`,1.1666`},0.08618456231269425`},{{0.`,2.`,0.93668`,1.1711`},0.08618456231269425`},{{0.`,2.`,0.93668`,1.1621000000000001`},0.08618456231269425`},{{0.`,2.2`,0.94018`,1.1666`},0.0941421956211798`},{{0.`,2.2`,0.94018`,1.1711`},0.0941421956211798`},{{0.`,2.2`,0.94018`,1.1621000000000001`},0.0941421956211798`},{{0.`,2.2`,0.94368`,1.1666`},0.09565848448489435`},{{0.`,2.2`,0.94368`,1.1711`},0.09565848448489435`},{{0.`,2.2`,0.94368`,1.1621000000000001`},0.09565848448489435`},{{0.`,2.2`,0.93668`,1.1666`},0.09264269535659722`},{{0.`,2.2`,0.93668`,1.1711`},0.09264269535659722`},{{0.`,2.2`,0.93668`,1.1621000000000001`},0.09264269535659722`},{{0.`,2.6`,0.94018`,1.1666`},0.1063854827306254`},{{0.`,2.6`,0.94018`,1.1711`},0.1063854827306254`},{{0.`,2.6`,0.94018`,1.1621000000000001`},0.1063854827306254`},{{0.`,2.6`,0.94368`,1.1666`},0.10810539460641273`},{{0.`,2.6`,0.94368`,1.1711`},0.10810539460641273`},{{0.`,2.6`,0.94368`,1.1621000000000001`},0.10810539460641273`},{{0.`,2.6`,0.93668`,1.1666`},0.10468462914095668`},{{0.`,2.6`,0.93668`,1.1711`},0.10468462914095668`},{{0.`,2.6`,0.93668`,1.1621000000000001`},0.10468462914095668`},{{0.`,3.`,0.94018`,1.1666`},0.11756209351362461`},{{0.`,3.`,0.94018`,1.1711`},0.11756209351362461`},{{0.`,3.`,0.94018`,1.1621000000000001`},0.11756209351362461`},{{0.`,3.`,0.94368`,1.1666`},0.1194693761670286`},{{0.`,3.`,0.94368`,1.1711`},0.1194693761670286`},{{0.`,3.`,0.94368`,1.1621000000000001`},0.1194693761670286`},{{0.`,3.`,0.93668`,1.1666`},0.11567595021162423`},{{0.`,3.`,0.93668`,1.1711`},0.11567595021162423`},{{0.`,3.`,0.93668`,1.1621000000000001`},0.11567595021162423`},{{0.`,3.4`,0.94018`,1.1666`},0.1277930956595736`},{{0.`,3.4`,0.94018`,1.1711`},0.1277930956595736`},{{0.`,3.4`,0.94018`,1.1621000000000001`},0.1277930956595736`},{{0.`,3.4`,0.94368`,1.1666`},0.12987321118692668`},{{0.`,3.4`,0.94368`,1.1711`},0.12987321118692668`},{{0.`,3.4`,0.94368`,1.1621000000000001`},0.12987321118692668`},{{0.`,3.4`,0.93668`,1.1666`},0.12573602910811815`},{{0.`,3.4`,0.93668`,1.1711`},0.12573602910811815`},{{0.`,3.4`,0.93668`,1.1621000000000001`},0.12573602910811815`},{{0.`,3.8`,0.94018`,1.1666`},0.13718227591225965`},{{0.`,3.8`,0.94018`,1.1711`},0.13718227591225965`},{{0.`,3.8`,0.94018`,1.1621000000000001`},0.13718227591225965`},{{0.`,3.8`,0.94368`,1.1666`},0.13942218935101916`},{{0.`,3.8`,0.94368`,1.1711`},0.13942218935101916`},{{0.`,3.8`,0.94368`,1.1621000000000001`},0.13942218935101916`},{{0.`,3.8`,0.93668`,1.1666`},0.13496716524771213`},{{0.`,3.8`,0.93668`,1.1711`},0.13496716524771213`},{{0.`,3.8`,0.93668`,1.1621000000000001`},0.13496716524771213`},{{0.`,4.2`,0.94018`,1.1666`},0.14581942814397117`},{{0.`,4.2`,0.94018`,1.1711`},0.14581942814397117`},{{0.`,4.2`,0.94018`,1.1621000000000001`},0.14581942814397117`},{{0.`,4.2`,0.94368`,1.1666`},0.14820742106733997`},{{0.`,4.2`,0.94368`,1.1711`},0.14820742106733997`},{{0.`,4.2`,0.94368`,1.1621000000000001`},0.14820742106733997`},{{0.`,4.2`,0.93668`,1.1666`},0.14345785006994602`},{{0.`,4.2`,0.93668`,1.1711`},0.14345785006994602`},{{0.`,4.2`,0.93668`,1.1621000000000001`},0.14345785006994602`},{{0.`,4.6`,0.94018`,1.1666`},0.15378307323501553`},{{0.`,4.6`,0.94018`,1.1711`},0.15378307323501553`},{{0.`,4.6`,0.94018`,1.1621000000000001`},0.15378307323501553`},{{0.`,4.6`,0.94368`,1.1666`},0.15630858313419302`},{{0.`,4.6`,0.94368`,1.1711`},0.15630858313419302`},{{0.`,4.6`,0.94368`,1.1621000000000001`},0.15630858313419302`},{{0.`,4.6`,0.93668`,1.1666`},0.15128546105711035`},{{0.`,4.6`,0.93668`,1.1711`},0.15128546105711035`},{{0.`,4.6`,0.93668`,1.1621000000000001`},0.15128546105711035`},{{0.`,5.`,0.94018`,1.1666`},0.1611411260793181`},{{0.`,5.`,0.94018`,1.1711`},0.1611411260793181`},{{0.`,5.`,0.94018`,1.1621000000000001`},0.1611411260793181`},{{0.`,5.`,0.94368`,1.1666`},0.16379460095123508`},{{0.`,5.`,0.94368`,1.1711`},0.16379460095123508`},{{0.`,5.`,0.94368`,1.1621000000000001`},0.16379460095123508`},{{0.`,5.`,0.93668`,1.1666`},0.15851691422727948`},{{0.`,5.`,0.93668`,1.1711`},0.15851691422727948`},{{0.`,5.`,0.93668`,1.1621000000000001`},0.15851691422727948`},{{0.`,5.4`,0.94018`,1.1666`},0.16795263328666257`},{{0.`,5.4`,0.94018`,1.1711`},0.16795263328666257`},{{0.`,5.4`,0.94018`,1.1621000000000001`},0.16795263328666257`},{{0.`,5.4`,0.94368`,1.1666`},0.17072542698718787`},{{0.`,5.4`,0.94368`,1.1711`},0.17072542698718787`},{{0.`,5.4`,0.94368`,1.1621000000000001`},0.17072542698718787`},{{0.`,5.4`,0.93668`,1.1666`},0.16521036024305877`},{{0.`,5.4`,0.93668`,1.1711`},0.16521036024305877`},{{0.`,5.4`,0.93668`,1.1621000000000001`},0.16521036024305877`},{{0.`,5.8`,0.94018`,1.1666`},0.17426991951718357`},{{0.`,5.8`,0.94018`,1.1711`},0.17426991951718357`},{{0.`,5.8`,0.94018`,1.1621000000000001`},0.17426991951718357`},{{0.`,5.8`,0.94368`,1.1666`},0.17715418308685255`},{{0.`,5.8`,0.94368`,1.1711`},0.17715418308685255`},{{0.`,5.8`,0.94368`,1.1621000000000001`},0.17715418308685255`},{{0.`,5.8`,0.93668`,1.1666`},0.17141733758787492`},{{0.`,5.8`,0.93668`,1.1711`},0.17141733758787492`},{{0.`,5.8`,0.93668`,1.1621000000000001`},0.17141733758787492`},{{0.`,6.2`,0.94018`,1.1666`},0.1801391158160965`},{{0.`,6.2`,0.94018`,1.1711`},0.1801391158160965`},{{0.`,6.2`,0.94018`,1.1621000000000001`},0.1801391158160965`},{{0.`,6.2`,0.94368`,1.1666`},0.1831277072381074`},{{0.`,6.2`,0.94368`,1.1711`},0.1831277072381074`},{{0.`,6.2`,0.94368`,1.1621000000000001`},0.1831277072381074`},{{0.`,6.2`,0.93668`,1.1666`},0.1771832767434044`},{{0.`,6.2`,0.93668`,1.1711`},0.1771832767434044`},{{0.`,6.2`,0.93668`,1.1621000000000001`},0.1771832767434044`},{{0.`,6.8`,0.94018`,1.1666`},0.188190382725269`},{{0.`,6.8`,0.94018`,1.1711`},0.188190382725269`},{{0.`,6.8`,0.94018`,1.1621000000000001`},0.188190382725269`},{{0.`,6.8`,0.94368`,1.1666`},0.19132343409375588`},{{0.`,6.8`,0.94368`,1.1711`},0.19132343409375588`},{{0.`,6.8`,0.94368`,1.1621000000000001`},0.19132343409375588`},{{0.`,6.8`,0.93668`,1.1666`},0.18509153781069304`},{{0.`,6.8`,0.93668`,1.1711`},0.18509153781069304`},{{0.`,6.8`,0.93668`,1.1621000000000001`},0.18509153781069304`},{{0.`,7.4`,0.94018`,1.1666`},0.19544269071185144`},{{0.`,7.4`,0.94018`,1.1711`},0.19544269071185144`},{{0.`,7.4`,0.94018`,1.1621000000000001`},0.19544269071185144`},{{0.`,7.4`,0.94368`,1.1666`},0.19870738955253547`},{{0.`,7.4`,0.94368`,1.1711`},0.19870738955253547`},{{0.`,7.4`,0.94368`,1.1621000000000001`},0.19870738955253547`},{{0.`,7.4`,0.93668`,1.1666`},0.19221349094777218`},{{0.`,7.4`,0.93668`,1.1711`},0.19221349094777218`},{{0.`,7.4`,0.93668`,1.1621000000000001`},0.19221349094777218`},{{0.`,8.`,0.94018`,1.1666`},0.2019959618961053`},{{0.`,8.`,0.94018`,1.1711`},0.2019959618961053`},{{0.`,8.`,0.94018`,1.1621000000000001`},0.2019959618961053`},{{0.`,8.`,0.94368`,1.1666`},0.20538106373806098`},{{0.`,8.`,0.94368`,1.1711`},0.20538106373806098`},{{0.`,8.`,0.94368`,1.1621000000000001`},0.20538106373806098`},{{0.`,8.`,0.93668`,1.1666`},0.19864750921374727`},{{0.`,8.`,0.93668`,1.1711`},0.19864750921374727`},{{0.`,8.`,0.93668`,1.1621000000000001`},0.19864750921374727`},{{0.`,8.6`,0.94018`,1.1666`},0.2079353067326712`},{{0.`,8.6`,0.94018`,1.1711`},0.2079353067326712`},{{0.`,8.6`,0.94018`,1.1621000000000001`},0.2079353067326712`},{{0.`,8.6`,0.94368`,1.1666`},0.21143090528094766`},{{0.`,8.6`,0.94368`,1.1711`},0.21143090528094766`},{{0.`,8.6`,0.94368`,1.1621000000000001`},0.21143090528094766`},{{0.`,8.6`,0.93668`,1.1666`},0.20447738158429554`},{{0.`,8.6`,0.93668`,1.1711`},0.20447738158429554`},{{0.`,8.6`,0.93668`,1.1621000000000001`},0.20447738158429554`},{{0.`,9.2`,0.94018`,1.1666`},0.21333263362550772`},{{0.`,9.2`,0.94018`,1.1711`},0.21333263362550772`},{{0.`,9.2`,0.94018`,1.1621000000000001`},0.21333263362550772`},{{0.`,9.2`,0.94368`,1.1666`},0.21692997027575336`},{{0.`,9.2`,0.94368`,1.1711`},0.21692997027575336`},{{0.`,9.2`,0.94368`,1.1621000000000001`},0.21692997027575336`},{{0.`,9.2`,0.93668`,1.1666`},0.2097738839615138`},{{0.`,9.2`,0.93668`,1.1711`},0.2097738839615138`},{{0.`,9.2`,0.93668`,1.1621000000000001`},0.2097738839615138`},{{0.`,9.8`,0.94018`,1.1666`},0.21824982650667987`},{{0.`,9.8`,0.94018`,1.1711`},0.21824982650667987`},{{0.`,9.8`,0.94018`,1.1621000000000001`},0.21824982650667987`},{{0.`,9.8`,0.94368`,1.1666`},0.22194112601304508`},{{0.`,9.8`,0.94368`,1.1711`},0.22194112601304508`},{{0.`,9.8`,0.94368`,1.1621000000000001`},0.22194112601304508`},{{0.`,9.8`,0.93668`,1.1666`},0.21459792799670735`},{{0.`,9.8`,0.93668`,1.1711`},0.21459792799670735`},{{0.`,9.8`,0.93668`,1.1621000000000001`},0.21459792799670735`},{{0.`,10.4`,0.94018`,1.1666`},0.2227394304274717`},{{0.`,10.4`,0.94018`,1.1711`},0.2227394304274717`},{{0.`,10.4`,0.94018`,1.1621000000000001`},0.2227394304274717`},{{0.`,10.4`,0.94368`,1.1666`},0.22651776962939998`},{{0.`,10.4`,0.94368`,1.1711`},0.22651776962939998`},{{0.`,10.4`,0.94368`,1.1621000000000001`},0.22651776962939998`},{{0.`,10.4`,0.93668`,1.1666`},0.2190012183287648`},{{0.`,10.4`,0.93668`,1.1711`},0.2190012183287648`},{{0.`,10.4`,0.93668`,1.1621000000000001`},0.2190012183287648`},{{0.`,11.`,0.94018`,1.1666`},0.22684778462410057`},{{0.`,11.`,0.94018`,1.1711`},0.22684778462410057`},{{0.`,11.`,0.94018`,1.1621000000000001`},0.22684778462410057`},{{0.`,11.`,0.94368`,1.1666`},0.23070698177599425`},{{0.`,11.`,0.94368`,1.1711`},0.23070698177599425`},{{0.`,11.`,0.94368`,1.1621000000000001`},0.23070698177599425`},{{0.`,11.`,0.93668`,1.1666`},0.22302936215505897`},{{0.`,11.`,0.93668`,1.1711`},0.22302936215505897`},{{0.`,11.`,0.93668`,1.1621000000000001`},0.22302936215505897`},{{0.`,11.6`,0.94018`,1.1666`},0.23061461595531446`},{{0.`,11.6`,0.94018`,1.1711`},0.23061461595531446`},{{0.`,11.6`,0.94018`,1.1621000000000001`},0.23061461595531446`},{{0.`,11.6`,0.94368`,1.1666`},0.23454913135775682`},{{0.`,11.6`,0.94368`,1.1711`},0.23454913135775682`},{{0.`,11.6`,0.94368`,1.1621000000000001`},0.23454913135775682`},{{0.`,11.6`,0.93668`,1.1666`},0.22672145263813193`},{{0.`,11.6`,0.93668`,1.1711`},0.22672145263813193`},{{0.`,11.6`,0.93668`,1.1621000000000001`},0.22672145263813193`},{{0.`,12.2`,0.94018`,1.1666`},0.23407377952637837`},{{0.`,12.2`,0.94018`,1.1711`},0.23407377952637837`},{{0.`,12.2`,0.94018`,1.1621000000000001`},0.23407377952637837`},{{0.`,12.2`,0.94368`,1.1666`},0.23807864121104652`},{{0.`,12.2`,0.94368`,1.1711`},0.23807864121104652`},{{0.`,12.2`,0.94368`,1.1621000000000001`},0.23807864121104652`},{{0.`,12.2`,0.93668`,1.1666`},0.23011078448526343`},{{0.`,12.2`,0.93668`,1.1711`},0.23011078448526343`},{{0.`,12.2`,0.93668`,1.1621000000000001`},0.23011078448526343`},{{0.`,12.8`,0.94018`,1.1666`},0.23725648940486635`},{{0.`,12.8`,0.94018`,1.1711`},0.23725648940486635`},{{0.`,12.8`,0.94018`,1.1621000000000001`},0.23725648940486635`},{{0.`,12.8`,0.94368`,1.1666`},0.24132721867974904`},{{0.`,12.8`,0.94368`,1.1711`},0.24132721867974904`},{{0.`,12.8`,0.94368`,1.1621000000000001`},0.24132721867974904`},{{0.`,12.8`,0.93668`,1.1666`},0.23322808467089584`},{{0.`,12.8`,0.93668`,1.1711`},0.23322808467089584`},{{0.`,12.8`,0.93668`,1.1621000000000001`},0.23322808467089584`},{{0.`,13.4`,0.94018`,1.1666`},0.24018886505888162`},{{0.`,13.4`,0.94018`,1.1711`},0.24018886505888162`},{{0.`,13.4`,0.94018`,1.1621000000000001`},0.24018886505888162`},{{0.`,13.4`,0.94368`,1.1666`},0.2443214166681661`},{{0.`,13.4`,0.94368`,1.1711`},0.2443214166681661`},{{0.`,13.4`,0.94368`,1.1621000000000001`},0.2443214166681661`},{{0.`,13.4`,0.93668`,1.1666`},0.23609904503850304`},{{0.`,13.4`,0.93668`,1.1711`},0.23609904503850304`},{{0.`,13.4`,0.93668`,1.1621000000000001`},0.23609904503850304`},{{0.`,14.`,0.94018`,1.1666`},0.24289479560001498`},{{0.`,14.`,0.94018`,1.1711`},0.24289479560001498`},{{0.`,14.`,0.94018`,1.1621000000000001`},0.24289479560001498`},{{0.`,14.`,0.94368`,1.1666`},0.24708551020485828`},{{0.`,14.`,0.94368`,1.1711`},0.24708551020485828`},{{0.`,14.`,0.94368`,1.1621000000000001`},0.24708551020485828`},{{0.`,14.`,0.93668`,1.1666`},0.23874717354785321`},{{0.`,14.`,0.93668`,1.1711`},0.23874717354785321`},{{0.`,14.`,0.93668`,1.1621000000000001`},0.23874717354785321`},{{0.`,14.6`,0.94018`,1.1666`},0.24539508394838055`},{{0.`,14.6`,0.94018`,1.1711`},0.24539508394838055`},{{0.`,14.6`,0.94018`,1.1621000000000001`},0.24539508394838055`},{{0.`,14.6`,0.94368`,1.1666`},0.24964063906545894`},{{0.`,14.6`,0.94368`,1.1711`},0.24964063906545894`},{{0.`,14.6`,0.94368`,1.1621000000000001`},0.24964063906545894`},{{0.`,14.6`,0.93668`,1.1666`},0.24119293816251178`},{{0.`,14.6`,0.93668`,1.1711`},0.24119293816251178`},{{0.`,14.6`,0.93668`,1.1621000000000001`},0.24119293816251178`},{{0.`,15.2`,0.94018`,1.1666`},0.2477073335174999`},{{0.`,15.2`,0.94018`,1.1711`},0.2477073335174999`},{{0.`,15.2`,0.94018`,1.1621000000000001`},0.2477073335174999`},{{0.`,15.2`,0.94368`,1.1666`},0.2520047145111109`},{{0.`,15.2`,0.94368`,1.1711`},0.2520047145111109`},{{0.`,15.2`,0.94368`,1.1621000000000001`},0.2520047145111109`},{{0.`,15.2`,0.93668`,1.1666`},0.2434536435793688`},{{0.`,15.2`,0.93668`,1.1711`},0.2434536435793688`},{{0.`,15.2`,0.93668`,1.1621000000000001`},0.2434536435793688`},{{0.`,15.8`,0.94018`,1.1666`},0.24984864269467227`},{{0.`,15.8`,0.94018`,1.1711`},0.24984864269467227`},{{0.`,15.8`,0.94018`,1.1621000000000001`},0.24984864269467227`},{{0.`,15.8`,0.94368`,1.1666`},0.254195103598226`},{{0.`,15.8`,0.94368`,1.1711`},0.254195103598226`},{{0.`,15.8`,0.94368`,1.1621000000000001`},0.254195103598226`},{{0.`,15.8`,0.93668`,1.1666`},0.2455461201439419`},{{0.`,15.8`,0.93668`,1.1711`},0.2455461201439419`},{{0.`,15.8`,0.93668`,1.1621000000000001`},0.2455461201439419`},{{0.`,16.4`,0.94018`,1.1666`},0.2518334938373998`},{{0.`,16.4`,0.94018`,1.1711`},0.2518334938373998`},{{0.`,16.4`,0.94018`,1.1621000000000001`},0.2518334938373998`},{{0.`,16.4`,0.94368`,1.1666`},0.25622652767723914`},{{0.`,16.4`,0.94368`,1.1711`},0.25622652767723914`},{{0.`,16.4`,0.94368`,1.1621000000000001`},0.25622652767723914`},{{0.`,16.4`,0.93668`,1.1666`},0.24748461437171443`},{{0.`,16.4`,0.93668`,1.1711`},0.24748461437171443`},{{0.`,16.4`,0.93668`,1.1621000000000001`},0.24748461437171443`},{{0.`,17.`,0.94018`,1.1666`},0.25367454240963005`},{{0.`,17.`,0.94018`,1.1711`},0.25367454240963005`},{{0.`,17.`,0.94018`,1.1621000000000001`},0.25367454240963005`},{{0.`,17.`,0.94368`,1.1666`},0.25811185871040687`},{{0.`,17.`,0.94368`,1.1711`},0.25811185871040687`},{{0.`,17.`,0.94368`,1.1621000000000001`},0.25811185871040687`},{{0.`,17.`,0.93668`,1.1666`},0.24928156813705526`},{{0.`,17.`,0.93668`,1.1711`},0.24928156813705526`},{{0.`,17.`,0.93668`,1.1621000000000001`},0.24928156813705526`},{{0.`,17.6`,0.94018`,1.1666`},0.25538362162131495`},{{0.`,17.6`,0.94018`,1.1711`},0.25538362162131495`},{{0.`,17.6`,0.94018`,1.1621000000000001`},0.25538362162131495`},{{0.`,17.6`,0.94368`,1.1666`},0.25986312804547596`},{{0.`,17.6`,0.94368`,1.1711`},0.25986312804547596`},{{0.`,17.6`,0.94368`,1.1621000000000001`},0.25986312804547596`},{{0.`,17.6`,0.93668`,1.1666`},0.25094861871129115`},{{0.`,17.6`,0.93668`,1.1711`},0.25094861871129115`},{{0.`,17.6`,0.93668`,1.1621000000000001`},0.25094861871129115`},{{0.`,18.2`,0.94018`,1.1666`},0.25697162474257984`},{{0.`,18.2`,0.94018`,1.1711`},0.25697162474257984`},{{0.`,18.2`,0.94018`,1.1621000000000001`},0.25697162474257984`},{{0.`,18.2`,0.94368`,1.1666`},0.2614913908312876`},{{0.`,18.2`,0.94368`,1.1711`},0.2614913908312876`},{{0.`,18.2`,0.94368`,1.1621000000000001`},0.2614913908312876`},{{0.`,18.2`,0.93668`,1.1666`},0.2524964993191157`},{{0.`,18.2`,0.93668`,1.1711`},0.2524964993191157`},{{0.`,18.2`,0.93668`,1.1621000000000001`},0.2524964993191157`},{{0.`,18.8`,0.94018`,1.1666`},0.25844733781549384`},{{0.`,18.8`,0.94018`,1.1711`},0.25844733781549384`},{{0.`,18.8`,0.94018`,1.1621000000000001`},0.25844733781549384`},{{0.`,18.8`,0.94368`,1.1666`},0.2630056090673704`},{{0.`,18.8`,0.94368`,1.1711`},0.2630056090673704`},{{0.`,18.8`,0.94368`,1.1621000000000001`},0.2630056090673704`},{{0.`,18.8`,0.93668`,1.1666`},0.2539338227266155`},{{0.`,18.8`,0.93668`,1.1711`},0.2539338227266155`},{{0.`,18.8`,0.93668`,1.1621000000000001`},0.2539338227266155`},{{0.`,19.4`,0.94018`,1.1666`},0.25981906683749867`},{{0.`,19.4`,0.94018`,1.1711`},0.25981906683749867`},{{0.`,19.4`,0.94018`,1.1621000000000001`},0.25981906683749867`},{{0.`,19.4`,0.94368`,1.1666`},0.2644142276983829`},{{0.`,19.4`,0.94368`,1.1711`},0.2644142276983829`},{{0.`,19.4`,0.94368`,1.1621000000000001`},0.2644142276983829`},{{0.`,19.4`,0.93668`,1.1666`},0.2552687576449314`},{{0.`,19.4`,0.93668`,1.1711`},0.2552687576449314`},{{0.`,19.4`,0.93668`,1.1621000000000001`},0.2552687576449314`},{{0.`,20.`,0.94018`,1.1666`},0.26109514907658365`},{{0.`,20.`,0.94018`,1.1711`},0.26109514907658365`},{{0.`,20.`,0.94018`,1.1621000000000001`},0.26109514907658365`},{{0.`,20.`,0.94368`,1.1666`},0.26572570982575316`},{{0.`,20.`,0.94368`,1.1711`},0.26572570982575316`},{{0.`,20.`,0.94368`,1.1621000000000001`},0.26572570982575316`},{{0.`,20.`,0.93668`,1.1666`},0.2565095167133593`},{{0.`,20.`,0.93668`,1.1711`},0.2565095167133593`},{{0.`,20.`,0.93668`,1.1621000000000001`},0.2565095167133593`},{{0.`,20.6`,0.94018`,1.1666`},0.26228245877693607`},{{0.`,20.6`,0.94018`,1.1711`},0.26228245877693607`},{{0.`,20.6`,0.94018`,1.1621000000000001`},0.26228245877693607`},{{0.`,20.6`,0.94368`,1.1666`},0.26694704663640595`},{{0.`,20.6`,0.94368`,1.1711`},0.26694704663640595`},{{0.`,20.6`,0.94368`,1.1621000000000001`},0.26694704663640595`},{{0.`,20.6`,0.93668`,1.1666`},0.2576628587676459`},{{0.`,20.6`,0.93668`,1.1711`},0.2576628587676459`},{{0.`,20.6`,0.93668`,1.1621000000000001`},0.2576628587676459`},{{0.`,21.2`,0.94018`,1.1666`},0.26338677009578865`},{{0.`,21.2`,0.94018`,1.1711`},0.26338677009578865`},{{0.`,21.2`,0.94018`,1.1621000000000001`},0.26338677009578865`},{{0.`,21.2`,0.94368`,1.1666`},0.26808412502060486`},{{0.`,21.2`,0.94368`,1.1711`},0.26808412502060486`},{{0.`,21.2`,0.94368`,1.1621000000000001`},0.26808412502060486`},{{0.`,21.2`,0.93668`,1.1666`},0.2587344467252565`},{{0.`,21.2`,0.93668`,1.1711`},0.2587344467252565`},{{0.`,21.2`,0.93668`,1.1621000000000001`},0.2587344467252565`},{{0.`,21.8`,0.94018`,1.1666`},0.26441446793110734`},{{0.`,21.8`,0.94018`,1.1711`},0.26441446793110734`},{{0.`,21.8`,0.94018`,1.1621000000000001`},0.26441446793110734`},{{0.`,21.8`,0.94368`,1.1666`},0.26914342251082374`},{{0.`,21.8`,0.94368`,1.1711`},0.26914342251082374`},{{0.`,21.8`,0.94368`,1.1621000000000001`},0.26914342251082374`},{{0.`,21.8`,0.93668`,1.1666`},0.2597305736554001`},{{0.`,21.8`,0.93668`,1.1711`},0.2597305736554001`},{{0.`,21.8`,0.93668`,1.1621000000000001`},0.2597305736554001`},{{0.`,22.4`,0.94018`,1.1666`},0.2653706389294736`},{{0.`,22.4`,0.94018`,1.1711`},0.2653706389294736`},{{0.`,22.4`,0.94018`,1.1621000000000001`},0.2653706389294736`},{{0.`,22.4`,0.94368`,1.1666`},0.2701301154719169`},{{0.`,22.4`,0.94368`,1.1711`},0.2701301154719169`},{{0.`,22.4`,0.94368`,1.1621000000000001`},0.2701301154719169`},{{0.`,22.4`,0.93668`,1.1666`},0.26065623763390505`},{{0.`,22.4`,0.93668`,1.1711`},0.26065623763390505`},{{0.`,22.4`,0.93668`,1.1621000000000001`},0.26065623763390505`},{{0.`,23.`,0.94018`,1.1666`},0.2662601007632407`},{{0.`,23.`,0.94018`,1.1711`},0.2662601007632407`},{{0.`,23.`,0.94018`,1.1621000000000001`},0.2662601007632407`},{{0.`,23.`,0.94368`,1.1666`},0.2710491025926678`},{{0.`,23.`,0.94368`,1.1711`},0.2710491025926678`},{{0.`,23.`,0.94368`,1.1621000000000001`},0.2710491025926678`},{{0.`,23.`,0.93668`,1.1666`},0.2615161762371724`},{{0.`,23.`,0.93668`,1.1711`},0.2615161762371724`},{{0.`,23.`,0.93668`,1.1621000000000001`},0.2615161762371724`},{{0.`,23.6`,0.94018`,1.1666`},0.26708726713400505`},{{0.`,23.6`,0.94018`,1.1711`},0.26708726713400505`},{{0.`,23.6`,0.94018`,1.1621000000000001`},0.26708726713400505`},{{0.`,23.6`,0.94368`,1.1666`},0.27190487155044235`},{{0.`,23.6`,0.94368`,1.1711`},0.27190487155044235`},{{0.`,23.6`,0.94368`,1.1621000000000001`},0.27190487155044235`},{{0.`,23.6`,0.93668`,1.1666`},0.26231473002176414`},{{0.`,23.6`,0.93668`,1.1711`},0.26231473002176414`},{{0.`,23.6`,0.93668`,1.1621000000000001`},0.26231473002176414`},{{0.`,24.2`,0.94018`,1.1666`},0.2678548308729263`},{{0.`,24.2`,0.94018`,1.1711`},0.2678548308729263`},{{0.`,24.2`,0.94018`,1.1621000000000001`},0.2678548308729263`},{{0.`,24.2`,0.94368`,1.1666`},0.27270020424422214`},{{0.`,24.2`,0.94368`,1.1711`},0.27270020424422214`},{{0.`,24.2`,0.94368`,1.1621000000000001`},0.27270020424422214`},{{0.`,24.2`,0.93668`,1.1666`},0.26305450404475755`},{{0.`,24.2`,0.93668`,1.1711`},0.26305450404475755`},{{0.`,24.2`,0.93668`,1.1621000000000001`},0.26305450404475755`},{{0.`,24.8`,0.94018`,1.1666`},0.26856807610117256`},{{0.`,24.8`,0.94018`,1.1711`},0.26856807610117256`},{{0.`,24.8`,0.94018`,1.1621000000000001`},0.26856807610117256`},{{0.`,24.8`,0.94368`,1.1666`},0.27344042630567444`},{{0.`,24.8`,0.94368`,1.1711`},0.27344042630567444`},{{0.`,24.8`,0.94368`,1.1621000000000001`},0.27344042630567444`},{{0.`,24.8`,0.93668`,1.1666`},0.2637407407475125`},{{0.`,24.8`,0.93668`,1.1711`},0.2637407407475125`},{{0.`,24.8`,0.93668`,1.1621000000000001`},0.2637407407475125`},{{0.`,25.4`,0.94018`,1.1666`},0.26922983245379556`},{{0.`,25.4`,0.94018`,1.1711`},0.26922983245379556`},{{0.`,25.4`,0.94018`,1.1621000000000001`},0.26922983245379556`},{{0.`,25.4`,0.94368`,1.1666`},0.27412843234037637`},{{0.`,25.4`,0.94368`,1.1711`},0.27412843234037637`},{{0.`,25.4`,0.94368`,1.1621000000000001`},0.27412843234037637`},{{0.`,25.4`,0.93668`,1.1666`},0.26437620574779924`},{{0.`,25.4`,0.93668`,1.1711`},0.26437620574779924`},{{0.`,25.4`,0.93668`,1.1621000000000001`},0.26437620574779924`},{{0.`,26.`,0.94018`,1.1666`},0.26984319685671265`},{{0.`,26.`,0.94018`,1.1711`},0.26984319685671265`},{{0.`,26.`,0.94018`,1.1621000000000001`},0.26984319685671265`},{{0.`,26.`,0.94368`,1.1666`},0.27476737293212095`},{{0.`,26.`,0.94368`,1.1711`},0.27476737293212095`},{{0.`,26.`,0.94368`,1.1621000000000001`},0.27476737293212095`},{{0.`,26.`,0.93668`,1.1666`},0.26496394288144937`},{{0.`,26.`,0.93668`,1.1711`},0.26496394288144937`},{{0.`,26.`,0.93668`,1.1621000000000001`},0.26496394288144937`},{{0.`,26.6`,0.94018`,1.1666`},0.2704110112967501`},{{0.`,26.6`,0.94018`,1.1711`},0.2704110112967501`},{{0.`,26.6`,0.94018`,1.1621000000000001`},0.2704110112967501`},{{0.`,26.6`,0.94368`,1.1666`},0.27536014107991663`},{{0.`,26.6`,0.94368`,1.1711`},0.27536014107991663`},{{0.`,26.6`,0.94368`,1.1621000000000001`},0.27536014107991663`},{{0.`,26.6`,0.93668`,1.1666`},0.26550674355237475`},{{0.`,26.6`,0.93668`,1.1711`},0.26550674355237475`},{{0.`,26.6`,0.93668`,1.1621000000000001`},0.26550674355237475`},{{0.`,27.2`,0.94018`,1.1666`},0.2709347247787096`},{{0.`,27.2`,0.94018`,1.1711`},0.2709347247787096`},{{0.`,27.2`,0.94018`,1.1621000000000001`},0.2709347247787096`},{{0.`,27.2`,0.94368`,1.1666`},0.2759082526220382`},{{0.`,27.2`,0.94368`,1.1711`},0.2759082526220382`},{{0.`,27.2`,0.94368`,1.1621000000000001`},0.2759082526220382`},{{0.`,27.2`,0.93668`,1.1666`},0.26600599103846084`},{{0.`,27.2`,0.93668`,1.1711`},0.26600599103846084`},{{0.`,27.2`,0.93668`,1.1621000000000001`},0.26600599103846084`},{{0.`,27.8`,0.94018`,1.1666`},0.27141815524155094`},{{0.`,27.8`,0.94018`,1.1711`},0.27141815524155094`},{{0.`,27.8`,0.94018`,1.1621000000000001`},0.27141815524155094`},{{0.`,27.8`,0.94368`,1.1666`},0.2764155475773673`},{{0.`,27.8`,0.94368`,1.1711`},0.2764155475773673`},{{0.`,27.8`,0.94368`,1.1621000000000001`},0.2764155475773673`},{{0.`,27.8`,0.93668`,1.1666`},0.26646548058601116`},{{0.`,27.8`,0.93668`,1.1711`},0.26646548058601116`},{{0.`,27.8`,0.93668`,1.1621000000000001`},0.26646548058601116`},{{0.`,28.4`,0.94018`,1.1666`},0.2718631115967449`},{{0.`,28.4`,0.94018`,1.1711`},0.2718631115967449`},{{0.`,28.4`,0.94018`,1.1621000000000001`},0.2718631115967449`},{{0.`,28.4`,0.94368`,1.1666`},0.27688387997329267`},{{0.`,28.4`,0.94368`,1.1711`},0.27688387997329267`},{{0.`,28.4`,0.94368`,1.1621000000000001`},0.27688387997329267`},{{0.`,28.4`,0.93668`,1.1666`},0.2668869767580769`},{{0.`,28.4`,0.93668`,1.1711`},0.2668869767580769`},{{0.`,28.4`,0.93668`,1.1621000000000001`},0.2668869767580769`},{{0.`,29.`,0.94018`,1.1666`},0.27227164666027814`},{{0.`,29.`,0.94018`,1.1711`},0.27227164666027814`},{{0.`,29.`,0.94018`,1.1621000000000001`},0.27227164666027814`},{{0.`,29.`,0.94368`,1.1666`},0.2773153402044783`},{{0.`,29.`,0.94368`,1.1711`},0.2773153402044783`},{{0.`,29.`,0.94368`,1.1621000000000001`},0.2773153402044783`},{{0.`,29.`,0.93668`,1.1666`},0.26727249510790296`},{{0.`,29.`,0.93668`,1.1711`},0.26727249510790296`},{{0.`,29.`,0.93668`,1.1621000000000001`},0.26727249510790296`},{{0.`,29.6`,0.94018`,1.1666`},0.2726450255517807`},{{0.`,29.6`,0.94018`,1.1711`},0.2726450255517807`},{{0.`,29.6`,0.94018`,1.1621000000000001`},0.2726450255517807`},{{0.`,29.6`,0.94368`,1.1666`},0.2777112402036224`},{{0.`,29.6`,0.94368`,1.1711`},0.2777112402036224`},{{0.`,29.6`,0.94368`,1.1621000000000001`},0.2777112402036224`},{{0.`,29.6`,0.93668`,1.1666`},0.2676232546540551`},{{0.`,29.6`,0.93668`,1.1711`},0.2676232546540551`},{{0.`,29.6`,0.93668`,1.1621000000000001`},0.2676232546540551`},{{0.`,30.2`,0.94018`,1.1666`},0.2729855953091811`},{{0.`,30.2`,0.94018`,1.1711`},0.2729855953091811`},{{0.`,30.2`,0.94018`,1.1621000000000001`},0.2729855953091811`},{{0.`,30.2`,0.94368`,1.1666`},0.2780739528572843`},{{0.`,30.2`,0.94368`,1.1711`},0.2780739528572843`},{{0.`,30.2`,0.94368`,1.1621000000000001`},0.2780739528572843`},{{0.`,30.2`,0.93668`,1.1666`},0.26794157616569053`},{{0.`,30.2`,0.93668`,1.1711`},0.26794157616569053`},{{0.`,30.2`,0.93668`,1.1621000000000001`},0.26794157616569053`},{{0.`,30.8`,0.94018`,1.1666`},0.2732948121930622`},{{0.`,30.8`,0.94018`,1.1711`},0.2732948121930622`},{{0.`,30.8`,0.94018`,1.1621000000000001`},0.2732948121930622`},{{0.`,30.8`,0.94368`,1.1666`},0.2784049663803594`},{{0.`,30.8`,0.94368`,1.1711`},0.2784049663803594`},{{0.`,30.8`,0.94368`,1.1621000000000001`},0.2784049663803594`},{{0.`,30.8`,0.93668`,1.1666`},0.26822888443039`},{{0.`,30.8`,0.93668`,1.1711`},0.26822888443039`},{{0.`,30.8`,0.93668`,1.1621000000000001`},0.26822888443039`},{{0.`,31.4`,0.94018`,1.1666`},0.2735741573924647`},{{0.`,31.4`,0.94018`,1.1711`},0.2735741573924647`},{{0.`,31.4`,0.94018`,1.1621000000000001`},0.2735741573924647`},{{0.`,31.4`,0.94368`,1.1666`},0.27870579168067705`},{{0.`,31.4`,0.94368`,1.1711`},0.27870579168067705`},{{0.`,31.4`,0.94368`,1.1621000000000001`},0.27870579168067705`},{{0.`,31.4`,0.93668`,1.1666`},0.2684866311046381`},{{0.`,31.4`,0.93668`,1.1711`},0.2684866311046381`},{{0.`,31.4`,0.93668`,1.1621000000000001`},0.2684866311046381`},{{0.`,32.`,0.94018`,1.1666`},0.27382469688520134`},{{0.`,32.`,0.94018`,1.1711`},0.27382469688520134`},{{0.`,32.`,0.94018`,1.1621000000000001`},0.27382469688520134`},{{0.`,32.`,0.94368`,1.1666`},0.2789775281523825`},{{0.`,32.`,0.94368`,1.1711`},0.2789775281523825`},{{0.`,32.`,0.94368`,1.1621000000000001`},0.2789775281523825`},{{0.`,32.`,0.93668`,1.1666`},0.26871584920222125`},{{0.`,32.`,0.93668`,1.1711`},0.26871584920222125`},{{0.`,32.`,0.93668`,1.1621000000000001`},0.26871584920222125`},{{0.`,32.6`,0.94018`,1.1666`},0.2740478904069172`},{{0.`,32.6`,0.94018`,1.1711`},0.2740478904069172`},{{0.`,32.6`,0.94018`,1.1621000000000001`},0.2740478904069172`},{{0.`,32.6`,0.94368`,1.1666`},0.2792216619330854`},{{0.`,32.6`,0.94368`,1.1711`},0.2792216619330854`},{{0.`,32.6`,0.94368`,1.1621000000000001`},0.2792216619330854`},{{0.`,32.6`,0.93668`,1.1666`},0.2689179717633393`},{{0.`,32.6`,0.93668`,1.1711`},0.2689179717633393`},{{0.`,32.6`,0.93668`,1.1621000000000001`},0.2689179717633393`},{{0.`,33.2`,0.94018`,1.1666`},0.2742448850208678`},{{0.`,33.2`,0.94018`,1.1711`},0.2742448850208678`},{{0.`,33.2`,0.94018`,1.1621000000000001`},0.2742448850208678`},{{0.`,33.2`,0.94368`,1.1666`},0.27943936406289677`},{{0.`,33.2`,0.94368`,1.1711`},0.27943936406289677`},{{0.`,33.2`,0.94368`,1.1621000000000001`},0.27943936406289677`},{{0.`,33.2`,0.93668`,1.1666`},0.2690941221466741`},{{0.`,33.2`,0.93668`,1.1711`},0.2690941221466741`},{{0.`,33.2`,0.93668`,1.1621000000000001`},0.2690941221466741`},{{0.`,33.8`,0.94018`,1.1666`},0.27441674859383186`},{{0.`,33.8`,0.94018`,1.1711`},0.27441674859383186`},{{0.`,33.8`,0.94018`,1.1621000000000001`},0.27441674859383186`},{{0.`,33.8`,0.94368`,1.1666`},0.2796317269304523`},{{0.`,33.8`,0.94368`,1.1711`},0.2796317269304523`},{{0.`,33.8`,0.94368`,1.1621000000000001`},0.2796317269304523`},{{0.`,33.8`,0.93668`,1.1666`},0.2692453437824425`},{{0.`,33.8`,0.93668`,1.1711`},0.2692453437824425`},{{0.`,33.8`,0.93668`,1.1621000000000001`},0.2692453437824425`},{{0.`,34.4`,0.94018`,1.1666`},0.27456446464382644`},{{0.`,34.4`,0.94018`,1.1711`},0.27456446464382644`},{{0.`,34.4`,0.94018`,1.1621000000000001`},0.27456446464382644`},{{0.`,34.4`,0.94368`,1.1666`},0.2797997611905993`},{{0.`,34.4`,0.94368`,1.1711`},0.2797997611905993`},{{0.`,34.4`,0.94368`,1.1621000000000001`},0.2797997611905993`},{{0.`,34.4`,0.93668`,1.1666`},0.2693726006579831`},{{0.`,34.4`,0.93668`,1.1711`},0.2693726006579831`},{{0.`,34.4`,0.93668`,1.1621000000000001`},0.2693726006579831`},{{0.`,35.`,0.94018`,1.1666`},0.274689005380237`},{{0.`,35.`,0.94018`,1.1711`},0.274689005380237`},{{0.`,35.`,0.94018`,1.1621000000000001`},0.274689005380237`},{{0.`,35.`,0.94368`,1.1666`},0.27994445422279973`},{{0.`,35.`,0.94368`,1.1711`},0.27994445422279973`},{{0.`,35.`,0.94368`,1.1621000000000001`},0.27994445422279973`},{{0.`,35.`,0.93668`,1.1666`},0.2694768353885189`},{{0.`,35.`,0.93668`,1.1711`},0.2694768353885189`},{{0.`,35.`,0.93668`,1.1621000000000001`},0.2694768353885189`},{{0.`,35.6`,0.94018`,1.1666`},0.27479027792721344`},{{0.`,35.6`,0.94018`,1.1711`},0.27479027792721344`},{{0.`,35.6`,0.94018`,1.1621000000000001`},0.27479027792721344`},{{0.`,35.6`,0.94368`,1.1666`},0.28006575740296197`},{{0.`,35.6`,0.94368`,1.1711`},0.28006575740296197`},{{0.`,35.6`,0.94368`,1.1621000000000001`},0.28006575740296197`},{{0.`,35.6`,0.93668`,1.1666`},0.2695579186144103`},{{0.`,35.6`,0.93668`,1.1711`},0.2695579186144103`},{{0.`,35.6`,0.93668`,1.1621000000000001`},0.2695579186144103`},{{0.`,36.2`,0.94018`,1.1666`},0.2748702747768452`},{{0.`,36.2`,0.94018`,1.1711`},0.2748702747768452`},{{0.`,36.2`,0.94018`,1.1621000000000001`},0.2748702747768452`},{{0.`,36.2`,0.94368`,1.1666`},0.28016565907673846`},{{0.`,36.2`,0.94368`,1.1711`},0.28016565907673846`},{{0.`,36.2`,0.94368`,1.1621000000000001`},0.28016565907673846`},{{0.`,36.2`,0.93668`,1.1666`},0.2696178458359347`},{{0.`,36.2`,0.93668`,1.1711`},0.2696178458359347`},{{0.`,36.2`,0.93668`,1.1621000000000001`},0.2696178458359347`},{{0.`,36.8`,0.94018`,1.1666`},0.27492923465791985`},{{0.`,36.8`,0.94018`,1.1711`},0.27492923465791985`},{{0.`,36.8`,0.94018`,1.1621000000000001`},0.27492923465791985`},{{0.`,36.8`,0.94368`,1.1666`},0.28024442766517105`},{{0.`,36.8`,0.94368`,1.1711`},0.28024442766517105`},{{0.`,36.8`,0.94368`,1.1621000000000001`},0.28024442766517105`},{{0.`,36.8`,0.93668`,1.1666`},0.26965682654134837`},{{0.`,36.8`,0.93668`,1.1711`},0.26965682654134837`},{{0.`,36.8`,0.93668`,1.1621000000000001`},0.26965682654134837`},{{0.`,37.4`,0.94018`,1.1666`},0.27496779522170295`},{{0.`,37.4`,0.94018`,1.1711`},0.27496779522170295`},{{0.`,37.4`,0.94018`,1.1621000000000001`},0.27496779522170295`},{{0.`,37.4`,0.94368`,1.1666`},0.2803027207420718`},{{0.`,37.4`,0.94368`,1.1711`},0.2803027207420718`},{{0.`,37.4`,0.94368`,1.1621000000000001`},0.2803027207420718`},{{0.`,37.4`,0.93668`,1.1666`},0.2696754784362879`},{{0.`,37.4`,0.93668`,1.1711`},0.2696754784362879`},{{0.`,37.4`,0.93668`,1.1621000000000001`},0.2696754784362879`},{{0.`,38.`,0.94018`,1.1666`},0.27498653897995534`},{{0.`,38.`,0.94018`,1.1711`},0.27498653897995534`},{{0.`,38.`,0.94018`,1.1621000000000001`},0.27498653897995534`},{{0.`,38.`,0.94368`,1.1666`},0.28034114019445416`},{{0.`,38.`,0.94368`,1.1711`},0.28034114019445416`},{{0.`,38.`,0.94368`,1.1621000000000001`},0.28034114019445416`},{{0.`,38.`,0.93668`,1.1666`},0.2696743646162553`},{{0.`,38.`,0.93668`,1.1711`},0.2696743646162553`},{{0.`,38.`,0.93668`,1.1621000000000001`},0.2696743646162553`},{{0.`,38.6`,0.94018`,1.1666`},0.2749859962147215`},{{0.`,38.6`,0.94018`,1.1711`},0.2749859962147215`},{{0.`,38.6`,0.94018`,1.1621000000000001`},0.2749859962147215`},{{0.`,38.6`,0.94368`,1.1666`},0.2803602352063685`},{{0.`,38.6`,0.94368`,1.1711`},0.2803602352063685`},{{0.`,38.6`,0.94368`,1.1621000000000001`},0.2803602352063685`},{{0.`,38.6`,0.93668`,1.1666`},0.26965399640272203`},{{0.`,38.6`,0.93668`,1.1711`},0.26965399640272203`},{{0.`,38.6`,0.93668`,1.1621000000000001`},0.26965399640272203`},{{0.`,39.2`,0.94018`,1.1666`},0.2749666475355014`},{{0.`,39.2`,0.94018`,1.1711`},0.2749666475355014`},{{0.`,39.2`,0.94018`,1.1621000000000001`},0.2749666475355014`},{{0.`,39.2`,0.94368`,1.1666`},0.28036050488767705`},{{0.`,39.2`,0.94368`,1.1711`},0.28036050488767705`},{{0.`,39.2`,0.94368`,1.1621000000000001`},0.28036050488767705`},{{0.`,39.2`,0.93668`,1.1666`},0.26961483582895984`},{{0.`,39.2`,0.93668`,1.1711`},0.26961483582895984`},{{0.`,39.2`,0.93668`,1.1621000000000001`},0.26961483582895984`},{{0.`,39.8`,0.94018`,1.1666`},0.2749289261076051`},{{0.`,39.8`,0.94018`,1.1711`},0.2749289261076051`},{{0.`,39.8`,0.94018`,1.1621000000000001`},0.2749289261076051`},{{0.`,39.8`,0.94368`,1.1666`},0.28034240057219495`},{{0.`,39.8`,0.94368`,1.1711`},0.28034240057219495`},{{0.`,39.8`,0.94368`,1.1621000000000001`},0.28034240057219495`},{{0.`,39.8`,0.93668`,1.1666`},0.26955729779879195`},{{0.`,39.8`,0.93668`,1.1711`},0.26955729779879195`},{{0.`,39.8`,0.93668`,1.1621000000000001`},0.26955729779879195`},{{0.03`,0.4`,0.94018`,1.1666`},0.0508714793213267`},{{0.03`,0.4`,0.94018`,1.1711`},0.0508714793213267`},{{0.03`,0.4`,0.94018`,1.1621000000000001`},0.0508714793213267`},{{0.03`,0.4`,0.94368`,1.1666`},0.05120302759928901`},{{0.03`,0.4`,0.94368`,1.1711`},0.05120302759928901`},{{0.03`,0.4`,0.94368`,1.1621000000000001`},0.05120302759928901`},{{0.03`,0.4`,0.93668`,1.1666`},0.05054359826460182`},{{0.03`,0.4`,0.93668`,1.1711`},0.05054359826460182`},{{0.03`,0.4`,0.93668`,1.1621000000000001`},0.05054359826460182`},{{0.03`,0.6`,0.94018`,1.1666`},0.06045302056957738`},{{0.03`,0.6`,0.94018`,1.1711`},0.06045302056957738`},{{0.03`,0.6`,0.94018`,1.1621000000000001`},0.06045302056957738`},{{0.03`,0.6`,0.94368`,1.1666`},0.060938125902655585`},{{0.03`,0.6`,0.94368`,1.1711`},0.060938125902655585`},{{0.03`,0.6`,0.94368`,1.1621000000000001`},0.060938125902655585`},{{0.03`,0.6`,0.93668`,1.1666`},0.05997329574957062`},{{0.03`,0.6`,0.93668`,1.1711`},0.05997329574957062`},{{0.03`,0.6`,0.93668`,1.1621000000000001`},0.05997329574957062`},{{0.03`,0.8`,0.94018`,1.1666`},0.06951977515803402`},{{0.03`,0.8`,0.94018`,1.1711`},0.06951977515803402`},{{0.03`,0.8`,0.94018`,1.1621000000000001`},0.06951977515803402`},{{0.03`,0.8`,0.94368`,1.1666`},0.07015098335473739`},{{0.03`,0.8`,0.94368`,1.1711`},0.07015098335473739`},{{0.03`,0.8`,0.94368`,1.1621000000000001`},0.07015098335473739`},{{0.03`,0.8`,0.93668`,1.1666`},0.06889558509134865`},{{0.03`,0.8`,0.93668`,1.1711`},0.06889558509134865`},{{0.03`,0.8`,0.93668`,1.1621000000000001`},0.06889558509134865`},{{0.03`,1.`,0.94018`,1.1666`},0.07810816929742614`},{{0.03`,1.`,0.94018`,1.1711`},0.07810816929742614`},{{0.03`,1.`,0.94018`,1.1621000000000001`},0.07810816929742614`},{{0.03`,1.`,0.94368`,1.1666`},0.07887849560380639`},{{0.03`,1.`,0.94368`,1.1711`},0.07887849560380639`},{{0.03`,1.`,0.94368`,1.1621000000000001`},0.07887849560380639`},{{0.03`,1.`,0.93668`,1.1666`},0.07734642640959725`},{{0.03`,1.`,0.93668`,1.1711`},0.07734642640959725`},{{0.03`,1.`,0.93668`,1.1621000000000001`},0.07734642640959725`},{{0.03`,1.2`,0.94018`,1.1666`},0.08625142945702735`},{{0.03`,1.2`,0.94018`,1.1711`},0.08625142945702735`},{{0.03`,1.2`,0.94018`,1.1621000000000001`},0.08625142945702735`},{{0.03`,1.2`,0.94368`,1.1666`},0.08715432359545987`},{{0.03`,1.2`,0.94368`,1.1711`},0.08715432359545987`},{{0.03`,1.2`,0.94368`,1.1621000000000001`},0.08715432359545987`},{{0.03`,1.2`,0.93668`,1.1666`},0.08535861496749776`},{{0.03`,1.2`,0.93668`,1.1711`},0.08535861496749776`},{{0.03`,1.2`,0.93668`,1.1621000000000001`},0.08535861496749776`},{{0.03`,1.4`,0.94018`,1.1666`},0.09397991596786001`},{{0.03`,1.4`,0.94018`,1.1711`},0.09397991596786001`},{{0.03`,1.4`,0.94018`,1.1621000000000001`},0.09397991596786001`},{{0.03`,1.4`,0.94368`,1.1666`},0.09500923005145773`},{{0.03`,1.4`,0.94368`,1.1711`},0.09500923005145773`},{{0.03`,1.4`,0.94368`,1.1621000000000001`},0.09500923005145773`},{{0.03`,1.4`,0.93668`,1.1666`},0.09296211188189256`},{{0.03`,1.4`,0.93668`,1.1711`},0.09296211188189256`},{{0.03`,1.4`,0.93668`,1.1621000000000001`},0.09296211188189256`},{{0.03`,1.6`,0.94018`,1.1666`},0.10132141664326852`},{{0.03`,1.6`,0.94018`,1.1711`},0.10132141664326852`},{{0.03`,1.6`,0.94018`,1.1621000000000001`},0.10132141664326852`},{{0.03`,1.6`,0.94368`,1.1666`},0.10247137572737029`},{{0.03`,1.6`,0.94368`,1.1711`},0.10247137572737029`},{{0.03`,1.6`,0.94368`,1.1621000000000001`},0.10247137572737029`},{{0.03`,1.6`,0.93668`,1.1666`},0.10018433509469277`},{{0.03`,1.6`,0.93668`,1.1711`},0.10018433509469277`},{{0.03`,1.6`,0.93668`,1.1621000000000001`},0.10018433509469277`},{{0.03`,1.8`,0.94018`,1.1666`},0.10830140579590117`},{{0.03`,1.8`,0.94018`,1.1711`},0.10830140579590117`},{{0.03`,1.8`,0.94018`,1.1621000000000001`},0.10830140579590117`},{{0.03`,1.8`,0.94368`,1.1666`},0.10956658084386492`},{{0.03`,1.8`,0.94368`,1.1711`},0.10956658084386492`},{{0.03`,1.8`,0.94368`,1.1621000000000001`},0.10956658084386492`},{{0.03`,1.8`,0.93668`,1.1666`},0.10705041596762983`},{{0.03`,1.8`,0.93668`,1.1711`},0.10705041596762983`},{{0.03`,1.8`,0.93668`,1.1621000000000001`},0.10705041596762983`},{{0.03`,2.`,0.94018`,1.1666`},0.11494327323268681`},{{0.03`,2.`,0.94018`,1.1711`},0.11494327323268681`},{{0.03`,2.`,0.94018`,1.1621000000000001`},0.11494327323268681`},{{0.03`,2.`,0.94368`,1.1666`},0.11631855628943319`},{{0.03`,2.`,0.94368`,1.1711`},0.11631855628943319`},{{0.03`,2.`,0.94368`,1.1621000000000001`},0.11631855628943319`},{{0.03`,2.`,0.93668`,1.1666`},0.11358342606478657`},{{0.03`,2.`,0.93668`,1.1711`},0.11358342606478657`},{{0.03`,2.`,0.93668`,1.1621000000000001`},0.11358342606478657`},{{0.03`,2.2`,0.94018`,1.1666`},0.12126852714027045`},{{0.03`,2.2`,0.94018`,1.1711`},0.12126852714027045`},{{0.03`,2.2`,0.94018`,1.1621000000000001`},0.12126852714027045`},{{0.03`,2.2`,0.94368`,1.1666`},0.12274910852309098`},{{0.03`,2.2`,0.94368`,1.1711`},0.12274910852309098`},{{0.03`,2.2`,0.94368`,1.1621000000000001`},0.12274910852309098`},{{0.03`,2.2`,0.93668`,1.1666`},0.11980457801857422`},{{0.03`,2.2`,0.93668`,1.1711`},0.11980457801857422`},{{0.03`,2.2`,0.93668`,1.1621000000000001`},0.11980457801857422`},{{0.03`,2.6`,0.94018`,1.1666`},0.13304502906670476`},{{0.03`,2.6`,0.94018`,1.1711`},0.13304502906670476`},{{0.03`,2.6`,0.94018`,1.1621000000000001`},0.13304502906670476`},{{0.03`,2.6`,0.94368`,1.1666`},0.13472287000948002`},{{0.03`,2.6`,0.94368`,1.1711`},0.13472287000948002`},{{0.03`,2.6`,0.94368`,1.1621000000000001`},0.13472287000948002`},{{0.03`,2.6`,0.93668`,1.1666`},0.13138606116096535`},{{0.03`,2.6`,0.93668`,1.1711`},0.13138606116096535`},{{0.03`,2.6`,0.93668`,1.1621000000000001`},0.13138606116096535`},{{0.03`,3.`,0.94018`,1.1666`},0.14377285284507715`},{{0.03`,3.`,0.94018`,1.1711`},0.14377285284507715`},{{0.03`,3.`,0.94018`,1.1621000000000001`},0.14377285284507715`},{{0.03`,3.`,0.94368`,1.1666`},0.14563181367491065`},{{0.03`,3.`,0.94368`,1.1711`},0.14563181367491065`},{{0.03`,3.`,0.94368`,1.1621000000000001`},0.14563181367491065`},{{0.03`,3.`,0.93668`,1.1666`},0.141934818493966`},{{0.03`,3.`,0.93668`,1.1711`},0.141934818493966`},{{0.03`,3.`,0.93668`,1.1621000000000001`},0.141934818493966`},{{0.03`,3.4`,0.94018`,1.1666`},0.15357280204873164`},{{0.03`,3.4`,0.94018`,1.1711`},0.15357280204873164`},{{0.03`,3.4`,0.94018`,1.1621000000000001`},0.15357280204873164`},{{0.03`,3.4`,0.94368`,1.1666`},0.1555984701608447`},{{0.03`,3.4`,0.94368`,1.1711`},0.1555984701608447`},{{0.03`,3.4`,0.94368`,1.1621000000000001`},0.1555984701608447`},{{0.03`,3.4`,0.93668`,1.1666`},0.15156994399111043`},{{0.03`,3.4`,0.93668`,1.1711`},0.15156994399111043`},{{0.03`,3.4`,0.93668`,1.1621000000000001`},0.15156994399111043`},{{0.03`,3.8`,0.94018`,1.1666`},0.16254825707347054`},{{0.03`,3.8`,0.94018`,1.1711`},0.16254825707347054`},{{0.03`,3.8`,0.94018`,1.1621000000000001`},0.16254825707347054`},{{0.03`,3.8`,0.94368`,1.1666`},0.16472773065363536`},{{0.03`,3.8`,0.94368`,1.1711`},0.16472773065363536`},{{0.03`,3.8`,0.94368`,1.1621000000000001`},0.16472773065363536`},{{0.03`,3.8`,0.93668`,1.1666`},0.1603933230811573`},{{0.03`,3.8`,0.93668`,1.1711`},0.1603933230811573`},{{0.03`,3.8`,0.93668`,1.1621000000000001`},0.1603933230811573`},{{0.03`,4.2`,0.94018`,1.1666`},0.1707885125564537`},{{0.03`,4.2`,0.94018`,1.1711`},0.1707885125564537`},{{0.03`,4.2`,0.94018`,1.1621000000000001`},0.1707885125564537`},{{0.03`,4.2`,0.94368`,1.1666`},0.17311021072738694`},{{0.03`,4.2`,0.94368`,1.1711`},0.17311021072738694`},{{0.03`,4.2`,0.94368`,1.1621000000000001`},0.17311021072738694`},{{0.03`,4.2`,0.93668`,1.1666`},0.1684929437117333`},{{0.03`,4.2`,0.93668`,1.1711`},0.1684929437117333`},{{0.03`,4.2`,0.93668`,1.1621000000000001`},0.1684929437117333`},{{0.03`,4.6`,0.94018`,1.1666`},0.1783715397852241`},{{0.03`,4.6`,0.94018`,1.1711`},0.1783715397852241`},{{0.03`,4.6`,0.94018`,1.1621000000000001`},0.1783715397852241`},{{0.03`,4.6`,0.94368`,1.1666`},0.18082503992615429`},{{0.03`,4.6`,0.94368`,1.1711`},0.18082503992615429`},{{0.03`,4.6`,0.94368`,1.1621000000000001`},0.18082503992615429`},{{0.03`,4.6`,0.93668`,1.1666`},0.1759456315353443`},{{0.03`,4.6`,0.93668`,1.1711`},0.1759456315353443`},{{0.03`,4.6`,0.93668`,1.1621000000000001`},0.1759456315353443`},{{0.03`,5.`,0.94018`,1.1666`},0.18536467274568694`},{{0.03`,5.`,0.94018`,1.1711`},0.18536467274568694`},{{0.03`,5.`,0.94018`,1.1621000000000001`},0.18536467274568694`},{{0.03`,5.`,0.94368`,1.1666`},0.18794056235730944`},{{0.03`,5.`,0.94368`,1.1711`},0.18794056235730944`},{{0.03`,5.`,0.94368`,1.1621000000000001`},0.18794056235730944`},{{0.03`,5.`,0.93668`,1.1666`},0.1828177220866419`},{{0.03`,5.`,0.93668`,1.1711`},0.1828177220866419`},{{0.03`,5.`,0.93668`,1.1621000000000001`},0.1828177220866419`},{{0.03`,5.4`,0.94018`,1.1666`},0.19182634148853225`},{{0.03`,5.4`,0.94018`,1.1711`},0.19182634148853225`},{{0.03`,5.4`,0.94018`,1.1621000000000001`},0.19182634148853225`},{{0.03`,5.4`,0.94368`,1.1666`},0.1945161120007532`},{{0.03`,5.4`,0.94368`,1.1711`},0.1945161120007532`},{{0.03`,5.4`,0.94368`,1.1621000000000001`},0.1945161120007532`},{{0.03`,5.4`,0.93668`,1.1666`},0.1891667518696534`},{{0.03`,5.4`,0.93668`,1.1711`},0.1891667518696534`},{{0.03`,5.4`,0.93668`,1.1621000000000001`},0.1891667518696534`},{{0.03`,5.8`,0.94018`,1.1666`},0.1978082596402262`},{{0.03`,5.8`,0.94018`,1.1711`},0.1978082596402262`},{{0.03`,5.8`,0.94018`,1.1621000000000001`},0.1978082596402262`},{{0.03`,5.8`,0.94368`,1.1666`},0.20060419647792999`},{{0.03`,5.8`,0.94368`,1.1711`},0.20060419647792999`},{{0.03`,5.8`,0.94368`,1.1621000000000001`},0.20060419647792999`},{{0.03`,5.8`,0.93668`,1.1666`},0.19504364982774192`},{{0.03`,5.8`,0.93668`,1.1711`},0.19504364982774192`},{{0.03`,5.8`,0.93668`,1.1621000000000001`},0.19504364982774192`},{{0.03`,6.2`,0.94018`,1.1666`},0.20335595135728957`},{{0.03`,6.2`,0.94018`,1.1711`},0.20335595135728957`},{{0.03`,6.2`,0.94018`,1.1621000000000001`},0.20335595135728957`},{{0.03`,6.2`,0.94368`,1.1666`},0.20625104419360527`},{{0.03`,6.2`,0.94368`,1.1711`},0.20625104419360527`},{{0.03`,6.2`,0.94368`,1.1621000000000001`},0.20625104419360527`},{{0.03`,6.2`,0.93668`,1.1666`},0.20049324424754358`},{{0.03`,6.2`,0.93668`,1.1711`},0.20049324424754358`},{{0.03`,6.2`,0.93668`,1.1621000000000001`},0.20049324424754358`},{{0.03`,6.8`,0.94018`,1.1666`},0.21094966736650436`},{{0.03`,6.8`,0.94018`,1.1711`},0.21094966736650436`},{{0.03`,6.8`,0.94018`,1.1621000000000001`},0.21094966736650436`},{{0.03`,6.8`,0.94368`,1.1666`},0.2139816999102339`},{{0.03`,6.8`,0.94368`,1.1711`},0.2139816999102339`},{{0.03`,6.8`,0.94368`,1.1621000000000001`},0.2139816999102339`},{{0.03`,6.8`,0.93668`,1.1666`},0.207951461002518`},{{0.03`,6.8`,0.93668`,1.1711`},0.207951461002518`},{{0.03`,6.8`,0.93668`,1.1621000000000001`},0.207951461002518`},{{0.03`,7.4`,0.94018`,1.1666`},0.2177723480262627`},{{0.03`,7.4`,0.94018`,1.1711`},0.2177723480262627`},{{0.03`,7.4`,0.94018`,1.1621000000000001`},0.2177723480262627`},{{0.03`,7.4`,0.94368`,1.1666`},0.22092877807416547`},{{0.03`,7.4`,0.94368`,1.1711`},0.22092877807416547`},{{0.03`,7.4`,0.94368`,1.1621000000000001`},0.22092877807416547`},{{0.03`,7.4`,0.93668`,1.1666`},0.21465102717788295`},{{0.03`,7.4`,0.93668`,1.1711`},0.21465102717788295`},{{0.03`,7.4`,0.93668`,1.1621000000000001`},0.21465102717788295`},{{0.03`,8.`,0.94018`,1.1666`},0.22392209794174087`},{{0.03`,8.`,0.94018`,1.1711`},0.22392209794174087`},{{0.03`,8.`,0.94018`,1.1621000000000001`},0.22392209794174087`},{{0.03`,8.`,0.94368`,1.1666`},0.22719193549390207`},{{0.03`,8.`,0.94368`,1.1711`},0.22719193549390207`},{{0.03`,8.`,0.94368`,1.1621000000000001`},0.22719193549390207`},{{0.03`,8.`,0.93668`,1.1666`},0.22068851438444945`},{{0.03`,8.`,0.93668`,1.1711`},0.22068851438444945`},{{0.03`,8.`,0.93668`,1.1621000000000001`},0.22068851438444945`},{{0.03`,8.6`,0.94018`,1.1666`},0.22948230707113662`},{{0.03`,8.6`,0.94018`,1.1711`},0.22948230707113662`},{{0.03`,8.6`,0.94018`,1.1621000000000001`},0.22948230707113662`},{{0.03`,8.6`,0.94368`,1.1666`},0.2328558839796991`},{{0.03`,8.6`,0.94368`,1.1711`},0.2328558839796991`},{{0.03`,8.6`,0.94368`,1.1621000000000001`},0.2328558839796991`},{{0.03`,8.6`,0.93668`,1.1666`},0.2261460072368788`},{{0.03`,8.6`,0.93668`,1.1711`},0.2261460072368788`},{{0.03`,8.6`,0.93668`,1.1621000000000001`},0.2261460072368788`},{{0.03`,9.2`,0.94018`,1.1666`},0.23452328840607337`},{{0.03`,9.2`,0.94018`,1.1711`},0.23452328840607337`},{{0.03`,9.2`,0.94018`,1.1621000000000001`},0.23452328840607337`},{{0.03`,9.2`,0.94368`,1.1666`},0.23799206704861575`},{{0.03`,9.2`,0.94368`,1.1711`},0.23799206704861575`},{{0.03`,9.2`,0.94368`,1.1621000000000001`},0.23799206704861575`},{{0.03`,9.2`,0.93668`,1.1666`},0.23109270247304484`},{{0.03`,9.2`,0.93668`,1.1711`},0.23109270247304484`},{{0.03`,9.2`,0.93668`,1.1621000000000001`},0.23109270247304484`},{{0.03`,9.8`,0.94018`,1.1666`},0.23910544083923646`},{{0.03`,9.8`,0.94018`,1.1711`},0.23910544083923646`},{{0.03`,9.8`,0.94018`,1.1621000000000001`},0.23910544083923646`},{{0.03`,9.8`,0.94368`,1.1666`},0.24266185263287052`},{{0.03`,9.8`,0.94368`,1.1711`},0.24266185263287052`},{{0.03`,9.8`,0.94368`,1.1621000000000001`},0.24266185263287052`},{{0.03`,9.8`,0.93668`,1.1666`},0.23558804226490399`},{{0.03`,9.8`,0.93668`,1.1711`},0.23558804226490399`},{{0.03`,9.8`,0.93668`,1.1621000000000001`},0.23558804226490399`},{{0.03`,10.4`,0.94018`,1.1666`},0.2432799513899009`},{{0.03`,10.4`,0.94018`,1.1711`},0.2432799513899009`},{{0.03`,10.4`,0.94018`,1.1621000000000001`},0.2432799513899009`},{{0.03`,10.4`,0.94368`,1.1666`},0.24691726342122894`},{{0.03`,10.4`,0.94368`,1.1711`},0.24691726342122894`},{{0.03`,10.4`,0.94368`,1.1621000000000001`},0.24691726342122894`},{{0.03`,10.4`,0.93668`,1.1666`},0.23968238875354012`},{{0.03`,10.4`,0.93668`,1.1711`},0.23968238875354012`},{{0.03`,10.4`,0.93668`,1.1621000000000001`},0.23968238875354012`},{{0.03`,11.`,0.94018`,1.1666`},0.24709187832611954`},{{0.03`,11.`,0.94018`,1.1711`},0.24709187832611954`},{{0.03`,11.`,0.94018`,1.1621000000000001`},0.24709187832611954`},{{0.03`,11.`,0.94368`,1.1666`},0.2508040849540481`},{{0.03`,11.`,0.94368`,1.1711`},0.2508040849540481`},{{0.03`,11.`,0.94368`,1.1621000000000001`},0.2508040849540481`},{{0.03`,11.`,0.93668`,1.1666`},0.24342008213547184`},{{0.03`,11.`,0.93668`,1.1711`},0.24342008213547184`},{{0.03`,11.`,0.93668`,1.1621000000000001`},0.24342008213547184`},{{0.03`,11.6`,0.94018`,1.1666`},0.2505797841474838`},{{0.03`,11.6`,0.94018`,1.1711`},0.2505797841474838`},{{0.03`,11.6`,0.94018`,1.1621000000000001`},0.2505797841474838`},{{0.03`,11.6`,0.94368`,1.1666`},0.25436150788513606`},{{0.03`,11.6`,0.94368`,1.1711`},0.25436150788513606`},{{0.03`,11.6`,0.94368`,1.1621000000000001`},0.25436150788513606`},{{0.03`,11.6`,0.93668`,1.1666`},0.24683906493016314`},{{0.03`,11.6`,0.93668`,1.1711`},0.24683906493016314`},{{0.03`,11.6`,0.93668`,1.1621000000000001`},0.24683906493016314`},{{0.03`,12.2`,0.94018`,1.1666`},0.25377645567930546`},{{0.03`,12.2`,0.94018`,1.1711`},0.25377645567930546`},{{0.03`,12.2`,0.94018`,1.1621000000000001`},0.25377645567930546`},{{0.03`,12.2`,0.94368`,1.1666`},0.25762287304180764`},{{0.03`,12.2`,0.94368`,1.1711`},0.25762287304180764`},{{0.03`,12.2`,0.94368`,1.1621000000000001`},0.25762287304180764`},{{0.03`,12.2`,0.93668`,1.1666`},0.24997157714705526`},{{0.03`,12.2`,0.93668`,1.1711`},0.24997157714705526`},{{0.03`,12.2`,0.93668`,1.1621000000000001`},0.24997157714705526`},{{0.03`,12.8`,0.94018`,1.1666`},0.2567120967548252`},{{0.03`,12.8`,0.94018`,1.1711`},0.2567120967548252`},{{0.03`,12.8`,0.94018`,1.1621000000000001`},0.2567120967548252`},{{0.03`,12.8`,0.94368`,1.1666`},0.26061886617064023`},{{0.03`,12.8`,0.94368`,1.1711`},0.26061886617064023`},{{0.03`,12.8`,0.94368`,1.1621000000000001`},0.26061886617064023`},{{0.03`,12.8`,0.93668`,1.1666`},0.2528473467410611`},{{0.03`,12.8`,0.93668`,1.1711`},0.2528473467410611`},{{0.03`,12.8`,0.93668`,1.1621000000000001`},0.2528473467410611`},{{0.03`,13.4`,0.94018`,1.1666`},0.2594119329747063`},{{0.03`,13.4`,0.94018`,1.1711`},0.2594119329747063`},{{0.03`,13.4`,0.94018`,1.1621000000000001`},0.2594119329747063`},{{0.03`,13.4`,0.94368`,1.1666`},0.26337513408417584`},{{0.03`,13.4`,0.94368`,1.1711`},0.26337513408417584`},{{0.03`,13.4`,0.94368`,1.1621000000000001`},0.26337513408417584`},{{0.03`,13.4`,0.93668`,1.1666`},0.2554911837615953`},{{0.03`,13.4`,0.93668`,1.1711`},0.2554911837615953`},{{0.03`,13.4`,0.93668`,1.1621000000000001`},0.2554911837615953`},{{0.03`,14.`,0.94018`,1.1666`},0.2618989934911345`},{{0.03`,14.`,0.94018`,1.1711`},0.2618989934911345`},{{0.03`,14.`,0.94018`,1.1621000000000001`},0.2618989934911345`},{{0.03`,14.`,0.94368`,1.1666`},0.26591508171076433`},{{0.03`,14.`,0.94368`,1.1711`},0.26591508171076433`},{{0.03`,14.`,0.94368`,1.1621000000000001`},0.26591508171076433`},{{0.03`,14.`,0.93668`,1.1666`},0.25792574623559283`},{{0.03`,14.`,0.93668`,1.1711`},0.25792574623559283`},{{0.03`,14.`,0.93668`,1.1621000000000001`},0.25792574623559283`},{{0.03`,14.6`,0.94018`,1.1666`},0.2641933040680235`},{{0.03`,14.6`,0.94018`,1.1711`},0.2641933040680235`},{{0.03`,14.6`,0.94018`,1.1621000000000001`},0.2641933040680235`},{{0.03`,14.6`,0.94368`,1.1666`},0.26825906294780155`},{{0.03`,14.6`,0.94368`,1.1711`},0.26825906294780155`},{{0.03`,14.6`,0.94368`,1.1621000000000001`},0.26825906294780155`},{{0.03`,14.6`,0.93668`,1.1666`},0.2601707360773542`},{{0.03`,14.6`,0.93668`,1.1711`},0.2601707360773542`},{{0.03`,14.6`,0.93668`,1.1621000000000001`},0.2601707360773542`},{{0.03`,15.2`,0.94018`,1.1666`},0.266311784772107`},{{0.03`,15.2`,0.94018`,1.1711`},0.266311784772107`},{{0.03`,15.2`,0.94018`,1.1621000000000001`},0.266311784772107`},{{0.03`,15.2`,0.94368`,1.1666`},0.27042429237891213`},{{0.03`,15.2`,0.94368`,1.1711`},0.27042429237891213`},{{0.03`,15.2`,0.94368`,1.1621000000000001`},0.27042429237891213`},{{0.03`,15.2`,0.93668`,1.1666`},0.26224278284166264`},{{0.03`,15.2`,0.93668`,1.1711`},0.26224278284166264`},{{0.03`,15.2`,0.93668`,1.1621000000000001`},0.26224278284166264`},{{0.03`,15.8`,0.94018`,1.1666`},0.2682708404329072`},{{0.03`,15.8`,0.94018`,1.1711`},0.2682708404329072`},{{0.03`,15.8`,0.94018`,1.1621000000000001`},0.2682708404329072`},{{0.03`,15.8`,0.94368`,1.1666`},0.2724274372386582`},{{0.03`,15.8`,0.94368`,1.1711`},0.2724274372386582`},{{0.03`,15.8`,0.94368`,1.1621000000000001`},0.2724274372386582`},{{0.03`,15.8`,0.93668`,1.1666`},0.26415803199525817`},{{0.03`,15.8`,0.93668`,1.1711`},0.26415803199525817`},{{0.03`,15.8`,0.93668`,1.1621000000000001`},0.26415803199525817`},{{0.03`,16.4`,0.94018`,1.1666`},0.2700843504609798`},{{0.03`,16.4`,0.94018`,1.1711`},0.2700843504609798`},{{0.03`,16.4`,0.94018`,1.1621000000000001`},0.2700843504609798`},{{0.03`,16.4`,0.94368`,1.1666`},0.2742826074469974`},{{0.03`,16.4`,0.94368`,1.1711`},0.2742826074469974`},{{0.03`,16.4`,0.94368`,1.1621000000000001`},0.2742826074469974`},{{0.03`,16.4`,0.93668`,1.1666`},0.26593013549668815`},{{0.03`,16.4`,0.93668`,1.1711`},0.26593013549668815`},{{0.03`,16.4`,0.93668`,1.1621000000000001`},0.26593013549668815`},{{0.03`,17.`,0.94018`,1.1666`},0.27176442641161036`},{{0.03`,17.`,0.94018`,1.1711`},0.27176442641161036`},{{0.03`,17.`,0.94018`,1.1621000000000001`},0.27176442641161036`},{{0.03`,17.`,0.94368`,1.1666`},0.27600212235606963`},{{0.03`,17.`,0.94368`,1.1711`},0.27600212235606963`},{{0.03`,17.`,0.94368`,1.1621000000000001`},0.27600212235606963`},{{0.03`,17.`,0.93668`,1.1666`},0.26757099993110106`},{{0.03`,17.`,0.93668`,1.1711`},0.26757099993110106`},{{0.03`,17.`,0.93668`,1.1621000000000001`},0.26757099993110106`},{{0.03`,17.6`,0.94018`,1.1666`},0.2733223661348808`},{{0.03`,17.6`,0.94018`,1.1711`},0.2733223661348808`},{{0.03`,17.6`,0.94018`,1.1621000000000001`},0.2733223661348808`},{{0.03`,17.6`,0.94368`,1.1666`},0.27759747109980376`},{{0.03`,17.6`,0.94368`,1.1711`},0.27759747109980376`},{{0.03`,17.6`,0.94368`,1.1621000000000001`},0.27759747109980376`},{{0.03`,17.6`,0.93668`,1.1666`},0.26909173401784037`},{{0.03`,17.6`,0.93668`,1.1711`},0.26909173401784037`},{{0.03`,17.6`,0.93668`,1.1621000000000001`},0.26909173401784037`},{{0.03`,18.2`,0.94018`,1.1666`},0.27476859093793016`},{{0.03`,18.2`,0.94018`,1.1711`},0.27476859093793016`},{{0.03`,18.2`,0.94018`,1.1621000000000001`},0.27476859093793016`},{{0.03`,18.2`,0.94368`,1.1666`},0.2790792306446236`},{{0.03`,18.2`,0.94368`,1.1711`},0.2790792306446236`},{{0.03`,18.2`,0.94368`,1.1621000000000001`},0.2790792306446236`},{{0.03`,18.2`,0.93668`,1.1666`},0.27050260517933733`},{{0.03`,18.2`,0.93668`,1.1711`},0.27050260517933733`},{{0.03`,18.2`,0.93668`,1.1621000000000001`},0.27050260517933733`},{{0.03`,18.8`,0.94018`,1.1666`},0.27611144310845454`},{{0.03`,18.8`,0.94018`,1.1711`},0.27611144310845454`},{{0.03`,18.8`,0.94018`,1.1621000000000001`},0.27611144310845454`},{{0.03`,18.8`,0.94368`,1.1666`},0.28045591152167804`},{{0.03`,18.8`,0.94368`,1.1711`},0.28045591152167804`},{{0.03`,18.8`,0.94368`,1.1621000000000001`},0.28045591152167804`},{{0.03`,18.8`,0.93668`,1.1666`},0.27181179006216966`},{{0.03`,18.8`,0.93668`,1.1711`},0.27181179006216966`},{{0.03`,18.8`,0.93668`,1.1621000000000001`},0.27181179006216966`},{{0.03`,19.4`,0.94018`,1.1666`},0.2773588377447952`},{{0.03`,19.4`,0.94018`,1.1711`},0.2773588377447952`},{{0.03`,19.4`,0.94018`,1.1621000000000001`},0.2773588377447952`},{{0.03`,19.4`,0.94368`,1.1666`},0.28173556062747795`},{{0.03`,19.4`,0.94368`,1.1711`},0.28173556062747795`},{{0.03`,19.4`,0.94368`,1.1621000000000001`},0.28173556062747795`},{{0.03`,19.4`,0.93668`,1.1666`},0.27302707359060235`},{{0.03`,19.4`,0.93668`,1.1711`},0.27302707359060235`},{{0.03`,19.4`,0.93668`,1.1621000000000001`},0.27302707359060235`},{{0.03`,20.`,0.94018`,1.1666`},0.27851869184189076`},{{0.03`,20.`,0.94018`,1.1711`},0.27851869184189076`},{{0.03`,20.`,0.94018`,1.1621000000000001`},0.27851869184189076`},{{0.03`,20.`,0.94368`,1.1666`},0.28292621684203456`},{{0.03`,20.`,0.94368`,1.1711`},0.28292621684203456`},{{0.03`,20.`,0.94368`,1.1621000000000001`},0.28292621684203456`},{{0.03`,20.`,0.93668`,1.1666`},0.2741562520451075`},{{0.03`,20.`,0.93668`,1.1711`},0.2741562520451075`},{{0.03`,20.`,0.93668`,1.1621000000000001`},0.2741562520451075`},{{0.03`,20.6`,0.94018`,1.1666`},0.279597535329016`},{{0.03`,20.6`,0.94018`,1.1711`},0.279597535329016`},{{0.03`,20.6`,0.94018`,1.1621000000000001`},0.279597535329016`},{{0.03`,20.6`,0.94368`,1.1666`},0.2840345211546949`},{{0.03`,20.6`,0.94368`,1.1711`},0.2840345211546949`},{{0.03`,20.6`,0.94368`,1.1621000000000001`},0.2840345211546949`},{{0.03`,20.6`,0.93668`,1.1666`},0.27520574578599183`},{{0.03`,20.6`,0.93668`,1.1711`},0.27520574578599183`},{{0.03`,20.6`,0.93668`,1.1621000000000001`},0.27520574578599183`},{{0.03`,21.2`,0.94018`,1.1666`},0.2806008519952576`},{{0.03`,21.2`,0.94018`,1.1711`},0.2806008519952576`},{{0.03`,21.2`,0.94018`,1.1621000000000001`},0.2806008519952576`},{{0.03`,21.2`,0.94368`,1.1666`},0.28506606307262045`},{{0.03`,21.2`,0.94368`,1.1711`},0.28506606307262045`},{{0.03`,21.2`,0.94368`,1.1621000000000001`},0.28506606307262045`},{{0.03`,21.2`,0.93668`,1.1666`},0.27618093434300467`},{{0.03`,21.2`,0.93668`,1.1711`},0.27618093434300467`},{{0.03`,21.2`,0.93668`,1.1621000000000001`},0.27618093434300467`},{{0.03`,21.8`,0.94018`,1.1666`},0.28153468005121046`},{{0.03`,21.8`,0.94018`,1.1711`},0.28153468005121046`},{{0.03`,21.8`,0.94018`,1.1621000000000001`},0.28153468005121046`},{{0.03`,21.8`,0.94368`,1.1666`},0.286026970458637`},{{0.03`,21.8`,0.94368`,1.1711`},0.286026970458637`},{{0.03`,21.8`,0.94368`,1.1621000000000001`},0.286026970458637`},{{0.03`,21.8`,0.93668`,1.1666`},0.2770877670707357`},{{0.03`,21.8`,0.93668`,1.1711`},0.2770877670707357`},{{0.03`,21.8`,0.93668`,1.1621000000000001`},0.2770877670707357`},{{0.03`,22.4`,0.94018`,1.1666`},0.2824038383235537`},{{0.03`,22.4`,0.94018`,1.1711`},0.2824038383235537`},{{0.03`,22.4`,0.94018`,1.1621000000000001`},0.2824038383235537`},{{0.03`,22.4`,0.94368`,1.1666`},0.2869221466025544`},{{0.03`,22.4`,0.94368`,1.1711`},0.2869221466025544`},{{0.03`,22.4`,0.94368`,1.1621000000000001`},0.2869221466025544`},{{0.03`,22.4`,0.93668`,1.1666`},0.2779309794494845`},{{0.03`,22.4`,0.93668`,1.1711`},0.2779309794494845`},{{0.03`,22.4`,0.93668`,1.1621000000000001`},0.2779309794494845`},{{0.03`,23.`,0.94018`,1.1666`},0.28321288297951297`},{{0.03`,23.`,0.94018`,1.1711`},0.28321288297951297`},{{0.03`,23.`,0.94018`,1.1621000000000001`},0.28321288297951297`},{{0.03`,23.`,0.94368`,1.1666`},0.28775622428483716`},{{0.03`,23.`,0.94368`,1.1711`},0.28775622428483716`},{{0.03`,23.`,0.94368`,1.1621000000000001`},0.28775622428483716`},{{0.03`,23.`,0.93668`,1.1666`},0.27871505193506535`},{{0.03`,23.`,0.93668`,1.1711`},0.27871505193506535`},{{0.03`,23.`,0.93668`,1.1621000000000001`},0.27871505193506535`},{{0.03`,23.6`,0.94018`,1.1666`},0.28396598515415616`},{{0.03`,23.6`,0.94018`,1.1711`},0.28396598515415616`},{{0.03`,23.6`,0.94018`,1.1621000000000001`},0.28396598515415616`},{{0.03`,23.6`,0.94368`,1.1666`},0.2885334444592567`},{{0.03`,23.6`,0.94368`,1.1711`},0.2885334444592567`},{{0.03`,23.6`,0.94368`,1.1621000000000001`},0.2885334444592567`},{{0.03`,23.6`,0.93668`,1.1666`},0.279444086658474`},{{0.03`,23.6`,0.93668`,1.1711`},0.279444086658474`},{{0.03`,23.6`,0.93668`,1.1621000000000001`},0.279444086658474`},{{0.03`,24.2`,0.94018`,1.1666`},0.28466570720994294`},{{0.03`,24.2`,0.94018`,1.1711`},0.28466570720994294`},{{0.03`,24.2`,0.94018`,1.1621000000000001`},0.28466570720994294`},{{0.03`,24.2`,0.94368`,1.1666`},0.2892564487570184`},{{0.03`,24.2`,0.94368`,1.1711`},0.2892564487570184`},{{0.03`,24.2`,0.94368`,1.1621000000000001`},0.2892564487570184`},{{0.03`,24.2`,0.93668`,1.1666`},0.2801205680226575`},{{0.03`,24.2`,0.93668`,1.1711`},0.2801205680226575`},{{0.03`,24.2`,0.93668`,1.1621000000000001`},0.2801205680226575`},{{0.03`,24.8`,0.94018`,1.1666`},0.2853170061034173`},{{0.03`,24.8`,0.94018`,1.1711`},0.2853170061034173`},{{0.03`,24.8`,0.94018`,1.1621000000000001`},0.2853170061034173`},{{0.03`,24.8`,0.94368`,1.1666`},0.28993023856844524`},{{0.03`,24.8`,0.94368`,1.1711`},0.28993023856844524`},{{0.03`,24.8`,0.94368`,1.1621000000000001`},0.28993023856844524`},{{0.03`,24.8`,0.93668`,1.1666`},0.28074940838255846`},{{0.03`,24.8`,0.93668`,1.1711`},0.28074940838255846`},{{0.03`,24.8`,0.93668`,1.1621000000000001`},0.28074940838255846`},{{0.03`,25.4`,0.94018`,1.1666`},0.28592256296667773`},{{0.03`,25.4`,0.94018`,1.1711`},0.28592256296667773`},{{0.03`,25.4`,0.94018`,1.1621000000000001`},0.28592256296667773`},{{0.03`,25.4`,0.94368`,1.1666`},0.2905575537473825`},{{0.03`,25.4`,0.94368`,1.1711`},0.2905575537473825`},{{0.03`,25.4`,0.94368`,1.1621000000000001`},0.2905575537473825`},{{0.03`,25.4`,0.93668`,1.1666`},0.2813332310911214`},{{0.03`,25.4`,0.93668`,1.1711`},0.2813332310911214`},{{0.03`,25.4`,0.93668`,1.1621000000000001`},0.2813332310911214`},{{0.03`,26.`,0.94018`,1.1666`},0.2864852989112232`},{{0.03`,26.`,0.94018`,1.1711`},0.2864852989112232`},{{0.03`,26.`,0.94018`,1.1621000000000001`},0.2864852989112232`},{{0.03`,26.`,0.94368`,1.1666`},0.29114136558247633`},{{0.03`,26.`,0.94368`,1.1711`},0.29114136558247633`},{{0.03`,26.`,0.94368`,1.1621000000000001`},0.29114136558247633`},{{0.03`,26.`,0.93668`,1.1666`},0.2818749076362671`},{{0.03`,26.`,0.93668`,1.1711`},0.2818749076362671`},{{0.03`,26.`,0.93668`,1.1621000000000001`},0.2818749076362671`},{{0.03`,26.6`,0.94018`,1.1666`},0.28700789013795747`},{{0.03`,26.6`,0.94018`,1.1711`},0.28700789013795747`},{{0.03`,26.6`,0.94018`,1.1621000000000001`},0.28700789013795747`},{{0.03`,26.6`,0.94368`,1.1666`},0.29168439690543385`},{{0.03`,26.6`,0.94368`,1.1711`},0.29168439690543385`},{{0.03`,26.6`,0.94368`,1.1621000000000001`},0.29168439690543385`},{{0.03`,26.6`,0.93668`,1.1666`},0.28237706808320545`},{{0.03`,26.6`,0.93668`,1.1711`},0.28237706808320545`},{{0.03`,26.6`,0.93668`,1.1621000000000001`},0.28237706808320545`},{{0.03`,27.2`,0.94018`,1.1666`},0.287491736083422`},{{0.03`,27.2`,0.94018`,1.1711`},0.287491736083422`},{{0.03`,27.2`,0.94018`,1.1621000000000001`},0.287491736083422`},{{0.03`,27.2`,0.94368`,1.1666`},0.2921881049256746`},{{0.03`,27.2`,0.94368`,1.1711`},0.2921881049256746`},{{0.03`,27.2`,0.94368`,1.1621000000000001`},0.2921881049256746`},{{0.03`,27.2`,0.93668`,1.1666`},0.2828410551783112`},{{0.03`,27.2`,0.93668`,1.1711`},0.2828410551783112`},{{0.03`,27.2`,0.93668`,1.1621000000000001`},0.2828410551783112`},{{0.03`,27.8`,0.94018`,1.1666`},0.2879403829548243`},{{0.03`,27.8`,0.94018`,1.1711`},0.2879403829548243`},{{0.03`,27.8`,0.94018`,1.1621000000000001`},0.2879403829548243`},{{0.03`,27.8`,0.94368`,1.1666`},0.29265606163606817`},{{0.03`,27.8`,0.94368`,1.1711`},0.29265606163606817`},{{0.03`,27.8`,0.94368`,1.1621000000000001`},0.29265606163606817`},{{0.03`,27.8`,0.93668`,1.1666`},0.2832703887827964`},{{0.03`,27.8`,0.93668`,1.1711`},0.2832703887827964`},{{0.03`,27.8`,0.93668`,1.1621000000000001`},0.2832703887827964`},{{0.03`,28.4`,0.94018`,1.1666`},0.2883555594037341`},{{0.03`,28.4`,0.94018`,1.1711`},0.2883555594037341`},{{0.03`,28.4`,0.94018`,1.1621000000000001`},0.2883555594037341`},{{0.03`,28.4`,0.94368`,1.1666`},0.2930900351036421`},{{0.03`,28.4`,0.94368`,1.1711`},0.2930900351036421`},{{0.03`,28.4`,0.94368`,1.1621000000000001`},0.2930900351036421`},{{0.03`,28.4`,0.93668`,1.1666`},0.2836667589003848`},{{0.03`,28.4`,0.93668`,1.1711`},0.2836667589003848`},{{0.03`,28.4`,0.93668`,1.1621000000000001`},0.2836667589003848`},{{0.03`,29.`,0.94018`,1.1666`},0.2887392024919346`},{{0.03`,29.`,0.94018`,1.1711`},0.2887392024919346`},{{0.03`,29.`,0.94018`,1.1621000000000001`},0.2887392024919346`},{{0.03`,29.`,0.94368`,1.1666`},0.2934919966021425`},{{0.03`,29.`,0.94368`,1.1711`},0.2934919966021425`},{{0.03`,29.`,0.94368`,1.1621000000000001`},0.2934919966021425`},{{0.03`,29.`,0.93668`,1.1666`},0.28403206872038417`},{{0.03`,29.`,0.93668`,1.1711`},0.28403206872038417`},{{0.03`,29.`,0.93668`,1.1621000000000001`},0.28403206872038417`},{{0.03`,29.6`,0.94018`,1.1666`},0.2890925447541193`},{{0.03`,29.6`,0.94018`,1.1711`},0.2890925447541193`},{{0.03`,29.6`,0.94018`,1.1621000000000001`},0.2890925447541193`},{{0.03`,29.6`,0.94368`,1.1666`},0.2938632182712743`},{{0.03`,29.6`,0.94368`,1.1711`},0.2938632182712743`},{{0.03`,29.6`,0.94368`,1.1621000000000001`},0.2938632182712743`},{{0.03`,29.6`,0.93668`,1.1666`},0.2843675119018659`},{{0.03`,29.6`,0.93668`,1.1711`},0.2843675119018659`},{{0.03`,29.6`,0.93668`,1.1621000000000001`},0.2843675119018659`},{{0.03`,30.2`,0.94018`,1.1666`},0.28941775197710284`},{{0.03`,30.2`,0.94018`,1.1711`},0.28941775197710284`},{{0.03`,30.2`,0.94018`,1.1621000000000001`},0.28941775197710284`},{{0.03`,30.2`,0.94368`,1.1666`},0.2942058919618863`},{{0.03`,30.2`,0.94368`,1.1711`},0.2942058919618863`},{{0.03`,30.2`,0.94368`,1.1621000000000001`},0.2942058919618863`},{{0.03`,30.2`,0.93668`,1.1666`},0.2846752278386637`},{{0.03`,30.2`,0.93668`,1.1711`},0.2846752278386637`},{{0.03`,30.2`,0.93668`,1.1621000000000001`},0.2846752278386637`},{{0.03`,30.8`,0.94018`,1.1666`},0.28971622284382303`},{{0.03`,30.8`,0.94018`,1.1711`},0.28971622284382303`},{{0.03`,30.8`,0.94018`,1.1621000000000001`},0.28971622284382303`},{{0.03`,30.8`,0.94368`,1.1666`},0.29452144402075836`},{{0.03`,30.8`,0.94368`,1.1711`},0.29452144402075836`},{{0.03`,30.8`,0.94368`,1.1621000000000001`},0.29452144402075836`},{{0.03`,30.8`,0.93668`,1.1666`},0.2849565880388436`},{{0.03`,30.8`,0.93668`,1.1711`},0.2849565880388436`},{{0.03`,30.8`,0.93668`,1.1621000000000001`},0.2849565880388436`},{{0.03`,31.4`,0.94018`,1.1666`},0.2899893621756139`},{{0.03`,31.4`,0.94018`,1.1711`},0.2899893621756139`},{{0.03`,31.4`,0.94018`,1.1621000000000001`},0.2899893621756139`},{{0.03`,31.4`,0.94368`,1.1666`},0.29481130557923824`},{{0.03`,31.4`,0.94368`,1.1711`},0.29481130557923824`},{{0.03`,31.4`,0.94368`,1.1621000000000001`},0.29481130557923824`},{{0.03`,31.4`,0.93668`,1.1666`},0.2852129712429028`},{{0.03`,31.4`,0.93668`,1.1711`},0.2852129712429028`},{{0.03`,31.4`,0.93668`,1.1621000000000001`},0.2852129712429028`},{{0.03`,32.`,0.94018`,1.1666`},0.29023821368252495`},{{0.03`,32.`,0.94018`,1.1711`},0.29023821368252495`},{{0.03`,32.`,0.94018`,1.1621000000000001`},0.29023821368252495`},{{0.03`,32.`,0.94368`,1.1666`},0.29507654825797286`},{{0.03`,32.`,0.94368`,1.1711`},0.29507654825797286`},{{0.03`,32.`,0.94368`,1.1621000000000001`},0.29507654825797286`},{{0.03`,32.`,0.93668`,1.1666`},0.2854453937256924`},{{0.03`,32.`,0.93668`,1.1711`},0.2854453937256924`},{{0.03`,32.`,0.93668`,1.1621000000000001`},0.2854453937256924`},{{0.03`,32.6`,0.94018`,1.1666`},0.290464135311916`},{{0.03`,32.6`,0.94018`,1.1711`},0.290464135311916`},{{0.03`,32.6`,0.94018`,1.1621000000000001`},0.290464135311916`},{{0.03`,32.6`,0.94368`,1.1666`},0.2953185541413132`},{{0.03`,32.6`,0.94368`,1.1711`},0.2953185541413132`},{{0.03`,32.6`,0.94368`,1.1621000000000001`},0.2953185541413132`},{{0.03`,32.6`,0.93668`,1.1666`},0.28565518911932436`},{{0.03`,32.6`,0.93668`,1.1711`},0.28565518911932436`},{{0.03`,32.6`,0.93668`,1.1621000000000001`},0.28565518911932436`},{{0.03`,33.2`,0.94018`,1.1666`},0.29066823409514275`},{{0.03`,33.2`,0.94018`,1.1711`},0.29066823409514275`},{{0.03`,33.2`,0.94018`,1.1621000000000001`},0.29066823409514275`},{{0.03`,33.2`,0.94368`,1.1666`},0.2955384506438333`},{{0.03`,33.2`,0.94368`,1.1711`},0.2955384506438333`},{{0.03`,33.2`,0.94368`,1.1621000000000001`},0.2955384506438333`},{{0.03`,33.2`,0.93668`,1.1666`},0.2858434443744455`},{{0.03`,33.2`,0.93668`,1.1711`},0.2858434443744455`},{{0.03`,33.2`,0.93668`,1.1621000000000001`},0.2858434443744455`},{{0.03`,33.8`,0.94018`,1.1666`},0.29085153561462485`},{{0.03`,33.8`,0.94018`,1.1711`},0.29085153561462485`},{{0.03`,33.8`,0.94018`,1.1621000000000001`},0.29085153561462485`},{{0.03`,33.8`,0.94368`,1.1666`},0.29573728424815887`},{{0.03`,33.8`,0.94368`,1.1711`},0.29573728424815887`},{{0.03`,33.8`,0.94368`,1.1621000000000001`},0.29573728424815887`},{{0.03`,33.8`,0.93668`,1.1666`},0.28601116432324486`},{{0.03`,33.8`,0.93668`,1.1711`},0.28601116432324486`},{{0.03`,33.8`,0.93668`,1.1621000000000001`},0.28601116432324486`},{{0.03`,34.4`,0.94018`,1.1666`},0.29101499228932276`},{{0.03`,34.4`,0.94018`,1.1711`},0.29101499228932276`},{{0.03`,34.4`,0.94018`,1.1621000000000001`},0.29101499228932276`},{{0.03`,34.4`,0.94368`,1.1666`},0.29591602708708176`},{{0.03`,34.4`,0.94368`,1.1711`},0.29591602708708176`},{{0.03`,34.4`,0.94368`,1.1621000000000001`},0.29591602708708176`},{{0.03`,34.4`,0.93668`,1.1666`},0.28615928180337546`},{{0.03`,34.4`,0.93668`,1.1711`},0.28615928180337546`},{{0.03`,34.4`,0.93668`,1.1621000000000001`},0.28615928180337546`},{{0.03`,35.`,0.94018`,1.1666`},0.2911595252598582`},{{0.03`,35.`,0.94018`,1.1711`},0.2911595252598582`},{{0.03`,35.`,0.94018`,1.1621000000000001`},0.2911595252598582`},{{0.03`,35.`,0.94368`,1.1666`},0.2960756191831862`},{{0.03`,35.`,0.94368`,1.1711`},0.2960756191831862`},{{0.03`,35.`,0.94368`,1.1621000000000001`},0.2960756191831862`},{{0.03`,35.`,0.93668`,1.1666`},0.2862886991230595`},{{0.03`,35.`,0.93668`,1.1711`},0.2862886991230595`},{{0.03`,35.`,0.93668`,1.1621000000000001`},0.2862886991230595`},{{0.03`,35.6`,0.94018`,1.1666`},0.2912851907054357`},{{0.03`,35.6`,0.94018`,1.1711`},0.2912851907054357`},{{0.03`,35.6`,0.94018`,1.1621000000000001`},0.2912851907054357`},{{0.03`,35.6`,0.94368`,1.1666`},0.2962161466531942`},{{0.03`,35.6`,0.94368`,1.1711`},0.2962161466531942`},{{0.03`,35.6`,0.94368`,1.1621000000000001`},0.2962161466531942`},{{0.03`,35.6`,0.93668`,1.1666`},0.2863994432908853`},{{0.03`,35.6`,0.93668`,1.1711`},0.2863994432908853`},{{0.03`,35.6`,0.93668`,1.1621000000000001`},0.2863994432908853`},{{0.03`,36.2`,0.94018`,1.1666`},0.2913937531476216`},{{0.03`,36.2`,0.94018`,1.1711`},0.2913937531476216`},{{0.03`,36.2`,0.94018`,1.1621000000000001`},0.2913937531476216`},{{0.03`,36.2`,0.94368`,1.1666`},0.29633937526430904`},{{0.03`,36.2`,0.94368`,1.1711`},0.29633937526430904`},{{0.03`,36.2`,0.94368`,1.1621000000000001`},0.29633937526430904`},{{0.03`,36.2`,0.93668`,1.1666`},0.28649327674491626`},{{0.03`,36.2`,0.93668`,1.1711`},0.28649327674491626`},{{0.03`,36.2`,0.93668`,1.1621000000000001`},0.28649327674491626`},{{0.03`,36.8`,0.94018`,1.1666`},0.2914855286945018`},{{0.03`,36.8`,0.94018`,1.1711`},0.2914855286945018`},{{0.03`,36.8`,0.94018`,1.1621000000000001`},0.2914855286945018`},{{0.03`,36.8`,0.94368`,1.1666`},0.2964456432194275`},{{0.03`,36.8`,0.94368`,1.1711`},0.2964456432194275`},{{0.03`,36.8`,0.94368`,1.1621000000000001`},0.2964456432194275`},{{0.03`,36.8`,0.93668`,1.1666`},0.2865704939408118`},{{0.03`,36.8`,0.93668`,1.1711`},0.2865704939408118`},{{0.03`,36.8`,0.93668`,1.1621000000000001`},0.2865704939408118`},{{0.03`,37.4`,0.94018`,1.1666`},0.29156115826744455`},{{0.03`,37.4`,0.94018`,1.1711`},0.29156115826744455`},{{0.03`,37.4`,0.94018`,1.1621000000000001`},0.29156115826744455`},{{0.03`,37.4`,0.94368`,1.1666`},0.2965356071478335`},{{0.03`,37.4`,0.94368`,1.1711`},0.2965356071478335`},{{0.03`,37.4`,0.94368`,1.1621000000000001`},0.2965356071478335`},{{0.03`,37.4`,0.93668`,1.1666`},0.286631720155529`},{{0.03`,37.4`,0.93668`,1.1711`},0.286631720155529`},{{0.03`,37.4`,0.93668`,1.1621000000000001`},0.286631720155529`},{{0.03`,38.`,0.94018`,1.1666`},0.2916212347781812`},{{0.03`,38.`,0.94018`,1.1711`},0.2916212347781812`},{{0.03`,38.`,0.94018`,1.1621000000000001`},0.2916212347781812`},{{0.03`,38.`,0.94368`,1.1666`},0.29660987500934255`},{{0.03`,38.`,0.94368`,1.1711`},0.29660987500934255`},{{0.03`,38.`,0.94368`,1.1621000000000001`},0.29660987500934255`},{{0.03`,38.`,0.93668`,1.1666`},0.2866775333037354`},{{0.03`,38.`,0.93668`,1.1711`},0.2866775333037354`},{{0.03`,38.`,0.93668`,1.1621000000000001`},0.2866775333037354`},{{0.03`,38.6`,0.94018`,1.1666`},0.2916663061053685`},{{0.03`,38.6`,0.94018`,1.1711`},0.2916663061053685`},{{0.03`,38.6`,0.94018`,1.1621000000000001`},0.2916663061053685`},{{0.03`,38.6`,0.94368`,1.1666`},0.2966690091324676`},{{0.03`,38.6`,0.94368`,1.1711`},0.2966690091324676`},{{0.03`,38.6`,0.94368`,1.1621000000000001`},0.2966690091324676`},{{0.03`,38.6`,0.93668`,1.1666`},0.28670846685333473`},{{0.03`,38.6`,0.93668`,1.1711`},0.28670846685333473`},{{0.03`,38.6`,0.93668`,1.1621000000000001`},0.28670846685333473`},{{0.03`,39.2`,0.94018`,1.1666`},0.29169687775975434`},{{0.03`,39.2`,0.94018`,1.1711`},0.29169687775975434`},{{0.03`,39.2`,0.94018`,1.1621000000000001`},0.29169687775975434`},{{0.03`,39.2`,0.94368`,1.1666`},0.2967135289377918`},{{0.03`,39.2`,0.94368`,1.1711`},0.2967135289377918`},{{0.03`,39.2`,0.94368`,1.1621000000000001`},0.2967135289377918`},{{0.03`,39.2`,0.93668`,1.1666`},0.28672501243291826`},{{0.03`,39.2`,0.93668`,1.1711`},0.28672501243291826`},{{0.03`,39.2`,0.93668`,1.1621000000000001`},0.28672501243291826`},{{0.03`,39.8`,0.94018`,1.1666`},0.2917134152631061`},{{0.03`,39.8`,0.94018`,1.1711`},0.2917134152631061`},{{0.03`,39.8`,0.94018`,1.1621000000000001`},0.2917134152631061`},{{0.03`,39.8`,0.94368`,1.1666`},0.29674391337221173`},{{0.03`,39.8`,0.94368`,1.1711`},0.29674391337221173`},{{0.03`,39.8`,0.94368`,1.1621000000000001`},0.29674391337221173`},{{0.03`,39.8`,0.93668`,1.1666`},0.2867276221558144`},{{0.03`,39.8`,0.93668`,1.1711`},0.2867276221558144`},{{0.03`,39.8`,0.93668`,1.1621000000000001`},0.2867276221558144`},{{0.06`,0.4`,0.94018`,1.1666`},0.08026308853819672`},{{0.06`,0.4`,0.94018`,1.1711`},0.08026308853819672`},{{0.06`,0.4`,0.94018`,1.1621000000000001`},0.08026308853819672`},{{0.06`,0.4`,0.94368`,1.1666`},0.08058828269318231`},{{0.06`,0.4`,0.94368`,1.1711`},0.08058828269318231`},{{0.06`,0.4`,0.94368`,1.1621000000000001`},0.08058828269318231`},{{0.06`,0.4`,0.93668`,1.1666`},0.07994153717257903`},{{0.06`,0.4`,0.93668`,1.1711`},0.07994153717257903`},{{0.06`,0.4`,0.93668`,1.1621000000000001`},0.07994153717257903`},{{0.06`,0.6`,0.94018`,1.1666`},0.08954621410570655`},{{0.06`,0.6`,0.94018`,1.1711`},0.08954621410570655`},{{0.06`,0.6`,0.94018`,1.1621000000000001`},0.08954621410570655`},{{0.06`,0.6`,0.94368`,1.1666`},0.09002174824247379`},{{0.06`,0.6`,0.94368`,1.1711`},0.09002174824247379`},{{0.06`,0.6`,0.94368`,1.1621000000000001`},0.09002174824247379`},{{0.06`,0.6`,0.93668`,1.1666`},0.08907602264523122`},{{0.06`,0.6`,0.93668`,1.1711`},0.08907602264523122`},{{0.06`,0.6`,0.93668`,1.1621000000000001`},0.08907602264523122`},{{0.06`,0.8`,0.94018`,1.1666`},0.09831883397917189`},{{0.06`,0.8`,0.94018`,1.1711`},0.09831883397917189`},{{0.06`,0.8`,0.94018`,1.1621000000000001`},0.09831883397917189`},{{0.06`,0.8`,0.94368`,1.1666`},0.09893724142186829`},{{0.06`,0.8`,0.94368`,1.1711`},0.09893724142186829`},{{0.06`,0.8`,0.94368`,1.1621000000000001`},0.09893724142186829`},{{0.06`,0.8`,0.93668`,1.1666`},0.0977073928682581`},{{0.06`,0.8`,0.93668`,1.1711`},0.0977073928682581`},{{0.06`,0.8`,0.93668`,1.1621000000000001`},0.0977073928682581`},{{0.06`,1.`,0.94018`,1.1666`},0.10661761070998928`},{{0.06`,1.`,0.94018`,1.1711`},0.10661761070998928`},{{0.06`,1.`,0.94018`,1.1621000000000001`},0.10661761070998928`},{{0.06`,1.`,0.94368`,1.1666`},0.10737190300521825`},{{0.06`,1.`,0.94368`,1.1711`},0.10737190300521825`},{{0.06`,1.`,0.94368`,1.1621000000000001`},0.10737190300521825`},{{0.06`,1.`,0.93668`,1.1666`},0.1058718356682359`},{{0.06`,1.`,0.93668`,1.1711`},0.1058718356682359`},{{0.06`,1.`,0.93668`,1.1621000000000001`},0.1058718356682359`},{{0.06`,1.2`,0.94018`,1.1666`},0.11447595203993904`},{{0.06`,1.2`,0.94018`,1.1711`},0.11447595203993904`},{{0.06`,1.2`,0.94018`,1.1621000000000001`},0.11447595203993904`},{{0.06`,1.2`,0.94368`,1.1666`},0.11535958273917095`},{{0.06`,1.2`,0.94368`,1.1711`},0.11535958273917095`},{{0.06`,1.2`,0.94368`,1.1621000000000001`},0.11535958273917095`},{{0.06`,1.2`,0.93668`,1.1666`},0.11360232018524304`},{{0.06`,1.2`,0.93668`,1.1711`},0.11360232018524304`},{{0.06`,1.2`,0.93668`,1.1621000000000001`},0.11360232018524304`},{{0.06`,1.4`,0.94018`,1.1666`},0.12192435308760445`},{{0.06`,1.4`,0.94018`,1.1711`},0.12192435308760445`},{{0.06`,1.4`,0.94018`,1.1621000000000001`},0.12192435308760445`},{{0.06`,1.4`,0.94368`,1.1666`},0.12293118456759021`},{{0.06`,1.4`,0.94368`,1.1711`},0.12293118456759021`},{{0.06`,1.4`,0.94368`,1.1621000000000001`},0.12293118456759021`},{{0.06`,1.4`,0.93668`,1.1666`},0.12092893600574103`},{{0.06`,1.4`,0.93668`,1.1711`},0.12092893600574103`},{{0.06`,1.4`,0.93668`,1.1621000000000001`},0.12092893600574103`},{{0.06`,1.6`,0.94018`,1.1666`},0.12899069723872714`},{{0.06`,1.6`,0.94018`,1.1711`},0.12899069723872714`},{{0.06`,1.6`,0.94018`,1.1621000000000001`},0.12899069723872714`},{{0.06`,1.6`,0.94368`,1.1666`},0.1301149703001594`},{{0.06`,1.6`,0.94368`,1.1711`},0.1301149703001594`},{{0.06`,1.6`,0.94368`,1.1621000000000001`},0.1301149703001594`},{{0.06`,1.6`,0.93668`,1.1666`},0.12787919126431807`},{{0.06`,1.6`,0.93668`,1.1711`},0.12787919126431807`},{{0.06`,1.6`,0.93668`,1.1621000000000001`},0.12787919126431807`},{{0.06`,1.8`,0.94018`,1.1666`},0.13570052132941288`},{{0.06`,1.8`,0.94018`,1.1711`},0.13570052132941288`},{{0.06`,1.8`,0.94018`,1.1621000000000001`},0.13570052132941288`},{{0.06`,1.8`,0.94368`,1.1666`},0.13693682733270077`},{{0.06`,1.8`,0.94368`,1.1711`},0.13693682733270077`},{{0.06`,1.8`,0.94368`,1.1621000000000001`},0.13693682733270077`},{{0.06`,1.8`,0.93668`,1.1666`},0.1344782752834237`},{{0.06`,1.8`,0.93668`,1.1711`},0.1344782752834237`},{{0.06`,1.8`,0.93668`,1.1621000000000001`},0.1344782752834237`},{{0.06`,2.`,0.94018`,1.1666`},0.14207724987815648`},{{0.06`,2.`,0.94018`,1.1711`},0.14207724987815648`},{{0.06`,2.`,0.94018`,1.1621000000000001`},0.14207724987815648`},{{0.06`,2.`,0.94368`,1.1666`},0.14342050519384414`},{{0.06`,2.`,0.94368`,1.1711`},0.14342050519384414`},{{0.06`,2.`,0.94368`,1.1621000000000001`},0.14342050519384414`},{{0.06`,2.`,0.93668`,1.1666`},0.14074929048747617`},{{0.06`,2.`,0.93668`,1.1711`},0.14074929048747617`},{{0.06`,2.`,0.93668`,1.1621000000000001`},0.14074929048747617`},{{0.06`,2.2`,0.94018`,1.1666`},0.1481424024244017`},{{0.06`,2.2`,0.94018`,1.1711`},0.1481424024244017`},{{0.06`,2.2`,0.94018`,1.1621000000000001`},0.1481424024244017`},{{0.06`,2.2`,0.94368`,1.1666`},0.14958782499394435`},{{0.06`,2.2`,0.94368`,1.1711`},0.14958782499394435`},{{0.06`,2.2`,0.94368`,1.1621000000000001`},0.14958782499394435`},{{0.06`,2.2`,0.93668`,1.1666`},0.14671345763014415`},{{0.06`,2.2`,0.93668`,1.1711`},0.14671345763014415`},{{0.06`,2.2`,0.93668`,1.1621000000000001`},0.14671345763014415`},{{0.06`,2.6`,0.94018`,1.1666`},0.1594137650754137`},{{0.06`,2.6`,0.94018`,1.1711`},0.1594137650754137`},{{0.06`,2.6`,0.94018`,1.1621000000000001`},0.1594137650754137`},{{0.06`,2.6`,0.94368`,1.1666`},0.16105027708946543`},{{0.06`,2.6`,0.94368`,1.1711`},0.16105027708946543`},{{0.06`,2.6`,0.94368`,1.1621000000000001`},0.16105027708946543`},{{0.06`,2.6`,0.93668`,1.1666`},0.1577959432946985`},{{0.06`,2.6`,0.93668`,1.1711`},0.1577959432946985`},{{0.06`,2.6`,0.93668`,1.1621000000000001`},0.1577959432946985`},{{0.06`,3.`,0.94018`,1.1666`},0.16965627924885895`},{{0.06`,3.`,0.94018`,1.1711`},0.16965627924885895`},{{0.06`,3.`,0.94018`,1.1621000000000001`},0.16965627924885895`},{{0.06`,3.`,0.94368`,1.1666`},0.1714678778020215`},{{0.06`,3.`,0.94368`,1.1711`},0.1714678778020215`},{{0.06`,3.`,0.94368`,1.1621000000000001`},0.1714678778020215`},{{0.06`,3.`,0.93668`,1.1666`},0.16786539736112158`},{{0.06`,3.`,0.93668`,1.1711`},0.16786539736112158`},{{0.06`,3.`,0.93668`,1.1621000000000001`},0.16786539736112158`},{{0.06`,3.4`,0.94018`,1.1666`},0.17899032186978023`},{{0.06`,3.4`,0.94018`,1.1711`},0.17899032186978023`},{{0.06`,3.4`,0.94018`,1.1621000000000001`},0.17899032186978023`},{{0.06`,3.4`,0.94368`,1.1666`},0.18096274217791766`},{{0.06`,3.4`,0.94368`,1.1711`},0.18096274217791766`},{{0.06`,3.4`,0.94368`,1.1621000000000001`},0.18096274217791766`},{{0.06`,3.4`,0.93668`,1.1666`},0.1770404763664406`},{{0.06`,3.4`,0.93668`,1.1711`},0.1770404763664406`},{{0.06`,3.4`,0.93668`,1.1621000000000001`},0.1770404763664406`},{{0.06`,3.8`,0.94018`,1.1666`},0.18751871861432706`},{{0.06`,3.8`,0.94018`,1.1711`},0.18751871861432706`},{{0.06`,3.8`,0.94018`,1.1621000000000001`},0.18751871861432706`},{{0.06`,3.8`,0.94368`,1.1666`},0.189639212991995`},{{0.06`,3.8`,0.94368`,1.1711`},0.189639212991995`},{{0.06`,3.8`,0.94368`,1.1621000000000001`},0.189639212991995`},{{0.06`,3.8`,0.93668`,1.1666`},0.18542250489888568`},{{0.06`,3.8`,0.93668`,1.1711`},0.18542250489888568`},{{0.06`,3.8`,0.93668`,1.1621000000000001`},0.18542250489888568`},{{0.06`,4.2`,0.94018`,1.1666`},0.19533012995175297`},{{0.06`,4.2`,0.94018`,1.1711`},0.19533012995175297`},{{0.06`,4.2`,0.94018`,1.1621000000000001`},0.19533012995175297`},{{0.06`,4.2`,0.94368`,1.1666`},0.19758727463725195`},{{0.06`,4.2`,0.94368`,1.1711`},0.19758727463725195`},{{0.06`,4.2`,0.94368`,1.1621000000000001`},0.19758727463725195`},{{0.06`,4.2`,0.93668`,1.1666`},0.1930988338756071`},{{0.06`,4.2`,0.93668`,1.1711`},0.1930988338756071`},{{0.06`,4.2`,0.93668`,1.1621000000000001`},0.1930988338756071`},{{0.06`,4.6`,0.94018`,1.1666`},0.2025018547615157`},{{0.06`,4.6`,0.94018`,1.1711`},0.2025018547615157`},{{0.06`,4.6`,0.94018`,1.1621000000000001`},0.2025018547615157`},{{0.06`,4.6`,0.94368`,1.1666`},0.20488538525528818`},{{0.06`,4.6`,0.94368`,1.1711`},0.20488538525528818`},{{0.06`,4.6`,0.94368`,1.1621000000000001`},0.20488538525528818`},{{0.06`,4.6`,0.93668`,1.1666`},0.20014561561755825`},{{0.06`,4.6`,0.93668`,1.1711`},0.20014561561755825`},{{0.06`,4.6`,0.93668`,1.1621000000000001`},0.20014561561755825`},{{0.06`,5.`,0.94018`,1.1666`},0.20910053402529027`},{{0.06`,5.`,0.94018`,1.1711`},0.20910053402529027`},{{0.06`,5.`,0.94018`,1.1621000000000001`},0.20910053402529027`},{{0.06`,5.`,0.94368`,1.1666`},0.211601194412332`},{{0.06`,5.`,0.94368`,1.1711`},0.211601194412332`},{{0.06`,5.`,0.94368`,1.1621000000000001`},0.211601194412332`},{{0.06`,5.`,0.93668`,1.1666`},0.20662849421639848`},{{0.06`,5.`,0.93668`,1.1711`},0.20662849421639848`},{{0.06`,5.`,0.93668`,1.1621000000000001`},0.20662849421639848`},{{0.06`,5.4`,0.94018`,1.1666`},0.2151838801087246`},{{0.06`,5.4`,0.94018`,1.1711`},0.2151838801087246`},{{0.06`,5.4`,0.94018`,1.1621000000000001`},0.2151838801087246`},{{0.06`,5.4`,0.94368`,1.1666`},0.21779331544934688`},{{0.06`,5.4`,0.94368`,1.1711`},0.21779331544934688`},{{0.06`,5.4`,0.94368`,1.1621000000000001`},0.21779331544934688`},{{0.06`,5.4`,0.93668`,1.1666`},0.2126042914582391`},{{0.06`,5.4`,0.93668`,1.1711`},0.2126042914582391`},{{0.06`,5.4`,0.93668`,1.1621000000000001`},0.2126042914582391`},{{0.06`,5.8`,0.94018`,1.1666`},0.2208029028616797`},{{0.06`,5.8`,0.94018`,1.1711`},0.2208029028616797`},{{0.06`,5.8`,0.94018`,1.1621000000000001`},0.2208029028616797`},{{0.06`,5.8`,0.94368`,1.1666`},0.22351354853064073`},{{0.06`,5.8`,0.94368`,1.1711`},0.22351354853064073`},{{0.06`,5.8`,0.94368`,1.1621000000000001`},0.22351354853064073`},{{0.06`,5.8`,0.93668`,1.1666`},0.21812323617674959`},{{0.06`,5.8`,0.93668`,1.1711`},0.21812323617674959`},{{0.06`,5.8`,0.93668`,1.1621000000000001`},0.21812323617674959`},{{0.06`,6.2`,0.94018`,1.1666`},0.22600243635222597`},{{0.06`,6.2`,0.94018`,1.1711`},0.22600243635222597`},{{0.06`,6.2`,0.94018`,1.1621000000000001`},0.22600243635222597`},{{0.06`,6.2`,0.94368`,1.1666`},0.22880742760144873`},{{0.06`,6.2`,0.94368`,1.1711`},0.22880742760144873`},{{0.06`,6.2`,0.94368`,1.1621000000000001`},0.22880742760144873`},{{0.06`,6.2`,0.93668`,1.1666`},0.22322947091132522`},{{0.06`,6.2`,0.93668`,1.1711`},0.22322947091132522`},{{0.06`,6.2`,0.93668`,1.1621000000000001`},0.22322947091132522`},{{0.06`,6.8`,0.94018`,1.1666`},0.23310009296489917`},{{0.06`,6.8`,0.94018`,1.1711`},0.23310009296489917`},{{0.06`,6.8`,0.94018`,1.1621000000000001`},0.23310009296489917`},{{0.06`,6.8`,0.94368`,1.1666`},0.23603507047532807`},{{0.06`,6.8`,0.94368`,1.1711`},0.23603507047532807`},{{0.06`,6.8`,0.94368`,1.1621000000000001`},0.23603507047532807`},{{0.06`,6.8`,0.93668`,1.1666`},0.23019856748519396`},{{0.06`,6.8`,0.93668`,1.1711`},0.23019856748519396`},{{0.06`,6.8`,0.93668`,1.1621000000000001`},0.23019856748519396`},{{0.06`,7.4`,0.94018`,1.1666`},0.2394562018729447`},{{0.06`,7.4`,0.94018`,1.1711`},0.2394562018729447`},{{0.06`,7.4`,0.94018`,1.1621000000000001`},0.2394562018729447`},{{0.06`,7.4`,0.94368`,1.1666`},0.24250892238697488`},{{0.06`,7.4`,0.94368`,1.1711`},0.24250892238697488`},{{0.06`,7.4`,0.94368`,1.1621000000000001`},0.24250892238697488`},{{0.06`,7.4`,0.93668`,1.1666`},0.23643820632574344`},{{0.06`,7.4`,0.93668`,1.1711`},0.23643820632574344`},{{0.06`,7.4`,0.93668`,1.1621000000000001`},0.23643820632574344`},{{0.06`,8.`,0.94018`,1.1666`},0.24516684801492572`},{{0.06`,8.`,0.94018`,1.1711`},0.24516684801492572`},{{0.06`,8.`,0.94018`,1.1621000000000001`},0.24516684801492572`},{{0.06`,8.`,0.94368`,1.1666`},0.24832660243524854`},{{0.06`,8.`,0.94368`,1.1711`},0.24832660243524854`},{{0.06`,8.`,0.94368`,1.1621000000000001`},0.24832660243524854`},{{0.06`,8.`,0.93668`,1.1666`},0.24204295721982924`},{{0.06`,8.`,0.93668`,1.1711`},0.24204295721982924`},{{0.06`,8.`,0.93668`,1.1621000000000001`},0.24204295721982924`},{{0.06`,8.6`,0.94018`,1.1666`},0.25031352312989846`},{{0.06`,8.6`,0.94018`,1.1711`},0.25031352312989846`},{{0.06`,8.6`,0.94018`,1.1621000000000001`},0.25031352312989846`},{{0.06`,8.6`,0.94368`,1.1666`},0.2535709063127534`},{{0.06`,8.6`,0.94368`,1.1711`},0.2535709063127534`},{{0.06`,8.6`,0.94368`,1.1621000000000001`},0.2535709063127534`},{{0.06`,8.6`,0.93668`,1.1666`},0.24709302424640647`},{{0.06`,8.6`,0.93668`,1.1711`},0.24709302424640647`},{{0.06`,8.6`,0.93668`,1.1621000000000001`},0.24709302424640647`},{{0.06`,9.2`,0.94018`,1.1666`},0.2549647888987512`},{{0.06`,9.2`,0.94018`,1.1711`},0.2549647888987512`},{{0.06`,9.2`,0.94018`,1.1621000000000001`},0.2549647888987512`},{{0.06`,9.2`,0.94368`,1.1666`},0.25831150854041063`},{{0.06`,9.2`,0.94368`,1.1711`},0.25831150854041063`},{{0.06`,9.2`,0.94368`,1.1621000000000001`},0.25831150854041063`},{{0.06`,9.2`,0.93668`,1.1666`},0.25165587030656483`},{{0.06`,9.2`,0.93668`,1.1711`},0.25165587030656483`},{{0.06`,9.2`,0.93668`,1.1621000000000001`},0.25165587030656483`},{{0.06`,9.8`,0.94018`,1.1666`},0.2591794207426586`},{{0.06`,9.8`,0.94018`,1.1711`},0.2591794207426586`},{{0.06`,9.8`,0.94018`,1.1621000000000001`},0.2591794207426586`},{{0.06`,9.8`,0.94368`,1.1666`},0.2626081367663206`},{{0.06`,9.8`,0.94368`,1.1711`},0.2626081367663206`},{{0.06`,9.8`,0.94368`,1.1621000000000001`},0.2626081367663206`},{{0.06`,9.8`,0.93668`,1.1666`},0.25578933069771015`},{{0.06`,9.8`,0.93668`,1.1711`},0.25578933069771015`},{{0.06`,9.8`,0.93668`,1.1621000000000001`},0.25578933069771015`},{{0.06`,10.4`,0.94018`,1.1666`},0.2630071254712237`},{{0.06`,10.4`,0.94018`,1.1711`},0.2630071254712237`},{{0.06`,10.4`,0.94018`,1.1621000000000001`},0.2630071254712237`},{{0.06`,10.4`,0.94368`,1.1666`},0.2665113170257236`},{{0.06`,10.4`,0.94368`,1.1711`},0.2665113170257236`},{{0.06`,10.4`,0.94368`,1.1621000000000001`},0.2665113170257236`},{{0.06`,10.4`,0.93668`,1.1666`},0.25954230359223457`},{{0.06`,10.4`,0.93668`,1.1711`},0.25954230359223457`},{{0.06`,10.4`,0.93668`,1.1621000000000001`},0.25954230359223457`},{{0.06`,11.`,0.94018`,1.1666`},0.2664915709396776`},{{0.06`,11.`,0.94018`,1.1711`},0.2664915709396776`},{{0.06`,11.`,0.94018`,1.1621000000000001`},0.2664915709396776`},{{0.06`,11.`,0.94368`,1.1666`},0.2700654295273877`},{{0.06`,11.`,0.94368`,1.1711`},0.2700654295273877`},{{0.06`,11.`,0.94368`,1.1621000000000001`},0.2700654295273877`},{{0.06`,11.`,0.93668`,1.1666`},0.2629577534973244`},{{0.06`,11.`,0.93668`,1.1711`},0.2629577534973244`},{{0.06`,11.`,0.93668`,1.1621000000000001`},0.2629577534973244`},{{0.06`,11.6`,0.94018`,1.1666`},0.26967005740308714`},{{0.06`,11.6`,0.94018`,1.1711`},0.26967005740308714`},{{0.06`,11.6`,0.94018`,1.1621000000000001`},0.26967005740308714`},{{0.06`,11.6`,0.94368`,1.1666`},0.2733083883045088`},{{0.06`,11.6`,0.94368`,1.1711`},0.2733083883045088`},{{0.06`,11.6`,0.94368`,1.1621000000000001`},0.2733083883045088`},{{0.06`,11.6`,0.93668`,1.1666`},0.2660723748761691`},{{0.06`,11.6`,0.93668`,1.1711`},0.2660723748761691`},{{0.06`,11.6`,0.93668`,1.1621000000000001`},0.2660723748761691`},{{0.06`,12.2`,0.94018`,1.1666`},0.2725742175407875`},{{0.06`,12.2`,0.94018`,1.1711`},0.2725742175407875`},{{0.06`,12.2`,0.94018`,1.1621000000000001`},0.2725742175407875`},{{0.06`,12.2`,0.94368`,1.1666`},0.27627236608815964`},{{0.06`,12.2`,0.94368`,1.1711`},0.27627236608815964`},{{0.06`,12.2`,0.94368`,1.1621000000000001`},0.27627236608815964`},{{0.06`,12.2`,0.93668`,1.1666`},0.2689172673804289`},{{0.06`,12.2`,0.93668`,1.1711`},0.2689172673804289`},{{0.06`,12.2`,0.93668`,1.1621000000000001`},0.2689172673804289`},{{0.06`,12.8`,0.94018`,1.1666`},0.2752331647269113`},{{0.06`,12.8`,0.94018`,1.1711`},0.2752331647269113`},{{0.06`,12.8`,0.94018`,1.1621000000000001`},0.2752331647269113`},{{0.06`,12.8`,0.94368`,1.1666`},0.27898694631210713`},{{0.06`,12.8`,0.94368`,1.1711`},0.27898694631210713`},{{0.06`,12.8`,0.94368`,1.1621000000000001`},0.27898694631210713`},{{0.06`,12.8`,0.93668`,1.1666`},0.2715210801949143`},{{0.06`,12.8`,0.93668`,1.1711`},0.2715210801949143`},{{0.06`,12.8`,0.93668`,1.1621000000000001`},0.2715210801949143`},{{0.06`,13.4`,0.94018`,1.1666`},0.27767115878253223`},{{0.06`,13.4`,0.94018`,1.1711`},0.27767115878253223`},{{0.06`,13.4`,0.94018`,1.1621000000000001`},0.27767115878253223`},{{0.06`,13.4`,0.94368`,1.1666`},0.2814767978218841`},{{0.06`,13.4`,0.94368`,1.1711`},0.2814767978218841`},{{0.06`,13.4`,0.94368`,1.1621000000000001`},0.2814767978218841`},{{0.06`,13.4`,0.93668`,1.1666`},0.2739076696196712`},{{0.06`,13.4`,0.93668`,1.1711`},0.2739076696196712`},{{0.06`,13.4`,0.93668`,1.1621000000000001`},0.2739076696196712`},{{0.06`,14.`,0.94018`,1.1666`},0.2799103040560466`},{{0.06`,14.`,0.94018`,1.1711`},0.2799103040560466`},{{0.06`,14.`,0.94018`,1.1621000000000001`},0.2799103040560466`},{{0.06`,14.`,0.94368`,1.1666`},0.2837643903334031`},{{0.06`,14.`,0.94368`,1.1711`},0.2837643903334031`},{{0.06`,14.`,0.94368`,1.1621000000000001`},0.2837643903334031`},{{0.06`,14.`,0.93668`,1.1666`},0.2760987791545093`},{{0.06`,14.`,0.93668`,1.1711`},0.2760987791545093`},{{0.06`,14.`,0.93668`,1.1621000000000001`},0.2760987791545093`},{{0.06`,14.6`,0.94018`,1.1666`},0.2819697904730012`},{{0.06`,14.6`,0.94018`,1.1711`},0.2819697904730012`},{{0.06`,14.6`,0.94018`,1.1621000000000001`},0.2819697904730012`},{{0.06`,14.6`,0.94368`,1.1666`},0.2858692319095805`},{{0.06`,14.6`,0.94368`,1.1711`},0.2858692319095805`},{{0.06`,14.6`,0.94368`,1.1621000000000001`},0.2858692319095805`},{{0.06`,14.6`,0.93668`,1.1666`},0.2781132847350363`},{{0.06`,14.6`,0.93668`,1.1711`},0.2781132847350363`},{{0.06`,14.6`,0.93668`,1.1621000000000001`},0.2781132847350363`},{{0.06`,15.2`,0.94018`,1.1666`},0.28386579741101203`},{{0.06`,15.2`,0.94018`,1.1711`},0.28386579741101203`},{{0.06`,15.2`,0.94018`,1.1621000000000001`},0.28386579741101203`},{{0.06`,15.2`,0.94368`,1.1666`},0.28780778603946255`},{{0.06`,15.2`,0.94368`,1.1711`},0.28780778603946255`},{{0.06`,15.2`,0.94368`,1.1621000000000001`},0.28780778603946255`},{{0.06`,15.2`,0.93668`,1.1666`},0.279967085514178`},{{0.06`,15.2`,0.93668`,1.1711`},0.279967085514178`},{{0.06`,15.2`,0.93668`,1.1621000000000001`},0.279967085514178`},{{0.06`,15.8`,0.94018`,1.1666`},0.28561398760203566`},{{0.06`,15.8`,0.94018`,1.1711`},0.28561398760203566`},{{0.06`,15.8`,0.94018`,1.1621000000000001`},0.28561398760203566`},{{0.06`,15.8`,0.94368`,1.1666`},0.2895959700853568`},{{0.06`,15.8`,0.94368`,1.1711`},0.2895959700853568`},{{0.06`,15.8`,0.94368`,1.1621000000000001`},0.2895959700853568`},{{0.06`,15.8`,0.93668`,1.1666`},0.2816755925374859`},{{0.06`,15.8`,0.93668`,1.1711`},0.2816755925374859`},{{0.06`,15.8`,0.93668`,1.1621000000000001`},0.2816755925374859`},{{0.06`,16.4`,0.94018`,1.1666`},0.28722759042965995`},{{0.06`,16.4`,0.94018`,1.1711`},0.28722759042965995`},{{0.06`,16.4`,0.94018`,1.1621000000000001`},0.28722759042965995`},{{0.06`,16.4`,0.94368`,1.1666`},0.2912472356993653`},{{0.06`,16.4`,0.94368`,1.1711`},0.2912472356993653`},{{0.06`,16.4`,0.94368`,1.1621000000000001`},0.2912472356993653`},{{0.06`,16.4`,0.93668`,1.1666`},0.2832518158679037`},{{0.06`,16.4`,0.93668`,1.1711`},0.2832518158679037`},{{0.06`,16.4`,0.93668`,1.1621000000000001`},0.2832518158679037`},{{0.06`,17.`,0.94018`,1.1666`},0.28871812951266956`},{{0.06`,17.`,0.94018`,1.1711`},0.28871812951266956`},{{0.06`,17.`,0.94018`,1.1621000000000001`},0.28871812951266956`},{{0.06`,17.`,0.94368`,1.1666`},0.29277330607977664`},{{0.06`,17.`,0.94368`,1.1711`},0.29277330607977664`},{{0.06`,17.`,0.94368`,1.1621000000000001`},0.29277330607977664`},{{0.06`,17.`,0.93668`,1.1666`},0.2847070822711142`},{{0.06`,17.`,0.93668`,1.1711`},0.2847070822711142`},{{0.06`,17.`,0.93668`,1.1621000000000001`},0.2847070822711142`},{{0.06`,17.6`,0.94018`,1.1666`},0.2900963282279362`},{{0.06`,17.6`,0.94018`,1.1711`},0.2900963282279362`},{{0.06`,17.6`,0.94018`,1.1621000000000001`},0.2900963282279362`},{{0.06`,17.6`,0.94368`,1.1666`},0.294185089116085`},{{0.06`,17.6`,0.94368`,1.1711`},0.294185089116085`},{{0.06`,17.6`,0.94368`,1.1621000000000001`},0.294185089116085`},{{0.06`,17.6`,0.93668`,1.1666`},0.28605193270584517`},{{0.06`,17.6`,0.93668`,1.1711`},0.28605193270584517`},{{0.06`,17.6`,0.93668`,1.1621000000000001`},0.28605193270584517`},{{0.06`,18.2`,0.94018`,1.1666`},0.29137210363167143`},{{0.06`,18.2`,0.94018`,1.1711`},0.29137210363167143`},{{0.06`,18.2`,0.94018`,1.1621000000000001`},0.29137210363167143`},{{0.06`,18.2`,0.94368`,1.1666`},0.2954926516774772`},{{0.06`,18.2`,0.94368`,1.1711`},0.2954926516774772`},{{0.06`,18.2`,0.94368`,1.1621000000000001`},0.2954926516774772`},{{0.06`,18.2`,0.93668`,1.1666`},0.2872961361111331`},{{0.06`,18.2`,0.93668`,1.1711`},0.2872961361111331`},{{0.06`,18.2`,0.93668`,1.1621000000000001`},0.2872961361111331`},{{0.06`,18.8`,0.94018`,1.1666`},0.2925533066614089`},{{0.06`,18.8`,0.94018`,1.1711`},0.2925533066614089`},{{0.06`,18.8`,0.94018`,1.1621000000000001`},0.2925533066614089`},{{0.06`,18.8`,0.94368`,1.1666`},0.29670400672982844`},{{0.06`,18.8`,0.94368`,1.1711`},0.29670400672982844`},{{0.06`,18.8`,0.94368`,1.1621000000000001`},0.29670400672982844`},{{0.06`,18.8`,0.93668`,1.1666`},0.28844738514458423`},{{0.06`,18.8`,0.93668`,1.1711`},0.28844738514458423`},{{0.06`,18.8`,0.93668`,1.1621000000000001`},0.28844738514458423`},{{0.06`,19.4`,0.94018`,1.1666`},0.2936474310461406`},{{0.06`,19.4`,0.94018`,1.1711`},0.2936474310461406`},{{0.06`,19.4`,0.94018`,1.1621000000000001`},0.2936474310461406`},{{0.06`,19.4`,0.94368`,1.1666`},0.2978267700900735`},{{0.06`,19.4`,0.94368`,1.1711`},0.2978267700900735`},{{0.06`,19.4`,0.94368`,1.1621000000000001`},0.2978267700900735`},{{0.06`,19.4`,0.93668`,1.1666`},0.28951304957594254`},{{0.06`,19.4`,0.93668`,1.1711`},0.28951304957594254`},{{0.06`,19.4`,0.93668`,1.1621000000000001`},0.28951304957594254`},{{0.06`,20.`,0.94018`,1.1666`},0.2946619443778519`},{{0.06`,20.`,0.94018`,1.1711`},0.2946619443778519`},{{0.06`,20.`,0.94018`,1.1621000000000001`},0.2946619443778519`},{{0.06`,20.`,0.94368`,1.1666`},0.29886853010136916`},{{0.06`,20.`,0.94368`,1.1711`},0.29886853010136916`},{{0.06`,20.`,0.94368`,1.1621000000000001`},0.29886853010136916`},{{0.06`,20.`,0.93668`,1.1666`},0.2905004803035237`},{{0.06`,20.`,0.93668`,1.1711`},0.2905004803035237`},{{0.06`,20.`,0.93668`,1.1621000000000001`},0.2905004803035237`},{{0.06`,20.6`,0.94018`,1.1666`},0.2956030004639324`},{{0.06`,20.6`,0.94018`,1.1711`},0.2956030004639324`},{{0.06`,20.6`,0.94018`,1.1621000000000001`},0.2956030004639324`},{{0.06`,20.6`,0.94368`,1.1666`},0.29983554582058386`},{{0.06`,20.6`,0.94368`,1.1711`},0.29983554582058386`},{{0.06`,20.6`,0.94368`,1.1621000000000001`},0.29983554582058386`},{{0.06`,20.6`,0.93668`,1.1666`},0.2914157268071766`},{{0.06`,20.6`,0.93668`,1.1711`},0.2914157268071766`},{{0.06`,20.6`,0.93668`,1.1621000000000001`},0.2914157268071766`},{{0.06`,21.2`,0.94018`,1.1666`},0.2964757592878506`},{{0.06`,21.2`,0.94018`,1.1711`},0.2964757592878506`},{{0.06`,21.2`,0.94018`,1.1621000000000001`},0.2964757592878506`},{{0.06`,21.2`,0.94368`,1.1666`},0.30073307676141403`},{{0.06`,21.2`,0.94368`,1.1711`},0.30073307676141403`},{{0.06`,21.2`,0.94368`,1.1621000000000001`},0.30073307676141403`},{{0.06`,21.2`,0.93668`,1.1666`},0.2922638507454647`},{{0.06`,21.2`,0.93668`,1.1711`},0.2922638507454647`},{{0.06`,21.2`,0.93668`,1.1621000000000001`},0.2922638507454647`},{{0.06`,21.8`,0.94018`,1.1666`},0.29728588951071677`},{{0.06`,21.8`,0.94018`,1.1711`},0.29728588951071677`},{{0.06`,21.8`,0.94018`,1.1621000000000001`},0.29728588951071677`},{{0.06`,21.8`,0.94368`,1.1666`},0.3015668772608383`},{{0.06`,21.8`,0.94368`,1.1711`},0.3015668772608383`},{{0.06`,21.8`,0.94368`,1.1621000000000001`},0.3015668772608383`},{{0.06`,21.8`,0.93668`,1.1666`},0.29305043397788866`},{{0.06`,21.8`,0.93668`,1.1711`},0.29305043397788866`},{{0.06`,21.8`,0.93668`,1.1621000000000001`},0.29305043397788866`},{{0.06`,22.4`,0.94018`,1.1666`},0.29803790999912905`},{{0.06`,22.4`,0.94018`,1.1711`},0.29803790999912905`},{{0.06`,22.4`,0.94018`,1.1621000000000001`},0.29803790999912905`},{{0.06`,22.4`,0.94368`,1.1666`},0.3023415490903964`},{{0.06`,22.4`,0.94368`,1.1711`},0.3023415490903964`},{{0.06`,22.4`,0.94368`,1.1621000000000001`},0.3023415490903964`},{{0.06`,22.4`,0.93668`,1.1666`},0.29377991917504315`},{{0.06`,22.4`,0.93668`,1.1711`},0.29377991917504315`},{{0.06`,22.4`,0.93668`,1.1621000000000001`},0.29377991917504315`},{{0.06`,23.`,0.94018`,1.1666`},0.29873609048275`},{{0.06`,23.`,0.94018`,1.1711`},0.29873609048275`},{{0.06`,23.`,0.94018`,1.1621000000000001`},0.29873609048275`},{{0.06`,23.`,0.94368`,1.1666`},0.3030614331005909`},{{0.06`,23.`,0.94368`,1.1711`},0.3030614331005909`},{{0.06`,23.`,0.94368`,1.1621000000000001`},0.3030614331005909`},{{0.06`,23.`,0.93668`,1.1666`},0.29445650204296947`},{{0.06`,23.`,0.93668`,1.1711`},0.29445650204296947`},{{0.06`,23.`,0.93668`,1.1621000000000001`},0.29445650204296947`},{{0.06`,23.6`,0.94018`,1.1666`},0.29938433273445236`},{{0.06`,23.6`,0.94018`,1.1711`},0.29938433273445236`},{{0.06`,23.6`,0.94018`,1.1621000000000001`},0.29938433273445236`},{{0.06`,23.6`,0.94368`,1.1666`},0.3037304932143884`},{{0.06`,23.6`,0.94368`,1.1711`},0.3037304932143884`},{{0.06`,23.6`,0.94368`,1.1621000000000001`},0.3037304932143884`},{{0.06`,23.6`,0.93668`,1.1666`},0.2950840191649346`},{{0.06`,23.6`,0.93668`,1.1711`},0.2950840191649346`},{{0.06`,23.6`,0.93668`,1.1621000000000001`},0.2950840191649346`},{{0.06`,24.2`,0.94018`,1.1666`},0.2999850326155428`},{{0.06`,24.2`,0.94018`,1.1711`},0.2999850326155428`},{{0.06`,24.2`,0.94018`,1.1621000000000001`},0.2999850326155428`},{{0.06`,24.2`,0.94368`,1.1666`},0.3043512020011795`},{{0.06`,24.2`,0.94368`,1.1711`},0.3043512020011795`},{{0.06`,24.2`,0.94368`,1.1621000000000001`},0.3043512020011795`},{{0.06`,24.2`,0.93668`,1.1666`},0.29566479537731527`},{{0.06`,24.2`,0.93668`,1.1711`},0.29566479537731527`},{{0.06`,24.2`,0.93668`,1.1621000000000001`},0.29566479537731527`},{{0.06`,24.8`,0.94018`,1.1666`},0.30054280650356874`},{{0.06`,24.8`,0.94018`,1.1711`},0.30054280650356874`},{{0.06`,24.8`,0.94018`,1.1621000000000001`},0.30054280650356874`},{{0.06`,24.8`,0.94368`,1.1666`},0.3049282218257306`},{{0.06`,24.8`,0.94368`,1.1711`},0.3049282218257306`},{{0.06`,24.8`,0.94368`,1.1621000000000001`},0.3049282218257306`},{{0.06`,24.8`,0.93668`,1.1666`},0.2962034030117028`},{{0.06`,24.8`,0.93668`,1.1711`},0.2962034030117028`},{{0.06`,24.8`,0.93668`,1.1621000000000001`},0.2962034030117028`},{{0.06`,25.4`,0.94018`,1.1666`},0.3010601580616832`},{{0.06`,25.4`,0.94018`,1.1711`},0.3010601580616832`},{{0.06`,25.4`,0.94018`,1.1621000000000001`},0.3010601580616832`},{{0.06`,25.4`,0.94368`,1.1666`},0.3054641082091668`},{{0.06`,25.4`,0.94368`,1.1711`},0.3054641082091668`},{{0.06`,25.4`,0.94368`,1.1621000000000001`},0.3054641082091668`},{{0.06`,25.4`,0.93668`,1.1666`},0.29670229066589354`},{{0.06`,25.4`,0.93668`,1.1711`},0.29670229066589354`},{{0.06`,25.4`,0.93668`,1.1621000000000001`},0.29670229066589354`},{{0.06`,26.`,0.94018`,1.1666`},0.3015398059914812`},{{0.06`,26.`,0.94018`,1.1711`},0.3015398059914812`},{{0.06`,26.`,0.94018`,1.1621000000000001`},0.3015398059914812`},{{0.06`,26.`,0.94368`,1.1666`},0.3059616276204419`},{{0.06`,26.`,0.94368`,1.1711`},0.3059616276204419`},{{0.06`,26.`,0.94368`,1.1621000000000001`},0.3059616276204419`},{{0.06`,26.`,0.93668`,1.1666`},0.29716413326373364`},{{0.06`,26.`,0.93668`,1.1711`},0.29716413326373364`},{{0.06`,26.`,0.93668`,1.1621000000000001`},0.29716413326373364`},{{0.06`,26.6`,0.94018`,1.1666`},0.30198423702599975`},{{0.06`,26.6`,0.94018`,1.1711`},0.30198423702599975`},{{0.06`,26.6`,0.94018`,1.1621000000000001`},0.30198423702599975`},{{0.06`,26.6`,0.94368`,1.1666`},0.30642331043013327`},{{0.06`,26.6`,0.94368`,1.1711`},0.30642331043013327`},{{0.06`,26.6`,0.94368`,1.1621000000000001`},0.30642331043013327`},{{0.06`,26.6`,0.93668`,1.1666`},0.2975913685814498`},{{0.06`,26.6`,0.93668`,1.1711`},0.2975913685814498`},{{0.06`,26.6`,0.93668`,1.1621000000000001`},0.2975913685814498`},{{0.06`,27.2`,0.94018`,1.1666`},0.30239475935092464`},{{0.06`,27.2`,0.94018`,1.1711`},0.30239475935092464`},{{0.06`,27.2`,0.94018`,1.1621000000000001`},0.30239475935092464`},{{0.06`,27.2`,0.94368`,1.1666`},0.3068505153751615`},{{0.06`,27.2`,0.94368`,1.1711`},0.3068505153751615`},{{0.06`,27.2`,0.94368`,1.1621000000000001`},0.3068505153751615`},{{0.06`,27.2`,0.93668`,1.1666`},0.29798525863950115`},{{0.06`,27.2`,0.93668`,1.1711`},0.29798525863950115`},{{0.06`,27.2`,0.93668`,1.1621000000000001`},0.29798525863950115`},{{0.06`,27.8`,0.94018`,1.1666`},0.3027746450746855`},{{0.06`,27.8`,0.94018`,1.1711`},0.3027746450746855`},{{0.06`,27.8`,0.94018`,1.1621000000000001`},0.3027746450746855`},{{0.06`,27.8`,0.94368`,1.1666`},0.30724654263629114`},{{0.06`,27.8`,0.94368`,1.1711`},0.30724654263629114`},{{0.06`,27.8`,0.94368`,1.1621000000000001`},0.30724654263629114`},{{0.06`,27.8`,0.93668`,1.1666`},0.2983490465296725`},{{0.06`,27.8`,0.93668`,1.1711`},0.2983490465296725`},{{0.06`,27.8`,0.93668`,1.1621000000000001`},0.2983490465296725`},{{0.06`,28.4`,0.94018`,1.1666`},0.3031255029521011`},{{0.06`,28.4`,0.94018`,1.1711`},0.3031255029521011`},{{0.06`,28.4`,0.94018`,1.1621000000000001`},0.3031255029521011`},{{0.06`,28.4`,0.94368`,1.1666`},0.3076130410660859`},{{0.06`,28.4`,0.94368`,1.1711`},0.3076130410660859`},{{0.06`,28.4`,0.94368`,1.1621000000000001`},0.3076130410660859`},{{0.06`,28.4`,0.93668`,1.1666`},0.29868431102579707`},{{0.06`,28.4`,0.93668`,1.1711`},0.29868431102579707`},{{0.06`,28.4`,0.93668`,1.1621000000000001`},0.29868431102579707`},{{0.06`,29.`,0.94018`,1.1666`},0.3034491350506102`},{{0.06`,29.`,0.94018`,1.1711`},0.3034491350506102`},{{0.06`,29.`,0.94018`,1.1621000000000001`},0.3034491350506102`},{{0.06`,29.`,0.94368`,1.1666`},0.30795183750852884`},{{0.06`,29.`,0.94368`,1.1711`},0.30795183750852884`},{{0.06`,29.`,0.94368`,1.1621000000000001`},0.30795183750852884`},{{0.06`,29.`,0.93668`,1.1666`},0.2989928157039294`},{{0.06`,29.`,0.93668`,1.1711`},0.2989928157039294`},{{0.06`,29.`,0.93668`,1.1621000000000001`},0.2989928157039294`},{{0.06`,29.6`,0.94018`,1.1666`},0.30374669620040917`},{{0.06`,29.6`,0.94018`,1.1711`},0.30374669620040917`},{{0.06`,29.6`,0.94018`,1.1621000000000001`},0.30374669620040917`},{{0.06`,29.6`,0.94368`,1.1666`},0.3082641242576092`},{{0.06`,29.6`,0.94368`,1.1711`},0.3082641242576092`},{{0.06`,29.6`,0.94368`,1.1621000000000001`},0.3082641242576092`},{{0.06`,29.6`,0.93668`,1.1666`},0.2992756841930351`},{{0.06`,29.6`,0.93668`,1.1711`},0.2992756841930351`},{{0.06`,29.6`,0.93668`,1.1621000000000001`},0.2992756841930351`},{{0.06`,30.2`,0.94018`,1.1666`},0.3040201645738227`},{{0.06`,30.2`,0.94018`,1.1711`},0.3040201645738227`},{{0.06`,30.2`,0.94018`,1.1621000000000001`},0.3040201645738227`},{{0.06`,30.2`,0.94368`,1.1666`},0.3085519055319539`},{{0.06`,30.2`,0.94368`,1.1711`},0.3085519055319539`},{{0.06`,30.2`,0.94368`,1.1621000000000001`},0.3085519055319539`},{{0.06`,30.2`,0.93668`,1.1666`},0.29953486834040677`},{{0.06`,30.2`,0.93668`,1.1711`},0.29953486834040677`},{{0.06`,30.2`,0.93668`,1.1621000000000001`},0.29953486834040677`},{{0.06`,30.8`,0.94018`,1.1666`},0.3042708457973903`},{{0.06`,30.8`,0.94018`,1.1711`},0.3042708457973903`},{{0.06`,30.8`,0.94018`,1.1621000000000001`},0.3042708457973903`},{{0.06`,30.8`,0.94368`,1.1666`},0.30881651177169644`},{{0.06`,30.8`,0.94368`,1.1711`},0.30881651177169644`},{{0.06`,30.8`,0.94368`,1.1621000000000001`},0.30881651177169644`},{{0.06`,30.8`,0.93668`,1.1666`},0.29977164939398315`},{{0.06`,30.8`,0.93668`,1.1711`},0.29977164939398315`},{{0.06`,30.8`,0.93668`,1.1621000000000001`},0.29977164939398315`},{{0.06`,31.4`,0.94018`,1.1666`},0.3045000398116167`},{{0.06`,31.4`,0.94018`,1.1711`},0.3045000398116167`},{{0.06`,31.4`,0.94018`,1.1621000000000001`},0.3045000398116167`},{{0.06`,31.4`,0.94368`,1.1666`},0.30905926696429575`},{{0.06`,31.4`,0.94368`,1.1711`},0.30905926696429575`},{{0.06`,31.4`,0.94368`,1.1621000000000001`},0.30905926696429575`},{{0.06`,31.4`,0.93668`,1.1666`},0.2999873041438714`},{{0.06`,31.4`,0.93668`,1.1711`},0.2999873041438714`},{{0.06`,31.4`,0.93668`,1.1621000000000001`},0.2999873041438714`},{{0.06`,32.`,0.94018`,1.1666`},0.3047087267045226`},{{0.06`,32.`,0.94018`,1.1711`},0.3047087267045226`},{{0.06`,32.`,0.94018`,1.1621000000000001`},0.3047087267045226`},{{0.06`,32.`,0.94368`,1.1666`},0.30928117555396845`},{{0.06`,32.`,0.94368`,1.1711`},0.30928117555396845`},{{0.06`,32.`,0.94368`,1.1621000000000001`},0.30928117555396845`},{{0.06`,32.`,0.93668`,1.1666`},0.3001827867445865`},{{0.06`,32.`,0.93668`,1.1711`},0.3001827867445865`},{{0.06`,32.`,0.93668`,1.1621000000000001`},0.3001827867445865`},{{0.06`,32.6`,0.94018`,1.1666`},0.30489814562842166`},{{0.06`,32.6`,0.94018`,1.1711`},0.30489814562842166`},{{0.06`,32.6`,0.94018`,1.1621000000000001`},0.30489814562842166`},{{0.06`,32.6`,0.94368`,1.1666`},0.30948349932894886`},{{0.06`,32.6`,0.94368`,1.1711`},0.30948349932894886`},{{0.06`,32.6`,0.94368`,1.1621000000000001`},0.30948349932894886`},{{0.06`,32.6`,0.93668`,1.1666`},0.3003593156325935`},{{0.06`,32.6`,0.93668`,1.1711`},0.3003593156325935`},{{0.06`,32.6`,0.93668`,1.1621000000000001`},0.3003593156325935`},{{0.06`,33.2`,0.94018`,1.1666`},0.305069328265912`},{{0.06`,33.2`,0.94018`,1.1711`},0.305069328265912`},{{0.06`,33.2`,0.94018`,1.1621000000000001`},0.305069328265912`},{{0.06`,33.2`,0.94368`,1.1666`},0.3096672881699785`},{{0.06`,33.2`,0.94368`,1.1711`},0.3096672881699785`},{{0.06`,33.2`,0.94368`,1.1621000000000001`},0.3096672881699785`},{{0.06`,33.2`,0.93668`,1.1666`},0.30051790390153915`},{{0.06`,33.2`,0.93668`,1.1711`},0.30051790390153915`},{{0.06`,33.2`,0.93668`,1.1621000000000001`},0.30051790390153915`},{{0.06`,33.8`,0.94018`,1.1666`},0.30522322557385645`},{{0.06`,33.8`,0.94018`,1.1711`},0.30522322557385645`},{{0.06`,33.8`,0.94018`,1.1621000000000001`},0.30522322557385645`},{{0.06`,33.8`,0.94368`,1.1666`},0.3098335117291546`},{{0.06`,33.8`,0.94368`,1.1711`},0.3098335117291546`},{{0.06`,33.8`,0.94368`,1.1621000000000001`},0.3098335117291546`},{{0.06`,33.8`,0.93668`,1.1666`},0.30065948397721093`},{{0.06`,33.8`,0.93668`,1.1711`},0.30065948397721093`},{{0.06`,33.8`,0.93668`,1.1621000000000001`},0.30065948397721093`},{{0.06`,34.4`,0.94018`,1.1666`},0.3053607216970633`},{{0.06`,34.4`,0.94018`,1.1711`},0.3053607216970633`},{{0.06`,34.4`,0.94018`,1.1621000000000001`},0.3053607216970633`},{{0.06`,34.4`,0.94368`,1.1666`},0.30998307168910266`},{{0.06`,34.4`,0.94368`,1.1711`},0.30998307168910266`},{{0.06`,34.4`,0.94368`,1.1621000000000001`},0.30998307168910266`},{{0.06`,34.4`,0.93668`,1.1666`},0.3007849226145519`},{{0.06`,34.4`,0.93668`,1.1711`},0.3007849226145519`},{{0.06`,34.4`,0.93668`,1.1621000000000001`},0.3007849226145519`},{{0.06`,35.`,0.94018`,1.1666`},0.3054826652239282`},{{0.06`,35.`,0.94018`,1.1711`},0.3054826652239282`},{{0.06`,35.`,0.94018`,1.1621000000000001`},0.3054826652239282`},{{0.06`,35.`,0.94368`,1.1666`},0.31011683346498053`},{{0.06`,35.`,0.94368`,1.1711`},0.31011683346498053`},{{0.06`,35.`,0.94368`,1.1621000000000001`},0.31011683346498053`},{{0.06`,35.`,0.93668`,1.1666`},0.30089505166242697`},{{0.06`,35.`,0.93668`,1.1711`},0.30089505166242697`},{{0.06`,35.`,0.93668`,1.1621000000000001`},0.30089505166242697`},{{0.06`,35.6`,0.94018`,1.1666`},0.305589171658156`},{{0.06`,35.6`,0.94018`,1.1711`},0.305589171658156`},{{0.06`,35.6`,0.94018`,1.1621000000000001`},0.305589171658156`},{{0.06`,35.6`,0.94368`,1.1666`},0.3102349359813147`},{{0.06`,35.6`,0.94368`,1.1711`},0.3102349359813147`},{{0.06`,35.6`,0.94368`,1.1621000000000001`},0.3102349359813147`},{{0.06`,35.6`,0.93668`,1.1666`},0.3009899638832762`},{{0.06`,35.6`,0.93668`,1.1711`},0.3009899638832762`},{{0.06`,35.6`,0.93668`,1.1621000000000001`},0.3009899638832762`},{{0.06`,36.2`,0.94018`,1.1666`},0.30568180496629593`},{{0.06`,36.2`,0.94018`,1.1711`},0.30568180496629593`},{{0.06`,36.2`,0.94018`,1.1621000000000001`},0.30568180496629593`},{{0.06`,36.2`,0.94368`,1.1666`},0.3103389480076067`},{{0.06`,36.2`,0.94368`,1.1711`},0.3103389480076067`},{{0.06`,36.2`,0.94368`,1.1621000000000001`},0.3103389480076067`},{{0.06`,36.2`,0.93668`,1.1666`},0.3010712177652944`},{{0.06`,36.2`,0.93668`,1.1711`},0.3010712177652944`},{{0.06`,36.2`,0.93668`,1.1621000000000001`},0.3010712177652944`},{{0.06`,36.8`,0.94018`,1.1666`},0.3057608946536457`},{{0.06`,36.8`,0.94018`,1.1711`},0.3057608946536457`},{{0.06`,36.8`,0.94018`,1.1621000000000001`},0.3057608946536457`},{{0.06`,36.8`,0.94368`,1.1666`},0.3104292167309118`},{{0.06`,36.8`,0.94368`,1.1711`},0.3104292167309118`},{{0.06`,36.8`,0.94368`,1.1621000000000001`},0.3104292167309118`},{{0.06`,36.8`,0.93668`,1.1666`},0.3011391255360438`},{{0.06`,36.8`,0.93668`,1.1711`},0.3011391255360438`},{{0.06`,36.8`,0.93668`,1.1621000000000001`},0.3011391255360438`},{{0.06`,37.4`,0.94018`,1.1666`},0.30582704384323944`},{{0.06`,37.4`,0.94018`,1.1711`},0.30582704384323944`},{{0.06`,37.4`,0.94018`,1.1621000000000001`},0.30582704384323944`},{{0.06`,37.4`,0.94368`,1.1666`},0.3105063587024837`},{{0.06`,37.4`,0.94368`,1.1711`},0.3105063587024837`},{{0.06`,37.4`,0.94368`,1.1621000000000001`},0.3105063587024837`},{{0.06`,37.4`,0.93668`,1.1666`},0.3011942769748005`},{{0.06`,37.4`,0.93668`,1.1711`},0.3011942769748005`},{{0.06`,37.4`,0.93668`,1.1621000000000001`},0.3011942769748005`},{{0.06`,38.`,0.94018`,1.1666`},0.3058808129945153`},{{0.06`,38.`,0.94018`,1.1711`},0.3058808129945153`},{{0.06`,38.`,0.94018`,1.1621000000000001`},0.3058808129945153`},{{0.06`,38.`,0.94368`,1.1666`},0.3105709471314728`},{{0.06`,38.`,0.94368`,1.1711`},0.3105709471314728`},{{0.06`,38.`,0.94368`,1.1621000000000001`},0.3105709471314728`},{{0.06`,38.`,0.93668`,1.1666`},0.3012372198647624`},{{0.06`,38.`,0.93668`,1.1711`},0.3012372198647624`},{{0.06`,38.`,0.93668`,1.1621000000000001`},0.3012372198647624`},{{0.06`,38.6`,0.94018`,1.1666`},0.3059227227995501`},{{0.06`,38.6`,0.94018`,1.1711`},0.3059227227995501`},{{0.06`,38.6`,0.94018`,1.1621000000000001`},0.3059227227995501`},{{0.06`,38.6`,0.94368`,1.1666`},0.31062351483635703`},{{0.06`,38.6`,0.94368`,1.1711`},0.31062351483635703`},{{0.06`,38.6`,0.94368`,1.1621000000000001`},0.31062351483635703`},{{0.06`,38.6`,0.93668`,1.1666`},0.3012684628350505`},{{0.06`,38.6`,0.93668`,1.1711`},0.3012684628350505`},{{0.06`,38.6`,0.93668`,1.1621000000000001`},0.3012684628350505`},{{0.06`,39.2`,0.94018`,1.1666`},0.3059532567958778`},{{0.06`,39.2`,0.94018`,1.1711`},0.3059532567958778`},{{0.06`,39.2`,0.94018`,1.1621000000000001`},0.3059532567958778`},{{0.06`,39.2`,0.94368`,1.1666`},0.31066455690925715`},{{0.06`,39.2`,0.94368`,1.1711`},0.31066455690925715`},{{0.06`,39.2`,0.94368`,1.1621000000000001`},0.31066455690925715`},{{0.06`,39.2`,0.93668`,1.1666`},0.3012884779229364`},{{0.06`,39.2`,0.93668`,1.1711`},0.3012884779229364`},{{0.06`,39.2`,0.93668`,1.1621000000000001`},0.3012884779229364`},{{0.06`,39.8`,0.94018`,1.1666`},0.305972863720914`},{{0.06`,39.8`,0.94018`,1.1711`},0.305972863720914`},{{0.06`,39.8`,0.94018`,1.1621000000000001`},0.305972863720914`},{{0.06`,39.8`,0.94368`,1.1666`},0.31069453311859624`},{{0.06`,39.8`,0.94368`,1.1711`},0.31069453311859624`},{{0.06`,39.8`,0.94368`,1.1621000000000001`},0.31069453311859624`},{{0.06`,39.8`,0.93668`,1.1666`},0.30129770288086033`},{{0.06`,39.8`,0.93668`,1.1711`},0.30129770288086033`},{{0.06`,39.8`,0.93668`,1.1621000000000001`},0.30129770288086033`},{{0.09`,0.4`,0.94018`,1.1666`},0.10960297678344463`},{{0.09`,0.4`,0.94018`,1.1711`},0.10960297678344463`},{{0.09`,0.4`,0.94018`,1.1621000000000001`},0.10960297678344463`},{{0.09`,0.4`,0.94368`,1.1666`},0.10992184392076235`},{{0.09`,0.4`,0.94368`,1.1711`},0.10992184392076235`},{{0.09`,0.4`,0.94368`,1.1621000000000001`},0.10992184392076235`},{{0.09`,0.4`,0.93668`,1.1666`},0.10928772808004546`},{{0.09`,0.4`,0.93668`,1.1711`},0.10928772808004546`},{{0.09`,0.4`,0.93668`,1.1621000000000001`},0.10928772808004546`},{{0.09`,0.6`,0.94018`,1.1666`},0.11856305971170926`},{{0.09`,0.6`,0.94018`,1.1711`},0.11856305971170926`},{{0.09`,0.6`,0.94018`,1.1621000000000001`},0.11856305971170926`},{{0.09`,0.6`,0.94368`,1.1666`},0.11902907601476355`},{{0.09`,0.6`,0.94368`,1.1711`},0.11902907601476355`},{{0.09`,0.6`,0.94368`,1.1621000000000001`},0.11902907601476355`},{{0.09`,0.6`,0.93668`,1.1666`},0.11810234841292781`},{{0.09`,0.6`,0.93668`,1.1711`},0.11810234841292781`},{{0.09`,0.6`,0.93668`,1.1621000000000001`},0.11810234841292781`},{{0.09`,0.8`,0.94018`,1.1666`},0.12701769409894628`},{{0.09`,0.8`,0.94018`,1.1711`},0.12701769409894628`},{{0.09`,0.8`,0.94018`,1.1621000000000001`},0.12701769409894628`},{{0.09`,0.8`,0.94368`,1.1666`},0.12762338857387695`},{{0.09`,0.8`,0.94368`,1.1711`},0.12762338857387695`},{{0.09`,0.8`,0.94368`,1.1621000000000001`},0.12762338857387695`},{{0.09`,0.8`,0.93668`,1.1666`},0.1264189144423771`},{{0.09`,0.8`,0.93668`,1.1711`},0.1264189144423771`},{{0.09`,0.8`,0.93668`,1.1621000000000001`},0.1264189144423771`},{{0.09`,1.`,0.94018`,1.1666`},0.13500374518009164`},{{0.09`,1.`,0.94018`,1.1711`},0.13500374518009164`},{{0.09`,1.`,0.94018`,1.1621000000000001`},0.13500374518009164`},{{0.09`,1.`,0.94368`,1.1666`},0.13574213358946094`},{{0.09`,1.`,0.94368`,1.1711`},0.13574213358946094`},{{0.09`,1.`,0.94368`,1.1621000000000001`},0.13574213358946094`},{{0.09`,1.`,0.93668`,1.1666`},0.13427380829379074`},{{0.09`,1.`,0.93668`,1.1711`},0.13427380829379074`},{{0.09`,1.`,0.93668`,1.1621000000000001`},0.13427380829379074`},{{0.09`,1.2`,0.94018`,1.1666`},0.1425547692812327`},{{0.09`,1.2`,0.94018`,1.1711`},0.1425547692812327`},{{0.09`,1.2`,0.94018`,1.1621000000000001`},0.1425547692812327`},{{0.09`,1.2`,0.94368`,1.1666`},0.14341931665906138`},{{0.09`,1.2`,0.94368`,1.1711`},0.14341931665906138`},{{0.09`,1.2`,0.94368`,1.1621000000000001`},0.14341931665906138`},{{0.09`,1.2`,0.93668`,1.1666`},0.1417001405556245`},{{0.09`,1.2`,0.93668`,1.1711`},0.1417001405556245`},{{0.09`,1.2`,0.93668`,1.1621000000000001`},0.1417001405556245`},{{0.09`,1.4`,0.94018`,1.1666`},0.14970136469446818`},{{0.09`,1.4`,0.94018`,1.1711`},0.14970136469446818`},{{0.09`,1.4`,0.94018`,1.1621000000000001`},0.14970136469446818`},{{0.09`,1.4`,0.94368`,1.1666`},0.15068595106655813`},{{0.09`,1.4`,0.94368`,1.1711`},0.15068595106655813`},{{0.09`,1.4`,0.94368`,1.1621000000000001`},0.15068595106655813`},{{0.09`,1.4`,0.93668`,1.1666`},0.14872809793542002`},{{0.09`,1.4`,0.93668`,1.1711`},0.14872809793542002`},{{0.09`,1.4`,0.93668`,1.1621000000000001`},0.14872809793542002`},{{0.09`,1.6`,0.94018`,1.1666`},0.156471479905895`},{{0.09`,1.6`,0.94018`,1.1711`},0.156471479905895`},{{0.09`,1.6`,0.94018`,1.1621000000000001`},0.156471479905895`},{{0.09`,1.6`,0.94368`,1.1666`},0.157570368933472`},{{0.09`,1.6`,0.94368`,1.1711`},0.157570368933472`},{{0.09`,1.6`,0.94368`,1.1621000000000001`},0.157570368933472`},{{0.09`,1.6`,0.93668`,1.1666`},0.15538524855591693`},{{0.09`,1.6`,0.93668`,1.1711`},0.15538524855591693`},{{0.09`,1.6`,0.93668`,1.1621000000000001`},0.15538524855591693`},{{0.09`,1.8`,0.94018`,1.1666`},0.16289068498387999`},{{0.09`,1.8`,0.94018`,1.1711`},0.16289068498387999`},{{0.09`,1.8`,0.94018`,1.1621000000000001`},0.16289068498387999`},{{0.09`,1.8`,0.94368`,1.1666`},0.1640984952702181`},{{0.09`,1.8`,0.94368`,1.1711`},0.1640984952702181`},{{0.09`,1.8`,0.94368`,1.1621000000000001`},0.1640984952702181`},{{0.09`,1.8`,0.93668`,1.1666`},0.161696810675619`},{{0.09`,1.8`,0.93668`,1.1711`},0.161696810675619`},{{0.09`,1.8`,0.93668`,1.1621000000000001`},0.161696810675619`},{{0.09`,2.`,0.94018`,1.1666`},0.1689824110646018`},{{0.09`,2.`,0.94018`,1.1711`},0.1689824110646018`},{{0.09`,2.`,0.94018`,1.1621000000000001`},0.1689824110646018`},{{0.09`,2.`,0.94368`,1.1666`},0.1702940898855685`},{{0.09`,2.`,0.94368`,1.1711`},0.1702940898855685`},{{0.09`,2.`,0.94368`,1.1621000000000001`},0.1702940898855685`},{{0.09`,2.`,0.93668`,1.1666`},0.16768588974861143`},{{0.09`,2.`,0.93668`,1.1711`},0.16768588974861143`},{{0.09`,2.`,0.93668`,1.1621000000000001`},0.16768588974861143`},{{0.09`,2.2`,0.94018`,1.1666`},0.17476816214307453`},{{0.09`,2.2`,0.94018`,1.1711`},0.17476816214307453`},{{0.09`,2.2`,0.94018`,1.1621000000000001`},0.17476816214307453`},{{0.09`,2.2`,0.94368`,1.1666`},0.17617896138295885`},{{0.09`,2.2`,0.94368`,1.1711`},0.17617896138295885`},{{0.09`,2.2`,0.94368`,1.1621000000000001`},0.17617896138295885`},{{0.09`,2.2`,0.93668`,1.1666`},0.17337368801070263`},{{0.09`,2.2`,0.93668`,1.1711`},0.17337368801070263`},{{0.09`,2.2`,0.93668`,1.1621000000000001`},0.17337368801070263`},{{0.09`,2.6`,0.94018`,1.1666`},0.18549737020209248`},{{0.09`,2.6`,0.94018`,1.1711`},0.18549737020209248`},{{0.09`,2.6`,0.94018`,1.1621000000000001`},0.18549737020209248`},{{0.09`,2.6`,0.94368`,1.1666`},0.18709327523891975`},{{0.09`,2.6`,0.94368`,1.1711`},0.18709327523891975`},{{0.09`,2.6`,0.94368`,1.1621000000000001`},0.18709327523891975`},{{0.09`,2.6`,0.93668`,1.1666`},0.18391997499291096`},{{0.09`,2.6`,0.93668`,1.1711`},0.18391997499291096`},{{0.09`,2.6`,0.93668`,1.1621000000000001`},0.18391997499291096`},{{0.09`,3.`,0.94018`,1.1666`},0.1952195194086689`},{{0.09`,3.`,0.94018`,1.1711`},0.1952195194086689`},{{0.09`,3.`,0.94018`,1.1621000000000001`},0.1952195194086689`},{{0.09`,3.`,0.94368`,1.1666`},0.19698468648125464`},{{0.09`,3.`,0.94368`,1.1711`},0.19698468648125464`},{{0.09`,3.`,0.94368`,1.1621000000000001`},0.19698468648125464`},{{0.09`,3.`,0.93668`,1.1666`},0.19347486218664373`},{{0.09`,3.`,0.93668`,1.1711`},0.19347486218664373`},{{0.09`,3.`,0.93668`,1.1621000000000001`},0.19347486218664373`},{{0.09`,3.4`,0.94018`,1.1666`},0.20405438615690713`},{{0.09`,3.4`,0.94018`,1.1711`},0.20405438615690713`},{{0.09`,3.4`,0.94018`,1.1621000000000001`},0.20405438615690713`},{{0.09`,3.4`,0.94368`,1.1666`},0.20597471886675184`},{{0.09`,3.4`,0.94368`,1.1711`},0.20597471886675184`},{{0.09`,3.4`,0.94368`,1.1621000000000001`},0.20597471886675184`},{{0.09`,3.4`,0.93668`,1.1666`},0.20215639660037918`},{{0.09`,3.4`,0.93668`,1.1711`},0.20215639660037918`},{{0.09`,3.4`,0.93668`,1.1621000000000001`},0.20215639660037918`},{{0.09`,3.8`,0.94018`,1.1666`},0.21210408347292034`},{{0.09`,3.8`,0.94018`,1.1711`},0.21210408347292034`},{{0.09`,3.8`,0.94018`,1.1621000000000001`},0.21210408347292034`},{{0.09`,3.8`,0.94368`,1.1666`},0.2141670071767111`},{{0.09`,3.8`,0.94368`,1.1711`},0.2141670071767111`},{{0.09`,3.8`,0.94368`,1.1621000000000001`},0.2141670071767111`},{{0.09`,3.8`,0.93668`,1.1666`},0.21006518568302643`},{{0.09`,3.8`,0.93668`,1.1711`},0.21006518568302643`},{{0.09`,3.8`,0.93668`,1.1621000000000001`},0.21006518568302643`},{{0.09`,4.2`,0.94018`,1.1666`},0.21945649462780503`},{{0.09`,4.2`,0.94018`,1.1711`},0.21945649462780503`},{{0.09`,4.2`,0.94018`,1.1621000000000001`},0.21945649462780503`},{{0.09`,4.2`,0.94368`,1.1666`},0.22165076008328174`},{{0.09`,4.2`,0.94368`,1.1711`},0.22165076008328174`},{{0.09`,4.2`,0.94368`,1.1621000000000001`},0.22165076008328174`},{{0.09`,4.2`,0.93668`,1.1666`},0.21728780178206286`},{{0.09`,4.2`,0.93668`,1.1711`},0.21728780178206286`},{{0.09`,4.2`,0.93668`,1.1621000000000001`},0.21728780178206286`},{{0.09`,4.6`,0.94018`,1.1666`},0.2261881163147168`},{{0.09`,4.6`,0.94018`,1.1711`},0.2261881163147168`},{{0.09`,4.6`,0.94018`,1.1621000000000001`},0.2261881163147168`},{{0.09`,4.6`,0.94368`,1.1666`},0.22850363313506852`},{{0.09`,4.6`,0.94368`,1.1711`},0.22850363313506852`},{{0.09`,4.6`,0.94368`,1.1621000000000001`},0.22850363313506852`},{{0.09`,4.6`,0.93668`,1.1666`},0.2238995955036291`},{{0.09`,4.6`,0.93668`,1.1711`},0.2238995955036291`},{{0.09`,4.6`,0.93668`,1.1621000000000001`},0.2238995955036291`},{{0.09`,5.`,0.94018`,1.1666`},0.23236477868569708`},{{0.09`,5.`,0.94018`,1.1711`},0.23236477868569708`},{{0.09`,5.`,0.94018`,1.1621000000000001`},0.23236477868569708`},{{0.09`,5.`,0.94368`,1.1666`},0.23479246230570394`},{{0.09`,5.`,0.94368`,1.1711`},0.23479246230570394`},{{0.09`,5.`,0.94368`,1.1621000000000001`},0.23479246230570394`},{{0.09`,5.`,0.93668`,1.1666`},0.2299654028829034`},{{0.09`,5.`,0.93668`,1.1711`},0.2299654028829034`},{{0.09`,5.`,0.93668`,1.1621000000000001`},0.2299654028829034`},{{0.09`,5.4`,0.94018`,1.1666`},0.2380433704782906`},{{0.09`,5.4`,0.94018`,1.1711`},0.2380433704782906`},{{0.09`,5.4`,0.94018`,1.1621000000000001`},0.2380433704782906`},{{0.09`,5.4`,0.94368`,1.1666`},0.24057503326206744`},{{0.09`,5.4`,0.94368`,1.1711`},0.24057503326206744`},{{0.09`,5.4`,0.94368`,1.1621000000000001`},0.24057503326206744`},{{0.09`,5.4`,0.93668`,1.1666`},0.2355412261233927`},{{0.09`,5.4`,0.93668`,1.1711`},0.2355412261233927`},{{0.09`,5.4`,0.93668`,1.1621000000000001`},0.2355412261233927`},{{0.09`,5.8`,0.94018`,1.1666`},0.24327410138041522`},{{0.09`,5.8`,0.94018`,1.1711`},0.24327410138041522`},{{0.09`,5.8`,0.94018`,1.1621000000000001`},0.24327410138041522`},{{0.09`,5.8`,0.94368`,1.1666`},0.24590234132336447`},{{0.09`,5.8`,0.94368`,1.1711`},0.24590234132336447`},{{0.09`,5.8`,0.94368`,1.1621000000000001`},0.24590234132336447`},{{0.09`,5.8`,0.93668`,1.1666`},0.24067649855434362`},{{0.09`,5.8`,0.93668`,1.1711`},0.24067649855434362`},{{0.09`,5.8`,0.93668`,1.1621000000000001`},0.24067649855434362`},{{0.09`,6.2`,0.94018`,1.1666`},0.24810102791362265`},{{0.09`,6.2`,0.94018`,1.1711`},0.24810102791362265`},{{0.09`,6.2`,0.94018`,1.1621000000000001`},0.24810102791362265`},{{0.09`,6.2`,0.94368`,1.1666`},0.25081913761779373`},{{0.09`,6.2`,0.94368`,1.1711`},0.25081913761779373`},{{0.09`,6.2`,0.94368`,1.1621000000000001`},0.25081913761779373`},{{0.09`,6.2`,0.93668`,1.1666`},0.24541459039860422`},{{0.09`,6.2`,0.93668`,1.1711`},0.24541459039860422`},{{0.09`,6.2`,0.93668`,1.1621000000000001`},0.24541459039860422`},{{0.09`,6.8`,0.94018`,1.1666`},0.25466755736442`},{{0.09`,6.8`,0.94018`,1.1711`},0.25466755736442`},{{0.09`,6.8`,0.94018`,1.1621000000000001`},0.25466755736442`},{{0.09`,6.8`,0.94368`,1.1666`},0.25750922214076066`},{{0.09`,6.8`,0.94368`,1.1711`},0.25750922214076066`},{{0.09`,6.8`,0.94368`,1.1621000000000001`},0.25750922214076066`},{{0.09`,6.8`,0.93668`,1.1666`},0.25185897673497937`},{{0.09`,6.8`,0.93668`,1.1711`},0.25185897673497937`},{{0.09`,6.8`,0.93668`,1.1621000000000001`},0.25185897673497937`},{{0.09`,7.4`,0.94018`,1.1666`},0.26052374423655295`},{{0.09`,7.4`,0.94018`,1.1711`},0.26052374423655295`},{{0.09`,7.4`,0.94018`,1.1621000000000001`},0.26052374423655295`},{{0.09`,7.4`,0.94368`,1.1666`},0.26347704211399386`},{{0.09`,7.4`,0.94368`,1.1711`},0.26347704211399386`},{{0.09`,7.4`,0.94368`,1.1621000000000001`},0.26347704211399386`},{{0.09`,7.4`,0.93668`,1.1666`},0.2576047930339748`},{{0.09`,7.4`,0.93668`,1.1711`},0.2576047930339748`},{{0.09`,7.4`,0.93668`,1.1621000000000001`},0.2576047930339748`},{{0.09`,8.`,0.94018`,1.1666`},0.2657634460334539`},{{0.09`,8.`,0.94018`,1.1711`},0.2657634460334539`},{{0.09`,8.`,0.94018`,1.1621000000000001`},0.2657634460334539`},{{0.09`,8.`,0.94368`,1.1666`},0.26881796919058465`},{{0.09`,8.`,0.94368`,1.1711`},0.26881796919058465`},{{0.09`,8.`,0.94368`,1.1621000000000001`},0.26881796919058465`},{{0.09`,8.`,0.93668`,1.1666`},0.26274440143485495`},{{0.09`,8.`,0.93668`,1.1711`},0.26274440143485495`},{{0.09`,8.`,0.93668`,1.1621000000000001`},0.26274440143485495`},{{0.09`,8.6`,0.94018`,1.1666`},0.2704660747767997`},{{0.09`,8.6`,0.94018`,1.1711`},0.2704660747767997`},{{0.09`,8.6`,0.94018`,1.1621000000000001`},0.2704660747767997`},{{0.09`,8.6`,0.94368`,1.1666`},0.27361269973634816`},{{0.09`,8.6`,0.94368`,1.1711`},0.27361269973634816`},{{0.09`,8.6`,0.94368`,1.1621000000000001`},0.27361269973634816`},{{0.09`,8.6`,0.93668`,1.1666`},0.2673559456750326`},{{0.09`,8.6`,0.93668`,1.1711`},0.2673559456750326`},{{0.09`,8.6`,0.93668`,1.1621000000000001`},0.2673559456750326`},{{0.09`,9.2`,0.94018`,1.1666`},0.2746982823369521`},{{0.09`,9.2`,0.94018`,1.1711`},0.2746982823369521`},{{0.09`,9.2`,0.94018`,1.1621000000000001`},0.2746982823369521`},{{0.09`,9.2`,0.94368`,1.1666`},0.27792897937706124`},{{0.09`,9.2`,0.94368`,1.1711`},0.27792897937706124`},{{0.09`,9.2`,0.94368`,1.1621000000000001`},0.27792897937706124`},{{0.09`,9.2`,0.93668`,1.1666`},0.27150499770171393`},{{0.09`,9.2`,0.93668`,1.1711`},0.27150499770171393`},{{0.09`,9.2`,0.93668`,1.1621000000000001`},0.27150499770171393`},{{0.09`,9.8`,0.94018`,1.1666`},0.27851708092722377`},{{0.09`,9.8`,0.94018`,1.1711`},0.27851708092722377`},{{0.09`,9.8`,0.94018`,1.1621000000000001`},0.27851708092722377`},{{0.09`,9.8`,0.94368`,1.1666`},0.28182475454216005`},{{0.09`,9.8`,0.94368`,1.1711`},0.28182475454216005`},{{0.09`,9.8`,0.94368`,1.1621000000000001`},0.28182475454216005`},{{0.09`,9.8`,0.93668`,1.1666`},0.275247647387186`},{{0.09`,9.8`,0.93668`,1.1711`},0.275247647387186`},{{0.09`,9.8`,0.93668`,1.1621000000000001`},0.275247647387186`},{{0.09`,10.4`,0.94018`,1.1666`},0.28197057434454553`},{{0.09`,10.4`,0.94018`,1.1711`},0.28197057434454553`},{{0.09`,10.4`,0.94018`,1.1621000000000001`},0.28197057434454553`},{{0.09`,10.4`,0.94368`,1.1666`},0.28534893090687835`},{{0.09`,10.4`,0.94368`,1.1711`},0.28534893090687835`},{{0.09`,10.4`,0.94368`,1.1621000000000001`},0.28534893090687835`},{{0.09`,10.4`,0.93668`,1.1666`},0.27863120702420247`},{{0.09`,10.4`,0.93668`,1.1711`},0.27863120702420247`},{{0.09`,10.4`,0.93668`,1.1621000000000001`},0.27863120702420247`},{{0.09`,11.`,0.94018`,1.1666`},0.28510093107538104`},{{0.09`,11.`,0.94018`,1.1711`},0.28510093107538104`},{{0.09`,11.`,0.94018`,1.1621000000000001`},0.28510093107538104`},{{0.09`,11.`,0.94368`,1.1666`},0.28854437349126516`},{{0.09`,11.`,0.94368`,1.1711`},0.28854437349126516`},{{0.09`,11.`,0.94368`,1.1621000000000001`},0.28854437349126516`},{{0.09`,11.`,0.93668`,1.1666`},0.2816971573669125`},{{0.09`,11.`,0.93668`,1.1711`},0.2816971573669125`},{{0.09`,11.`,0.93668`,1.1621000000000001`},0.2816971573669125`},{{0.09`,11.6`,0.94018`,1.1666`},0.28794409228497103`},{{0.09`,11.6`,0.94018`,1.1711`},0.28794409228497103`},{{0.09`,11.6`,0.94018`,1.1621000000000001`},0.28794409228497103`},{{0.09`,11.6`,0.94368`,1.1666`},0.291447622208462`},{{0.09`,11.6`,0.94368`,1.1711`},0.291447622208462`},{{0.09`,11.6`,0.94368`,1.1621000000000001`},0.291447622208462`},{{0.09`,11.6`,0.93668`,1.1666`},0.284480848623411`},{{0.09`,11.6`,0.93668`,1.1711`},0.284480848623411`},{{0.09`,11.6`,0.93668`,1.1621000000000001`},0.284480848623411`},{{0.09`,12.2`,0.94018`,1.1666`},0.29053045177112363`},{{0.09`,12.2`,0.94018`,1.1711`},0.29053045177112363`},{{0.09`,12.2`,0.94018`,1.1621000000000001`},0.29053045177112363`},{{0.09`,12.2`,0.94368`,1.1666`},0.29408959652235656`},{{0.09`,12.2`,0.94368`,1.1711`},0.29408959652235656`},{{0.09`,12.2`,0.94368`,1.1621000000000001`},0.29408959652235656`},{{0.09`,12.2`,0.93668`,1.1666`},0.28701215577887884`},{{0.09`,12.2`,0.93668`,1.1711`},0.28701215577887884`},{{0.09`,12.2`,0.93668`,1.1621000000000001`},0.28701215577887884`},{{0.09`,12.8`,0.94018`,1.1666`},0.29288795467936884`},{{0.09`,12.8`,0.94018`,1.1711`},0.29288795467936884`},{{0.09`,12.8`,0.94018`,1.1621000000000001`},0.29288795467936884`},{{0.09`,12.8`,0.94368`,1.1666`},0.2964986995545735`},{{0.09`,12.8`,0.94368`,1.1711`},0.2964986995545735`},{{0.09`,12.8`,0.94368`,1.1621000000000001`},0.2964986995545735`},{{0.09`,12.8`,0.93668`,1.1666`},0.2893185720799492`},{{0.09`,12.8`,0.93668`,1.1711`},0.2893185720799492`},{{0.09`,12.8`,0.93668`,1.1621000000000001`},0.2893185720799492`},{{0.09`,13.4`,0.94018`,1.1666`},0.2950398256244316`},{{0.09`,13.4`,0.94018`,1.1711`},0.2950398256244316`},{{0.09`,13.4`,0.94018`,1.1621000000000001`},0.2950398256244316`},{{0.09`,13.4`,0.94368`,1.1666`},0.2986985514307359`},{{0.09`,13.4`,0.94368`,1.1711`},0.2986985514307359`},{{0.09`,13.4`,0.94368`,1.1621000000000001`},0.2986985514307359`},{{0.09`,13.4`,0.93668`,1.1666`},0.2914229308528722`},{{0.09`,13.4`,0.93668`,1.1711`},0.2914229308528722`},{{0.09`,13.4`,0.93668`,1.1621000000000001`},0.2914229308528722`},{{0.09`,14.`,0.94018`,1.1666`},0.29700718256004655`},{{0.09`,14.`,0.94018`,1.1711`},0.29700718256004655`},{{0.09`,14.`,0.94018`,1.1621000000000001`},0.29700718256004655`},{{0.09`,14.`,0.94368`,1.1666`},0.3007106254774957`},{{0.09`,14.`,0.94368`,1.1711`},0.3007106254774957`},{{0.09`,14.`,0.94368`,1.1621000000000001`},0.3007106254774957`},{{0.09`,14.`,0.93668`,1.1666`},0.29334599960332647`},{{0.09`,14.`,0.93668`,1.1711`},0.29334599960332647`},{{0.09`,14.`,0.93668`,1.1621000000000001`},0.29334599960332647`},{{0.09`,14.6`,0.94018`,1.1666`},0.2988083222166718`},{{0.09`,14.6`,0.94018`,1.1711`},0.2988083222166718`},{{0.09`,14.6`,0.94018`,1.1621000000000001`},0.2988083222166718`},{{0.09`,14.6`,0.94368`,1.1666`},0.3025535270064574`},{{0.09`,14.6`,0.94368`,1.1711`},0.3025535270064574`},{{0.09`,14.6`,0.94368`,1.1621000000000001`},0.3025535270064574`},{{0.09`,14.6`,0.93668`,1.1666`},0.29510577197896104`},{{0.09`,14.6`,0.93668`,1.1711`},0.29510577197896104`},{{0.09`,14.6`,0.93668`,1.1621000000000001`},0.29510577197896104`},{{0.09`,15.2`,0.94018`,1.1666`},0.3004586327741707`},{{0.09`,15.2`,0.94018`,1.1711`},0.3004586327741707`},{{0.09`,15.2`,0.94018`,1.1621000000000001`},0.3004586327741707`},{{0.09`,15.2`,0.94368`,1.1666`},0.30424291665239717`},{{0.09`,15.2`,0.94368`,1.1711`},0.30424291665239717`},{{0.09`,15.2`,0.94368`,1.1621000000000001`},0.30424291665239717`},{{0.09`,15.2`,0.93668`,1.1666`},0.2967173658479354`},{{0.09`,15.2`,0.93668`,1.1711`},0.2967173658479354`},{{0.09`,15.2`,0.93668`,1.1621000000000001`},0.2967173658479354`},{{0.09`,15.8`,0.94018`,1.1666`},0.30197298887272833`},{{0.09`,15.8`,0.94018`,1.1711`},0.30197298887272833`},{{0.09`,15.8`,0.94018`,1.1621000000000001`},0.30197298887272833`},{{0.09`,15.8`,0.94368`,1.1666`},0.3057939162408353`},{{0.09`,15.8`,0.94368`,1.1711`},0.3057939162408353`},{{0.09`,15.8`,0.94368`,1.1621000000000001`},0.3057939162408353`},{{0.09`,15.8`,0.93668`,1.1666`},0.2981954107876127`},{{0.09`,15.8`,0.93668`,1.1711`},0.2981954107876127`},{{0.09`,15.8`,0.93668`,1.1621000000000001`},0.2981954107876127`},{{0.09`,16.4`,0.94018`,1.1666`},0.30336392769156395`},{{0.09`,16.4`,0.94018`,1.1711`},0.30336392769156395`},{{0.09`,16.4`,0.94018`,1.1621000000000001`},0.30336392769156395`},{{0.09`,16.4`,0.94368`,1.1666`},0.3072192762247601`},{{0.09`,16.4`,0.94368`,1.1711`},0.3072192762247601`},{{0.09`,16.4`,0.94368`,1.1621000000000001`},0.3072192762247601`},{{0.09`,16.4`,0.93668`,1.1666`},0.2995522336968212`},{{0.09`,16.4`,0.93668`,1.1711`},0.2995522336968212`},{{0.09`,16.4`,0.93668`,1.1621000000000001`},0.2995522336968212`},{{0.09`,17.`,0.94018`,1.1666`},0.30464234326612777`},{{0.09`,17.`,0.94018`,1.1711`},0.30464234326612777`},{{0.09`,17.`,0.94018`,1.1621000000000001`},0.30464234326612777`},{{0.09`,17.`,0.94368`,1.1666`},0.3085300844215944`},{{0.09`,17.`,0.94368`,1.1711`},0.3085300844215944`},{{0.09`,17.`,0.94368`,1.1621000000000001`},0.3085300844215944`},{{0.09`,17.`,0.93668`,1.1666`},0.3007985415750548`},{{0.09`,17.`,0.93668`,1.1711`},0.3007985415750548`},{{0.09`,17.`,0.93668`,1.1621000000000001`},0.3007985415750548`},{{0.09`,17.6`,0.94018`,1.1666`},0.3058183522235976`},{{0.09`,17.6`,0.94018`,1.1711`},0.3058183522235976`},{{0.09`,17.6`,0.94018`,1.1621000000000001`},0.3058183522235976`},{{0.09`,17.6`,0.94368`,1.1666`},0.3097366326654922`},{{0.09`,17.6`,0.94368`,1.1711`},0.3097366326654922`},{{0.09`,17.6`,0.94368`,1.1621000000000001`},0.3097366326654922`},{{0.09`,17.6`,0.93668`,1.1666`},0.30194427308978655`},{{0.09`,17.6`,0.93668`,1.1711`},0.30194427308978655`},{{0.09`,17.6`,0.93668`,1.1621000000000001`},0.30194427308978655`},{{0.09`,18.2`,0.94018`,1.1666`},0.30690133869714364`},{{0.09`,18.2`,0.94018`,1.1711`},0.30690133869714364`},{{0.09`,18.2`,0.94018`,1.1621000000000001`},0.30690133869714364`},{{0.09`,18.2`,0.94368`,1.1666`},0.3108484499626874`},{{0.09`,18.2`,0.94368`,1.1711`},0.3108484499626874`},{{0.09`,18.2`,0.94368`,1.1621000000000001`},0.3108484499626874`},{{0.09`,18.2`,0.93668`,1.1666`},0.3029986712101495`},{{0.09`,18.2`,0.93668`,1.1711`},0.3029986712101495`},{{0.09`,18.2`,0.93668`,1.1621000000000001`},0.3029986712101495`},{{0.09`,18.8`,0.94018`,1.1666`},0.3078986210706209`},{{0.09`,18.8`,0.94018`,1.1711`},0.3078986210706209`},{{0.09`,18.8`,0.94018`,1.1621000000000001`},0.3078986210706209`},{{0.09`,18.8`,0.94368`,1.1666`},0.31187300810955165`},{{0.09`,18.8`,0.94368`,1.1711`},0.31187300810955165`},{{0.09`,18.8`,0.94368`,1.1621000000000001`},0.31187300810955165`},{{0.09`,18.8`,0.93668`,1.1666`},0.30396890135997845`},{{0.09`,18.8`,0.93668`,1.1711`},0.30396890135997845`},{{0.09`,18.8`,0.93668`,1.1621000000000001`},0.30396890135997845`},{{0.09`,19.4`,0.94018`,1.1666`},0.3088172468480245`},{{0.09`,19.4`,0.94018`,1.1711`},0.3088172468480245`},{{0.09`,19.4`,0.94018`,1.1621000000000001`},0.3088172468480245`},{{0.09`,19.4`,0.94368`,1.1666`},0.3128174742721618`},{{0.09`,19.4`,0.94368`,1.1711`},0.3128174742721618`},{{0.09`,19.4`,0.94368`,1.1621000000000001`},0.3128174742721618`},{{0.09`,19.4`,0.93668`,1.1666`},0.3048618950886023`},{{0.09`,19.4`,0.93668`,1.1711`},0.3048618950886023`},{{0.09`,19.4`,0.93668`,1.1621000000000001`},0.3048618950886023`},{{0.09`,20.`,0.94018`,1.1666`},0.30966421008055944`},{{0.09`,20.`,0.94018`,1.1711`},0.30966421008055944`},{{0.09`,20.`,0.94018`,1.1621000000000001`},0.30966421008055944`},{{0.09`,20.`,0.94368`,1.1666`},0.3136889560187526`},{{0.09`,20.`,0.94368`,1.1711`},0.3136889560187526`},{{0.09`,20.`,0.94368`,1.1621000000000001`},0.3136889560187526`},{{0.09`,20.`,0.93668`,1.1666`},0.3056845332391517`},{{0.09`,20.`,0.93668`,1.1711`},0.3056845332391517`},{{0.09`,20.`,0.93668`,1.1621000000000001`},0.3056845332391517`},{{0.09`,20.6`,0.94018`,1.1666`},0.3104452629073078`},{{0.09`,20.6`,0.94018`,1.1711`},0.3104452629073078`},{{0.09`,20.6`,0.94018`,1.1621000000000001`},0.3104452629073078`},{{0.09`,20.6`,0.94368`,1.1666`},0.3144933061758913`},{{0.09`,20.6`,0.94368`,1.1711`},0.3144933061758913`},{{0.09`,20.6`,0.94368`,1.1621000000000001`},0.3144933061758913`},{{0.09`,20.6`,0.93668`,1.1666`},0.3064424686261007`},{{0.09`,20.6`,0.93668`,1.1711`},0.3064424686261007`},{{0.09`,20.6`,0.93668`,1.1621000000000001`},0.3064424686261007`},{{0.09`,21.2`,0.94018`,1.1666`},0.3111652154156907`},{{0.09`,21.2`,0.94018`,1.1711`},0.3111652154156907`},{{0.09`,21.2`,0.94018`,1.1621000000000001`},0.3111652154156907`},{{0.09`,21.2`,0.94368`,1.1666`},0.3152354290941364`},{{0.09`,21.2`,0.94368`,1.1711`},0.3152354290941364`},{{0.09`,21.2`,0.94368`,1.1621000000000001`},0.3152354290941364`},{{0.09`,21.2`,0.93668`,1.1666`},0.30714041841187506`},{{0.09`,21.2`,0.93668`,1.1711`},0.30714041841187506`},{{0.09`,21.2`,0.93668`,1.1621000000000001`},0.30714041841187506`},{{0.09`,21.8`,0.94018`,1.1666`},0.3118293460714935`},{{0.09`,21.8`,0.94018`,1.1711`},0.3118293460714935`},{{0.09`,21.8`,0.94018`,1.1621000000000001`},0.3118293460714935`},{{0.09`,21.8`,0.94368`,1.1666`},0.3159206865367675`},{{0.09`,21.8`,0.94368`,1.1711`},0.3159206865367675`},{{0.09`,21.8`,0.94368`,1.1621000000000001`},0.3159206865367675`},{{0.09`,21.8`,0.93668`,1.1666`},0.30778357851532123`},{{0.09`,21.8`,0.93668`,1.1711`},0.30778357851532123`},{{0.09`,21.8`,0.93668`,1.1621000000000001`},0.30778357851532123`},{{0.09`,22.4`,0.94018`,1.1666`},0.31244185695774057`},{{0.09`,22.4`,0.94018`,1.1711`},0.31244185695774057`},{{0.09`,22.4`,0.94018`,1.1621000000000001`},0.31244185695774057`},{{0.09`,22.4`,0.94368`,1.1666`},0.316553356308663`},{{0.09`,22.4`,0.94368`,1.1711`},0.316553356308663`},{{0.09`,22.4`,0.94368`,1.1621000000000001`},0.316553356308663`},{{0.09`,22.4`,0.93668`,1.1666`},0.3083760763102593`},{{0.09`,22.4`,0.93668`,1.1711`},0.3083760763102593`},{{0.09`,22.4`,0.93668`,1.1621000000000001`},0.3083760763102593`},{{0.09`,23.`,0.94018`,1.1666`},0.3130067071446107`},{{0.09`,23.`,0.94018`,1.1711`},0.3130067071446107`},{{0.09`,23.`,0.94018`,1.1621000000000001`},0.3130067071446107`},{{0.09`,23.`,0.94368`,1.1666`},0.31713746658782493`},{{0.09`,23.`,0.94368`,1.1711`},0.31713746658782493`},{{0.09`,23.`,0.94368`,1.1621000000000001`},0.31713746658782493`},{{0.09`,23.`,0.93668`,1.1666`},0.30892180258398844`},{{0.09`,23.`,0.93668`,1.1711`},0.30892180258398844`},{{0.09`,23.`,0.93668`,1.1621000000000001`},0.30892180258398844`},{{0.09`,23.6`,0.94018`,1.1666`},0.3135275104124136`},{{0.09`,23.6`,0.94018`,1.1711`},0.3135275104124136`},{{0.09`,23.6`,0.94018`,1.1621000000000001`},0.3135275104124136`},{{0.09`,23.6`,0.94368`,1.1666`},0.3176766939947801`},{{0.09`,23.6`,0.94368`,1.1711`},0.3176766939947801`},{{0.09`,23.6`,0.94368`,1.1621000000000001`},0.3176766939947801`},{{0.09`,23.6`,0.93668`,1.1666`},0.30942430901962215`},{{0.09`,23.6`,0.93668`,1.1711`},0.30942430901962215`},{{0.09`,23.6`,0.93668`,1.1621000000000001`},0.30942430901962215`},{{0.09`,24.2`,0.94018`,1.1666`},0.31400646946119337`},{{0.09`,24.2`,0.94018`,1.1711`},0.31400646946119337`},{{0.09`,24.2`,0.94018`,1.1621000000000001`},0.31400646946119337`},{{0.09`,24.2`,0.94368`,1.1666`},0.318173306862637`},{{0.09`,24.2`,0.94368`,1.1711`},0.318173306862637`},{{0.09`,24.2`,0.94368`,1.1621000000000001`},0.318173306862637`},{{0.09`,24.2`,0.93668`,1.1666`},0.30988573392011337`},{{0.09`,24.2`,0.93668`,1.1711`},0.30988573392011337`},{{0.09`,24.2`,0.93668`,1.1621000000000001`},0.30988573392011337`},{{0.09`,24.8`,0.94018`,1.1666`},0.3144478563160599`},{{0.09`,24.8`,0.94018`,1.1711`},0.3144478563160599`},{{0.09`,24.8`,0.94018`,1.1621000000000001`},0.3144478563160599`},{{0.09`,24.8`,0.94368`,1.1666`},0.3186316235496593`},{{0.09`,24.8`,0.94368`,1.1711`},0.3186316235496593`},{{0.09`,24.8`,0.94368`,1.1621000000000001`},0.3186316235496593`},{{0.09`,24.8`,0.93668`,1.1666`},0.31031030282197053`},{{0.09`,24.8`,0.93668`,1.1711`},0.31031030282197053`},{{0.09`,24.8`,0.93668`,1.1621000000000001`},0.31031030282197053`},{{0.09`,25.4`,0.94018`,1.1666`},0.3148539721664951`},{{0.09`,25.4`,0.94018`,1.1711`},0.3148539721664951`},{{0.09`,25.4`,0.94018`,1.1621000000000001`},0.3148539721664951`},{{0.09`,25.4`,0.94368`,1.1666`},0.3190539951223748`},{{0.09`,25.4`,0.94368`,1.1711`},0.3190539951223748`},{{0.09`,25.4`,0.94368`,1.1621000000000001`},0.3190539951223748`},{{0.09`,25.4`,0.93668`,1.1666`},0.31070026789346494`},{{0.09`,25.4`,0.93668`,1.1711`},0.31070026789346494`},{{0.09`,25.4`,0.93668`,1.1621000000000001`},0.31070026789346494`},{{0.09`,26.`,0.94018`,1.1666`},0.315227317605043`},{{0.09`,26.`,0.94018`,1.1711`},0.315227317605043`},{{0.09`,26.`,0.94018`,1.1621000000000001`},0.315227317605043`},{{0.09`,26.`,0.94368`,1.1666`},0.3194429666484308`},{{0.09`,26.`,0.94368`,1.1711`},0.3194429666484308`},{{0.09`,26.`,0.94368`,1.1621000000000001`},0.3194429666484308`},{{0.09`,26.`,0.93668`,1.1666`},0.3110580857617003`},{{0.09`,26.`,0.93668`,1.1711`},0.3110580857617003`},{{0.09`,26.`,0.93668`,1.1621000000000001`},0.3110580857617003`},{{0.09`,26.6`,0.94018`,1.1666`},0.315570173511427`},{{0.09`,26.6`,0.94018`,1.1711`},0.315570173511427`},{{0.09`,26.6`,0.94018`,1.1621000000000001`},0.315570173511427`},{{0.09`,26.6`,0.94368`,1.1666`},0.31980086020486204`},{{0.09`,26.6`,0.94368`,1.1711`},0.31980086020486204`},{{0.09`,26.6`,0.94368`,1.1621000000000001`},0.31980086020486204`},{{0.09`,26.6`,0.93668`,1.1666`},0.311385996572924`},{{0.09`,26.6`,0.93668`,1.1711`},0.311385996572924`},{{0.09`,26.6`,0.93668`,1.1621000000000001`},0.311385996572924`},{{0.09`,27.2`,0.94018`,1.1666`},0.31588373096158306`},{{0.09`,27.2`,0.94018`,1.1711`},0.31588373096158306`},{{0.09`,27.2`,0.94018`,1.1621000000000001`},0.31588373096158306`},{{0.09`,27.2`,0.94368`,1.1666`},0.32012891211848465`},{{0.09`,27.2`,0.94368`,1.1711`},0.32012891211848465`},{{0.09`,27.2`,0.94368`,1.1621000000000001`},0.32012891211848465`},{{0.09`,27.2`,0.93668`,1.1666`},0.3116851471573309`},{{0.09`,27.2`,0.93668`,1.1711`},0.3116851471573309`},{{0.09`,27.2`,0.93668`,1.1621000000000001`},0.3116851471573309`},{{0.09`,27.8`,0.94018`,1.1666`},0.31617098615572337`},{{0.09`,27.8`,0.94018`,1.1711`},0.31617098615572337`},{{0.09`,27.8`,0.94018`,1.1621000000000001`},0.31617098615572337`},{{0.09`,27.8`,0.94368`,1.1666`},0.32043014802921244`},{{0.09`,27.8`,0.94368`,1.1711`},0.32043014802921244`},{{0.09`,27.8`,0.94368`,1.1621000000000001`},0.32043014802921244`},{{0.09`,27.8`,0.93668`,1.1666`},0.3119585038212131`},{{0.09`,27.8`,0.93668`,1.1711`},0.3119585038212131`},{{0.09`,27.8`,0.93668`,1.1621000000000001`},0.3119585038212131`},{{0.09`,28.4`,0.94018`,1.1666`},0.31643341613130077`},{{0.09`,28.4`,0.94018`,1.1711`},0.31643341613130077`},{{0.09`,28.4`,0.94018`,1.1621000000000001`},0.31643341613130077`},{{0.09`,28.4`,0.94368`,1.1666`},0.3207060771311291`},{{0.09`,28.4`,0.94368`,1.1711`},0.3207060771311291`},{{0.09`,28.4`,0.94368`,1.1621000000000001`},0.3207060771311291`},{{0.09`,28.4`,0.93668`,1.1666`},0.31220751211694103`},{{0.09`,28.4`,0.93668`,1.1711`},0.31220751211694103`},{{0.09`,28.4`,0.93668`,1.1621000000000001`},0.31220751211694103`},{{0.09`,29.`,0.94018`,1.1666`},0.31667265842937603`},{{0.09`,29.`,0.94018`,1.1711`},0.31667265842937603`},{{0.09`,29.`,0.94018`,1.1621000000000001`},0.31667265842937603`},{{0.09`,29.`,0.94368`,1.1666`},0.3209583666644237`},{{0.09`,29.`,0.94368`,1.1711`},0.3209583666644237`},{{0.09`,29.`,0.94368`,1.1621000000000001`},0.3209583666644237`},{{0.09`,29.`,0.93668`,1.1666`},0.3124337802083767`},{{0.09`,29.`,0.93668`,1.1711`},0.3124337802083767`},{{0.09`,29.`,0.93668`,1.1621000000000001`},0.3124337802083767`},{{0.09`,29.6`,0.94018`,1.1666`},0.31688977059992673`},{{0.09`,29.6`,0.94018`,1.1711`},0.31688977059992673`},{{0.09`,29.6`,0.94018`,1.1621000000000001`},0.31688977059992673`},{{0.09`,29.6`,0.94368`,1.1666`},0.32118810510878465`},{{0.09`,29.6`,0.94368`,1.1711`},0.32118810510878465`},{{0.09`,29.6`,0.94368`,1.1621000000000001`},0.32118810510878465`},{{0.09`,29.6`,0.93668`,1.1666`},0.3126383353685665`},{{0.09`,29.6`,0.93668`,1.1711`},0.3126383353685665`},{{0.09`,29.6`,0.93668`,1.1621000000000001`},0.3126383353685665`},{{0.09`,30.2`,0.94018`,1.1666`},0.3170865406078907`},{{0.09`,30.2`,0.94018`,1.1711`},0.3170865406078907`},{{0.09`,30.2`,0.94018`,1.1621000000000001`},0.3170865406078907`},{{0.09`,30.2`,0.94368`,1.1666`},0.3213971060675782`},{{0.09`,30.2`,0.94368`,1.1711`},0.3213971060675782`},{{0.09`,30.2`,0.94368`,1.1621000000000001`},0.3213971060675782`},{{0.09`,30.2`,0.93668`,1.1666`},0.31282293973344333`},{{0.09`,30.2`,0.93668`,1.1711`},0.31282293973344333`},{{0.09`,30.2`,0.93668`,1.1621000000000001`},0.31282293973344333`},{{0.09`,30.8`,0.94018`,1.1666`},0.31726416067129687`},{{0.09`,30.8`,0.94018`,1.1711`},0.31726416067129687`},{{0.09`,30.8`,0.94018`,1.1621000000000001`},0.31726416067129687`},{{0.09`,30.8`,0.94368`,1.1666`},0.3215865843984097`},{{0.09`,30.8`,0.94368`,1.1711`},0.3215865843984097`},{{0.09`,30.8`,0.94368`,1.1621000000000001`},0.3215865843984097`},{{0.09`,30.8`,0.93668`,1.1666`},0.31298876329980085`},{{0.09`,30.8`,0.93668`,1.1711`},0.31298876329980085`},{{0.09`,30.8`,0.93668`,1.1621000000000001`},0.31298876329980085`},{{0.09`,31.4`,0.94018`,1.1666`},0.31742381011064824`},{{0.09`,31.4`,0.94018`,1.1711`},0.31742381011064824`},{{0.09`,31.4`,0.94018`,1.1621000000000001`},0.31742381011064824`},{{0.09`,31.4`,0.94368`,1.1666`},0.32175774168213644`},{{0.09`,31.4`,0.94368`,1.1711`},0.32175774168213644`},{{0.09`,31.4`,0.94368`,1.1621000000000001`},0.32175774168213644`},{{0.09`,31.4`,0.93668`,1.1666`},0.31313696335954605`},{{0.09`,31.4`,0.93668`,1.1711`},0.31313696335954605`},{{0.09`,31.4`,0.93668`,1.1621000000000001`},0.31313696335954605`},{{0.09`,32.`,0.94018`,1.1666`},0.3175663822906444`},{{0.09`,32.`,0.94018`,1.1711`},0.3175663822906444`},{{0.09`,32.`,0.94018`,1.1621000000000001`},0.3175663822906444`},{{0.09`,32.`,0.94368`,1.1666`},0.321911493054597`},{{0.09`,32.`,0.94368`,1.1711`},0.321911493054597`},{{0.09`,32.`,0.94368`,1.1621000000000001`},0.321911493054597`},{{0.09`,32.`,0.93668`,1.1666`},0.31326841192449284`},{{0.09`,32.`,0.93668`,1.1711`},0.31326841192449284`},{{0.09`,32.`,0.93668`,1.1621000000000001`},0.31326841192449284`},{{0.09`,32.6`,0.94018`,1.1666`},0.31769298915853045`},{{0.09`,32.6`,0.94018`,1.1711`},0.31769298915853045`},{{0.09`,32.6`,0.94018`,1.1621000000000001`},0.31769298915853045`},{{0.09`,32.6`,0.94368`,1.1666`},0.32204897180830877`},{{0.09`,32.6`,0.94368`,1.1711`},0.32204897180830877`},{{0.09`,32.6`,0.94368`,1.1621000000000001`},0.32204897180830877`},{{0.09`,32.6`,0.93668`,1.1666`},0.31338419955279573`},{{0.09`,32.6`,0.93668`,1.1711`},0.31338419955279573`},{{0.09`,32.6`,0.93668`,1.1621000000000001`},0.31338419955279573`},{{0.09`,33.2`,0.94018`,1.1666`},0.31780456821223485`},{{0.09`,33.2`,0.94018`,1.1711`},0.31780456821223485`},{{0.09`,33.2`,0.94018`,1.1621000000000001`},0.31780456821223485`},{{0.09`,33.2`,0.94368`,1.1666`},0.32217113205541936`},{{0.09`,33.2`,0.94368`,1.1711`},0.32217113205541936`},{{0.09`,33.2`,0.94368`,1.1621000000000001`},0.32217113205541936`},{{0.09`,33.2`,0.93668`,1.1666`},0.3134852473924043`},{{0.09`,33.2`,0.93668`,1.1711`},0.3134852473924043`},{{0.09`,33.2`,0.93668`,1.1621000000000001`},0.3134852473924043`},{{0.09`,33.8`,0.94018`,1.1666`},0.31790197891312244`},{{0.09`,33.8`,0.94018`,1.1711`},0.31790197891312244`},{{0.09`,33.8`,0.94018`,1.1621000000000001`},0.31790197891312244`},{{0.09`,33.8`,0.94368`,1.1666`},0.3222788456528941`},{{0.09`,33.8`,0.94368`,1.1711`},0.3222788456528941`},{{0.09`,33.8`,0.94368`,1.1621000000000001`},0.3222788456528941`},{{0.09`,33.8`,0.93668`,1.1666`},0.3135723979912557`},{{0.09`,33.8`,0.93668`,1.1711`},0.3135723979912557`},{{0.09`,33.8`,0.93668`,1.1621000000000001`},0.3135723979912557`},{{0.09`,34.4`,0.94018`,1.1666`},0.3179860199183351`},{{0.09`,34.4`,0.94018`,1.1711`},0.3179860199183351`},{{0.09`,34.4`,0.94018`,1.1621000000000001`},0.3179860199183351`},{{0.09`,34.4`,0.94368`,1.1666`},0.3223729355862436`},{{0.09`,34.4`,0.94368`,1.1711`},0.3223729355862436`},{{0.09`,34.4`,0.94368`,1.1621000000000001`},0.3223729355862436`},{{0.09`,34.4`,0.93668`,1.1666`},0.31364643418579613`},{{0.09`,34.4`,0.93668`,1.1711`},0.31364643418579613`},{{0.09`,34.4`,0.93668`,1.1621000000000001`},0.31364643418579613`},{{0.09`,35.`,0.94018`,1.1666`},0.3180574530100797`},{{0.09`,35.`,0.94018`,1.1711`},0.3180574530100797`},{{0.09`,35.`,0.94018`,1.1621000000000001`},0.3180574530100797`},{{0.09`,35.`,0.94368`,1.1666`},0.32245417515170544`},{{0.09`,35.`,0.94368`,1.1711`},0.32245417515170544`},{{0.09`,35.`,0.94368`,1.1621000000000001`},0.32245417515170544`},{{0.09`,35.`,0.93668`,1.1666`},0.31370810252658016`},{{0.09`,35.`,0.93668`,1.1711`},0.31370810252658016`},{{0.09`,35.`,0.93668`,1.1621000000000001`},0.31370810252658016`},{{0.09`,35.6`,0.94018`,1.1666`},0.3181164059632247`},{{0.09`,35.6`,0.94018`,1.1711`},0.3181164059632247`},{{0.09`,35.6`,0.94018`,1.1621000000000001`},0.3181164059632247`},{{0.09`,35.6`,0.94368`,1.1666`},0.3225227112713745`},{{0.09`,35.6`,0.94368`,1.1711`},0.3225227112713745`},{{0.09`,35.6`,0.94368`,1.1621000000000001`},0.3225227112713745`},{{0.09`,35.6`,0.93668`,1.1666`},0.3137575122243586`},{{0.09`,35.6`,0.93668`,1.1711`},0.3137575122243586`},{{0.09`,35.6`,0.93668`,1.1621000000000001`},0.3137575122243586`},{{0.09`,36.2`,0.94018`,1.1666`},0.31816426087957994`},{{0.09`,36.2`,0.94018`,1.1711`},0.31816426087957994`},{{0.09`,36.2`,0.94018`,1.1621000000000001`},0.31816426087957994`},{{0.09`,36.2`,0.94368`,1.1666`},0.32257993300875865`},{{0.09`,36.2`,0.94368`,1.1711`},0.32257993300875865`},{{0.09`,36.2`,0.94368`,1.1621000000000001`},0.32257993300875865`},{{0.09`,36.2`,0.93668`,1.1666`},0.3137960378714053`},{{0.09`,36.2`,0.93668`,1.1711`},0.3137960378714053`},{{0.09`,36.2`,0.93668`,1.1621000000000001`},0.3137960378714053`},{{0.09`,36.8`,0.94018`,1.1666`},0.3182013270322266`},{{0.09`,36.8`,0.94018`,1.1711`},0.3182013270322266`},{{0.09`,36.8`,0.94018`,1.1621000000000001`},0.3182013270322266`},{{0.09`,36.8`,0.94368`,1.1666`},0.32262616443779235`},{{0.09`,36.8`,0.94368`,1.1711`},0.32262616443779235`},{{0.09`,36.8`,0.94368`,1.1621000000000001`},0.32262616443779235`},{{0.09`,36.8`,0.93668`,1.1666`},0.31382397429440195`},{{0.09`,36.8`,0.93668`,1.1711`},0.31382397429440195`},{{0.09`,36.8`,0.93668`,1.1621000000000001`},0.31382397429440195`},{{0.09`,37.4`,0.94018`,1.1666`},0.3182281496076193`},{{0.09`,37.4`,0.94018`,1.1711`},0.3182281496076193`},{{0.09`,37.4`,0.94018`,1.1621000000000001`},0.3182281496076193`},{{0.09`,37.4`,0.94368`,1.1666`},0.3226619626727235`},{{0.09`,37.4`,0.94368`,1.1711`},0.3226619626727235`},{{0.09`,37.4`,0.94368`,1.1621000000000001`},0.3226619626727235`},{{0.09`,37.4`,0.93668`,1.1666`},0.3138418548408373`},{{0.09`,37.4`,0.93668`,1.1711`},0.3138418548408373`},{{0.09`,37.4`,0.93668`,1.1621000000000001`},0.3138418548408373`},{{0.09`,38.`,0.94018`,1.1666`},0.31824523577104047`},{{0.09`,38.`,0.94018`,1.1711`},0.31824523577104047`},{{0.09`,38.`,0.94018`,1.1621000000000001`},0.31824523577104047`},{{0.09`,38.`,0.94368`,1.1666`},0.3226878461439076`},{{0.09`,38.`,0.94368`,1.1711`},0.3226878461439076`},{{0.09`,38.`,0.94368`,1.1621000000000001`},0.3226878461439076`},{{0.09`,38.`,0.93668`,1.1666`},0.3138501754908981`},{{0.09`,38.`,0.93668`,1.1711`},0.3138501754908981`},{{0.09`,38.`,0.93668`,1.1621000000000001`},0.3138501754908981`},{{0.09`,38.6`,0.94018`,1.1666`},0.31825305741120286`},{{0.09`,38.6`,0.94018`,1.1711`},0.31825305741120286`},{{0.09`,38.6`,0.94018`,1.1621000000000001`},0.31825305741120286`},{{0.09`,38.6`,0.94368`,1.1666`},0.32270429739336576`},{{0.09`,38.6`,0.94368`,1.1711`},0.32270429739336576`},{{0.09`,38.6`,0.94368`,1.1621000000000001`},0.32270429739336576`},{{0.09`,38.6`,0.93668`,1.1666`},0.31384939755181035`},{{0.09`,38.6`,0.93668`,1.1711`},0.31384939755181035`},{{0.09`,38.6`,0.93668`,1.1621000000000001`},0.31384939755181035`},{{0.09`,39.2`,0.94018`,1.1666`},0.31825205362379555`},{{0.09`,39.2`,0.94018`,1.1711`},0.31825205362379555`},{{0.09`,39.2`,0.94018`,1.1621000000000001`},0.31825205362379555`},{{0.09`,39.2`,0.94368`,1.1666`},0.3227117656055344`},{{0.09`,39.2`,0.94368`,1.1711`},0.3227117656055344`},{{0.09`,39.2`,0.94368`,1.1621000000000001`},0.3227117656055344`},{{0.09`,39.2`,0.93668`,1.1666`},0.31383995009482824`},{{0.09`,39.2`,0.93668`,1.1711`},0.31383995009482824`},{{0.09`,39.2`,0.93668`,1.1621000000000001`},0.31383995009482824`},{{0.09`,39.8`,0.94018`,1.1666`},0.3182426329581923`},{{0.09`,39.8`,0.94018`,1.1711`},0.3182426329581923`},{{0.09`,39.8`,0.94018`,1.1621000000000001`},0.3182426329581923`},{{0.09`,39.8`,0.94368`,1.1666`},0.32271066889782696`},{{0.09`,39.8`,0.94368`,1.1711`},0.32271066889782696`},{{0.09`,39.8`,0.94368`,1.1621000000000001`},0.32271066889782696`},{{0.09`,39.8`,0.93668`,1.1666`},0.3138222321586766`},{{0.09`,39.8`,0.93668`,1.1711`},0.3138222321586766`},{{0.09`,39.8`,0.93668`,1.1621000000000001`},0.3138222321586766`},{{0.12`,0.4`,0.94018`,1.1666`},0.13889146125541374`},{{0.12`,0.4`,0.94018`,1.1711`},0.13889146125541374`},{{0.12`,0.4`,0.94018`,1.1621000000000001`},0.13889146125541374`},{{0.12`,0.4`,0.94368`,1.1666`},0.13920402822950706`},{{0.12`,0.4`,0.94368`,1.1711`},0.13920402822950706`},{{0.12`,0.4`,0.94368`,1.1621000000000001`},0.13920402822950706`},{{0.12`,0.4`,0.93668`,1.1666`},0.13858248843537585`},{{0.12`,0.4`,0.93668`,1.1711`},0.13858248843537585`},{{0.12`,0.4`,0.93668`,1.1621000000000001`},0.13858248843537585`},{{0.12`,0.6`,0.94018`,1.1666`},0.1475041219824198`},{{0.12`,0.6`,0.94018`,1.1711`},0.1475041219824198`},{{0.12`,0.6`,0.94018`,1.1621000000000001`},0.1475041219824198`},{{0.12`,0.6`,0.94368`,1.1666`},0.14796067322470793`},{{0.12`,0.6`,0.94368`,1.1711`},0.14796067322470793`},{{0.12`,0.6`,0.94368`,1.1621000000000001`},0.14796067322470793`},{{0.12`,0.6`,0.93668`,1.1666`},0.14705283823521684`},{{0.12`,0.6`,0.93668`,1.1711`},0.14705283823521684`},{{0.12`,0.6`,0.93668`,1.1621000000000001`},0.14705283823521684`},{{0.12`,0.8`,0.94018`,1.1666`},0.15561722152903898`},{{0.12`,0.8`,0.94018`,1.1711`},0.15561722152903898`},{{0.12`,0.8`,0.94018`,1.1621000000000001`},0.15561722152903898`},{{0.12`,0.8`,0.94368`,1.1666`},0.1562102897017411`},{{0.12`,0.8`,0.94368`,1.1711`},0.1562102897017411`},{{0.12`,0.8`,0.94368`,1.1621000000000001`},0.1562102897017411`},{{0.12`,0.8`,0.93668`,1.1666`},0.1550310169424877`},{{0.12`,0.8`,0.93668`,1.1711`},0.1550310169424877`},{{0.12`,0.8`,0.93668`,1.1621000000000001`},0.1550310169424877`},{{0.12`,1.`,0.94018`,1.1666`},0.16326779064700245`},{{0.12`,1.`,0.94018`,1.1711`},0.16326779064700245`},{{0.12`,1.`,0.94018`,1.1621000000000001`},0.16326779064700245`},{{0.12`,1.`,0.94368`,1.1666`},0.16399040341785667`},{{0.12`,1.`,0.94368`,1.1711`},0.16399040341785667`},{{0.12`,1.`,0.94368`,1.1621000000000001`},0.16399040341785667`},{{0.12`,1.`,0.93668`,1.1666`},0.16255356409755847`},{{0.12`,1.`,0.93668`,1.1711`},0.16255356409755847`},{{0.12`,1.`,0.93668`,1.1621000000000001`},0.16255356409755847`},{{0.12`,1.2`,0.94018`,1.1666`},0.17048949832297133`},{{0.12`,1.2`,0.94018`,1.1711`},0.17048949832297133`},{{0.12`,1.2`,0.94018`,1.1621000000000001`},0.17048949832297133`},{{0.12`,1.2`,0.94368`,1.1666`},0.17133513960463004`},{{0.12`,1.2`,0.94368`,1.1711`},0.17133513960463004`},{{0.12`,1.2`,0.94368`,1.1621000000000001`},0.17133513960463004`},{{0.12`,1.2`,0.93668`,1.1666`},0.16965369610435915`},{{0.12`,1.2`,0.93668`,1.1711`},0.16965369610435915`},{{0.12`,1.2`,0.93668`,1.1621000000000001`},0.16965369610435915`},{{0.12`,1.4`,0.94018`,1.1666`},0.1773130114270879`},{{0.12`,1.4`,0.94018`,1.1711`},0.1773130114270879`},{{0.12`,1.4`,0.94018`,1.1621000000000001`},0.1773130114270879`},{{0.12`,1.4`,0.94368`,1.1666`},0.1782755859938582`},{{0.12`,1.4`,0.94368`,1.1711`},0.1782755859938582`},{{0.12`,1.4`,0.94368`,1.1621000000000001`},0.1782755859938582`},{{0.12`,1.4`,0.93668`,1.1666`},0.1763616624901265`},{{0.12`,1.4`,0.93668`,1.1711`},0.1763616624901265`},{{0.12`,1.4`,0.93668`,1.1621000000000001`},0.1763616624901265`},{{0.12`,1.6`,0.94018`,1.1666`},0.18376631032740595`},{{0.12`,1.6`,0.94018`,1.1711`},0.18376631032740595`},{{0.12`,1.6`,0.94018`,1.1621000000000001`},0.18376631032740595`},{{0.12`,1.6`,0.94368`,1.1666`},0.18484011150411855`},{{0.12`,1.6`,0.94368`,1.1711`},0.18484011150411855`},{{0.12`,1.6`,0.94368`,1.1621000000000001`},0.18484011150411855`},{{0.12`,1.6`,0.93668`,1.1666`},0.18270505844103765`},{{0.12`,1.6`,0.93668`,1.1711`},0.18270505844103765`},{{0.12`,1.6`,0.93668`,1.1621000000000001`},0.18270505844103765`},{{0.12`,1.8`,0.94018`,1.1666`},0.18987496650409488`},{{0.12`,1.8`,0.94018`,1.1711`},0.18987496650409488`},{{0.12`,1.8`,0.94018`,1.1621000000000001`},0.18987496650409488`},{{0.12`,1.8`,0.94368`,1.1666`},0.1910546466467261`},{{0.12`,1.8`,0.94368`,1.1711`},0.1910546466467261`},{{0.12`,1.8`,0.94368`,1.1621000000000001`},0.1910546466467261`},{{0.12`,1.8`,0.93668`,1.1666`},0.1887090996216355`},{{0.12`,1.8`,0.93668`,1.1711`},0.1887090996216355`},{{0.12`,1.8`,0.93668`,1.1621000000000001`},0.1887090996216355`},{{0.12`,2.`,0.94018`,1.1666`},0.19566238728810398`},{{0.12`,2.`,0.94018`,1.1711`},0.19566238728810398`},{{0.12`,2.`,0.94018`,1.1621000000000001`},0.19566238728810398`},{{0.12`,2.`,0.94368`,1.1666`},0.19694293079980985`},{{0.12`,2.`,0.94368`,1.1711`},0.19694293079980985`},{{0.12`,2.`,0.94368`,1.1621000000000001`},0.19694293079980985`},{{0.12`,2.`,0.93668`,1.1666`},0.19439686437779835`},{{0.12`,2.`,0.93668`,1.1711`},0.19439686437779835`},{{0.12`,2.`,0.93668`,1.1621000000000001`},0.19439686437779835`},{{0.12`,2.2`,0.94018`,1.1666`},0.20115003208826635`},{{0.12`,2.2`,0.94018`,1.1711`},0.20115003208826635`},{{0.12`,2.2`,0.94018`,1.1621000000000001`},0.20115003208826635`},{{0.12`,2.2`,0.94368`,1.1666`},0.2025267307373009`},{{0.12`,2.2`,0.94368`,1.1711`},0.2025267307373009`},{{0.12`,2.2`,0.94368`,1.1621000000000001`},0.2025267307373009`},{{0.12`,2.2`,0.93668`,1.1666`},0.1997895076637242`},{{0.12`,2.2`,0.93668`,1.1711`},0.1997895076637242`},{{0.12`,2.2`,0.93668`,1.1621000000000001`},0.1997895076637242`},{{0.12`,2.6`,0.94018`,1.1666`},0.21130135752693352`},{{0.12`,2.6`,0.94018`,1.1711`},0.21130135752693352`},{{0.12`,2.6`,0.94018`,1.1621000000000001`},0.21130135752693352`},{{0.12`,2.6`,0.94368`,1.1666`},0.21285735822514096`},{{0.12`,2.6`,0.94368`,1.1711`},0.21285735822514096`},{{0.12`,2.6`,0.94368`,1.1621000000000001`},0.21285735822514096`},{{0.12`,2.6`,0.93668`,1.1666`},0.20976368860238112`},{{0.12`,2.6`,0.93668`,1.1711`},0.20976368860238112`},{{0.12`,2.6`,0.93668`,1.1621000000000001`},0.20976368860238112`},{{0.12`,3.`,0.94018`,1.1666`},0.22046949046033615`},{{0.12`,3.`,0.94018`,1.1711`},0.22046949046033615`},{{0.12`,3.`,0.94018`,1.1621000000000001`},0.22046949046033615`},{{0.12`,3.`,0.94368`,1.1666`},0.22218912925967388`},{{0.12`,3.`,0.94368`,1.1711`},0.22218912925967388`},{{0.12`,3.`,0.94368`,1.1621000000000001`},0.22218912925967388`},{{0.12`,3.`,0.93668`,1.1666`},0.21877015763542904`},{{0.12`,3.`,0.93668`,1.1711`},0.21877015763542904`},{{0.12`,3.`,0.93668`,1.1621000000000001`},0.21877015763542904`},{{0.12`,3.4`,0.94018`,1.1666`},0.22877342089023747`},{{0.12`,3.4`,0.94018`,1.1711`},0.22877342089023747`},{{0.12`,3.4`,0.94018`,1.1621000000000001`},0.22877342089023747`},{{0.12`,3.4`,0.94368`,1.1666`},0.23064278853125764`},{{0.12`,3.4`,0.94368`,1.1711`},0.23064278853125764`},{{0.12`,3.4`,0.94368`,1.1621000000000001`},0.23064278853125764`},{{0.12`,3.4`,0.93668`,1.1666`},0.2269261682769958`},{{0.12`,3.4`,0.93668`,1.1711`},0.2269261682769958`},{{0.12`,3.4`,0.93668`,1.1621000000000001`},0.2269261682769958`},{{0.12`,3.8`,0.94018`,1.1666`},0.23631438117272224`},{{0.12`,3.8`,0.94018`,1.1711`},0.23631438117272224`},{{0.12`,3.8`,0.94018`,1.1621000000000001`},0.23631438117272224`},{{0.12`,3.8`,0.94368`,1.1666`},0.2383210930698066`},{{0.12`,3.8`,0.94368`,1.1711`},0.2383210930698066`},{{0.12`,3.8`,0.94368`,1.1621000000000001`},0.2383210930698066`},{{0.12`,3.8`,0.93668`,1.1666`},0.2343314445358953`},{{0.12`,3.8`,0.93668`,1.1711`},0.2343314445358953`},{{0.12`,3.8`,0.93668`,1.1621000000000001`},0.2343314445358953`},{{0.12`,4.2`,0.94018`,1.1666`},0.24317932578409646`},{{0.12`,4.2`,0.94018`,1.1711`},0.24317932578409646`},{{0.12`,4.2`,0.94018`,1.1621000000000001`},0.24317932578409646`},{{0.12`,4.2`,0.94368`,1.1666`},0.2453123226498164`},{{0.12`,4.2`,0.94368`,1.1711`},0.2453123226498164`},{{0.12`,4.2`,0.94368`,1.1621000000000001`},0.2453123226498164`},{{0.12`,4.2`,0.93668`,1.1666`},0.2410716301565994`},{{0.12`,4.2`,0.93668`,1.1711`},0.2410716301565994`},{{0.12`,4.2`,0.93668`,1.1621000000000001`},0.2410716301565994`},{{0.12`,4.6`,0.94018`,1.1666`},0.24944381209222977`},{{0.12`,4.6`,0.94018`,1.1711`},0.24944381209222977`},{{0.12`,4.6`,0.94018`,1.1621000000000001`},0.24944381209222977`},{{0.12`,4.6`,0.94368`,1.1666`},0.2516931916205624`},{{0.12`,4.6`,0.94368`,1.1711`},0.2516931916205624`},{{0.12`,4.6`,0.94368`,1.1621000000000001`},0.2516931916205624`},{{0.12`,4.6`,0.93668`,1.1666`},0.24722113834316267`},{{0.12`,4.6`,0.93668`,1.1711`},0.24722113834316267`},{{0.12`,4.6`,0.93668`,1.1621000000000001`},0.24722113834316267`},{{0.12`,5.`,0.94018`,1.1666`},0.2551727354687589`},{{0.12`,5.`,0.94018`,1.1711`},0.2551727354687589`},{{0.12`,5.`,0.94018`,1.1621000000000001`},0.2551727354687589`},{{0.12`,5.`,0.94368`,1.1666`},0.25752959713765194`},{{0.12`,5.`,0.94368`,1.1711`},0.25752959713765194`},{{0.12`,5.`,0.94368`,1.1621000000000001`},0.25752959713765194`},{{0.12`,5.`,0.93668`,1.1666`},0.25284387438568345`},{{0.12`,5.`,0.93668`,1.1711`},0.25284387438568345`},{{0.12`,5.`,0.93668`,1.1621000000000001`},0.25284387438568345`},{{0.12`,5.4`,0.94018`,1.1666`},0.2604220498776532`},{{0.12`,5.4`,0.94018`,1.1711`},0.2604220498776532`},{{0.12`,5.4`,0.94018`,1.1621000000000001`},0.2604220498776532`},{{0.12`,5.4`,0.94368`,1.1666`},0.26287838491345616`},{{0.12`,5.4`,0.94368`,1.1711`},0.26287838491345616`},{{0.12`,5.4`,0.94368`,1.1621000000000001`},0.26287838491345616`},{{0.12`,5.4`,0.93668`,1.1666`},0.25799491088260346`},{{0.12`,5.4`,0.93668`,1.1711`},0.25799491088260346`},{{0.12`,5.4`,0.93668`,1.1621000000000001`},0.25799491088260346`},{{0.12`,5.8`,0.94018`,1.1666`},0.26524106400941855`},{{0.12`,5.8`,0.94018`,1.1711`},0.26524106400941855`},{{0.12`,5.8`,0.94018`,1.1621000000000001`},0.26524106400941855`},{{0.12`,5.8`,0.94368`,1.1666`},0.2677896435498481`},{{0.12`,5.8`,0.94368`,1.1711`},0.2677896435498481`},{{0.12`,5.8`,0.94368`,1.1621000000000001`},0.2677896435498481`},{{0.12`,5.8`,0.93668`,1.1666`},0.2627227858497861`},{{0.12`,5.8`,0.93668`,1.1711`},0.2627227858497861`},{{0.12`,5.8`,0.93668`,1.1621000000000001`},0.2627227858497861`},{{0.12`,6.2`,0.94018`,1.1666`},0.2696729656072525`},{{0.12`,6.2`,0.94018`,1.1711`},0.2696729656072525`},{{0.12`,6.2`,0.94018`,1.1621000000000001`},0.2696729656072525`},{{0.12`,6.2`,0.94368`,1.1666`},0.2723072491977574`},{{0.12`,6.2`,0.94368`,1.1711`},0.2723072491977574`},{{0.12`,6.2`,0.94368`,1.1621000000000001`},0.2723072491977574`},{{0.12`,6.2`,0.93668`,1.1666`},0.26707000688136234`},{{0.12`,6.2`,0.93668`,1.1711`},0.26707000688136234`},{{0.12`,6.2`,0.93668`,1.1621000000000001`},0.26707000688136234`},{{0.12`,6.8`,0.94018`,1.1666`},0.27567645035912264`},{{0.12`,6.8`,0.94018`,1.1711`},0.27567645035912264`},{{0.12`,6.8`,0.94018`,1.1621000000000001`},0.27567645035912264`},{{0.12`,6.8`,0.94368`,1.1666`},0.27842833920865706`},{{0.12`,6.8`,0.94368`,1.1711`},0.27842833920865706`},{{0.12`,6.8`,0.94368`,1.1621000000000001`},0.27842833920865706`},{{0.12`,6.8`,0.93668`,1.1666`},0.2729572841187153`},{{0.12`,6.8`,0.93668`,1.1711`},0.2729572841187153`},{{0.12`,6.8`,0.93668`,1.1621000000000001`},0.2729572841187153`},{{0.12`,7.4`,0.94018`,1.1666`},0.2810026324267959`},{{0.12`,7.4`,0.94018`,1.1711`},0.2810026324267959`},{{0.12`,7.4`,0.94018`,1.1621000000000001`},0.2810026324267959`},{{0.12`,7.4`,0.94368`,1.1666`},0.2838605431595579`},{{0.12`,7.4`,0.94368`,1.1711`},0.2838605431595579`},{{0.12`,7.4`,0.94368`,1.1621000000000001`},0.2838605431595579`},{{0.12`,7.4`,0.93668`,1.1666`},0.2781786962225781`},{{0.12`,7.4`,0.93668`,1.1711`},0.2781786962225781`},{{0.12`,7.4`,0.93668`,1.1621000000000001`},0.2781786962225781`},{{0.12`,8.`,0.94018`,1.1666`},0.28574292729891826`},{{0.12`,8.`,0.94018`,1.1711`},0.28574292729891826`},{{0.12`,8.`,0.94018`,1.1621000000000001`},0.28574292729891826`},{{0.12`,8.`,0.94368`,1.1666`},0.28869676863872085`},{{0.12`,8.`,0.94368`,1.1711`},0.28869676863872085`},{{0.12`,8.`,0.94368`,1.1621000000000001`},0.28869676863872085`},{{0.12`,8.`,0.93668`,1.1666`},0.2828241851278332`},{{0.12`,8.`,0.93668`,1.1711`},0.2828241851278332`},{{0.12`,8.`,0.93668`,1.1621000000000001`},0.2828241851278332`},{{0.12`,8.6`,0.94018`,1.1666`},0.2899744807881983`},{{0.12`,8.6`,0.94018`,1.1711`},0.2899744807881983`},{{0.12`,8.6`,0.94018`,1.1621000000000001`},0.2899744807881983`},{{0.12`,8.6`,0.94368`,1.1666`},0.2930154244333457`},{{0.12`,8.6`,0.94368`,1.1711`},0.2930154244333457`},{{0.12`,8.6`,0.94368`,1.1621000000000001`},0.2930154244333457`},{{0.12`,8.6`,0.93668`,1.1666`},0.28696964948621373`},{{0.12`,8.6`,0.93668`,1.1711`},0.28696964948621373`},{{0.12`,8.6`,0.93668`,1.1621000000000001`},0.28696964948621373`},{{0.12`,9.2`,0.94018`,1.1666`},0.2937618725851524`},{{0.12`,9.2`,0.94018`,1.1711`},0.2937618725851524`},{{0.12`,9.2`,0.94018`,1.1621000000000001`},0.2937618725851524`},{{0.12`,9.2`,0.94368`,1.1666`},0.2968821635189335`},{{0.12`,9.2`,0.94368`,1.1711`},0.2968821635189335`},{{0.12`,9.2`,0.94368`,1.1621000000000001`},0.2968821635189335`},{{0.12`,9.2`,0.93668`,1.1666`},0.2906786093677831`},{{0.12`,9.2`,0.93668`,1.1711`},0.2906786093677831`},{{0.12`,9.2`,0.93668`,1.1621000000000001`},0.2906786093677831`},{{0.12`,9.8`,0.94018`,1.1666`},0.2971602093784857`},{{0.12`,9.8`,0.94018`,1.1711`},0.2971602093784857`},{{0.12`,9.8`,0.94018`,1.1621000000000001`},0.2971602093784857`},{{0.12`,9.8`,0.94368`,1.1666`},0.30035300727144104`},{{0.12`,9.8`,0.94368`,1.1711`},0.30035300727144104`},{{0.12`,9.8`,0.94368`,1.1621000000000001`},0.30035300727144104`},{{0.12`,9.8`,0.93668`,1.1666`},0.29400526808289906`},{{0.12`,9.8`,0.93668`,1.1711`},0.29400526808289906`},{{0.12`,9.8`,0.93668`,1.1621000000000001`},0.29400526808289906`},{{0.12`,10.4`,0.94018`,1.1666`},0.300215866918563`},{{0.12`,10.4`,0.94018`,1.1711`},0.300215866918563`},{{0.12`,10.4`,0.94018`,1.1621000000000001`},0.300215866918563`},{{0.12`,10.4`,0.94368`,1.1666`},0.30347511555824475`},{{0.12`,10.4`,0.94368`,1.1711`},0.30347511555824475`},{{0.12`,10.4`,0.94368`,1.1621000000000001`},0.30347511555824475`},{{0.12`,10.4`,0.93668`,1.1666`},0.2969952282598508`},{{0.12`,10.4`,0.93668`,1.1711`},0.2969952282598508`},{{0.12`,10.4`,0.93668`,1.1621000000000001`},0.2969952282598508`},{{0.12`,11.`,0.94018`,1.1666`},0.3029694047128061`},{{0.12`,11.`,0.94018`,1.1711`},0.3029694047128061`},{{0.12`,11.`,0.94018`,1.1621000000000001`},0.3029694047128061`},{{0.12`,11.`,0.94368`,1.1666`},0.30628972678182825`},{{0.12`,11.`,0.94368`,1.1711`},0.30628972678182825`},{{0.12`,11.`,0.94368`,1.1621000000000001`},0.30628972678182825`},{{0.12`,11.`,0.93668`,1.1666`},0.29968837764434053`},{{0.12`,11.`,0.93668`,1.1711`},0.29968837764434053`},{{0.12`,11.`,0.93668`,1.1621000000000001`},0.29968837764434053`},{{0.12`,11.6`,0.94018`,1.1666`},0.3054553070708258`},{{0.12`,11.6`,0.94018`,1.1711`},0.3054553070708258`},{{0.12`,11.6`,0.94018`,1.1621000000000001`},0.3054553070708258`},{{0.12`,11.6`,0.94368`,1.1666`},0.30883190917023484`},{{0.12`,11.6`,0.94368`,1.1711`},0.30883190917023484`},{{0.12`,11.6`,0.94368`,1.1621000000000001`},0.30883190917023484`},{{0.12`,11.6`,0.93668`,1.1666`},0.3021186258566166`},{{0.12`,11.6`,0.93668`,1.1711`},0.3021186258566166`},{{0.12`,11.6`,0.93668`,1.1621000000000001`},0.3021186258566166`},{{0.12`,12.2`,0.94018`,1.1666`},0.30770264401902647`},{{0.12`,12.2`,0.94018`,1.1711`},0.30770264401902647`},{{0.12`,12.2`,0.94018`,1.1621000000000001`},0.30770264401902647`},{{0.12`,12.2`,0.94368`,1.1666`},0.3111312429877612`},{{0.12`,12.2`,0.94368`,1.1711`},0.3111312429877612`},{{0.12`,12.2`,0.94368`,1.1621000000000001`},0.3111312429877612`},{{0.12`,12.2`,0.93668`,1.1666`},0.30431453905962463`},{{0.12`,12.2`,0.93668`,1.1711`},0.30431453905962463`},{{0.12`,12.2`,0.93668`,1.1621000000000001`},0.30431453905962463`},{{0.12`,12.8`,0.94018`,1.1666`},0.30973811539198837`},{{0.12`,12.8`,0.94018`,1.1711`},0.30973811539198837`},{{0.12`,12.8`,0.94018`,1.1621000000000001`},0.30973811539198837`},{{0.12`,12.8`,0.94368`,1.1666`},0.3132148726936624`},{{0.12`,12.8`,0.94368`,1.1711`},0.3132148726936624`},{{0.12`,12.8`,0.94368`,1.1621000000000001`},0.3132148726936624`},{{0.12`,12.8`,0.93668`,1.1666`},0.30630237609329536`},{{0.12`,12.8`,0.93668`,1.1711`},0.30630237609329536`},{{0.12`,12.8`,0.93668`,1.1621000000000001`},0.30630237609329536`},{{0.12`,13.4`,0.94018`,1.1666`},0.31158384176675546`},{{0.12`,13.4`,0.94018`,1.1711`},0.31158384176675546`},{{0.12`,13.4`,0.94018`,1.1621000000000001`},0.31158384176675546`},{{0.12`,13.4`,0.94368`,1.1666`},0.3151053027834021`},{{0.12`,13.4`,0.94368`,1.1711`},0.3151053027834021`},{{0.12`,13.4`,0.94368`,1.1621000000000001`},0.3151053027834021`},{{0.12`,13.4`,0.93668`,1.1666`},0.3081038809974559`},{{0.12`,13.4`,0.93668`,1.1711`},0.3081038809974559`},{{0.12`,13.4`,0.93668`,1.1621000000000001`},0.3081038809974559`},{{0.12`,14.`,0.94018`,1.1666`},0.313259893460504`},{{0.12`,14.`,0.94018`,1.1711`},0.313259893460504`},{{0.12`,14.`,0.94018`,1.1621000000000001`},0.313259893460504`},{{0.12`,14.`,0.94368`,1.1666`},0.3168229468582842`},{{0.12`,14.`,0.94368`,1.1711`},0.3168229468582842`},{{0.12`,14.`,0.94368`,1.1621000000000001`},0.3168229468582842`},{{0.12`,14.`,0.93668`,1.1666`},0.3097387843060769`},{{0.12`,14.`,0.93668`,1.1711`},0.3097387843060769`},{{0.12`,14.`,0.93668`,1.1621000000000001`},0.3097387843060769`},{{0.12`,14.6`,0.94018`,1.1666`},0.3147836205735803`},{{0.12`,14.6`,0.94018`,1.1711`},0.3147836205735803`},{{0.12`,14.6`,0.94018`,1.1621000000000001`},0.3147836205735803`},{{0.12`,14.6`,0.94368`,1.1666`},0.3183854524353435`},{{0.12`,14.6`,0.94368`,1.1711`},0.3183854524353435`},{{0.12`,14.6`,0.94368`,1.1621000000000001`},0.3183854524353435`},{{0.12`,14.6`,0.93668`,1.1666`},0.31122414257647846`},{{0.12`,14.6`,0.93668`,1.1711`},0.31122414257647846`},{{0.12`,14.6`,0.93668`,1.1621000000000001`},0.31122414257647846`},{{0.12`,15.2`,0.94018`,1.1666`},0.31616956839958055`},{{0.12`,15.2`,0.94018`,1.1711`},0.31616956839958055`},{{0.12`,15.2`,0.94018`,1.1621000000000001`},0.31616956839958055`},{{0.12`,15.2`,0.94368`,1.1666`},0.31980762826272185`},{{0.12`,15.2`,0.94368`,1.1711`},0.31980762826272185`},{{0.12`,15.2`,0.94368`,1.1621000000000001`},0.31980762826272185`},{{0.12`,15.2`,0.93668`,1.1666`},0.3125742412890143`},{{0.12`,15.2`,0.93668`,1.1711`},0.3125742412890143`},{{0.12`,15.2`,0.93668`,1.1621000000000001`},0.3125742412890143`},{{0.12`,15.8`,0.94018`,1.1666`},0.31743178003282996`},{{0.12`,15.8`,0.94018`,1.1711`},0.31743178003282996`},{{0.12`,15.8`,0.94018`,1.1621000000000001`},0.31743178003282996`},{{0.12`,15.8`,0.94368`,1.1666`},0.3211037553843667`},{{0.12`,15.8`,0.94368`,1.1711`},0.3211037553843667`},{{0.12`,15.8`,0.94368`,1.1621000000000001`},0.3211037553843667`},{{0.12`,15.8`,0.93668`,1.1666`},0.313802888330524`},{{0.12`,15.8`,0.93668`,1.1711`},0.313802888330524`},{{0.12`,15.8`,0.93668`,1.1621000000000001`},0.313802888330524`},{{0.12`,16.4`,0.94018`,1.1666`},0.31858205855799526`},{{0.12`,16.4`,0.94018`,1.1711`},0.31858205855799526`},{{0.12`,16.4`,0.94018`,1.1621000000000001`},0.31858205855799526`},{{0.12`,16.4`,0.94368`,1.1666`},0.3222858425509148`},{{0.12`,16.4`,0.94368`,1.1711`},0.3222858425509148`},{{0.12`,16.4`,0.94368`,1.1621000000000001`},0.3222858425509148`},{{0.12`,16.4`,0.93668`,1.1666`},0.3149216838502884`},{{0.12`,16.4`,0.93668`,1.1711`},0.3149216838502884`},{{0.12`,16.4`,0.93668`,1.1621000000000001`},0.3149216838502884`},{{0.12`,17.`,0.94018`,1.1666`},0.31963063559589844`},{{0.12`,17.`,0.94018`,1.1711`},0.31963063559589844`},{{0.12`,17.`,0.94018`,1.1621000000000001`},0.31963063559589844`},{{0.12`,17.`,0.94368`,1.1666`},0.32336430489002327`},{{0.12`,17.`,0.94368`,1.1711`},0.32336430489002327`},{{0.12`,17.`,0.94368`,1.1621000000000001`},0.32336430489002327`},{{0.12`,17.`,0.93668`,1.1666`},0.3159406784875527`},{{0.12`,17.`,0.93668`,1.1711`},0.3159406784875527`},{{0.12`,17.`,0.93668`,1.1621000000000001`},0.3159406784875527`},{{0.12`,17.6`,0.94018`,1.1666`},0.3205869836567386`},{{0.12`,17.6`,0.94018`,1.1711`},0.3205869836567386`},{{0.12`,17.6`,0.94018`,1.1621000000000001`},0.3205869836567386`},{{0.12`,17.6`,0.94368`,1.1666`},0.3243487854688399`},{{0.12`,17.6`,0.94368`,1.1711`},0.3243487854688399`},{{0.12`,17.6`,0.94368`,1.1621000000000001`},0.3243487854688399`},{{0.12`,17.6`,0.93668`,1.1666`},0.3168691761575803`},{{0.12`,17.6`,0.93668`,1.1711`},0.3168691761575803`},{{0.12`,17.6`,0.93668`,1.1621000000000001`},0.3168691761575803`},{{0.12`,18.2`,0.94018`,1.1666`},0.321459929594813`},{{0.12`,18.2`,0.94018`,1.1711`},0.321459929594813`},{{0.12`,18.2`,0.94018`,1.1621000000000001`},0.321459929594813`},{{0.12`,18.2`,0.94368`,1.1666`},0.3252482493446106`},{{0.12`,18.2`,0.94368`,1.1711`},0.3252482493446106`},{{0.12`,18.2`,0.94368`,1.1621000000000001`},0.3252482493446106`},{{0.12`,18.2`,0.93668`,1.1666`},0.3177158670447966`},{{0.12`,18.2`,0.93668`,1.1711`},0.3177158670447966`},{{0.12`,18.2`,0.93668`,1.1621000000000001`},0.3177158670447966`},{{0.12`,18.8`,0.94018`,1.1666`},0.3222562218169906`},{{0.12`,18.8`,0.94018`,1.1711`},0.3222562218169906`},{{0.12`,18.8`,0.94018`,1.1621000000000001`},0.3222562218169906`},{{0.12`,18.8`,0.94368`,1.1666`},0.32606959094542826`},{{0.12`,18.8`,0.94368`,1.1711`},0.32606959094542826`},{{0.12`,18.8`,0.94368`,1.1621000000000001`},0.32606959094542826`},{{0.12`,18.8`,0.93668`,1.1666`},0.318487355897028`},{{0.12`,18.8`,0.93668`,1.1711`},0.318487355897028`},{{0.12`,18.8`,0.93668`,1.1621000000000001`},0.318487355897028`},{{0.12`,19.4`,0.94018`,1.1666`},0.32298243907614493`},{{0.12`,19.4`,0.94018`,1.1711`},0.32298243907614493`},{{0.12`,19.4`,0.94018`,1.1621000000000001`},0.32298243907614493`},{{0.12`,19.4`,0.94368`,1.1666`},0.3268195030265891`},{{0.12`,19.4`,0.94368`,1.1711`},0.3268195030265891`},{{0.12`,19.4`,0.94368`,1.1621000000000001`},0.3268195030265891`},{{0.12`,19.4`,0.93668`,1.1666`},0.31919010888448257`},{{0.12`,19.4`,0.93668`,1.1711`},0.31919010888448257`},{{0.12`,19.4`,0.93668`,1.1621000000000001`},0.31919010888448257`},{{0.12`,20.`,0.94018`,1.1666`},0.32364508034151884`},{{0.12`,20.`,0.94018`,1.1711`},0.32364508034151884`},{{0.12`,20.`,0.94018`,1.1621000000000001`},0.32364508034151884`},{{0.12`,20.`,0.94368`,1.1666`},0.327504593511521`},{{0.12`,20.`,0.94368`,1.1711`},0.327504593511521`},{{0.12`,20.`,0.94368`,1.1621000000000001`},0.327504593511521`},{{0.12`,20.`,0.93668`,1.1666`},0.31983051707378995`},{{0.12`,20.`,0.93668`,1.1711`},0.31983051707378995`},{{0.12`,20.`,0.93668`,1.1621000000000001`},0.31983051707378995`},{{0.12`,20.6`,0.94018`,1.1666`},0.3242494736059191`},{{0.12`,20.6`,0.94018`,1.1711`},0.3242494736059191`},{{0.12`,20.6`,0.94018`,1.1621000000000001`},0.3242494736059191`},{{0.12`,20.6`,0.94368`,1.1666`},0.32813028610251216`},{{0.12`,20.6`,0.94368`,1.1711`},0.32813028610251216`},{{0.12`,20.6`,0.94368`,1.1621000000000001`},0.32813028610251216`},{{0.12`,20.6`,0.93668`,1.1666`},0.3204138140555237`},{{0.12`,20.6`,0.93668`,1.1711`},0.3204138140555237`},{{0.12`,20.6`,0.93668`,1.1621000000000001`},0.3204138140555237`},{{0.12`,21.2`,0.94018`,1.1666`},0.32480005645724186`},{{0.12`,21.2`,0.94018`,1.1711`},0.32480005645724186`},{{0.12`,21.2`,0.94018`,1.1621000000000001`},0.32480005645724186`},{{0.12`,21.2`,0.94368`,1.1666`},0.3287011074800358`},{{0.12`,21.2`,0.94368`,1.1711`},0.3287011074800358`},{{0.12`,21.2`,0.94368`,1.1621000000000001`},0.3287011074800358`},{{0.12`,21.2`,0.93668`,1.1666`},0.320944349612224`},{{0.12`,21.2`,0.93668`,1.1711`},0.320944349612224`},{{0.12`,21.2`,0.93668`,1.1621000000000001`},0.320944349612224`},{{0.12`,21.8`,0.94018`,1.1666`},0.325301702138903`},{{0.12`,21.8`,0.94018`,1.1711`},0.325301702138903`},{{0.12`,21.8`,0.94018`,1.1621000000000001`},0.325301702138903`},{{0.12`,21.8`,0.94368`,1.1666`},0.32922201067303536`},{{0.12`,21.8`,0.94368`,1.1711`},0.32922201067303536`},{{0.12`,21.8`,0.94368`,1.1621000000000001`},0.32922201067303536`},{{0.12`,21.8`,0.93668`,1.1666`},0.3214269179357335`},{{0.12`,21.8`,0.93668`,1.1711`},0.3214269179357335`},{{0.12`,21.8`,0.93668`,1.1621000000000001`},0.3214269179357335`},{{0.12`,22.4`,0.94018`,1.1666`},0.32575827468302765`},{{0.12`,22.4`,0.94018`,1.1711`},0.32575827468302765`},{{0.12`,22.4`,0.94018`,1.1621000000000001`},0.32575827468302765`},{{0.12`,22.4`,0.94368`,1.1666`},0.3296969313819953`},{{0.12`,22.4`,0.94368`,1.1711`},0.3296969313819953`},{{0.12`,22.4`,0.94368`,1.1621000000000001`},0.3296969313819953`},{{0.12`,22.4`,0.93668`,1.1666`},0.3218653123663684`},{{0.12`,22.4`,0.93668`,1.1711`},0.3218653123663684`},{{0.12`,22.4`,0.93668`,1.1621000000000001`},0.3218653123663684`},{{0.12`,23.`,0.94018`,1.1666`},0.32617340814100054`},{{0.12`,23.`,0.94018`,1.1711`},0.32617340814100054`},{{0.12`,23.`,0.94018`,1.1621000000000001`},0.32617340814100054`},{{0.12`,23.`,0.94368`,1.1666`},0.33012956919061576`},{{0.12`,23.`,0.94368`,1.1711`},0.33012956919061576`},{{0.12`,23.`,0.94368`,1.1621000000000001`},0.33012956919061576`},{{0.12`,23.`,0.93668`,1.1666`},0.3222631022267302`},{{0.12`,23.`,0.93668`,1.1711`},0.3222631022267302`},{{0.12`,23.`,0.93668`,1.1621000000000001`},0.3222631022267302`},{{0.12`,23.6`,0.94018`,1.1666`},0.32655041252538425`},{{0.12`,23.6`,0.94018`,1.1711`},0.32655041252538425`},{{0.12`,23.6`,0.94018`,1.1621000000000001`},0.32655041252538425`},{{0.12`,23.6`,0.94368`,1.1666`},0.3305232936512878`},{{0.12`,23.6`,0.94368`,1.1711`},0.3305232936512878`},{{0.12`,23.6`,0.94368`,1.1621000000000001`},0.3305232936512878`},{{0.12`,23.6`,0.93668`,1.1666`},0.32262353871803573`},{{0.12`,23.6`,0.93668`,1.1711`},0.32262353871803573`},{{0.12`,23.6`,0.93668`,1.1621000000000001`},0.32262353871803573`},{{0.12`,24.2`,0.94018`,1.1666`},0.3268912772819821`},{{0.12`,24.2`,0.94018`,1.1711`},0.3268912772819821`},{{0.12`,24.2`,0.94018`,1.1621000000000001`},0.3268912772819821`},{{0.12`,24.2`,0.94368`,1.1666`},0.3308801510094881`},{{0.12`,24.2`,0.94368`,1.1711`},0.3308801510094881`},{{0.12`,24.2`,0.94368`,1.1621000000000001`},0.3308801510094881`},{{0.12`,24.2`,0.93668`,1.1666`},0.3229485521303739`},{{0.12`,24.2`,0.93668`,1.1711`},0.3229485521303739`},{{0.12`,24.2`,0.93668`,1.1621000000000001`},0.3229485521303739`},{{0.12`,24.8`,0.94018`,1.1666`},0.32719992217087535`},{{0.12`,24.8`,0.94018`,1.1711`},0.32719992217087535`},{{0.12`,24.8`,0.94018`,1.1621000000000001`},0.32719992217087535`},{{0.12`,24.8`,0.94368`,1.1666`},0.3312041127112914`},{{0.12`,24.8`,0.94368`,1.1711`},0.3312041127112914`},{{0.12`,24.8`,0.94368`,1.1621000000000001`},0.3312041127112914`},{{0.12`,24.8`,0.93668`,1.1666`},0.32324201619988885`},{{0.12`,24.8`,0.93668`,1.1711`},0.32324201619988885`},{{0.12`,24.8`,0.93668`,1.1621000000000001`},0.32324201619988885`},{{0.12`,25.4`,0.94018`,1.1666`},0.3274784318337548`},{{0.12`,25.4`,0.94018`,1.1711`},0.3274784318337548`},{{0.12`,25.4`,0.94018`,1.1621000000000001`},0.3274784318337548`},{{0.12`,25.4`,0.94368`,1.1666`},0.3314973070970342`},{{0.12`,25.4`,0.94368`,1.1711`},0.3314973070970342`},{{0.12`,25.4`,0.94368`,1.1621000000000001`},0.3314973070970342`},{{0.12`,25.4`,0.93668`,1.1666`},0.3235059700874973`},{{0.12`,25.4`,0.93668`,1.1711`},0.3235059700874973`},{{0.12`,25.4`,0.93668`,1.1621000000000001`},0.3235059700874973`},{{0.12`,26.`,0.94018`,1.1666`},0.32772907551024505`},{{0.12`,26.`,0.94018`,1.1711`},0.32772907551024505`},{{0.12`,26.`,0.94018`,1.1621000000000001`},0.32772907551024505`},{{0.12`,26.`,0.94368`,1.1666`},0.3317620452463248`},{{0.12`,26.`,0.94368`,1.1711`},0.3317620452463248`},{{0.12`,26.`,0.94368`,1.1621000000000001`},0.3317620452463248`},{{0.12`,26.`,0.93668`,1.1666`},0.3237426416200806`},{{0.12`,26.`,0.93668`,1.1711`},0.3237426416200806`},{{0.12`,26.`,0.93668`,1.1621000000000001`},0.3237426416200806`},{{0.12`,26.6`,0.94018`,1.1666`},0.32795391269839813`},{{0.12`,26.6`,0.94018`,1.1711`},0.32795391269839813`},{{0.12`,26.6`,0.94018`,1.1621000000000001`},0.32795391269839813`},{{0.12`,26.6`,0.94368`,1.1666`},0.3320004291289056`},{{0.12`,26.6`,0.94368`,1.1711`},0.3320004291289056`},{{0.12`,26.6`,0.94368`,1.1621000000000001`},0.3320004291289056`},{{0.12`,26.6`,0.93668`,1.1666`},0.32395405574999514`},{{0.12`,26.6`,0.93668`,1.1711`},0.32395405574999514`},{{0.12`,26.6`,0.93668`,1.1621000000000001`},0.32395405574999514`},{{0.12`,27.2`,0.94018`,1.1666`},0.32815400526613125`},{{0.12`,27.2`,0.94018`,1.1711`},0.32815400526613125`},{{0.12`,27.2`,0.94018`,1.1621000000000001`},0.32815400526613125`},{{0.12`,27.2`,0.94368`,1.1666`},0.3322135549529061`},{{0.12`,27.2`,0.94368`,1.1711`},0.3322135549529061`},{{0.12`,27.2`,0.94368`,1.1621000000000001`},0.3322135549529061`},{{0.12`,27.2`,0.93668`,1.1666`},0.3241412281673286`},{{0.12`,27.2`,0.93668`,1.1711`},0.3241412281673286`},{{0.12`,27.2`,0.93668`,1.1621000000000001`},0.3241412281673286`},{{0.12`,27.8`,0.94018`,1.1666`},0.32833206998351205`},{{0.12`,27.8`,0.94018`,1.1711`},0.32833206998351205`},{{0.12`,27.8`,0.94018`,1.1621000000000001`},0.32833206998351205`},{{0.12`,27.8`,0.94368`,1.1666`},0.33240417208295964`},{{0.12`,27.8`,0.94368`,1.1711`},0.33240417208295964`},{{0.12`,27.8`,0.94368`,1.1621000000000001`},0.33240417208295964`},{{0.12`,27.8`,0.93668`,1.1666`},0.32430684830823986`},{{0.12`,27.8`,0.93668`,1.1711`},0.32430684830823986`},{{0.12`,27.8`,0.93668`,1.1621000000000001`},0.32430684830823986`},{{0.12`,28.4`,0.94018`,1.1666`},0.328489432618594`},{{0.12`,28.4`,0.94018`,1.1711`},0.328489432618594`},{{0.12`,28.4`,0.94018`,1.1621000000000001`},0.328489432618594`},{{0.12`,28.4`,0.94368`,1.1666`},0.33257363569482873`},{{0.12`,28.4`,0.94368`,1.1711`},0.33257363569482873`},{{0.12`,28.4`,0.94368`,1.1621000000000001`},0.33257363569482873`},{{0.12`,28.4`,0.93668`,1.1666`},0.32445221317342354`},{{0.12`,28.4`,0.93668`,1.1711`},0.32445221317342354`},{{0.12`,28.4`,0.93668`,1.1621000000000001`},0.32445221317342354`},{{0.12`,29.`,0.94018`,1.1666`},0.328627562610125`},{{0.12`,29.`,0.94018`,1.1711`},0.328627562610125`},{{0.12`,29.`,0.94018`,1.1621000000000001`},0.328627562610125`},{{0.12`,29.`,0.94368`,1.1666`},0.33272344299141987`},{{0.12`,29.`,0.94368`,1.1711`},0.33272344299141987`},{{0.12`,29.`,0.94368`,1.1621000000000001`},0.33272344299141987`},{{0.12`,29.`,0.93668`,1.1666`},0.32457876475728914`},{{0.12`,29.`,0.93668`,1.1711`},0.32457876475728914`},{{0.12`,29.`,0.93668`,1.1621000000000001`},0.32457876475728914`},{{0.12`,29.6`,0.94018`,1.1666`},0.32874740036093786`},{{0.12`,29.6`,0.94018`,1.1711`},0.32874740036093786`},{{0.12`,29.6`,0.94018`,1.1621000000000001`},0.32874740036093786`},{{0.12`,29.6`,0.94368`,1.1666`},0.33285456224487403`},{{0.12`,29.6`,0.94368`,1.1711`},0.33285456224487403`},{{0.12`,29.6`,0.94368`,1.1621000000000001`},0.33285456224487403`},{{0.12`,29.6`,0.93668`,1.1666`},0.3246874125562276`},{{0.12`,29.6`,0.93668`,1.1711`},0.3246874125562276`},{{0.12`,29.6`,0.93668`,1.1621000000000001`},0.3246874125562276`},{{0.12`,30.2`,0.94018`,1.1666`},0.32885054225894844`},{{0.12`,30.2`,0.94018`,1.1711`},0.32885054225894844`},{{0.12`,30.2`,0.94018`,1.1621000000000001`},0.32885054225894844`},{{0.12`,30.2`,0.94368`,1.1666`},0.33296861471473316`},{{0.12`,30.2`,0.94368`,1.1711`},0.33296861471473316`},{{0.12`,30.2`,0.94368`,1.1621000000000001`},0.33296861471473316`},{{0.12`,30.2`,0.93668`,1.1666`},0.3247797343602381`},{{0.12`,30.2`,0.93668`,1.1711`},0.3247797343602381`},{{0.12`,30.2`,0.93668`,1.1621000000000001`},0.3247797343602381`},{{0.12`,30.8`,0.94018`,1.1666`},0.32893805396773956`},{{0.12`,30.8`,0.94018`,1.1711`},0.32893805396773956`},{{0.12`,30.8`,0.94018`,1.1621000000000001`},0.32893805396773956`},{{0.12`,30.8`,0.94368`,1.1666`},0.33306668683227797`},{{0.12`,30.8`,0.94368`,1.1711`},0.33306668683227797`},{{0.12`,30.8`,0.94368`,1.1621000000000001`},0.33306668683227797`},{{0.12`,30.8`,0.93668`,1.1666`},0.3248567725412975`},{{0.12`,30.8`,0.93668`,1.1711`},0.3248567725412975`},{{0.12`,30.8`,0.93668`,1.1621000000000001`},0.3248567725412975`},{{0.12`,31.4`,0.94018`,1.1666`},0.32901098428454595`},{{0.12`,31.4`,0.94018`,1.1711`},0.32901098428454595`},{{0.12`,31.4`,0.94018`,1.1621000000000001`},0.32901098428454595`},{{0.12`,31.4`,0.94368`,1.1666`},0.33314984804217773`},{{0.12`,31.4`,0.94368`,1.1711`},0.33314984804217773`},{{0.12`,31.4`,0.94368`,1.1621000000000001`},0.33314984804217773`},{{0.12`,31.4`,0.93668`,1.1666`},0.3249195554643176`},{{0.12`,31.4`,0.93668`,1.1711`},0.3249195554643176`},{{0.12`,31.4`,0.93668`,1.1621000000000001`},0.3249195554643176`},{{0.12`,32.`,0.94018`,1.1666`},0.3290701252898896`},{{0.12`,32.`,0.94018`,1.1711`},0.3290701252898896`},{{0.12`,32.`,0.94018`,1.1621000000000001`},0.3290701252898896`},{{0.12`,32.`,0.94368`,1.1666`},0.33321891007913595`},{{0.12`,32.`,0.94368`,1.1711`},0.33321891007913595`},{{0.12`,32.`,0.94368`,1.1621000000000001`},0.33321891007913595`},{{0.12`,32.`,0.93668`,1.1666`},0.3249688559324717`},{{0.12`,32.`,0.93668`,1.1711`},0.3249688559324717`},{{0.12`,32.`,0.93668`,1.1621000000000001`},0.3249688559324717`},{{0.12`,32.6`,0.94018`,1.1666`},0.32911645681131035`},{{0.12`,32.6`,0.94018`,1.1711`},0.32911645681131035`},{{0.12`,32.6`,0.94018`,1.1621000000000001`},0.32911645681131035`},{{0.12`,32.6`,0.94368`,1.1666`},0.33327487283370255`},{{0.12`,32.6`,0.94368`,1.1711`},0.33327487283370255`},{{0.12`,32.6`,0.94368`,1.1621000000000001`},0.33327487283370255`},{{0.12`,32.6`,0.93668`,1.1666`},0.3250056336929288`},{{0.12`,32.6`,0.93668`,1.1711`},0.3250056336929288`},{{0.12`,32.6`,0.93668`,1.1621000000000001`},0.3250056336929288`},{{0.12`,33.2`,0.94018`,1.1666`},0.3291508109107871`},{{0.12`,33.2`,0.94018`,1.1711`},0.3291508109107871`},{{0.12`,33.2`,0.94018`,1.1621000000000001`},0.3291508109107871`},{{0.12`,33.2`,0.94368`,1.1666`},0.333318583621082`},{{0.12`,33.2`,0.94368`,1.1711`},0.333318583621082`},{{0.12`,33.2`,0.94368`,1.1621000000000001`},0.333318583621082`},{{0.12`,33.2`,0.93668`,1.1666`},0.3250307057849578`},{{0.12`,33.2`,0.93668`,1.1711`},0.3250307057849578`},{{0.12`,33.2`,0.93668`,1.1621000000000001`},0.3250307057849578`},{{0.12`,33.8`,0.94018`,1.1666`},0.32917394562671476`},{{0.12`,33.8`,0.94018`,1.1711`},0.32917394562671476`},{{0.12`,33.8`,0.94018`,1.1621000000000001`},0.32917394562671476`},{{0.12`,33.8`,0.94368`,1.1666`},0.3333508161711648`},{{0.12`,33.8`,0.94368`,1.1711`},0.3333508161711648`},{{0.12`,33.8`,0.94368`,1.1621000000000001`},0.3333508161711648`},{{0.12`,33.8`,0.93668`,1.1666`},0.3250448147103077`},{{0.12`,33.8`,0.93668`,1.1711`},0.3250448147103077`},{{0.12`,33.8`,0.93668`,1.1621000000000001`},0.3250448147103077`},{{0.12`,34.4`,0.94018`,1.1666`},0.3291865641519796`},{{0.12`,34.4`,0.94018`,1.1711`},0.3291865641519796`},{{0.12`,34.4`,0.94018`,1.1621000000000001`},0.3291865641519796`},{{0.12`,34.4`,0.94368`,1.1666`},0.33337228831902344`},{{0.12`,34.4`,0.94368`,1.1711`},0.33337228831902344`},{{0.12`,34.4`,0.94368`,1.1621000000000001`},0.33337228831902344`},{{0.12`,34.4`,0.93668`,1.1666`},0.32504864916078197`},{{0.12`,34.4`,0.93668`,1.1711`},0.32504864916078197`},{{0.12`,34.4`,0.93668`,1.1621000000000001`},0.32504864916078197`},{{0.12`,35.`,0.94018`,1.1666`},0.3291893334710515`},{{0.12`,35.`,0.94018`,1.1711`},0.3291893334710515`},{{0.12`,35.`,0.94018`,1.1621000000000001`},0.3291893334710515`},{{0.12`,35.`,0.94368`,1.1666`},0.33338368111167166`},{{0.12`,35.`,0.94368`,1.1711`},0.33338368111167166`},{{0.12`,35.`,0.94368`,1.1621000000000001`},0.33338368111167166`},{{0.12`,35.`,0.93668`,1.1666`},0.3250428621657508`},{{0.12`,35.`,0.93668`,1.1711`},0.3250428621657508`},{{0.12`,35.`,0.93668`,1.1621000000000001`},0.3250428621657508`},{{0.12`,35.6`,0.94018`,1.1666`},0.32918236499015124`},{{0.12`,35.6`,0.94018`,1.1711`},0.32918236499015124`},{{0.12`,35.6`,0.94018`,1.1621000000000001`},0.32918236499015124`},{{0.12`,35.6`,0.94368`,1.1666`},0.33338512208309123`},{{0.12`,35.6`,0.94368`,1.1711`},0.33338512208309123`},{{0.12`,35.6`,0.94368`,1.1621000000000001`},0.33338512208309123`},{{0.12`,35.6`,0.93668`,1.1666`},0.32502754953804686`},{{0.12`,35.6`,0.93668`,1.1711`},0.32502754953804686`},{{0.12`,35.6`,0.93668`,1.1621000000000001`},0.32502754953804686`},{{0.12`,36.2`,0.94018`,1.1666`},0.3291668723829777`},{{0.12`,36.2`,0.94018`,1.1711`},0.3291668723829777`},{{0.12`,36.2`,0.94018`,1.1621000000000001`},0.3291668723829777`},{{0.12`,36.2`,0.94368`,1.1666`},0.3333778330394013`},{{0.12`,36.2`,0.94368`,1.1711`},0.3333778330394013`},{{0.12`,36.2`,0.94368`,1.1621000000000001`},0.3333778330394013`},{{0.12`,36.2`,0.93668`,1.1666`},0.32500391634624853`},{{0.12`,36.2`,0.93668`,1.1711`},0.32500391634624853`},{{0.12`,36.2`,0.93668`,1.1621000000000001`},0.32500391634624853`},{{0.12`,36.8`,0.94018`,1.1666`},0.32914312495870707`},{{0.12`,36.8`,0.94018`,1.1711`},0.32914312495870707`},{{0.12`,36.8`,0.94018`,1.1621000000000001`},0.32914312495870707`},{{0.12`,36.8`,0.94368`,1.1666`},0.33336209601869005`},{{0.12`,36.8`,0.94368`,1.1711`},0.33336209601869005`},{{0.12`,36.8`,0.94368`,1.1621000000000001`},0.33336209601869005`},{{0.12`,36.8`,0.93668`,1.1666`},0.32497221950072364`},{{0.12`,36.8`,0.93668`,1.1711`},0.32497221950072364`},{{0.12`,36.8`,0.93668`,1.1621000000000001`},0.32497221950072364`},{{0.12`,37.4`,0.94018`,1.1666`},0.3291115989975345`},{{0.12`,37.4`,0.94018`,1.1711`},0.3291115989975345`},{{0.12`,37.4`,0.94018`,1.1621000000000001`},0.3291115989975345`},{{0.12`,37.4`,0.94368`,1.1666`},0.3333383980663593`},{{0.12`,37.4`,0.94368`,1.1711`},0.3333383980663593`},{{0.12`,37.4`,0.94368`,1.1621000000000001`},0.3333383980663593`},{{0.12`,37.4`,0.93668`,1.1666`},0.3249329246099672`},{{0.12`,37.4`,0.93668`,1.1711`},0.3249329246099672`},{{0.12`,37.4`,0.93668`,1.1621000000000001`},0.3249329246099672`},{{0.12`,38.`,0.94018`,1.1666`},0.32907273713575735`},{{0.12`,38.`,0.94018`,1.1711`},0.32907273713575735`},{{0.12`,38.`,0.94018`,1.1621000000000001`},0.32907273713575735`},{{0.12`,38.`,0.94368`,1.1666`},0.33330719195034014`},{{0.12`,38.`,0.94368`,1.1711`},0.33330719195034014`},{{0.12`,38.`,0.94368`,1.1621000000000001`},0.33330719195034014`},{{0.12`,38.`,0.93668`,1.1666`},0.32488646426360385`},{{0.12`,38.`,0.93668`,1.1711`},0.32488646426360385`},{{0.12`,38.`,0.93668`,1.1621000000000001`},0.32488646426360385`},{{0.12`,38.6`,0.94018`,1.1666`},0.32902695091859924`},{{0.12`,38.6`,0.94018`,1.1711`},0.32902695091859924`},{{0.12`,38.6`,0.94018`,1.1621000000000001`},0.32902695091859924`},{{0.12`,38.6`,0.94368`,1.1666`},0.3332688987613852`},{{0.12`,38.6`,0.94368`,1.1711`},0.3332688987613852`},{{0.12`,38.6`,0.94368`,1.1621000000000001`},0.3332688987613852`},{{0.12`,38.6`,0.93668`,1.1666`},0.3248332405383039`},{{0.12`,38.6`,0.93668`,1.1711`},0.3248332405383039`},{{0.12`,38.6`,0.93668`,1.1621000000000001`},0.3248332405383039`},{{0.12`,39.2`,0.94018`,1.1666`},0.3289746231119213`},{{0.12`,39.2`,0.94018`,1.1711`},0.3289746231119213`},{{0.12`,39.2`,0.94018`,1.1621000000000001`},0.3289746231119213`},{{0.12`,39.2`,0.94368`,1.1666`},0.3332239102685473`},{{0.12`,39.2`,0.94368`,1.1711`},0.3332239102685473`},{{0.12`,39.2`,0.94368`,1.1621000000000001`},0.3332239102685473`},{{0.12`,39.2`,0.93668`,1.1666`},0.32477362726625103`},{{0.12`,39.2`,0.93668`,1.1711`},0.32477362726625103`},{{0.12`,39.2`,0.93668`,1.1621000000000001`},0.32477362726625103`},{{0.12`,39.8`,0.94018`,1.1666`},0.3289161097959343`},{{0.12`,39.8`,0.94018`,1.1711`},0.3289161097959343`},{{0.12`,39.8`,0.94018`,1.1621000000000001`},0.3289161097959343`},{{0.12`,39.8`,0.94368`,1.1666`},0.33317259105334757`},{{0.12`,39.8`,0.94368`,1.1711`},0.33317259105334757`},{{0.12`,39.8`,0.94368`,1.1621000000000001`},0.33317259105334757`},{{0.12`,39.8`,0.93668`,1.1666`},0.32470797208886626`},{{0.12`,39.8`,0.93668`,1.1711`},0.32470797208886626`},{{0.12`,39.8`,0.93668`,1.1621000000000001`},0.32470797208886626`},{{0.15`,0.4`,0.94018`,1.1666`},0.16812885430280375`},{{0.15`,0.4`,0.94018`,1.1711`},0.16812885430280375`},{{0.15`,0.4`,0.94018`,1.1621000000000001`},0.16812885430280375`},{{0.15`,0.4`,0.94368`,1.1666`},0.16843514772097895`},{{0.15`,0.4`,0.94368`,1.1711`},0.16843514772097895`},{{0.15`,0.4`,0.94368`,1.1621000000000001`},0.16843514772097895`},{{0.15`,0.4`,0.93668`,1.1666`},0.16782613083358458`},{{0.15`,0.4`,0.93668`,1.1711`},0.16782613083358458`},{{0.15`,0.4`,0.93668`,1.1621000000000001`},0.16782613083358458`},{{0.15`,0.6`,0.94018`,1.1666`},0.17636995643847417`},{{0.15`,0.6`,0.94018`,1.1711`},0.17636995643847417`},{{0.15`,0.6`,0.94018`,1.1621000000000001`},0.17636995643847417`},{{0.15`,0.6`,0.94368`,1.1666`},0.1768170948136239`},{{0.15`,0.6`,0.94368`,1.1711`},0.1768170948136239`},{{0.15`,0.6`,0.94368`,1.1621000000000001`},0.1768170948136239`},{{0.15`,0.6`,0.93668`,1.1666`},0.1759280482101562`},{{0.15`,0.6`,0.93668`,1.1711`},0.1759280482101562`},{{0.15`,0.6`,0.93668`,1.1621000000000001`},0.1759280482101562`},{{0.15`,0.8`,0.94018`,1.1666`},0.1841182674774575`},{{0.15`,0.8`,0.94018`,1.1711`},0.1841182674774575`},{{0.15`,0.8`,0.94018`,1.1621000000000001`},0.1841182674774575`},{{0.15`,0.8`,0.94368`,1.1666`},0.18469879491491625`},{{0.15`,0.8`,0.94368`,1.1711`},0.18469879491491625`},{{0.15`,0.8`,0.94368`,1.1621000000000001`},0.18469879491491625`},{{0.15`,0.8`,0.93668`,1.1666`},0.1835445526716102`},{{0.15`,0.8`,0.93668`,1.1711`},0.1835445526716102`},{{0.15`,0.8`,0.93668`,1.1621000000000001`},0.1835445526716102`},{{0.15`,1.`,0.94018`,1.1666`},0.19141094281616053`},{{0.15`,1.`,0.94018`,1.1711`},0.19141094281616053`},{{0.15`,1.`,0.94018`,1.1621000000000001`},0.19141094281616053`},{{0.15`,1.`,0.94368`,1.1666`},0.19211790635889178`},{{0.15`,1.`,0.94368`,1.1711`},0.19211790635889178`},{{0.15`,1.`,0.94368`,1.1621000000000001`},0.19211790635889178`},{{0.15`,1.`,0.93668`,1.1666`},0.19071230061612596`},{{0.15`,1.`,0.93668`,1.1711`},0.19071230061612596`},{{0.15`,1.`,0.93668`,1.1621000000000001`},0.19071230061612596`},{{0.15`,1.2`,0.94018`,1.1666`},0.19828172476947356`},{{0.15`,1.2`,0.94018`,1.1711`},0.19828172476947356`},{{0.15`,1.2`,0.94018`,1.1621000000000001`},0.19828172476947356`},{{0.15`,1.2`,0.94368`,1.1666`},0.1991086343564691`},{{0.15`,1.2`,0.94368`,1.1711`},0.1991086343564691`},{{0.15`,1.2`,0.94368`,1.1621000000000001`},0.1991086343564691`},{{0.15`,1.2`,0.93668`,1.1666`},0.19746457525076663`},{{0.15`,1.2`,0.93668`,1.1711`},0.19746457525076663`},{{0.15`,1.2`,0.93668`,1.1621000000000001`},0.19746457525076663`},{{0.15`,1.4`,0.94018`,1.1666`},0.20476131105554654`},{{0.15`,1.4`,0.94018`,1.1711`},0.20476131105554654`},{{0.15`,1.4`,0.94018`,1.1621000000000001`},0.20476131105554654`},{{0.15`,1.4`,0.94368`,1.1666`},0.2057021030342341`},{{0.15`,1.4`,0.94368`,1.1711`},0.2057021030342341`},{{0.15`,1.4`,0.94368`,1.1621000000000001`},0.2057021030342341`},{{0.15`,1.4`,0.93668`,1.1666`},0.20383165151297417`},{{0.15`,1.4`,0.93668`,1.1711`},0.20383165151297417`},{{0.15`,1.4`,0.93668`,1.1621000000000001`},0.20383165151297417`},{{0.15`,1.6`,0.94018`,1.1666`},0.21087767782401629`},{{0.15`,1.6`,0.94018`,1.1711`},0.21087767782401629`},{{0.15`,1.6`,0.94018`,1.1621000000000001`},0.21087767782401629`},{{0.15`,1.6`,0.94368`,1.1666`},0.2119266816871595`},{{0.15`,1.6`,0.94368`,1.1711`},0.2119266816871595`},{{0.15`,1.6`,0.94368`,1.1621000000000001`},0.2119266816871595`},{{0.15`,1.6`,0.93668`,1.1666`},0.20984111586959828`},{{0.15`,1.6`,0.93668`,1.1711`},0.20984111586959828`},{{0.15`,1.6`,0.93668`,1.1621000000000001`},0.20984111586959828`},{{0.15`,1.8`,0.94018`,1.1666`},0.21665636349688452`},{{0.15`,1.8`,0.94018`,1.1711`},0.21665636349688452`},{{0.15`,1.8`,0.94018`,1.1621000000000001`},0.21665636349688452`},{{0.15`,1.8`,0.94368`,1.1666`},0.21780827154272026`},{{0.15`,1.8`,0.94368`,1.1711`},0.21780827154272026`},{{0.15`,1.8`,0.94368`,1.1621000000000001`},0.21780827154272026`},{{0.15`,1.8`,0.93668`,1.1666`},0.21551814723327162`},{{0.15`,1.8`,0.93668`,1.1711`},0.21551814723327162`},{{0.15`,1.8`,0.93668`,1.1621000000000001`},0.21551814723327162`},{{0.15`,2.`,0.94018`,1.1666`},0.22212071874115702`},{{0.15`,2.`,0.94018`,1.1711`},0.22212071874115702`},{{0.15`,2.`,0.94018`,1.1621000000000001`},0.22212071874115702`},{{0.15`,2.`,0.94368`,1.1666`},0.2233705583824782`},{{0.15`,2.`,0.94368`,1.1711`},0.2233705583824782`},{{0.15`,2.`,0.94368`,1.1621000000000001`},0.2233705583824782`},{{0.15`,2.`,0.93668`,1.1666`},0.22088576428739262`},{{0.15`,2.`,0.93668`,1.1711`},0.22088576428739262`},{{0.15`,2.`,0.93668`,1.1621000000000001`},0.22088576428739262`},{{0.15`,2.2`,0.94018`,1.1666`},0.2272921270982428`},{{0.15`,2.2`,0.94018`,1.1711`},0.2272921270982428`},{{0.15`,2.2`,0.94018`,1.1621000000000001`},0.2272921270982428`},{{0.15`,2.2`,0.94368`,1.1666`},0.2286352355714536`},{{0.15`,2.2`,0.94368`,1.1711`},0.2286352355714536`},{{0.15`,2.2`,0.94368`,1.1621000000000001`},0.2286352355714536`},{{0.15`,2.2`,0.93668`,1.1666`},0.22596504371871595`},{{0.15`,2.2`,0.93668`,1.1711`},0.22596504371871595`},{{0.15`,2.2`,0.93668`,1.1621000000000001`},0.22596504371871595`},{{0.15`,2.6`,0.94018`,1.1666`},0.23683108006647363`},{{0.15`,2.6`,0.94018`,1.1711`},0.23683108006647363`},{{0.15`,2.6`,0.94018`,1.1621000000000001`},0.23683108006647363`},{{0.15`,2.6`,0.94368`,1.1666`},0.23834786045784895`},{{0.15`,2.6`,0.94368`,1.1711`},0.23834786045784895`},{{0.15`,2.6`,0.94368`,1.1621000000000001`},0.23834786045784895`},{{0.15`,2.6`,0.93668`,1.1666`},0.2353324557012027`},{{0.15`,2.6`,0.93668`,1.1711`},0.2353324557012027`},{{0.15`,2.6`,0.93668`,1.1621000000000001`},0.2353324557012027`},{{0.15`,3.`,0.94018`,1.1666`},0.24541288951255993`},{{0.15`,3.`,0.94018`,1.1711`},0.24541288951255993`},{{0.15`,3.`,0.94018`,1.1621000000000001`},0.24541288951255993`},{{0.15`,3.`,0.94368`,1.1666`},0.24708787676125263`},{{0.15`,3.`,0.94368`,1.1711`},0.24708787676125263`},{{0.15`,3.`,0.94368`,1.1621000000000001`},0.24708787676125263`},{{0.15`,3.`,0.93668`,1.1666`},0.24375800724244887`},{{0.15`,3.`,0.93668`,1.1711`},0.24375800724244887`},{{0.15`,3.`,0.93668`,1.1621000000000001`},0.24375800724244887`},{{0.15`,3.4`,0.94018`,1.1666`},0.25315556072323747`},{{0.15`,3.4`,0.94018`,1.1711`},0.25315556072323747`},{{0.15`,3.4`,0.94018`,1.1621000000000001`},0.25315556072323747`},{{0.15`,3.4`,0.94368`,1.1666`},0.25497504978468344`},{{0.15`,3.4`,0.94368`,1.1711`},0.25497504978468344`},{{0.15`,3.4`,0.94368`,1.1621000000000001`},0.25497504978468344`},{{0.15`,3.4`,0.93668`,1.1666`},0.25135796201895827`},{{0.15`,3.4`,0.93668`,1.1711`},0.25135796201895827`},{{0.15`,3.4`,0.93668`,1.1621000000000001`},0.25135796201895827`},{{0.15`,3.8`,0.94018`,1.1666`},0.26015926688990904`},{{0.15`,3.8`,0.94018`,1.1711`},0.26015926688990904`},{{0.15`,3.8`,0.94018`,1.1621000000000001`},0.26015926688990904`},{{0.15`,3.8`,0.94368`,1.1666`},0.2621110785090818`},{{0.15`,3.8`,0.94368`,1.1711`},0.2621110785090818`},{{0.15`,3.8`,0.94368`,1.1621000000000001`},0.2621110785090818`},{{0.15`,3.8`,0.93668`,1.1666`},0.2582309838903823`},{{0.15`,3.8`,0.93668`,1.1711`},0.2582309838903823`},{{0.15`,3.8`,0.93668`,1.1621000000000001`},0.2582309838903823`},{{0.15`,4.2`,0.94018`,1.1666`},0.26650987320951913`},{{0.15`,4.2`,0.94018`,1.1711`},0.26650987320951913`},{{0.15`,4.2`,0.94018`,1.1621000000000001`},0.26650987320951913`},{{0.15`,4.2`,0.94368`,1.1666`},0.26858315169691666`},{{0.15`,4.2`,0.94368`,1.1711`},0.26858315169691666`},{{0.15`,4.2`,0.94368`,1.1621000000000001`},0.26858315169691666`},{{0.15`,4.2`,0.93668`,1.1666`},0.2644616291279359`},{{0.15`,4.2`,0.93668`,1.1711`},0.2644616291279359`},{{0.15`,4.2`,0.93668`,1.1621000000000001`},0.2644616291279359`},{{0.15`,4.6`,0.94018`,1.1666`},0.27228185297342467`},{{0.15`,4.6`,0.94018`,1.1711`},0.27228185297342467`},{{0.15`,4.6`,0.94018`,1.1621000000000001`},0.27228185297342467`},{{0.15`,4.6`,0.94368`,1.1666`},0.2744668962451723`},{{0.15`,4.6`,0.94368`,1.1711`},0.2744668962451723`},{{0.15`,4.6`,0.94368`,1.1621000000000001`},0.2744668962451723`},{{0.15`,4.6`,0.93668`,1.1666`},0.27012323026998597`},{{0.15`,4.6`,0.93668`,1.1711`},0.27012323026998597`},{{0.15`,4.6`,0.93668`,1.1621000000000001`},0.27012323026998597`},{{0.15`,5.`,0.94018`,1.1666`},0.277539036452875`},{{0.15`,5.`,0.94018`,1.1711`},0.277539036452875`},{{0.15`,5.`,0.94018`,1.1621000000000001`},0.277539036452875`},{{0.15`,5.`,0.94368`,1.1666`},0.27982713886906635`},{{0.15`,5.`,0.94368`,1.1711`},0.27982713886906635`},{{0.15`,5.`,0.94368`,1.1621000000000001`},0.27982713886906635`},{{0.15`,5.`,0.93668`,1.1666`},0.27527863283288345`},{{0.15`,5.`,0.93668`,1.1711`},0.27527863283288345`},{{0.15`,5.`,0.93668`,1.1621000000000001`},0.27527863283288345`},{{0.15`,5.4`,0.94018`,1.1666`},0.282336326259647`},{{0.15`,5.4`,0.94018`,1.1711`},0.282336326259647`},{{0.15`,5.4`,0.94018`,1.1621000000000001`},0.282336326259647`},{{0.15`,5.4`,0.94368`,1.1666`},0.2847196675906562`},{{0.15`,5.4`,0.94368`,1.1711`},0.2847196675906562`},{{0.15`,5.4`,0.94368`,1.1621000000000001`},0.2847196675906562`},{{0.15`,5.4`,0.93668`,1.1666`},0.2799818643781683`},{{0.15`,5.4`,0.93668`,1.1711`},0.2799818643781683`},{{0.15`,5.4`,0.93668`,1.1621000000000001`},0.2799818643781683`},{{0.15`,5.8`,0.94018`,1.1666`},0.2867220246016683`},{{0.15`,5.8`,0.94018`,1.1711`},0.2867220246016683`},{{0.15`,5.8`,0.94018`,1.1621000000000001`},0.2867220246016683`},{{0.15`,5.8`,0.94368`,1.1666`},0.28919355775897976`},{{0.15`,5.8`,0.94368`,1.1711`},0.28919355775897976`},{{0.15`,5.8`,0.94368`,1.1621000000000001`},0.28919355775897976`},{{0.15`,5.8`,0.93668`,1.1666`},0.284280463164906`},{{0.15`,5.8`,0.93668`,1.1711`},0.284280463164906`},{{0.15`,5.8`,0.93668`,1.1621000000000001`},0.284280463164906`},{{0.15`,6.2`,0.94018`,1.1666`},0.29073835525003183`},{{0.15`,6.2`,0.94018`,1.1711`},0.29073835525003183`},{{0.15`,6.2`,0.94018`,1.1621000000000001`},0.29073835525003183`},{{0.15`,6.2`,0.94368`,1.1666`},0.29329171477819527`},{{0.15`,6.2`,0.94368`,1.1711`},0.29329171477819527`},{{0.15`,6.2`,0.94368`,1.1621000000000001`},0.29329171477819527`},{{0.15`,6.2`,0.93668`,1.1666`},0.2882159798945334`},{{0.15`,6.2`,0.93668`,1.1711`},0.2882159798945334`},{{0.15`,6.2`,0.93668`,1.1621000000000001`},0.2882159798945334`},{{0.15`,6.8`,0.94018`,1.1666`},0.29614976480489696`},{{0.15`,6.8`,0.94018`,1.1711`},0.29614976480489696`},{{0.15`,6.8`,0.94018`,1.1621000000000001`},0.29614976480489696`},{{0.15`,6.8`,0.94368`,1.1666`},0.29881522350608775`},{{0.15`,6.8`,0.94368`,1.1711`},0.29881522350608775`},{{0.15`,6.8`,0.94368`,1.1621000000000001`},0.29881522350608775`},{{0.15`,6.8`,0.93668`,1.1666`},0.29351667389554675`},{{0.15`,6.8`,0.93668`,1.1711`},0.29351667389554675`},{{0.15`,6.8`,0.93668`,1.1621000000000001`},0.29351667389554675`},{{0.15`,7.4`,0.94018`,1.1666`},0.300918832918485`},{{0.15`,7.4`,0.94018`,1.1711`},0.300918832918485`},{{0.15`,7.4`,0.94018`,1.1621000000000001`},0.300918832918485`},{{0.15`,7.4`,0.94368`,1.1666`},0.3036851595618175`},{{0.15`,7.4`,0.94368`,1.1711`},0.3036851595618175`},{{0.15`,7.4`,0.94368`,1.1621000000000001`},0.3036851595618175`},{{0.15`,7.4`,0.93668`,1.1666`},0.29818611502052794`},{{0.15`,7.4`,0.93668`,1.1711`},0.29818611502052794`},{{0.15`,7.4`,0.93668`,1.1621000000000001`},0.29818611502052794`},{{0.15`,8.`,0.94018`,1.1666`},0.3051343115471891`},{{0.15`,8.`,0.94018`,1.1711`},0.3051343115471891`},{{0.15`,8.`,0.94018`,1.1621000000000001`},0.3051343115471891`},{{0.15`,8.`,0.94368`,1.1666`},0.3079917418803707`},{{0.15`,8.`,0.94368`,1.1711`},0.3079917418803707`},{{0.15`,8.`,0.94368`,1.1621000000000001`},0.3079917418803707`},{{0.15`,8.`,0.93668`,1.1666`},0.3023116063444334`},{{0.15`,8.`,0.93668`,1.1711`},0.3023116063444334`},{{0.15`,8.`,0.93668`,1.1621000000000001`},0.3023116063444334`},{{0.15`,8.6`,0.94018`,1.1666`},0.3088708871726475`},{{0.15`,8.6`,0.94018`,1.1711`},0.3088708871726475`},{{0.15`,8.6`,0.94018`,1.1621000000000001`},0.3088708871726475`},{{0.15`,8.6`,0.94368`,1.1666`},0.31181089799302647`},{{0.15`,8.6`,0.94368`,1.1711`},0.31181089799302647`},{{0.15`,8.6`,0.94368`,1.1621000000000001`},0.31181089799302647`},{{0.15`,8.6`,0.93668`,1.1666`},0.30596661058420965`},{{0.15`,8.6`,0.93668`,1.1711`},0.30596661058420965`},{{0.15`,8.6`,0.93668`,1.1621000000000001`},0.30596661058420965`},{{0.15`,9.2`,0.94018`,1.1666`},0.3121909013695692`},{{0.15`,9.2`,0.94018`,1.1711`},0.3121909013695692`},{{0.15`,9.2`,0.94018`,1.1621000000000001`},0.3121909013695692`},{{0.15`,9.2`,0.94368`,1.1666`},0.3152060196934019`},{{0.15`,9.2`,0.94368`,1.1711`},0.3152060196934019`},{{0.15`,9.2`,0.94368`,1.1621000000000001`},0.3152060196934019`},{{0.15`,9.2`,0.93668`,1.1666`},0.3092124305261246`},{{0.15`,9.2`,0.93668`,1.1711`},0.3092124305261246`},{{0.15`,9.2`,0.93668`,1.1621000000000001`},0.3092124305261246`},{{0.15`,9.8`,0.94018`,1.1666`},0.31514740914921324`},{{0.15`,9.8`,0.94018`,1.1711`},0.31514740914921324`},{{0.15`,9.8`,0.94018`,1.1621000000000001`},0.31514740914921324`},{{0.15`,9.8`,0.94368`,1.1666`},0.3182310567783776`},{{0.15`,9.8`,0.94368`,1.1711`},0.3182310567783776`},{{0.15`,9.8`,0.94368`,1.1621000000000001`},0.3182310567783776`},{{0.15`,9.8`,0.93668`,1.1666`},0.31210123841719395`},{{0.15`,9.8`,0.93668`,1.1711`},0.31210123841719395`},{{0.15`,9.8`,0.93668`,1.1621000000000001`},0.31210123841719395`},{{0.15`,10.4`,0.94018`,1.1666`},0.317784930960415`},{{0.15`,10.4`,0.94018`,1.1711`},0.317784930960415`},{{0.15`,10.4`,0.94018`,1.1621000000000001`},0.317784930960415`},{{0.15`,10.4`,0.94368`,1.1666`},0.3209312939398135`},{{0.15`,10.4`,0.94368`,1.1711`},0.3209312939398135`},{{0.15`,10.4`,0.94368`,1.1621000000000001`},0.3209312939398135`},{{0.15`,10.4`,0.93668`,1.1666`},0.314676800395917`},{{0.15`,10.4`,0.93668`,1.1711`},0.314676800395917`},{{0.15`,10.4`,0.93668`,1.1621000000000001`},0.314676800395917`},{{0.15`,11.`,0.94018`,1.1666`},0.32014230511323655`},{{0.15`,11.`,0.94018`,1.1711`},0.32014230511323655`},{{0.15`,11.`,0.94018`,1.1621000000000001`},0.32014230511323655`},{{0.15`,11.`,0.94368`,1.1666`},0.32334623160437026`},{{0.15`,11.`,0.94368`,1.1711`},0.32334623160437026`},{{0.15`,11.`,0.94368`,1.1621000000000001`},0.32334623160437026`},{{0.15`,11.`,0.93668`,1.1666`},0.31697730104357247`},{{0.15`,11.`,0.93668`,1.1711`},0.31697730104357247`},{{0.15`,11.`,0.93668`,1.1621000000000001`},0.31697730104357247`},{{0.15`,11.6`,0.94018`,1.1666`},0.3222524611522318`},{{0.15`,11.6`,0.94018`,1.1711`},0.3222524611522318`},{{0.15`,11.6`,0.94018`,1.1621000000000001`},0.3222524611522318`},{{0.15`,11.6`,0.94368`,1.1666`},0.32550936585832074`},{{0.15`,11.6`,0.94368`,1.1711`},0.32550936585832074`},{{0.15`,11.6`,0.94368`,1.1621000000000001`},0.32550936585832074`},{{0.15`,11.6`,0.93668`,1.1666`},0.3190351107618728`},{{0.15`,11.6`,0.93668`,1.1711`},0.3190351107618728`},{{0.15`,11.6`,0.93668`,1.1621000000000001`},0.3190351107618728`},{{0.15`,12.2`,0.94018`,1.1666`},0.32414305813694144`},{{0.15`,12.2`,0.94018`,1.1711`},0.32414305813694144`},{{0.15`,12.2`,0.94018`,1.1621000000000001`},0.32414305813694144`},{{0.15`,12.2`,0.94368`,1.1666`},0.3274488510448878`},{{0.15`,12.2`,0.94368`,1.1711`},0.3274488510448878`},{{0.15`,12.2`,0.94368`,1.1621000000000001`},0.3274488510448878`},{{0.15`,12.2`,0.93668`,1.1666`},0.32087739983389907`},{{0.15`,12.2`,0.93668`,1.1711`},0.32087739983389907`},{{0.15`,12.2`,0.93668`,1.1621000000000001`},0.32087739983389907`},{{0.15`,12.8`,0.94018`,1.1666`},0.3258394737070843`},{{0.15`,12.8`,0.94018`,1.1711`},0.3258394737070843`},{{0.15`,12.8`,0.94018`,1.1621000000000001`},0.3258394737070843`},{{0.15`,12.8`,0.94368`,1.1666`},0.32919049563618663`},{{0.15`,12.8`,0.94368`,1.1711`},0.32919049563618663`},{{0.15`,12.8`,0.94368`,1.1621000000000001`},0.32919049563618663`},{{0.15`,12.8`,0.93668`,1.1666`},0.3225291204379429`},{{0.15`,12.8`,0.93668`,1.1711`},0.3225291204379429`},{{0.15`,12.8`,0.93668`,1.1621000000000001`},0.3225291204379429`},{{0.15`,13.4`,0.94018`,1.1666`},0.32736265520675195`},{{0.15`,13.4`,0.94018`,1.1711`},0.32736265520675195`},{{0.15`,13.4`,0.94018`,1.1621000000000001`},0.32736265520675195`},{{0.15`,13.4`,0.94368`,1.1666`},0.33075561783530233`},{{0.15`,13.4`,0.94368`,1.1711`},0.33075561783530233`},{{0.15`,13.4`,0.94368`,1.1621000000000001`},0.33075561783530233`},{{0.15`,13.4`,0.93668`,1.1666`},0.3240108540844194`},{{0.15`,13.4`,0.93668`,1.1711`},0.3240108540844194`},{{0.15`,13.4`,0.93668`,1.1621000000000001`},0.3240108540844194`},{{0.15`,14.`,0.94018`,1.1666`},0.3287315651184962`},{{0.15`,14.`,0.94018`,1.1711`},0.3287315651184962`},{{0.15`,14.`,0.94018`,1.1621000000000001`},0.3287315651184962`},{{0.15`,14.`,0.94368`,1.1666`},0.33216351172271225`},{{0.15`,14.`,0.94368`,1.1711`},0.33216351172271225`},{{0.15`,14.`,0.94368`,1.1621000000000001`},0.33216351172271225`},{{0.15`,14.`,0.93668`,1.1666`},0.3253412357740754`},{{0.15`,14.`,0.93668`,1.1711`},0.3253412357740754`},{{0.15`,14.`,0.93668`,1.1621000000000001`},0.3253412357740754`},{{0.15`,14.6`,0.94018`,1.1666`},0.329962551335373`},{{0.15`,14.6`,0.94018`,1.1711`},0.329962551335373`},{{0.15`,14.6`,0.94018`,1.1621000000000001`},0.329962551335373`},{{0.15`,14.6`,0.94368`,1.1666`},0.3334308118047579`},{{0.15`,14.6`,0.94368`,1.1711`},0.3334308118047579`},{{0.15`,14.6`,0.94368`,1.1621000000000001`},0.3334308118047579`},{{0.15`,14.6`,0.93668`,1.1666`},0.3265363305325493`},{{0.15`,14.6`,0.93668`,1.1711`},0.3265363305325493`},{{0.15`,14.6`,0.93668`,1.1621000000000001`},0.3265363305325493`},{{0.15`,15.2`,0.94018`,1.1666`},0.3310692672004181`},{{0.15`,15.2`,0.94018`,1.1711`},0.3310692672004181`},{{0.15`,15.2`,0.94018`,1.1621000000000001`},0.3310692672004181`},{{0.15`,15.2`,0.94368`,1.1666`},0.33457142441301885`},{{0.15`,15.2`,0.94368`,1.1711`},0.33457142441301885`},{{0.15`,15.2`,0.94368`,1.1621000000000001`},0.33457142441301885`},{{0.15`,15.2`,0.93668`,1.1666`},0.3276095422396202`},{{0.15`,15.2`,0.93668`,1.1711`},0.3276095422396202`},{{0.15`,15.2`,0.93668`,1.1621000000000001`},0.3276095422396202`},{{0.15`,15.8`,0.94018`,1.1666`},0.33206488120451566`},{{0.15`,15.8`,0.94018`,1.1711`},0.33206488120451566`},{{0.15`,15.8`,0.94018`,1.1621000000000001`},0.33206488120451566`},{{0.15`,15.8`,0.94368`,1.1666`},0.33559874712621063`},{{0.15`,15.8`,0.94368`,1.1711`},0.33559874712621063`},{{0.15`,15.8`,0.94368`,1.1621000000000001`},0.33559874712621063`},{{0.15`,15.8`,0.93668`,1.1666`},0.32857381295104054`},{{0.15`,15.8`,0.93668`,1.1711`},0.32857381295104054`},{{0.15`,15.8`,0.93668`,1.1621000000000001`},0.32857381295104054`},{{0.15`,16.4`,0.94018`,1.1666`},0.3329604229494733`},{{0.15`,16.4`,0.94018`,1.1711`},0.3329604229494733`},{{0.15`,16.4`,0.94018`,1.1621000000000001`},0.3329604229494733`},{{0.15`,16.4`,0.94368`,1.1666`},0.33652400672705457`},{{0.15`,16.4`,0.94368`,1.1711`},0.33652400672705457`},{{0.15`,16.4`,0.94368`,1.1621000000000001`},0.33652400672705457`},{{0.15`,16.4`,0.93668`,1.1666`},0.32943997772422967`},{{0.15`,16.4`,0.93668`,1.1711`},0.32943997772422967`},{{0.15`,16.4`,0.93668`,1.1621000000000001`},0.32943997772422967`},{{0.15`,17.`,0.94018`,1.1666`},0.333765422855345`},{{0.15`,17.`,0.94018`,1.1711`},0.333765422855345`},{{0.15`,17.`,0.94018`,1.1621000000000001`},0.333765422855345`},{{0.15`,17.`,0.94368`,1.1666`},0.3373569090914149`},{{0.15`,17.`,0.94368`,1.1711`},0.3373569090914149`},{{0.15`,17.`,0.94368`,1.1621000000000001`},0.3373569090914149`},{{0.15`,17.`,0.93668`,1.1666`},0.3302173939641659`},{{0.15`,17.`,0.93668`,1.1711`},0.3302173939641659`},{{0.15`,17.`,0.93668`,1.1621000000000001`},0.3302173939641659`},{{0.15`,17.6`,0.94018`,1.1666`},0.3344886801725548`},{{0.15`,17.6`,0.94018`,1.1711`},0.3344886801725548`},{{0.15`,17.6`,0.94018`,1.1621000000000001`},0.3344886801725548`},{{0.15`,17.6`,0.94368`,1.1666`},0.3381064168136242`},{{0.15`,17.6`,0.94368`,1.1711`},0.3381064168136242`},{{0.15`,17.6`,0.94368`,1.1621000000000001`},0.3381064168136242`},{{0.15`,17.6`,0.93668`,1.1666`},0.3309146994888032`},{{0.15`,17.6`,0.93668`,1.1711`},0.3309146994888032`},{{0.15`,17.6`,0.93668`,1.1621000000000001`},0.3309146994888032`},{{0.15`,18.2`,0.94018`,1.1666`},0.33513843812573957`},{{0.15`,18.2`,0.94018`,1.1711`},0.33513843812573957`},{{0.15`,18.2`,0.94018`,1.1621000000000001`},0.33513843812573957`},{{0.15`,18.2`,0.94368`,1.1666`},0.33878090541175643`},{{0.15`,18.2`,0.94368`,1.1711`},0.33878090541175643`},{{0.15`,18.2`,0.94368`,1.1621000000000001`},0.33878090541175643`},{{0.15`,18.2`,0.93668`,1.1666`},0.33154000670377115`},{{0.15`,18.2`,0.93668`,1.1711`},0.33154000670377115`},{{0.15`,18.2`,0.93668`,1.1621000000000001`},0.33154000670377115`},{{0.15`,18.8`,0.94018`,1.1666`},0.33572084008279424`},{{0.15`,18.8`,0.94018`,1.1711`},0.33572084008279424`},{{0.15`,18.8`,0.94018`,1.1621000000000001`},0.33572084008279424`},{{0.15`,18.8`,0.94368`,1.1666`},0.3393866542647536`},{{0.15`,18.8`,0.94368`,1.1711`},0.3393866542647536`},{{0.15`,18.8`,0.94368`,1.1621000000000001`},0.3393866542647536`},{{0.15`,18.8`,0.93668`,1.1666`},0.3320993226336379`},{{0.15`,18.8`,0.93668`,1.1711`},0.3320993226336379`},{{0.15`,18.8`,0.93668`,1.1621000000000001`},0.3320993226336379`},{{0.15`,19.4`,0.94018`,1.1666`},0.3362419743093508`},{{0.15`,19.4`,0.94018`,1.1711`},0.3362419743093508`},{{0.15`,19.4`,0.94018`,1.1621000000000001`},0.3362419743093508`},{{0.15`,19.4`,0.94368`,1.1666`},0.33992986404185055`},{{0.15`,19.4`,0.94368`,1.1711`},0.33992986404185055`},{{0.15`,19.4`,0.94368`,1.1621000000000001`},0.33992986404185055`},{{0.15`,19.4`,0.93668`,1.1666`},0.33259862844509747`},{{0.15`,19.4`,0.93668`,1.1711`},0.33259862844509747`},{{0.15`,19.4`,0.93668`,1.1621000000000001`},0.33259862844509747`},{{0.15`,20.`,0.94018`,1.1666`},0.3367078218310993`},{{0.15`,20.`,0.94018`,1.1711`},0.3367078218310993`},{{0.15`,20.`,0.94018`,1.1621000000000001`},0.3367078218310993`},{{0.15`,20.`,0.94368`,1.1666`},0.34041662080109925`},{{0.15`,20.`,0.94368`,1.1711`},0.34041662080109925`},{{0.15`,20.`,0.94368`,1.1621000000000001`},0.34041662080109925`},{{0.15`,20.`,0.93668`,1.1666`},0.3330438046001048`},{{0.15`,20.`,0.93668`,1.1711`},0.3330438046001048`},{{0.15`,20.`,0.93668`,1.1621000000000001`},0.3330438046001048`},{{0.15`,20.6`,0.94018`,1.1666`},0.337123269567574`},{{0.15`,20.6`,0.94018`,1.1711`},0.337123269567574`},{{0.15`,20.6`,0.94018`,1.1621000000000001`},0.337123269567574`},{{0.15`,20.6`,0.94368`,1.1666`},0.3408518980647263`},{{0.15`,20.6`,0.94368`,1.1711`},0.3408518980647263`},{{0.15`,20.6`,0.94368`,1.1621000000000001`},0.3408518980647263`},{{0.15`,20.6`,0.93668`,1.1666`},0.3334396444251561`},{{0.15`,20.6`,0.93668`,1.1711`},0.3334396444251561`},{{0.15`,20.6`,0.93668`,1.1621000000000001`},0.3334396444251561`},{{0.15`,21.2`,0.94018`,1.1666`},0.3374923598356473`},{{0.15`,21.2`,0.94018`,1.1711`},0.3374923598356473`},{{0.15`,21.2`,0.94018`,1.1621000000000001`},0.3374923598356473`},{{0.15`,21.2`,0.94368`,1.1666`},0.3412398239681591`},{{0.15`,21.2`,0.94368`,1.1711`},0.3412398239681591`},{{0.15`,21.2`,0.94368`,1.1621000000000001`},0.3412398239681591`},{{0.15`,21.2`,0.93668`,1.1666`},0.3337901092180472`},{{0.15`,21.2`,0.93668`,1.1711`},0.3337901092180472`},{{0.15`,21.2`,0.93668`,1.1621000000000001`},0.3337901092180472`},{{0.15`,21.8`,0.94018`,1.1666`},0.33781954585685264`},{{0.15`,21.8`,0.94018`,1.1711`},0.33781954585685264`},{{0.15`,21.8`,0.94018`,1.1621000000000001`},0.33781954585685264`},{{0.15`,21.8`,0.94368`,1.1666`},0.3415849277937274`},{{0.15`,21.8`,0.94368`,1.1711`},0.3415849277937274`},{{0.15`,21.8`,0.94368`,1.1621000000000001`},0.3415849277937274`},{{0.15`,21.8`,0.93668`,1.1666`},0.3340995736675748`},{{0.15`,21.8`,0.93668`,1.1711`},0.3340995736675748`},{{0.15`,21.8`,0.93668`,1.1621000000000001`},0.3340995736675748`},{{0.15`,22.4`,0.94018`,1.1666`},0.3381083366661914`},{{0.15`,22.4`,0.94018`,1.1711`},0.3381083366661914`},{{0.15`,22.4`,0.94018`,1.1621000000000001`},0.3381083366661914`},{{0.15`,22.4`,0.94368`,1.1666`},0.3418907862156036`},{{0.15`,22.4`,0.94368`,1.1711`},0.3418907862156036`},{{0.15`,22.4`,0.94368`,1.1621000000000001`},0.3418907862156036`},{{0.15`,22.4`,0.93668`,1.1666`},0.3343714853442274`},{{0.15`,22.4`,0.93668`,1.1711`},0.3343714853442274`},{{0.15`,22.4`,0.93668`,1.1621000000000001`},0.3343714853442274`},{{0.15`,23.`,0.94018`,1.1666`},0.3383620264037596`},{{0.15`,23.`,0.94018`,1.1711`},0.3383620264037596`},{{0.15`,23.`,0.94018`,1.1621000000000001`},0.3383620264037596`},{{0.15`,23.`,0.94368`,1.1666`},0.3421607552904546`},{{0.15`,23.`,0.94368`,1.1711`},0.3421607552904546`},{{0.15`,23.`,0.94368`,1.1621000000000001`},0.3421607552904546`},{{0.15`,23.`,0.93668`,1.1666`},0.33460907494623543`},{{0.15`,23.`,0.93668`,1.1711`},0.33460907494623543`},{{0.15`,23.`,0.93668`,1.1621000000000001`},0.33460907494623543`},{{0.15`,23.6`,0.94018`,1.1666`},0.3385836074524179`},{{0.15`,23.6`,0.94018`,1.1711`},0.3385836074524179`},{{0.15`,23.6`,0.94018`,1.1621000000000001`},0.3385836074524179`},{{0.15`,23.6`,0.94368`,1.1666`},0.3423978835899444`},{{0.15`,23.6`,0.94368`,1.1711`},0.3423978835899444`},{{0.15`,23.6`,0.94368`,1.1621000000000001`},0.3423978835899444`},{{0.15`,23.6`,0.93668`,1.1666`},0.33481527934429706`},{{0.15`,23.6`,0.93668`,1.1711`},0.33481527934429706`},{{0.15`,23.6`,0.93668`,1.1621000000000001`},0.33481527934429706`},{{0.15`,24.2`,0.94018`,1.1666`},0.3387748376215026`},{{0.15`,24.2`,0.94018`,1.1711`},0.3387748376215026`},{{0.15`,24.2`,0.94018`,1.1621000000000001`},0.3387748376215026`},{{0.15`,24.2`,0.94368`,1.1666`},0.34260398448529744`},{{0.15`,24.2`,0.94368`,1.1711`},0.34260398448529744`},{{0.15`,24.2`,0.94368`,1.1621000000000001`},0.34260398448529744`},{{0.15`,24.2`,0.93668`,1.1666`},0.33499180192379513`},{{0.15`,24.2`,0.93668`,1.1711`},0.33499180192379513`},{{0.15`,24.2`,0.93668`,1.1621000000000001`},0.33499180192379513`},{{0.15`,24.8`,0.94018`,1.1666`},0.33893927944116753`},{{0.15`,24.8`,0.94018`,1.1711`},0.33893927944116753`},{{0.15`,24.8`,0.94018`,1.1621000000000001`},0.33893927944116753`},{{0.15`,24.8`,0.94368`,1.1666`},0.34278266530540047`},{{0.15`,24.8`,0.94368`,1.1711`},0.34278266530540047`},{{0.15`,24.8`,0.94368`,1.1621000000000001`},0.34278266530540047`},{{0.15`,24.8`,0.93668`,1.1666`},0.3351421602838172`},{{0.15`,24.8`,0.93668`,1.1711`},0.3351421602838172`},{{0.15`,24.8`,0.93668`,1.1621000000000001`},0.3351421602838172`},{{0.15`,25.4`,0.94018`,1.1666`},0.33907878702130106`},{{0.15`,25.4`,0.94018`,1.1711`},0.33907878702130106`},{{0.15`,25.4`,0.94018`,1.1621000000000001`},0.33907878702130106`},{{0.15`,25.4`,0.94368`,1.1666`},0.3429358230897283`},{{0.15`,25.4`,0.94368`,1.1711`},0.3429358230897283`},{{0.15`,25.4`,0.94368`,1.1621000000000001`},0.3429358230897283`},{{0.15`,25.4`,0.93668`,1.1666`},0.33526816637439094`},{{0.15`,25.4`,0.93668`,1.1711`},0.33526816637439094`},{{0.15`,25.4`,0.93668`,1.1621000000000001`},0.33526816637439094`},{{0.15`,26.`,0.94018`,1.1666`},0.33919538745291977`},{{0.15`,26.`,0.94018`,1.1711`},0.33919538745291977`},{{0.15`,26.`,0.94018`,1.1621000000000001`},0.33919538745291977`},{{0.15`,26.`,0.94368`,1.1666`},0.34306552424994885`},{{0.15`,26.`,0.94368`,1.1711`},0.34306552424994885`},{{0.15`,26.`,0.94368`,1.1621000000000001`},0.34306552424994885`},{{0.15`,26.`,0.93668`,1.1666`},0.335371808429317`},{{0.15`,26.`,0.93668`,1.1711`},0.335371808429317`},{{0.15`,26.`,0.93668`,1.1621000000000001`},0.335371808429317`},{{0.15`,26.6`,0.94018`,1.1666`},0.33929091636891684`},{{0.15`,26.6`,0.94018`,1.1711`},0.33929091636891684`},{{0.15`,26.6`,0.94018`,1.1621000000000001`},0.33929091636891684`},{{0.15`,26.6`,0.94368`,1.1666`},0.34317364074501777`},{{0.15`,26.6`,0.94368`,1.1711`},0.34317364074501777`},{{0.15`,26.6`,0.94368`,1.1621000000000001`},0.34317364074501777`},{{0.15`,26.6`,0.93668`,1.1666`},0.33545488618041325`},{{0.15`,26.6`,0.93668`,1.1711`},0.33545488618041325`},{{0.15`,26.6`,0.93668`,1.1621000000000001`},0.33545488618041325`},{{0.15`,27.2`,0.94018`,1.1666`},0.3393662782488597`},{{0.15`,27.2`,0.94018`,1.1711`},0.3393662782488597`},{{0.15`,27.2`,0.94018`,1.1621000000000001`},0.3393662782488597`},{{0.15`,27.2`,0.94368`,1.1666`},0.343261113918722`},{{0.15`,27.2`,0.94368`,1.1711`},0.343261113918722`},{{0.15`,27.2`,0.94368`,1.1621000000000001`},0.343261113918722`},{{0.15`,27.2`,0.93668`,1.1666`},0.33551826814580404`},{{0.15`,27.2`,0.93668`,1.1711`},0.33551826814580404`},{{0.15`,27.2`,0.93668`,1.1621000000000001`},0.33551826814580404`},{{0.15`,27.8`,0.94018`,1.1666`},0.33942391530555244`},{{0.15`,27.8`,0.94018`,1.1711`},0.33942391530555244`},{{0.15`,27.8`,0.94018`,1.1621000000000001`},0.33942391530555244`},{{0.15`,27.8`,0.94368`,1.1666`},0.3433304154376025`},{{0.15`,27.8`,0.94368`,1.1711`},0.3433304154376025`},{{0.15`,27.8`,0.94368`,1.1621000000000001`},0.3433304154376025`},{{0.15`,27.8`,0.93668`,1.1666`},0.33556436671841594`},{{0.15`,27.8`,0.93668`,1.1711`},0.33556436671841594`},{{0.15`,27.8`,0.93668`,1.1621000000000001`},0.33556436671841594`},{{0.15`,28.4`,0.94018`,1.1666`},0.3394649903734614`},{{0.15`,28.4`,0.94018`,1.1711`},0.3394649903734614`},{{0.15`,28.4`,0.94018`,1.1621000000000001`},0.3394649903734614`},{{0.15`,28.4`,0.94368`,1.1666`},0.3433827350866673`},{{0.15`,28.4`,0.94368`,1.1711`},0.3433827350866673`},{{0.15`,28.4`,0.94368`,1.1621000000000001`},0.3433827350866673`},{{0.15`,28.4`,0.93668`,1.1666`},0.3355943183614958`},{{0.15`,28.4`,0.93668`,1.1711`},0.3355943183614958`},{{0.15`,28.4`,0.93668`,1.1621000000000001`},0.3355943183614958`},{{0.15`,29.`,0.94018`,1.1666`},0.33949079651727354`},{{0.15`,29.`,0.94018`,1.1711`},0.33949079651727354`},{{0.15`,29.`,0.94018`,1.1621000000000001`},0.33949079651727354`},{{0.15`,29.`,0.94368`,1.1666`},0.3434193918356955`},{{0.15`,29.`,0.94368`,1.1711`},0.3434193918356955`},{{0.15`,29.`,0.94368`,1.1621000000000001`},0.3434193918356955`},{{0.15`,29.`,0.93668`,1.1666`},0.33560939052585514`},{{0.15`,29.`,0.93668`,1.1711`},0.33560939052585514`},{{0.15`,29.`,0.93668`,1.1621000000000001`},0.33560939052585514`},{{0.15`,29.6`,0.94018`,1.1666`},0.33950214398277484`},{{0.15`,29.6`,0.94018`,1.1711`},0.33950214398277484`},{{0.15`,29.6`,0.94018`,1.1621000000000001`},0.33950214398277484`},{{0.15`,29.6`,0.94368`,1.1666`},0.3434412211715659`},{{0.15`,29.6`,0.94368`,1.1711`},0.3434412211715659`},{{0.15`,29.6`,0.94368`,1.1621000000000001`},0.3434412211715659`},{{0.15`,29.6`,0.93668`,1.1666`},0.3356103687829843`},{{0.15`,29.6`,0.93668`,1.1711`},0.3356103687829843`},{{0.15`,29.6`,0.93668`,1.1621000000000001`},0.3356103687829843`},{{0.15`,30.2`,0.94018`,1.1666`},0.33950043628178916`},{{0.15`,30.2`,0.94018`,1.1711`},0.33950043628178916`},{{0.15`,30.2`,0.94018`,1.1621000000000001`},0.33950043628178916`},{{0.15`,30.2`,0.94368`,1.1666`},0.34344965045887577`},{{0.15`,30.2`,0.94368`,1.1711`},0.34344965045887577`},{{0.15`,30.2`,0.94368`,1.1621000000000001`},0.34344965045887577`},{{0.15`,30.2`,0.93668`,1.1666`},0.3355986326775982`},{{0.15`,30.2`,0.93668`,1.1711`},0.3355986326775982`},{{0.15`,30.2`,0.93668`,1.1621000000000001`},0.3355986326775982`},{{0.15`,30.8`,0.94018`,1.1666`},0.33948660287744503`},{{0.15`,30.8`,0.94018`,1.1711`},0.33948660287744503`},{{0.15`,30.8`,0.94018`,1.1621000000000001`},0.33948660287744503`},{{0.15`,30.8`,0.94368`,1.1666`},0.3434456282481775`},{{0.15`,30.8`,0.94368`,1.1711`},0.3434456282481775`},{{0.15`,30.8`,0.94368`,1.1621000000000001`},0.3434456282481775`},{{0.15`,30.8`,0.93668`,1.1666`},0.3355750929342399`},{{0.15`,30.8`,0.93668`,1.1711`},0.3355750929342399`},{{0.15`,30.8`,0.93668`,1.1621000000000001`},0.3355750929342399`},{{0.15`,31.4`,0.94018`,1.1666`},0.3394615548047223`},{{0.15`,31.4`,0.94018`,1.1711`},0.3394615548047223`},{{0.15`,31.4`,0.94018`,1.1621000000000001`},0.3394615548047223`},{{0.15`,31.4`,0.94368`,1.1666`},0.3434300847150421`},{{0.15`,31.4`,0.94368`,1.1711`},0.3434300847150421`},{{0.15`,31.4`,0.94368`,1.1621000000000001`},0.3434300847150421`},{{0.15`,31.4`,0.93668`,1.1666`},0.33554064165597414`},{{0.15`,31.4`,0.93668`,1.1711`},0.33554064165597414`},{{0.15`,31.4`,0.93668`,1.1621000000000001`},0.33554064165597414`},{{0.15`,32.`,0.94018`,1.1666`},0.3394259724566769`},{{0.15`,32.`,0.94018`,1.1711`},0.3394259724566769`},{{0.15`,32.`,0.94018`,1.1621000000000001`},0.3394259724566769`},{{0.15`,32.`,0.94368`,1.1666`},0.34340371809022746`},{{0.15`,32.`,0.94368`,1.1711`},0.34340371809022746`},{{0.15`,32.`,0.94368`,1.1621000000000001`},0.34340371809022746`},{{0.15`,32.`,0.93668`,1.1666`},0.3354959417493571`},{{0.15`,32.`,0.93668`,1.1711`},0.3354959417493571`},{{0.15`,32.`,0.93668`,1.1621000000000001`},0.3354959417493571`},{{0.15`,32.6`,0.94018`,1.1666`},0.3393806999065325`},{{0.15`,32.6`,0.94018`,1.1711`},0.3393806999065325`},{{0.15`,32.6`,0.94018`,1.1621000000000001`},0.3393806999065325`},{{0.15`,32.6`,0.94368`,1.1666`},0.34336739122422766`},{{0.15`,32.6`,0.94368`,1.1711`},0.34336739122422766`},{{0.15`,32.6`,0.94368`,1.1621000000000001`},0.34336739122422766`},{{0.15`,32.6`,0.93668`,1.1666`},0.33544181852005045`},{{0.15`,32.6`,0.93668`,1.1711`},0.33544181852005045`},{{0.15`,32.6`,0.93668`,1.1621000000000001`},0.33544181852005045`},{{0.15`,33.2`,0.94018`,1.1666`},0.3393264560747739`},{{0.15`,33.2`,0.94018`,1.1711`},0.3393264560747739`},{{0.15`,33.2`,0.94018`,1.1621000000000001`},0.3393264560747739`},{{0.15`,33.2`,0.94368`,1.1666`},0.34332183707092045`},{{0.15`,33.2`,0.94368`,1.1711`},0.34332183707092045`},{{0.15`,33.2`,0.94368`,1.1621000000000001`},0.34332183707092045`},{{0.15`,33.2`,0.93668`,1.1666`},0.3353789770692781`},{{0.15`,33.2`,0.93668`,1.1711`},0.3353789770692781`},{{0.15`,33.2`,0.93668`,1.1621000000000001`},0.3353789770692781`},{{0.15`,33.8`,0.94018`,1.1666`},0.33926389079963354`},{{0.15`,33.8`,0.94018`,1.1711`},0.33926389079963354`},{{0.15`,33.8`,0.94018`,1.1621000000000001`},0.33926389079963354`},{{0.15`,33.8`,0.94368`,1.1666`},0.3432677199054288`},{{0.15`,33.8`,0.94368`,1.1711`},0.3432677199054288`},{{0.15`,33.8`,0.94368`,1.1621000000000001`},0.3432677199054288`},{{0.15`,33.8`,0.93668`,1.1666`},0.3353080529505565`},{{0.15`,33.8`,0.93668`,1.1711`},0.3353080529505565`},{{0.15`,33.8`,0.93668`,1.1621000000000001`},0.3353080529505565`},{{0.15`,34.4`,0.94018`,1.1666`},0.3391936051112185`},{{0.15`,34.4`,0.94018`,1.1711`},0.3391936051112185`},{{0.15`,34.4`,0.94018`,1.1621000000000001`},0.3391936051112185`},{{0.15`,34.4`,0.94368`,1.1666`},0.34320565420703997`},{{0.15`,34.4`,0.94368`,1.1711`},0.34320565420703997`},{{0.15`,34.4`,0.94368`,1.1621000000000001`},0.34320565420703997`},{{0.15`,34.4`,0.93668`,1.1666`},0.3352296338841052`},{{0.15`,34.4`,0.93668`,1.1711`},0.3352296338841052`},{{0.15`,34.4`,0.93668`,1.1621000000000001`},0.3352296338841052`},{{0.15`,35.`,0.94018`,1.1666`},0.339116165901189`},{{0.15`,35.`,0.94018`,1.1711`},0.339116165901189`},{{0.15`,35.`,0.94018`,1.1621000000000001`},0.339116165901189`},{{0.15`,35.`,0.94368`,1.1666`},0.3431362197765653`},{{0.15`,35.`,0.94368`,1.1711`},0.3431362197765653`},{{0.15`,35.`,0.94368`,1.1621000000000001`},0.3431362197765653`},{{0.15`,35.`,0.93668`,1.1666`},0.33514427396554547`},{{0.15`,35.`,0.93668`,1.1711`},0.33514427396554547`},{{0.15`,35.`,0.93668`,1.1621000000000001`},0.33514427396554547`},{{0.15`,35.6`,0.94018`,1.1666`},0.33903164898637006`},{{0.15`,35.6`,0.94018`,1.1711`},0.33903164898637006`},{{0.15`,35.6`,0.94018`,1.1621000000000001`},0.33903164898637006`},{{0.15`,35.6`,0.94368`,1.1666`},0.3430595062572918`},{{0.15`,35.6`,0.94368`,1.1711`},0.3430595062572918`},{{0.15`,35.6`,0.94368`,1.1621000000000001`},0.3430595062572918`},{{0.15`,35.6`,0.93668`,1.1666`},0.33505203566799846`},{{0.15`,35.6`,0.93668`,1.1711`},0.33505203566799846`},{{0.15`,35.6`,0.93668`,1.1621000000000001`},0.33505203566799846`},{{0.15`,36.2`,0.94018`,1.1666`},0.3389411092374981`},{{0.15`,36.2`,0.94018`,1.1711`},0.3389411092374981`},{{0.15`,36.2`,0.94018`,1.1621000000000001`},0.3389411092374981`},{{0.15`,36.2`,0.94368`,1.1666`},0.3429765771965607`},{{0.15`,36.2`,0.94368`,1.1711`},0.3429765771965607`},{{0.15`,36.2`,0.94368`,1.1621000000000001`},0.3429765771965607`},{{0.15`,36.2`,0.93668`,1.1666`},0.3349539647851345`},{{0.15`,36.2`,0.93668`,1.1711`},0.3349539647851345`},{{0.15`,36.2`,0.93668`,1.1621000000000001`},0.3349539647851345`},{{0.15`,36.8`,0.94018`,1.1666`},0.33884476307692457`},{{0.15`,36.8`,0.94018`,1.1711`},0.33884476307692457`},{{0.15`,36.8`,0.94018`,1.1621000000000001`},0.33884476307692457`},{{0.15`,36.8`,0.94368`,1.1666`},0.34288766012359573`},{{0.15`,36.8`,0.94368`,1.1711`},0.34288766012359573`},{{0.15`,36.8`,0.94368`,1.1621000000000001`},0.34288766012359573`},{{0.15`,36.8`,0.93668`,1.1666`},0.3348502669356495`},{{0.15`,36.8`,0.93668`,1.1711`},0.3348502669356495`},{{0.15`,36.8`,0.93668`,1.1621000000000001`},0.3348502669356495`},{{0.15`,37.4`,0.94018`,1.1666`},0.338743011034654`},{{0.15`,37.4`,0.94018`,1.1711`},0.338743011034654`},{{0.15`,37.4`,0.94018`,1.1621000000000001`},0.338743011034654`},{{0.15`,37.4`,0.94368`,1.1666`},0.34279316533781257`},{{0.15`,37.4`,0.94368`,1.1711`},0.34279316533781257`},{{0.15`,37.4`,0.94368`,1.1621000000000001`},0.34279316533781257`},{{0.15`,37.4`,0.93668`,1.1666`},0.3347413329762132`},{{0.15`,37.4`,0.93668`,1.1711`},0.3347413329762132`},{{0.15`,37.4`,0.93668`,1.1621000000000001`},0.3347413329762132`},{{0.15`,38.`,0.94018`,1.1666`},0.338636224299682`},{{0.15`,38.`,0.94018`,1.1711`},0.338636224299682`},{{0.15`,38.`,0.94018`,1.1621000000000001`},0.338636224299682`},{{0.15`,38.`,0.94368`,1.1666`},0.3426934732001656`},{{0.15`,38.`,0.94368`,1.1711`},0.3426934732001656`},{{0.15`,38.`,0.94368`,1.1621000000000001`},0.3426934732001656`},{{0.15`,38.`,0.93668`,1.1666`},0.3346275250124365`},{{0.15`,38.`,0.93668`,1.1711`},0.3346275250124365`},{{0.15`,38.`,0.93668`,1.1621000000000001`},0.3346275250124365`},{{0.15`,38.6`,0.94018`,1.1666`},0.338524747055038`},{{0.15`,38.6`,0.94018`,1.1711`},0.338524747055038`},{{0.15`,38.6`,0.94018`,1.1621000000000001`},0.338524747055038`},{{0.15`,38.6`,0.94368`,1.1666`},0.3425889365127352`},{{0.15`,38.6`,0.94368`,1.1711`},0.3425889365127352`},{{0.15`,38.6`,0.94368`,1.1621000000000001`},0.3425889365127352`},{{0.15`,38.6`,0.93668`,1.1666`},0.33450917869000857`},{{0.15`,38.6`,0.93668`,1.1711`},0.33450917869000857`},{{0.15`,38.6`,0.93668`,1.1621000000000001`},0.33450917869000857`},{{0.15`,39.2`,0.94018`,1.1666`},0.33840889859076057`},{{0.15`,39.2`,0.94018`,1.1711`},0.33840889859076057`},{{0.15`,39.2`,0.94018`,1.1621000000000001`},0.33840889859076057`},{{0.15`,39.2`,0.94368`,1.1666`},0.3424798826726938`},{{0.15`,39.2`,0.94368`,1.1711`},0.3424798826726938`},{{0.15`,39.2`,0.94368`,1.1621000000000001`},0.3424798826726938`},{{0.15`,39.2`,0.93668`,1.1666`},0.3343866052673189`},{{0.15`,39.2`,0.93668`,1.1711`},0.3343866052673189`},{{0.15`,39.2`,0.93668`,1.1621000000000001`},0.3343866052673189`},{{0.15`,39.8`,0.94018`,1.1666`},0.3382889752166351`},{{0.15`,39.8`,0.94018`,1.1711`},0.3382889752166351`},{{0.15`,39.8`,0.94018`,1.1621000000000001`},0.3382889752166351`},{{0.15`,39.8`,0.94368`,1.1666`},0.3423666156228323`},{{0.15`,39.8`,0.94368`,1.1711`},0.3423666156228323`},{{0.15`,39.8`,0.94368`,1.1621000000000001`},0.3423666156228323`},{{0.15`,39.8`,0.93668`,1.1666`},0.3342600934910115`},{{0.15`,39.8`,0.93668`,1.1711`},0.3342600934910115`},{{0.15`,39.8`,0.93668`,1.1621000000000001`},0.3342600934910115`},{{0.18`,0.4`,0.94018`,1.1666`},0.19731546348051873`},{{0.18`,0.4`,0.94018`,1.1711`},0.19731546348051873`},{{0.18`,0.4`,0.94018`,1.1621000000000001`},0.19731546348051873`},{{0.18`,0.4`,0.94368`,1.1666`},0.19761550970661507`},{{0.18`,0.4`,0.94368`,1.1711`},0.19761550970661507`},{{0.18`,0.4`,0.94368`,1.1621000000000001`},0.19761550970661507`},{{0.18`,0.4`,0.93668`,1.1666`},0.1970189630722318`},{{0.18`,0.4`,0.93668`,1.1711`},0.1970189630722318`},{{0.18`,0.4`,0.93668`,1.1621000000000001`},0.1970189630722318`},{{0.18`,0.6`,0.94018`,1.1666`},0.20516110966576143`},{{0.18`,0.6`,0.94018`,1.1711`},0.20516110966576143`},{{0.18`,0.6`,0.94018`,1.1621000000000001`},0.20516110966576143`},{{0.18`,0.6`,0.94368`,1.1666`},0.20559888679821056`},{{0.18`,0.6`,0.94368`,1.1711`},0.20559888679821056`},{{0.18`,0.6`,0.94368`,1.1621000000000001`},0.20559888679821056`},{{0.18`,0.6`,0.93668`,1.1666`},0.20472852549095738`},{{0.18`,0.6`,0.93668`,1.1711`},0.20472852549095738`},{{0.18`,0.6`,0.93668`,1.1621000000000001`},0.20472852549095738`},{{0.18`,0.8`,0.94018`,1.1666`},0.2125216686228849`},{{0.18`,0.8`,0.94018`,1.1711`},0.2125216686228849`},{{0.18`,0.8`,0.94018`,1.1621000000000001`},0.2125216686228849`},{{0.18`,0.8`,0.94368`,1.1666`},0.21308973981517595`},{{0.18`,0.8`,0.94368`,1.1711`},0.21308973981517595`},{{0.18`,0.8`,0.94368`,1.1621000000000001`},0.21308973981517595`},{{0.18`,0.8`,0.93668`,1.1666`},0.21196035938186242`},{{0.18`,0.8`,0.93668`,1.1711`},0.21196035938186242`},{{0.18`,0.8`,0.93668`,1.1621000000000001`},0.21196035938186242`},{{0.18`,1.`,0.94018`,1.1666`},0.21943437563180526`},{{0.18`,1.`,0.94018`,1.1711`},0.21943437563180526`},{{0.18`,1.`,0.94018`,1.1621000000000001`},0.21943437563180526`},{{0.18`,1.`,0.94368`,1.1666`},0.2201258145597767`},{{0.18`,1.`,0.94368`,1.1711`},0.2201258145597767`},{{0.18`,1.`,0.94368`,1.1621000000000001`},0.2201258145597767`},{{0.18`,1.`,0.93668`,1.1666`},0.2187511935850691`},{{0.18`,1.`,0.93668`,1.1711`},0.2187511935850691`},{{0.18`,1.`,0.93668`,1.1621000000000001`},0.2187511935850691`},{{0.18`,1.2`,0.94018`,1.1666`},0.22593300343456965`},{{0.18`,1.2`,0.94018`,1.1711`},0.22593300343456965`},{{0.18`,1.2`,0.94018`,1.1621000000000001`},0.22593300343456965`},{{0.18`,1.2`,0.94368`,1.1666`},0.22674135297152703`},{{0.18`,1.2`,0.94368`,1.1711`},0.22674135297152703`},{{0.18`,1.2`,0.94368`,1.1621000000000001`},0.22674135297152703`},{{0.18`,1.2`,0.93668`,1.1666`},0.22513433555701146`},{{0.18`,1.2`,0.93668`,1.1711`},0.22513433555701146`},{{0.18`,1.2`,0.93668`,1.1621000000000001`},0.22513433555701146`},{{0.18`,1.4`,0.94018`,1.1666`},0.2320482395932617`},{{0.18`,1.4`,0.94018`,1.1711`},0.2320482395932617`},{{0.18`,1.4`,0.94018`,1.1621000000000001`},0.2320482395932617`},{{0.18`,1.4`,0.94368`,1.1666`},0.2329674742201615`},{{0.18`,1.4`,0.94368`,1.1711`},0.2329674742201615`},{{0.18`,1.4`,0.94368`,1.1621000000000001`},0.2329674742201615`},{{0.18`,1.4`,0.93668`,1.1666`},0.2311400449862767`},{{0.18`,1.4`,0.93668`,1.1711`},0.2311400449862767`},{{0.18`,1.4`,0.93668`,1.1621000000000001`},0.2311400449862767`},{{0.18`,1.6`,0.94018`,1.1666`},0.23780801693533615`},{{0.18`,1.6`,0.94018`,1.1711`},0.23780801693533615`},{{0.18`,1.6`,0.94018`,1.1621000000000001`},0.23780801693533615`},{{0.18`,1.6`,0.94368`,1.1666`},0.23883250853117857`},{{0.18`,1.6`,0.94368`,1.1711`},0.23883250853117857`},{{0.18`,1.6`,0.94368`,1.1621000000000001`},0.23883250853117857`},{{0.18`,1.6`,0.93668`,1.1666`},0.23679586085606702`},{{0.18`,1.6`,0.93668`,1.1711`},0.23679586085606702`},{{0.18`,1.6`,0.93668`,1.1621000000000001`},0.23679586085606702`},{{0.18`,1.8`,0.94018`,1.1666`},0.2432378035995241`},{{0.18`,1.8`,0.94018`,1.1711`},0.2432378035995241`},{{0.18`,1.8`,0.94018`,1.1621000000000001`},0.2432378035995241`},{{0.18`,1.8`,0.94368`,1.1666`},0.24436229028897574`},{{0.18`,1.8`,0.94368`,1.1711`},0.24436229028897574`},{{0.18`,1.8`,0.94368`,1.1621000000000001`},0.24436229028897574`},{{0.18`,1.8`,0.93668`,1.1666`},0.24212688843342736`},{{0.18`,1.8`,0.93668`,1.1711`},0.24212688843342736`},{{0.18`,1.8`,0.93668`,1.1621000000000001`},0.24212688843342736`},{{0.18`,2.`,0.94018`,1.1666`},0.24836085820254555`},{{0.18`,2.`,0.94018`,1.1711`},0.24836085820254555`},{{0.18`,2.`,0.94018`,1.1621000000000001`},0.24836085820254555`},{{0.18`,2.`,0.94368`,1.1666`},0.24958041596787595`},{{0.18`,2.`,0.94368`,1.1711`},0.24958041596787595`},{{0.18`,2.`,0.94368`,1.1621000000000001`},0.24958041596787595`},{{0.18`,2.`,0.93668`,1.1666`},0.24715605167455307`},{{0.18`,2.`,0.93668`,1.1711`},0.24715605167455307`},{{0.18`,2.`,0.93668`,1.1621000000000001`},0.24715605167455307`},{{0.18`,2.2`,0.94018`,1.1666`},0.25319845481786424`},{{0.18`,2.2`,0.94018`,1.1711`},0.25319845481786424`},{{0.18`,2.2`,0.94018`,1.1621000000000001`},0.25319845481786424`},{{0.18`,2.2`,0.94368`,1.1666`},0.25450847161024415`},{{0.18`,2.2`,0.94368`,1.1711`},0.25450847161024415`},{{0.18`,2.2`,0.94368`,1.1621000000000001`},0.25450847161024415`},{{0.18`,2.2`,0.93668`,1.1666`},0.2519043157087825`},{{0.18`,2.2`,0.93668`,1.1711`},0.2519043157087825`},{{0.18`,2.2`,0.93668`,1.1621000000000001`},0.2519043157087825`},{{0.18`,2.6`,0.94018`,1.1666`},0.26209173678427555`},{{0.18`,2.6`,0.94018`,1.1711`},0.26209173678427555`},{{0.18`,2.6`,0.94018`,1.1621000000000001`},0.26209173678427555`},{{0.18`,2.6`,0.94368`,1.1666`},0.26356996296785346`},{{0.18`,2.6`,0.94368`,1.1711`},0.26356996296785346`},{{0.18`,2.6`,0.94368`,1.1621000000000001`},0.26356996296785346`},{{0.18`,2.6`,0.93668`,1.1666`},0.2606314931414595`},{{0.18`,2.6`,0.93668`,1.1711`},0.2606314931414595`},{{0.18`,2.6`,0.93668`,1.1621000000000001`},0.2606314931414595`},{{0.18`,3.`,0.94018`,1.1666`},0.2700562026877475`},{{0.18`,3.`,0.94018`,1.1711`},0.2700562026877475`},{{0.18`,3.`,0.94018`,1.1621000000000001`},0.2700562026877475`},{{0.18`,3.`,0.94368`,1.1666`},0.2716873896730706`},{{0.18`,3.`,0.94368`,1.1711`},0.2716873896730706`},{{0.18`,3.`,0.94368`,1.1621000000000001`},0.2716873896730706`},{{0.18`,3.`,0.93668`,1.1666`},0.26844492250822394`},{{0.18`,3.`,0.93668`,1.1711`},0.26844492250822394`},{{0.18`,3.`,0.93668`,1.1621000000000001`},0.26844492250822394`},{{0.18`,3.4`,0.94018`,1.1666`},0.2772086619614231`},{{0.18`,3.4`,0.94018`,1.1711`},0.2772086619614231`},{{0.18`,3.4`,0.94018`,1.1621000000000001`},0.2772086619614231`},{{0.18`,3.4`,0.94368`,1.1666`},0.2789793244407279`},{{0.18`,3.4`,0.94368`,1.1711`},0.2789793244407279`},{{0.18`,3.4`,0.94368`,1.1621000000000001`},0.2789793244407279`},{{0.18`,3.4`,0.93668`,1.1666`},0.27545966855387055`},{{0.18`,3.4`,0.93668`,1.1711`},0.27545966855387055`},{{0.18`,3.4`,0.93668`,1.1621000000000001`},0.27545966855387055`},{{0.18`,3.8`,0.94018`,1.1666`},0.2836480394038619`},{{0.18`,3.8`,0.94018`,1.1711`},0.2836480394038619`},{{0.18`,3.8`,0.94018`,1.1621000000000001`},0.2836480394038619`},{{0.18`,3.8`,0.94368`,1.1666`},0.28554621712507117`},{{0.18`,3.8`,0.94368`,1.1711`},0.28554621712507117`},{{0.18`,3.8`,0.94368`,1.1621000000000001`},0.28554621712507117`},{{0.18`,3.8`,0.93668`,1.1666`},0.2817731475940909`},{{0.18`,3.8`,0.93668`,1.1711`},0.2817731475940909`},{{0.18`,3.8`,0.93668`,1.1621000000000001`},0.2817731475940909`},{{0.18`,4.2`,0.94018`,1.1666`},0.28945894136411077`},{{0.18`,4.2`,0.94018`,1.1711`},0.28945894136411077`},{{0.18`,4.2`,0.94018`,1.1621000000000001`},0.28945894136411077`},{{0.18`,4.2`,0.94368`,1.1666`},0.29147399449243744`},{{0.18`,4.2`,0.94368`,1.1711`},0.29147399449243744`},{{0.18`,4.2`,0.94368`,1.1621000000000001`},0.29147399449243744`},{{0.18`,4.2`,0.93668`,1.1666`},0.28746866050545217`},{{0.18`,4.2`,0.93668`,1.1711`},0.28746866050545217`},{{0.18`,4.2`,0.93668`,1.1621000000000001`},0.28746866050545217`},{{0.18`,4.6`,0.94018`,1.1666`},0.2947146046144941`},{{0.18`,4.6`,0.94018`,1.1711`},0.2947146046144941`},{{0.18`,4.6`,0.94018`,1.1621000000000001`},0.2947146046144941`},{{0.18`,4.6`,0.94368`,1.1666`},0.29683704124626814`},{{0.18`,4.6`,0.94368`,1.1711`},0.29683704124626814`},{{0.18`,4.6`,0.94368`,1.1621000000000001`},0.29683704124626814`},{{0.18`,4.6`,0.93668`,1.1666`},0.2926183083608196`},{{0.18`,4.6`,0.93668`,1.1711`},0.2926183083608196`},{{0.18`,4.6`,0.93668`,1.1621000000000001`},0.2926183083608196`},{{0.18`,5.`,0.94018`,1.1666`},0.2994776573709673`},{{0.18`,5.`,0.94018`,1.1711`},0.2994776573709673`},{{0.18`,5.`,0.94018`,1.1621000000000001`},0.2994776573709673`},{{0.18`,5.`,0.94368`,1.1666`},0.3016989762599358`},{{0.18`,5.`,0.94368`,1.1711`},0.3016989762599358`},{{0.18`,5.`,0.94368`,1.1621000000000001`},0.3016989762599358`},{{0.18`,5.`,0.93668`,1.1666`},0.29728374084482423`},{{0.18`,5.`,0.93668`,1.1711`},0.29728374084482423`},{{0.18`,5.`,0.93668`,1.1621000000000001`},0.29728374084482423`},{{0.18`,5.4`,0.94018`,1.1666`},0.30380182894718605`},{{0.18`,5.4`,0.94018`,1.1711`},0.30380182894718605`},{{0.18`,5.4`,0.94018`,1.1621000000000001`},0.30380182894718605`},{{0.18`,5.4`,0.94368`,1.1666`},0.30611440651334243`},{{0.18`,5.4`,0.94368`,1.1711`},0.30611440651334243`},{{0.18`,5.4`,0.94368`,1.1621000000000001`},0.30611440651334243`},{{0.18`,5.4`,0.93668`,1.1666`},0.3015178200640285`},{{0.18`,5.4`,0.93668`,1.1711`},0.3015178200640285`},{{0.18`,5.4`,0.93668`,1.1621000000000001`},0.3015178200640285`},{{0.18`,5.8`,0.94018`,1.1666`},0.30773430473980246`},{{0.18`,5.8`,0.94018`,1.1711`},0.30773430473980246`},{{0.18`,5.8`,0.94018`,1.1621000000000001`},0.30773430473980246`},{{0.18`,5.8`,0.94368`,1.1666`},0.31013128237226206`},{{0.18`,5.8`,0.94368`,1.1711`},0.31013128237226206`},{{0.18`,5.8`,0.94368`,1.1621000000000001`},0.31013128237226206`},{{0.18`,5.8`,0.93668`,1.1666`},0.3053669752956895`},{{0.18`,5.8`,0.93668`,1.1711`},0.3053669752956895`},{{0.18`,5.8`,0.93668`,1.1621000000000001`},0.3053669752956895`},{{0.18`,6.2`,0.94018`,1.1666`},0.3113162453976819`},{{0.18`,6.2`,0.94018`,1.1711`},0.3113162453976819`},{{0.18`,6.2`,0.94018`,1.1621000000000001`},0.3113162453976819`},{{0.18`,6.2`,0.94368`,1.1666`},0.3137914380887505`},{{0.18`,6.2`,0.94368`,1.1711`},0.3137914380887505`},{{0.18`,6.2`,0.94368`,1.1621000000000001`},0.3137914380887505`},{{0.18`,6.2`,0.93668`,1.1666`},0.30887170169448774`},{{0.18`,6.2`,0.93668`,1.1711`},0.30887170169448774`},{{0.18`,6.2`,0.93668`,1.1621000000000001`},0.30887170169448774`},{{0.18`,6.8`,0.94018`,1.1666`},0.31610919715770497`},{{0.18`,6.8`,0.94018`,1.1711`},0.31610919715770497`},{{0.18`,6.8`,0.94018`,1.1621000000000001`},0.31610919715770497`},{{0.18`,6.8`,0.94368`,1.1666`},0.31869139395639723`},{{0.18`,6.8`,0.94368`,1.1711`},0.31869139395639723`},{{0.18`,6.8`,0.94368`,1.1621000000000001`},0.31869139395639723`},{{0.18`,6.8`,0.93668`,1.1666`},0.3135590190909143`},{{0.18`,6.8`,0.93668`,1.1711`},0.3135590190909143`},{{0.18`,6.8`,0.93668`,1.1621000000000001`},0.3135590190909143`},{{0.18`,7.4`,0.94018`,1.1666`},0.32029675120962414`},{{0.18`,7.4`,0.94018`,1.1711`},0.32029675120962414`},{{0.18`,7.4`,0.94018`,1.1621000000000001`},0.32029675120962414`},{{0.18`,7.4`,0.94368`,1.1666`},0.3229750813254095`},{{0.18`,7.4`,0.94368`,1.1711`},0.3229750813254095`},{{0.18`,7.4`,0.94368`,1.1621000000000001`},0.3229750813254095`},{{0.18`,7.4`,0.93668`,1.1666`},0.3176516703248421`},{{0.18`,7.4`,0.93668`,1.1711`},0.3176516703248421`},{{0.18`,7.4`,0.93668`,1.1621000000000001`},0.3176516703248421`},{{0.18`,8.`,0.94018`,1.1666`},0.32396476544664354`},{{0.18`,8.`,0.94018`,1.1711`},0.32396476544664354`},{{0.18`,8.`,0.94018`,1.1621000000000001`},0.32396476544664354`},{{0.18`,8.`,0.94368`,1.1666`},0.3267298000059284`},{{0.18`,8.`,0.94368`,1.1711`},0.3267298000059284`},{{0.18`,8.`,0.94368`,1.1621000000000001`},0.3267298000059284`},{{0.18`,8.`,0.93668`,1.1666`},0.321234089406743`},{{0.18`,8.`,0.93668`,1.1711`},0.321234089406743`},{{0.18`,8.`,0.93668`,1.1621000000000001`},0.321234089406743`},{{0.18`,8.6`,0.94018`,1.1666`},0.3271852710647624`},{{0.18`,8.6`,0.94018`,1.1711`},0.3271852710647624`},{{0.18`,8.6`,0.94018`,1.1621000000000001`},0.3271852710647624`},{{0.18`,8.6`,0.94368`,1.1666`},0.330028796259307`},{{0.18`,8.6`,0.94368`,1.1711`},0.330028796259307`},{{0.18`,8.6`,0.94368`,1.1621000000000001`},0.330028796259307`},{{0.18`,8.6`,0.93668`,1.1666`},0.3243771077684283`},{{0.18`,8.6`,0.93668`,1.1711`},0.3243771077684283`},{{0.18`,8.6`,0.93668`,1.1621000000000001`},0.3243771077684283`},{{0.18`,9.2`,0.94018`,1.1666`},0.3300181980408383`},{{0.18`,9.2`,0.94018`,1.1711`},0.3300181980408383`},{{0.18`,9.2`,0.94018`,1.1621000000000001`},0.3300181980408383`},{{0.18`,9.2`,0.94368`,1.1666`},0.33293302791483076`},{{0.18`,9.2`,0.94368`,1.1711`},0.33293302791483076`},{{0.18`,9.2`,0.94368`,1.1621000000000001`},0.33293302791483076`},{{0.18`,9.2`,0.93668`,1.1666`},0.3271396406386827`},{{0.18`,9.2`,0.93668`,1.1711`},0.3271396406386827`},{{0.18`,9.2`,0.93668`,1.1621000000000001`},0.3271396406386827`},{{0.18`,9.8`,0.94018`,1.1666`},0.3325144010972582`},{{0.18`,9.8`,0.94018`,1.1711`},0.3325144010972582`},{{0.18`,9.8`,0.94018`,1.1621000000000001`},0.3325144010972582`},{{0.18`,9.8`,0.94368`,1.1666`},0.3354942225088103`},{{0.18`,9.8`,0.94368`,1.1711`},0.3354942225088103`},{{0.18`,9.8`,0.94368`,1.1621000000000001`},0.3354942225088103`},{{0.18`,9.8`,0.93668`,1.1666`},0.32957168109329305`},{{0.18`,9.8`,0.93668`,1.1711`},0.32957168109329305`},{{0.18`,9.8`,0.93668`,1.1621000000000001`},0.32957168109329305`},{{0.18`,10.4`,0.94018`,1.1666`},0.33471641460256174`},{{0.18`,10.4`,0.94018`,1.1711`},0.33471641460256174`},{{0.18`,10.4`,0.94018`,1.1621000000000001`},0.33471641460256174`},{{0.18`,10.4`,0.94368`,1.1666`},0.3377556584059755`},{{0.18`,10.4`,0.94368`,1.1711`},0.3377556584059755`},{{0.18`,10.4`,0.94368`,1.1621000000000001`},0.3377556584059755`},{{0.18`,10.4`,0.93668`,1.1666`},0.3317150292170911`},{{0.18`,10.4`,0.93668`,1.1711`},0.3317150292170911`},{{0.18`,10.4`,0.93668`,1.1621000000000001`},0.3317150292170911`},{{0.18`,11.`,0.94018`,1.1666`},0.3366612422872853`},{{0.18`,11.`,0.94018`,1.1711`},0.3366612422872853`},{{0.18`,11.`,0.94018`,1.1621000000000001`},0.3366612422872853`},{{0.18`,11.`,0.94368`,1.1666`},0.33975498295597184`},{{0.18`,11.`,0.94368`,1.1711`},0.33975498295597184`},{{0.18`,11.`,0.94368`,1.1621000000000001`},0.33975498295597184`},{{0.18`,11.`,0.93668`,1.1666`},0.33360605330760607`},{{0.18`,11.`,0.93668`,1.1711`},0.33360605330760607`},{{0.18`,11.`,0.93668`,1.1621000000000001`},0.33360605330760607`},{{0.18`,11.6`,0.94018`,1.1666`},0.338380158168887`},{{0.18`,11.6`,0.94018`,1.1711`},0.338380158168887`},{{0.18`,11.6`,0.94018`,1.1621000000000001`},0.338380158168887`},{{0.18`,11.6`,0.94368`,1.1666`},0.3415240196002059`},{{0.18`,11.6`,0.94368`,1.1711`},0.3415240196002059`},{{0.18`,11.6`,0.94368`,1.1621000000000001`},0.3415240196002059`},{{0.18`,11.6`,0.93668`,1.1666`},0.33527548516788863`},{{0.18`,11.6`,0.93668`,1.1711`},0.33527548516788863`},{{0.18`,11.6`,0.93668`,1.1621000000000001`},0.33527548516788863`},{{0.18`,12.2`,0.94018`,1.1666`},0.33989932263215106`},{{0.18`,12.2`,0.94018`,1.1711`},0.33989932263215106`},{{0.18`,12.2`,0.94018`,1.1621000000000001`},0.33989932263215106`},{{0.18`,12.2`,0.94368`,1.1666`},0.34308940802900745`},{{0.18`,12.2`,0.94368`,1.1711`},0.34308940802900745`},{{0.18`,12.2`,0.94368`,1.1621000000000001`},0.34308940802900745`},{{0.18`,12.2`,0.93668`,1.1666`},0.33674901221709835`},{{0.18`,12.2`,0.93668`,1.1711`},0.33674901221709835`},{{0.18`,12.2`,0.93668`,1.1621000000000001`},0.33674901221709835`},{{0.18`,12.8`,0.94018`,1.1666`},0.3412427133024129`},{{0.18`,12.8`,0.94018`,1.1711`},0.3412427133024129`},{{0.18`,12.8`,0.94018`,1.1621000000000001`},0.3412427133024129`},{{0.18`,12.8`,0.94368`,1.1666`},0.3444755425093241`},{{0.18`,12.8`,0.94368`,1.1711`},0.3444755425093241`},{{0.18`,12.8`,0.94368`,1.1621000000000001`},0.3444755425093241`},{{0.18`,12.8`,0.93668`,1.1666`},0.3380502006578735`},{{0.18`,12.8`,0.93668`,1.1711`},0.3380502006578735`},{{0.18`,12.8`,0.93668`,1.1621000000000001`},0.3380502006578735`},{{0.18`,13.4`,0.94018`,1.1666`},0.3424300343916017`},{{0.18`,13.4`,0.94018`,1.1711`},0.3424300343916017`},{{0.18`,13.4`,0.94018`,1.1621000000000001`},0.3424300343916017`},{{0.18`,13.4`,0.94368`,1.1666`},0.3457024847374456`},{{0.18`,13.4`,0.94368`,1.1711`},0.3457024847374456`},{{0.18`,13.4`,0.94368`,1.1621000000000001`},0.3457024847374456`},{{0.18`,13.4`,0.93668`,1.1666`},0.33919840209814867`},{{0.18`,13.4`,0.93668`,1.1711`},0.33919840209814867`},{{0.18`,13.4`,0.93668`,1.1621000000000001`},0.33919840209814867`},{{0.18`,14.`,0.94018`,1.1666`},0.34347907982029463`},{{0.18`,14.`,0.94018`,1.1711`},0.34347907982029463`},{{0.18`,14.`,0.94018`,1.1621000000000001`},0.34347907982029463`},{{0.18`,14.`,0.94368`,1.1666`},0.34678834820414356`},{{0.18`,14.`,0.94368`,1.1711`},0.34678834820414356`},{{0.18`,14.`,0.94368`,1.1621000000000001`},0.34678834820414356`},{{0.18`,14.`,0.93668`,1.1666`},0.3402110948889888`},{{0.18`,14.`,0.93668`,1.1711`},0.3402110948889888`},{{0.18`,14.`,0.93668`,1.1621000000000001`},0.3402110948889888`},{{0.18`,14.6`,0.94018`,1.1666`},0.3444051404288381`},{{0.18`,14.6`,0.94018`,1.1711`},0.3444051404288381`},{{0.18`,14.6`,0.94018`,1.1621000000000001`},0.3444051404288381`},{{0.18`,14.6`,0.94368`,1.1666`},0.3477486993274267`},{{0.18`,14.6`,0.94368`,1.1711`},0.3477486993274267`},{{0.18`,14.6`,0.94368`,1.1621000000000001`},0.3477486993274267`},{{0.18`,14.6`,0.93668`,1.1666`},0.34110329793045324`},{{0.18`,14.6`,0.93668`,1.1711`},0.34110329793045324`},{{0.18`,14.6`,0.93668`,1.1621000000000001`},0.34110329793045324`},{{0.18`,15.2`,0.94018`,1.1666`},0.3452209275736111`},{{0.18`,15.2`,0.94018`,1.1711`},0.3452209275736111`},{{0.18`,15.2`,0.94018`,1.1621000000000001`},0.3452209275736111`},{{0.18`,15.2`,0.94368`,1.1666`},0.34859648976666235`},{{0.18`,15.2`,0.94368`,1.1711`},0.34859648976666235`},{{0.18`,15.2`,0.94368`,1.1621000000000001`},0.34859648976666235`},{{0.18`,15.2`,0.93668`,1.1666`},0.34188748356575627`},{{0.18`,15.2`,0.93668`,1.1711`},0.34188748356575627`},{{0.18`,15.2`,0.93668`,1.1621000000000001`},0.34188748356575627`},{{0.18`,15.8`,0.94018`,1.1666`},0.3459386907005325`},{{0.18`,15.8`,0.94018`,1.1711`},0.3459386907005325`},{{0.18`,15.8`,0.94018`,1.1621000000000001`},0.3459386907005325`},{{0.18`,15.8`,0.94368`,1.1666`},0.34934419379105697`},{{0.18`,15.8`,0.94368`,1.1711`},0.34934419379105697`},{{0.18`,15.8`,0.94368`,1.1621000000000001`},0.34934419379105697`},{{0.18`,15.8`,0.93668`,1.1666`},0.34257568572411207`},{{0.18`,15.8`,0.93668`,1.1711`},0.34257568572411207`},{{0.18`,15.8`,0.93668`,1.1621000000000001`},0.34257568572411207`},{{0.18`,16.4`,0.94018`,1.1666`},0.3465686489519248`},{{0.18`,16.4`,0.94018`,1.1711`},0.3465686489519248`},{{0.18`,16.4`,0.94018`,1.1621000000000001`},0.3465686489519248`},{{0.18`,16.4`,0.94368`,1.1666`},0.350002215044328`},{{0.18`,16.4`,0.94368`,1.1711`},0.350002215044328`},{{0.18`,16.4`,0.94368`,1.1621000000000001`},0.350002215044328`},{{0.18`,16.4`,0.93668`,1.1666`},0.3431779348093163`},{{0.18`,16.4`,0.93668`,1.1711`},0.3431779348093163`},{{0.18`,16.4`,0.93668`,1.1621000000000001`},0.3431779348093163`},{{0.18`,17.`,0.94018`,1.1666`},0.34711959406483217`},{{0.18`,17.`,0.94018`,1.1711`},0.34711959406483217`},{{0.18`,17.`,0.94018`,1.1621000000000001`},0.34711959406483217`},{{0.18`,17.`,0.94368`,1.1666`},0.3505795137405767`},{{0.18`,17.`,0.94368`,1.1711`},0.3505795137405767`},{{0.18`,17.`,0.94368`,1.1621000000000001`},0.3505795137405767`},{{0.18`,17.`,0.93668`,1.1666`},0.3437028563177965`},{{0.18`,17.`,0.93668`,1.1711`},0.3437028563177965`},{{0.18`,17.`,0.93668`,1.1621000000000001`},0.3437028563177965`},{{0.18`,17.6`,0.94018`,1.1666`},0.3475996207617308`},{{0.18`,17.6`,0.94018`,1.1711`},0.3475996207617308`},{{0.18`,17.6`,0.94018`,1.1621000000000001`},0.3475996207617308`},{{0.18`,17.6`,0.94368`,1.1666`},0.3510843405578859`},{{0.18`,17.6`,0.94368`,1.1711`},0.3510843405578859`},{{0.18`,17.6`,0.94368`,1.1621000000000001`},0.3510843405578859`},{{0.18`,17.6`,0.93668`,1.1666`},0.344158394662402`},{{0.18`,17.6`,0.93668`,1.1711`},0.344158394662402`},{{0.18`,17.6`,0.93668`,1.1621000000000001`},0.344158394662402`},{{0.18`,18.2`,0.94018`,1.1666`},0.3480163629597131`},{{0.18`,18.2`,0.94018`,1.1711`},0.3480163629597131`},{{0.18`,18.2`,0.94018`,1.1621000000000001`},0.3480163629597131`},{{0.18`,18.2`,0.94368`,1.1666`},0.35152445562865753`},{{0.18`,18.2`,0.94368`,1.1711`},0.35152445562865753`},{{0.18`,18.2`,0.94368`,1.1621000000000001`},0.35152445562865753`},{{0.18`,18.2`,0.93668`,1.1666`},0.34455205732613636`},{{0.18`,18.2`,0.93668`,1.1711`},0.34455205732613636`},{{0.18`,18.2`,0.93668`,1.1621000000000001`},0.34455205732613636`},{{0.18`,18.8`,0.94018`,1.1666`},0.3483753253435853`},{{0.18`,18.8`,0.94018`,1.1711`},0.3483753253435853`},{{0.18`,18.8`,0.94018`,1.1621000000000001`},0.3483753253435853`},{{0.18`,18.8`,0.94368`,1.1666`},0.3519054948680786`},{{0.18`,18.8`,0.94368`,1.1711`},0.3519054948680786`},{{0.18`,18.8`,0.94368`,1.1621000000000001`},0.3519054948680786`},{{0.18`,18.8`,0.93668`,1.1666`},0.3448892199987497`},{{0.18`,18.8`,0.93668`,1.1711`},0.3448892199987497`},{{0.18`,18.8`,0.93668`,1.1621000000000001`},0.3448892199987497`},{{0.18`,19.4`,0.94018`,1.1666`},0.34868208397055894`},{{0.18`,19.4`,0.94018`,1.1711`},0.34868208397055894`},{{0.18`,19.4`,0.94018`,1.1621000000000001`},0.34868208397055894`},{{0.18`,19.4`,0.94368`,1.1666`},0.35223313721249655`},{{0.18`,19.4`,0.94368`,1.1711`},0.35223313721249655`},{{0.18`,19.4`,0.94368`,1.1621000000000001`},0.35223313721249655`},{{0.18`,19.4`,0.93668`,1.1666`},0.34517535714211633`},{{0.18`,19.4`,0.93668`,1.1711`},0.34517535714211633`},{{0.18`,19.4`,0.93668`,1.1621000000000001`},0.34517535714211633`},{{0.18`,20.`,0.94018`,1.1666`},0.3489420872519267`},{{0.18`,20.`,0.94018`,1.1711`},0.3489420872519267`},{{0.18`,20.`,0.94018`,1.1621000000000001`},0.3489420872519267`},{{0.18`,20.`,0.94368`,1.1666`},0.35251293032162884`},{{0.18`,20.`,0.94368`,1.1711`},0.35251293032162884`},{{0.18`,20.`,0.94368`,1.1621000000000001`},0.35251293032162884`},{{0.18`,20.`,0.93668`,1.1666`},0.34541581889843764`},{{0.18`,20.`,0.93668`,1.1711`},0.34541581889843764`},{{0.18`,20.`,0.93668`,1.1621000000000001`},0.34541581889843764`},{{0.18`,20.6`,0.94018`,1.1666`},0.34915975240151176`},{{0.18`,20.6`,0.94018`,1.1711`},0.34915975240151176`},{{0.18`,20.6`,0.94018`,1.1621000000000001`},0.34915975240151176`},{{0.18`,20.6`,0.94368`,1.1666`},0.35274937721429284`},{{0.18`,20.6`,0.94368`,1.1711`},0.35274937721429284`},{{0.18`,20.6`,0.94368`,1.1621000000000001`},0.35274937721429284`},{{0.18`,20.6`,0.93668`,1.1666`},0.3456149378710126`},{{0.18`,20.6`,0.93668`,1.1711`},0.3456149378710126`},{{0.18`,20.6`,0.93668`,1.1621000000000001`},0.3456149378710126`},{{0.18`,21.2`,0.94018`,1.1666`},0.34933870991162347`},{{0.18`,21.2`,0.94018`,1.1711`},0.34933870991162347`},{{0.18`,21.2`,0.94018`,1.1621000000000001`},0.34933870991162347`},{{0.18`,21.2`,0.94368`,1.1666`},0.35294618753269635`},{{0.18`,21.2`,0.94368`,1.1711`},0.35294618753269635`},{{0.18`,21.2`,0.94368`,1.1621000000000001`},0.35294618753269635`},{{0.18`,21.2`,0.93668`,1.1666`},0.34577626657662236`},{{0.18`,21.2`,0.93668`,1.1711`},0.34577626657662236`},{{0.18`,21.2`,0.93668`,1.1621000000000001`},0.34577626657662236`},{{0.18`,21.8`,0.94018`,1.1666`},0.34948297860250743`},{{0.18`,21.8`,0.94018`,1.1711`},0.34948297860250743`},{{0.18`,21.8`,0.94018`,1.1621000000000001`},0.34948297860250743`},{{0.18`,21.8`,0.94368`,1.1666`},0.35310745233520574`},{{0.18`,21.8`,0.94368`,1.1711`},0.35310745233520574`},{{0.18`,21.8`,0.94368`,1.1621000000000001`},0.35310745233520574`},{{0.18`,21.8`,0.93668`,1.1666`},0.3459037522797486`},{{0.18`,21.8`,0.93668`,1.1711`},0.3459037522797486`},{{0.18`,21.8`,0.93668`,1.1621000000000001`},0.3459037522797486`},{{0.18`,22.4`,0.94018`,1.1666`},0.34959569645024796`},{{0.18`,22.4`,0.94018`,1.1711`},0.34959569645024796`},{{0.18`,22.4`,0.94018`,1.1621000000000001`},0.34959569645024796`},{{0.18`,22.4`,0.94368`,1.1666`},0.35323637328441443`},{{0.18`,22.4`,0.94368`,1.1711`},0.35323637328441443`},{{0.18`,22.4`,0.94368`,1.1621000000000001`},0.35323637328441443`},{{0.18`,22.4`,0.93668`,1.1666`},0.3460004701504733`},{{0.18`,22.4`,0.93668`,1.1711`},0.3460004701504733`},{{0.18`,22.4`,0.93668`,1.1621000000000001`},0.3460004701504733`},{{0.18`,23.`,0.94018`,1.1666`},0.3496798035941787`},{{0.18`,23.`,0.94018`,1.1711`},0.3496798035941787`},{{0.18`,23.`,0.94018`,1.1621000000000001`},0.3496798035941787`},{{0.18`,23.`,0.94368`,1.1666`},0.3533359488660116`},{{0.18`,23.`,0.94368`,1.1711`},0.3533359488660116`},{{0.18`,23.`,0.94368`,1.1621000000000001`},0.3533359488660116`},{{0.18`,23.`,0.93668`,1.1666`},0.34606930270652964`},{{0.18`,23.`,0.93668`,1.1711`},0.34606930270652964`},{{0.18`,23.`,0.93668`,1.1621000000000001`},0.34606930270652964`},{{0.18`,23.6`,0.94018`,1.1666`},0.34973796177037025`},{{0.18`,23.6`,0.94018`,1.1711`},0.34973796177037025`},{{0.18`,23.6`,0.94018`,1.1621000000000001`},0.34973796177037025`},{{0.18`,23.6`,0.94368`,1.1666`},0.35340889370748557`},{{0.18`,23.6`,0.94368`,1.1711`},0.35340889370748557`},{{0.18`,23.6`,0.94368`,1.1621000000000001`},0.35340889370748557`},{{0.18`,23.6`,0.93668`,1.1666`},0.3461128594438391`},{{0.18`,23.6`,0.93668`,1.1711`},0.3461128594438391`},{{0.18`,23.6`,0.93668`,1.1621000000000001`},0.3461128594438391`},{{0.18`,24.2`,0.94018`,1.1666`},0.34977168044932483`},{{0.18`,24.2`,0.94018`,1.1711`},0.34977168044932483`},{{0.18`,24.2`,0.94018`,1.1621000000000001`},0.34977168044932483`},{{0.18`,24.2`,0.94368`,1.1666`},0.35345676846394636`},{{0.18`,24.2`,0.94368`,1.1711`},0.35345676846394636`},{{0.18`,24.2`,0.94368`,1.1621000000000001`},0.35345676846394636`},{{0.18`,24.2`,0.93668`,1.1666`},0.34613259973852023`},{{0.18`,24.2`,0.93668`,1.1711`},0.34613259973852023`},{{0.18`,24.2`,0.93668`,1.1621000000000001`},0.34613259973852023`},{{0.18`,24.8`,0.94018`,1.1666`},0.34978415978063726`},{{0.18`,24.8`,0.94018`,1.1711`},0.34978415978063726`},{{0.18`,24.8`,0.94018`,1.1621000000000001`},0.34978415978063726`},{{0.18`,24.8`,0.94368`,1.1666`},0.3534828166230245`},{{0.18`,24.8`,0.94368`,1.1711`},0.3534828166230245`},{{0.18`,24.8`,0.94368`,1.1621000000000001`},0.3534828166230245`},{{0.18`,24.8`,0.93668`,1.1666`},0.3461316802913428`},{{0.18`,24.8`,0.93668`,1.1711`},0.3461316802913428`},{{0.18`,24.8`,0.93668`,1.1621000000000001`},0.3461316802913428`},{{0.18`,25.4`,0.94018`,1.1666`},0.34977701074853096`},{{0.18`,25.4`,0.94018`,1.1711`},0.34977701074853096`},{{0.18`,25.4`,0.94018`,1.1621000000000001`},0.34977701074853096`},{{0.18`,25.4`,0.94368`,1.1666`},0.3534886889530032`},{{0.18`,25.4`,0.94368`,1.1711`},0.3534886889530032`},{{0.18`,25.4`,0.94368`,1.1621000000000001`},0.3534886889530032`},{{0.18`,25.4`,0.93668`,1.1666`},0.3461116730365111`},{{0.18`,25.4`,0.93668`,1.1711`},0.3461116730365111`},{{0.18`,25.4`,0.93668`,1.1621000000000001`},0.3461116730365111`},{{0.18`,26.`,0.94018`,1.1666`},0.3497520085232445`},{{0.18`,26.`,0.94018`,1.1711`},0.3497520085232445`},{{0.18`,26.`,0.94018`,1.1621000000000001`},0.3497520085232445`},{{0.18`,26.`,0.94368`,1.1666`},0.3534761974379089`},{{0.18`,26.`,0.94368`,1.1711`},0.3534761974379089`},{{0.18`,26.`,0.94368`,1.1621000000000001`},0.3534761974379089`},{{0.18`,26.`,0.93668`,1.1666`},0.3460743167779921`},{{0.18`,26.`,0.93668`,1.1711`},0.3460743167779921`},{{0.18`,26.`,0.93668`,1.1621000000000001`},0.3460743167779921`},{{0.18`,26.6`,0.94018`,1.1666`},0.34971075208411906`},{{0.18`,26.6`,0.94018`,1.1711`},0.34971075208411906`},{{0.18`,26.6`,0.94018`,1.1621000000000001`},0.34971075208411906`},{{0.18`,26.6`,0.94368`,1.1666`},0.3534469750230249`},{{0.18`,26.6`,0.94368`,1.1711`},0.3534469750230249`},{{0.18`,26.6`,0.94368`,1.1621000000000001`},0.3534469750230249`},{{0.18`,26.6`,0.93668`,1.1666`},0.3460211769413506`},{{0.18`,26.6`,0.93668`,1.1711`},0.3460211769413506`},{{0.18`,26.6`,0.93668`,1.1621000000000001`},0.3460211769413506`},{{0.18`,27.2`,0.94018`,1.1666`},0.34965398175656753`},{{0.18`,27.2`,0.94018`,1.1711`},0.34965398175656753`},{{0.18`,27.2`,0.94018`,1.1621000000000001`},0.34965398175656753`},{{0.18`,27.2`,0.94368`,1.1666`},0.35340179545996847`},{{0.18`,27.2`,0.94368`,1.1711`},0.35340179545996847`},{{0.18`,27.2`,0.94368`,1.1621000000000001`},0.35340179545996847`},{{0.18`,27.2`,0.93668`,1.1666`},0.34595296128226677`},{{0.18`,27.2`,0.93668`,1.1711`},0.34595296128226677`},{{0.18`,27.2`,0.93668`,1.1621000000000001`},0.34595296128226677`},{{0.18`,27.8`,0.94018`,1.1666`},0.3495838606857771`},{{0.18`,27.8`,0.94018`,1.1711`},0.3495838606857771`},{{0.18`,27.8`,0.94018`,1.1621000000000001`},0.3495838606857771`},{{0.18`,27.8`,0.94368`,1.1666`},0.35334285061708437`},{{0.18`,27.8`,0.94368`,1.1711`},0.35334285061708437`},{{0.18`,27.8`,0.94368`,1.1621000000000001`},0.35334285061708437`},{{0.18`,27.8`,0.93668`,1.1666`},0.3458718039035177`},{{0.18`,27.8`,0.93668`,1.1711`},0.3458718039035177`},{{0.18`,27.8`,0.93668`,1.1621000000000001`},0.3458718039035177`},{{0.18`,28.4`,0.94018`,1.1666`},0.3495013788897486`},{{0.18`,28.4`,0.94018`,1.1711`},0.3495013788897486`},{{0.18`,28.4`,0.94018`,1.1621000000000001`},0.3495013788897486`},{{0.18`,28.4`,0.94368`,1.1666`},0.3532711552157769`},{{0.18`,28.4`,0.94368`,1.1711`},0.3532711552157769`},{{0.18`,28.4`,0.94368`,1.1621000000000001`},0.3532711552157769`},{{0.18`,28.4`,0.93668`,1.1666`},0.34577867066515616`},{{0.18`,28.4`,0.93668`,1.1711`},0.34577867066515616`},{{0.18`,28.4`,0.93668`,1.1621000000000001`},0.34577867066515616`},{{0.18`,29.`,0.94018`,1.1666`},0.3494076458540513`},{{0.18`,29.`,0.94018`,1.1711`},0.3494076458540513`},{{0.18`,29.`,0.94018`,1.1621000000000001`},0.3494076458540513`},{{0.18`,29.`,0.94368`,1.1666`},0.35318784284673294`},{{0.18`,29.`,0.94368`,1.1711`},0.35318784284673294`},{{0.18`,29.`,0.94368`,1.1621000000000001`},0.35318784284673294`},{{0.18`,29.`,0.93668`,1.1666`},0.3456746472315712`},{{0.18`,29.`,0.93668`,1.1711`},0.3456746472315712`},{{0.18`,29.`,0.93668`,1.1621000000000001`},0.3456746472315712`},{{0.18`,29.6`,0.94018`,1.1666`},0.3493033311527975`},{{0.18`,29.6`,0.94018`,1.1711`},0.3493033311527975`},{{0.18`,29.6`,0.94018`,1.1621000000000001`},0.3493033311527975`},{{0.18`,29.6`,0.94368`,1.1666`},0.3530936059968343`},{{0.18`,29.6`,0.94368`,1.1711`},0.3530936059968343`},{{0.18`,29.6`,0.94368`,1.1621000000000001`},0.3530936059968343`},{{0.18`,29.6`,0.93668`,1.1666`},0.3455603807994038`},{{0.18`,29.6`,0.93668`,1.1711`},0.3455603807994038`},{{0.18`,29.6`,0.93668`,1.1621000000000001`},0.3455603807994038`},{{0.18`,30.2`,0.94018`,1.1666`},0.3491896434195072`},{{0.18`,30.2`,0.94018`,1.1711`},0.3491896434195072`},{{0.18`,30.2`,0.94018`,1.1621000000000001`},0.3491896434195072`},{{0.18`,30.2`,0.94368`,1.1666`},0.3529896759712259`},{{0.18`,30.2`,0.94368`,1.1711`},0.3529896759712259`},{{0.18`,30.2`,0.94368`,1.1621000000000001`},0.3529896759712259`},{{0.18`,30.2`,0.93668`,1.1666`},0.34543705725234797`},{{0.18`,30.2`,0.93668`,1.1711`},0.34543705725234797`},{{0.18`,30.2`,0.93668`,1.1621000000000001`},0.34543705725234797`},{{0.18`,30.8`,0.94018`,1.1666`},0.34906736813964195`},{{0.18`,30.8`,0.94018`,1.1711`},0.34906736813964195`},{{0.18`,30.8`,0.94018`,1.1621000000000001`},0.34906736813964195`},{{0.18`,30.8`,0.94368`,1.1666`},0.352876855797218`},{{0.18`,30.8`,0.94368`,1.1711`},0.352876855797218`},{{0.18`,30.8`,0.94368`,1.1621000000000001`},0.352876855797218`},{{0.18`,30.8`,0.93668`,1.1666`},0.3453054448639766`},{{0.18`,30.8`,0.93668`,1.1711`},0.3453054448639766`},{{0.18`,30.8`,0.93668`,1.1621000000000001`},0.3453054448639766`},{{0.18`,31.4`,0.94018`,1.1666`},0.3489372725860675`},{{0.18`,31.4`,0.94018`,1.1711`},0.3489372725860675`},{{0.18`,31.4`,0.94018`,1.1621000000000001`},0.3489372725860675`},{{0.18`,31.4`,0.94368`,1.1666`},0.3527559304590458`},{{0.18`,31.4`,0.94368`,1.1711`},0.3527559304590458`},{{0.18`,31.4`,0.94368`,1.1621000000000001`},0.3527559304590458`},{{0.18`,31.4`,0.93668`,1.1666`},0.3451662934039152`},{{0.18`,31.4`,0.93668`,1.1711`},0.3451662934039152`},{{0.18`,31.4`,0.93668`,1.1621000000000001`},0.3451662934039152`},{{0.18`,32.`,0.94018`,1.1666`},0.348799917425937`},{{0.18`,32.`,0.94018`,1.1711`},0.348799917425937`},{{0.18`,32.`,0.94018`,1.1621000000000001`},0.348799917425937`},{{0.18`,32.`,0.94368`,1.1666`},0.3526274768505155`},{{0.18`,32.`,0.94368`,1.1711`},0.3526274768505155`},{{0.18`,32.`,0.94368`,1.1621000000000001`},0.3526274768505155`},{{0.18`,32.`,0.93668`,1.1666`},0.34502014764780803`},{{0.18`,32.`,0.93668`,1.1711`},0.34502014764780803`},{{0.18`,32.`,0.93668`,1.1621000000000001`},0.34502014764780803`},{{0.18`,32.6`,0.94018`,1.1666`},0.34865600754158`},{{0.18`,32.6`,0.94018`,1.1711`},0.34865600754158`},{{0.18`,32.6`,0.94018`,1.1621000000000001`},0.34865600754158`},{{0.18`,32.6`,0.94368`,1.1666`},0.35249221735515074`},{{0.18`,32.6`,0.94368`,1.1711`},0.35249221735515074`},{{0.18`,32.6`,0.94368`,1.1621000000000001`},0.35249221735515074`},{{0.18`,32.6`,0.93668`,1.1666`},0.34486769501609155`},{{0.18`,32.6`,0.93668`,1.1711`},0.34486769501609155`},{{0.18`,32.6`,0.93668`,1.1621000000000001`},0.34486769501609155`},{{0.18`,33.2`,0.94018`,1.1666`},0.3485061427520243`},{{0.18`,33.2`,0.94018`,1.1711`},0.3485061427520243`},{{0.18`,33.2`,0.94018`,1.1621000000000001`},0.3485061427520243`},{{0.18`,33.2`,0.94368`,1.1666`},0.3523507647070591`},{{0.18`,33.2`,0.94368`,1.1711`},0.3523507647070591`},{{0.18`,33.2`,0.94368`,1.1621000000000001`},0.3523507647070591`},{{0.18`,33.2`,0.93668`,1.1666`},0.34470952262404964`},{{0.18`,33.2`,0.93668`,1.1711`},0.34470952262404964`},{{0.18`,33.2`,0.93668`,1.1621000000000001`},0.34470952262404964`},{{0.18`,33.8`,0.94018`,1.1666`},0.34835085939253957`},{{0.18`,33.8`,0.94018`,1.1711`},0.34835085939253957`},{{0.18`,33.8`,0.94018`,1.1621000000000001`},0.34835085939253957`},{{0.18`,33.8`,0.94368`,1.1666`},0.352203668527064`},{{0.18`,33.8`,0.94368`,1.1711`},0.352203668527064`},{{0.18`,33.8`,0.94368`,1.1621000000000001`},0.352203668527064`},{{0.18`,33.8`,0.93668`,1.1666`},0.3445461536843691`},{{0.18`,33.8`,0.93668`,1.1711`},0.3445461536843691`},{{0.18`,33.8`,0.93668`,1.1621000000000001`},0.3445461536843691`},{{0.18`,34.4`,0.94018`,1.1666`},0.34819065116508907`},{{0.18`,34.4`,0.94018`,1.1711`},0.34819065116508907`},{{0.18`,34.4`,0.94018`,1.1621000000000001`},0.34819065116508907`},{{0.18`,34.4`,0.94368`,1.1666`},0.3520514348827846`},{{0.18`,34.4`,0.94368`,1.1711`},0.3520514348827846`},{{0.18`,34.4`,0.94368`,1.1621000000000001`},0.3520514348827846`},{{0.18`,34.4`,0.93668`,1.1666`},0.3443780696880658`},{{0.18`,34.4`,0.93668`,1.1711`},0.3443780696880658`},{{0.18`,34.4`,0.93668`,1.1621000000000001`},0.3443780696880658`},{{0.18`,35.`,0.94018`,1.1666`},0.3480259806892272`},{{0.18`,35.`,0.94018`,1.1711`},0.3480259806892272`},{{0.18`,35.`,0.94018`,1.1621000000000001`},0.3480259806892272`},{{0.18`,35.`,0.94368`,1.1666`},0.3518945382579548`},{{0.18`,35.`,0.94368`,1.1711`},0.3518945382579548`},{{0.18`,35.`,0.94368`,1.1621000000000001`},0.3518945382579548`},{{0.18`,35.`,0.93668`,1.1666`},0.3442057215294526`},{{0.18`,35.`,0.93668`,1.1711`},0.3442057215294526`},{{0.18`,35.`,0.93668`,1.1621000000000001`},0.3442057215294526`},{{0.18`,35.6`,0.94018`,1.1666`},0.3478568750083893`},{{0.18`,35.6`,0.94018`,1.1711`},0.3478568750083893`},{{0.18`,35.6`,0.94018`,1.1621000000000001`},0.3478568750083893`},{{0.18`,35.6`,0.94368`,1.1666`},0.35173301772786125`},{{0.18`,35.6`,0.94368`,1.1711`},0.35173301772786125`},{{0.18`,35.6`,0.94368`,1.1621000000000001`},0.35173301772786125`},{{0.18`,35.6`,0.93668`,1.1666`},0.34402912468722013`},{{0.18`,35.6`,0.93668`,1.1711`},0.34402912468722013`},{{0.18`,35.6`,0.93668`,1.1621000000000001`},0.34402912468722013`},{{0.18`,36.2`,0.94018`,1.1666`},0.3476842358909992`},{{0.18`,36.2`,0.94018`,1.1711`},0.3476842358909992`},{{0.18`,36.2`,0.94018`,1.1621000000000001`},0.3476842358909992`},{{0.18`,36.2`,0.94368`,1.1666`},0.3515677839221199`},{{0.18`,36.2`,0.94368`,1.1711`},0.3515677839221199`},{{0.18`,36.2`,0.94368`,1.1621000000000001`},0.3515677839221199`},{{0.18`,36.2`,0.93668`,1.1666`},0.3438491717661271`},{{0.18`,36.2`,0.93668`,1.1711`},0.3438491717661271`},{{0.18`,36.2`,0.93668`,1.1621000000000001`},0.3438491717661271`},{{0.18`,36.8`,0.94018`,1.1666`},0.3475082179655956`},{{0.18`,36.8`,0.94018`,1.1711`},0.3475082179655956`},{{0.18`,36.8`,0.94018`,1.1621000000000001`},0.3475082179655956`},{{0.18`,36.8`,0.94368`,1.1666`},0.35139900130830026`},{{0.18`,36.8`,0.94368`,1.1711`},0.35139900130830026`},{{0.18`,36.8`,0.94368`,1.1621000000000001`},0.35139900130830026`},{{0.18`,36.8`,0.93668`,1.1666`},0.34366600788260887`},{{0.18`,36.8`,0.93668`,1.1711`},0.34366600788260887`},{{0.18`,36.8`,0.93668`,1.1621000000000001`},0.34366600788260887`},{{0.18`,37.4`,0.94018`,1.1666`},0.3473291411239337`},{{0.18`,37.4`,0.94018`,1.1711`},0.3473291411239337`},{{0.18`,37.4`,0.94018`,1.1621000000000001`},0.3473291411239337`},{{0.18`,37.4`,0.94368`,1.1666`},0.35122699218328396`},{{0.18`,37.4`,0.94368`,1.1711`},0.35122699218328396`},{{0.18`,37.4`,0.94368`,1.1621000000000001`},0.35122699218328396`},{{0.18`,37.4`,0.93668`,1.1666`},0.3434799441285493`},{{0.18`,37.4`,0.93668`,1.1711`},0.3434799441285493`},{{0.18`,37.4`,0.93668`,1.1621000000000001`},0.3434799441285493`},{{0.18`,38.`,0.94018`,1.1666`},0.34714730024005563`},{{0.18`,38.`,0.94018`,1.1711`},0.34714730024005563`},{{0.18`,38.`,0.94018`,1.1621000000000001`},0.34714730024005563`},{{0.18`,38.`,0.94368`,1.1666`},0.35105207065975164`},{{0.18`,38.`,0.94368`,1.1711`},0.35105207065975164`},{{0.18`,38.`,0.94368`,1.1621000000000001`},0.35105207065975164`},{{0.18`,38.`,0.93668`,1.1666`},0.3432912671259182`},{{0.18`,38.`,0.93668`,1.1711`},0.3432912671259182`},{{0.18`,38.`,0.93668`,1.1621000000000001`},0.3432912671259182`},{{0.18`,38.6`,0.94018`,1.1666`},0.3469629672700804`},{{0.18`,38.6`,0.94018`,1.1711`},0.3469629672700804`},{{0.18`,38.6`,0.94018`,1.1621000000000001`},0.3469629672700804`},{{0.18`,38.6`,0.94368`,1.1666`},0.3508745116372287`},{{0.18`,38.6`,0.94368`,1.1711`},0.3508745116372287`},{{0.18`,38.6`,0.94368`,1.1621000000000001`},0.3508745116372287`},{{0.18`,38.6`,0.93668`,1.1666`},0.3431002410845684`},{{0.18`,38.6`,0.93668`,1.1711`},0.3431002410845684`},{{0.18`,38.6`,0.93668`,1.1621000000000001`},0.3431002410845684`},{{0.18`,39.2`,0.94018`,1.1666`},0.3467763931490506`},{{0.18`,39.2`,0.94018`,1.1711`},0.3467763931490506`},{{0.18`,39.2`,0.94018`,1.1621000000000001`},0.3467763931490506`},{{0.18`,39.2`,0.94368`,1.1666`},0.35069457333048554`},{{0.18`,39.2`,0.94368`,1.1711`},0.35069457333048554`},{{0.18`,39.2`,0.94368`,1.1621000000000001`},0.35069457333048554`},{{0.18`,39.2`,0.93668`,1.1666`},0.3429071096603327`},{{0.18`,39.2`,0.93668`,1.1711`},0.3429071096603327`},{{0.18`,39.2`,0.93668`,1.1621000000000001`},0.3429071096603327`},{{0.18`,39.8`,0.94018`,1.1666`},0.34658780950526386`},{{0.18`,39.8`,0.94018`,1.1711`},0.34658780950526386`},{{0.18`,39.8`,0.94018`,1.1621000000000001`},0.34658780950526386`},{{0.18`,39.8`,0.94368`,1.1666`},0.3505124941932133`},{{0.18`,39.8`,0.94368`,1.1711`},0.3505124941932133`},{{0.18`,39.8`,0.94368`,1.1621000000000001`},0.3505124941932133`},{{0.18`,39.8`,0.93668`,1.1666`},0.34271209763347094`},{{0.18`,39.8`,0.93668`,1.1711`},0.34271209763347094`},{{0.18`,39.8`,0.93668`,1.1621000000000001`},0.34271209763347094`},{{0.21`,0.4`,0.94018`,1.1666`},0.2264515916046305`},{{0.21`,0.4`,0.94018`,1.1711`},0.2264515916046305`},{{0.21`,0.4`,0.94018`,1.1621000000000001`},0.2264515916046305`},{{0.21`,0.4`,0.94368`,1.1666`},0.22674541676263363`},{{0.21`,0.4`,0.94368`,1.1711`},0.22674541676263363`},{{0.21`,0.4`,0.94368`,1.1621000000000001`},0.22674541676263363`},{{0.21`,0.4`,0.93668`,1.1666`},0.22616128820644354`},{{0.21`,0.4`,0.93668`,1.1711`},0.22616128820644354`},{{0.21`,0.4`,0.93668`,1.1621000000000001`},0.22616128820644354`},{{0.21`,0.6`,0.94018`,1.1666`},0.23387811945214795`},{{0.21`,0.6`,0.94018`,1.1711`},0.23387811945214795`},{{0.21`,0.6`,0.94018`,1.1621000000000001`},0.23387811945214795`},{{0.21`,0.6`,0.94368`,1.1666`},0.23430658640707772`},{{0.21`,0.6`,0.94368`,1.1711`},0.23430658640707772`},{{0.21`,0.6`,0.94368`,1.1621000000000001`},0.23430658640707772`},{{0.21`,0.6`,0.93668`,1.1666`},0.23345480842290786`},{{0.21`,0.6`,0.93668`,1.1711`},0.23345480842290786`},{{0.21`,0.6`,0.93668`,1.1621000000000001`},0.23345480842290786`},{{0.21`,0.8`,0.94018`,1.1666`},0.2408282473827437`},{{0.21`,0.8`,0.94018`,1.1711`},0.2408282473827437`},{{0.21`,0.8`,0.94018`,1.1621000000000001`},0.2408282473827437`},{{0.21`,0.8`,0.94368`,1.1666`},0.24138394576417838`},{{0.21`,0.8`,0.94368`,1.1711`},0.24138394576417838`},{{0.21`,0.8`,0.94368`,1.1621000000000001`},0.24138394576417838`},{{0.21`,0.8`,0.93668`,1.1666`},0.24027926054301837`},{{0.21`,0.8`,0.93668`,1.1711`},0.24027926054301837`},{{0.21`,0.8`,0.93668`,1.1621000000000001`},0.24027926054301837`},{{0.21`,1.`,0.94018`,1.1666`},0.24733924173730695`},{{0.21`,1.`,0.94018`,1.1711`},0.24733924173730695`},{{0.21`,1.`,0.94018`,1.1621000000000001`},0.24733924173730695`},{{0.21`,1.`,0.94368`,1.1666`},0.24801527890574007`},{{0.21`,1.`,0.94368`,1.1711`},0.24801527890574007`},{{0.21`,1.`,0.94368`,1.1621000000000001`},0.24801527890574007`},{{0.21`,1.`,0.93668`,1.1666`},0.24667139740031782`},{{0.21`,1.`,0.93668`,1.1711`},0.24667139740031782`},{{0.21`,1.`,0.93668`,1.1621000000000001`},0.24667139740031782`},{{0.21`,1.2`,0.94018`,1.1666`},0.25344485906724923`},{{0.21`,1.2`,0.94018`,1.1711`},0.25344485906724923`},{{0.21`,1.2`,0.94018`,1.1621000000000001`},0.25344485906724923`},{{0.21`,1.2`,0.94368`,1.1666`},0.2542348175068329`},{{0.21`,1.2`,0.94368`,1.1711`},0.2542348175068329`},{{0.21`,1.2`,0.94368`,1.1621000000000001`},0.2542348175068329`},{{0.21`,1.2`,0.93668`,1.1666`},0.2526645044556704`},{{0.21`,1.2`,0.93668`,1.1711`},0.2526645044556704`},{{0.21`,1.2`,0.93668`,1.1621000000000001`},0.2526645044556704`},{{0.21`,1.4`,0.94018`,1.1666`},0.2591757323736938`},{{0.21`,1.4`,0.94018`,1.1711`},0.2591757323736938`},{{0.21`,1.4`,0.94018`,1.1621000000000001`},0.2591757323736938`},{{0.21`,1.4`,0.94368`,1.1666`},0.2600736310052787`},{{0.21`,1.4`,0.94368`,1.1711`},0.2600736310052787`},{{0.21`,1.4`,0.94368`,1.1621000000000001`},0.2600736310052787`},{{0.21`,1.4`,0.93668`,1.1666`},0.2582887821115273`},{{0.21`,1.4`,0.93668`,1.1711`},0.2582887821115273`},{{0.21`,1.4`,0.93668`,1.1621000000000001`},0.2582887821115273`},{{0.21`,1.6`,0.94018`,1.1666`},0.26455970894646347`},{{0.21`,1.6`,0.94018`,1.1711`},0.26455970894646347`},{{0.21`,1.6`,0.94018`,1.1621000000000001`},0.26455970894646347`},{{0.21`,1.6`,0.94368`,1.1666`},0.26555996797968096`},{{0.21`,1.6`,0.94368`,1.1711`},0.26555996797968096`},{{0.21`,1.6`,0.94368`,1.1621000000000001`},0.26555996797968096`},{{0.21`,1.6`,0.93668`,1.1666`},0.26357168001132253`},{{0.21`,1.6`,0.93668`,1.1711`},0.26357168001132253`},{{0.21`,1.6`,0.93668`,1.1621000000000001`},0.26357168001132253`},{{0.21`,1.8`,0.94018`,1.1666`},0.2696221465685789`},{{0.21`,1.8`,0.94018`,1.1711`},0.2696221465685789`},{{0.21`,1.8`,0.94018`,1.1621000000000001`},0.2696221465685789`},{{0.21`,1.8`,0.94368`,1.1666`},0.2707195555474252`},{{0.21`,1.8`,0.94368`,1.1711`},0.2707195555474252`},{{0.21`,1.8`,0.94368`,1.1621000000000001`},0.2707195555474252`},{{0.21`,1.8`,0.93668`,1.1666`},0.26853819005289686`},{{0.21`,1.8`,0.93668`,1.1711`},0.26853819005289686`},{{0.21`,1.8`,0.93668`,1.1621000000000001`},0.26853819005289686`},{{0.21`,2.`,0.94018`,1.1666`},0.27438617381429564`},{{0.21`,2.`,0.94018`,1.1711`},0.27438617381429564`},{{0.21`,2.`,0.94018`,1.1621000000000001`},0.27438617381429564`},{{0.21`,2.`,0.94368`,1.1666`},0.27557586254401567`},{{0.21`,2.`,0.94368`,1.1711`},0.27557586254401567`},{{0.21`,2.`,0.94368`,1.1621000000000001`},0.27557586254401567`},{{0.21`,2.`,0.93668`,1.1666`},0.2732111038098107`},{{0.21`,2.`,0.93668`,1.1711`},0.2732111038098107`},{{0.21`,2.`,0.93668`,1.1621000000000001`},0.2732111038098107`},{{0.21`,2.2`,0.94018`,1.1666`},0.2788729193032827`},{{0.21`,2.2`,0.94018`,1.1711`},0.2788729193032827`},{{0.21`,2.2`,0.94018`,1.1621000000000001`},0.2788729193032827`},{{0.21`,2.2`,0.94368`,1.1666`},0.2801503313770979`},{{0.21`,2.2`,0.94368`,1.1711`},0.2801503313770979`},{{0.21`,2.2`,0.94368`,1.1621000000000001`},0.2801503313770979`},{{0.21`,2.2`,0.93668`,1.1666`},0.2776112391917493`},{{0.21`,2.2`,0.93668`,1.1711`},0.2776112391917493`},{{0.21`,2.2`,0.93668`,1.1621000000000001`},0.2776112391917493`},{{0.21`,2.6`,0.94018`,1.1666`},0.28708837832608347`},{{0.21`,2.6`,0.94018`,1.1711`},0.28708837832608347`},{{0.21`,2.6`,0.94018`,1.1621000000000001`},0.28708837832608347`},{{0.21`,2.6`,0.94368`,1.1666`},0.28852869927512614`},{{0.21`,2.6`,0.94368`,1.1711`},0.28852869927512614`},{{0.21`,2.6`,0.94368`,1.1621000000000001`},0.28852869927512614`},{{0.21`,2.6`,0.93668`,1.1666`},0.285665868814694`},{{0.21`,2.6`,0.93668`,1.1711`},0.285665868814694`},{{0.21`,2.6`,0.93668`,1.1621000000000001`},0.285665868814694`},{{0.21`,3.`,0.94018`,1.1666`},0.29440571372573465`},{{0.21`,3.`,0.94018`,1.1711`},0.29440571372573465`},{{0.21`,3.`,0.94018`,1.1621000000000001`},0.29440571372573465`},{{0.21`,3.`,0.94368`,1.1666`},0.29599392728637136`},{{0.21`,3.`,0.94368`,1.1711`},0.29599392728637136`},{{0.21`,3.`,0.94368`,1.1621000000000001`},0.29599392728637136`},{{0.21`,3.`,0.93668`,1.1666`},0.29283721157902093`},{{0.21`,3.`,0.93668`,1.1711`},0.29283721157902093`},{{0.21`,3.`,0.93668`,1.1621000000000001`},0.29283721157902093`},{{0.21`,3.4`,0.94018`,1.1666`},0.3009403148384773`},{{0.21`,3.4`,0.94018`,1.1711`},0.3009403148384773`},{{0.21`,3.4`,0.94018`,1.1621000000000001`},0.3009403148384773`},{{0.21`,3.4`,0.94368`,1.1666`},0.3026631697088405`},{{0.21`,3.4`,0.94368`,1.1711`},0.3026631697088405`},{{0.21`,3.4`,0.94368`,1.1621000000000001`},0.3026631697088405`},{{0.21`,3.4`,0.93668`,1.1666`},0.29923891107252487`},{{0.21`,3.4`,0.93668`,1.1711`},0.29923891107252487`},{{0.21`,3.4`,0.93668`,1.1621000000000001`},0.29923891107252487`},{{0.21`,3.8`,0.94018`,1.1666`},0.3067896580760759`},{{0.21`,3.8`,0.94018`,1.1711`},0.3067896580760759`},{{0.21`,3.8`,0.94018`,1.1621000000000001`},0.3067896580760759`},{{0.21`,3.8`,0.94368`,1.1666`},0.30863542531036336`},{{0.21`,3.8`,0.94368`,1.1711`},0.30863542531036336`},{{0.21`,3.8`,0.94368`,1.1621000000000001`},0.30863542531036336`},{{0.21`,3.8`,0.93668`,1.1666`},0.30496693796211366`},{{0.21`,3.8`,0.93668`,1.1711`},0.30496693796211366`},{{0.21`,3.8`,0.93668`,1.1621000000000001`},0.30496693796211366`},{{0.21`,4.2`,0.94018`,1.1666`},0.3120369119667998`},{{0.21`,4.2`,0.94018`,1.1711`},0.3120369119667998`},{{0.21`,4.2`,0.94018`,1.1621000000000001`},0.3120369119667998`},{{0.21`,4.2`,0.94368`,1.1666`},0.3139951773889697`},{{0.21`,4.2`,0.94368`,1.1711`},0.3139951773889697`},{{0.21`,4.2`,0.94368`,1.1621000000000001`},0.3139951773889697`},{{0.21`,4.2`,0.93668`,1.1666`},0.31010316054886344`},{{0.21`,4.2`,0.93668`,1.1711`},0.31010316054886344`},{{0.21`,4.2`,0.93668`,1.1621000000000001`},0.31010316054886344`},{{0.21`,4.6`,0.94018`,1.1666`},0.31675391662309904`},{{0.21`,4.6`,0.94018`,1.1711`},0.31675391662309904`},{{0.21`,4.6`,0.94018`,1.1621000000000001`},0.31675391662309904`},{{0.21`,4.6`,0.94368`,1.1666`},0.3188154086977296`},{{0.21`,4.6`,0.94368`,1.1711`},0.3188154086977296`},{{0.21`,4.6`,0.94368`,1.1621000000000001`},0.3188154086977296`},{{0.21`,4.6`,0.93668`,1.1666`},0.31471828938149`},{{0.21`,4.6`,0.93668`,1.1711`},0.31471828938149`},{{0.21`,4.6`,0.93668`,1.1621000000000001`},0.31471828938149`},{{0.21`,5.`,0.94018`,1.1666`},0.3210019551172536`},{{0.21`,5.`,0.94018`,1.1711`},0.3210019551172536`},{{0.21`,5.`,0.94018`,1.1621000000000001`},0.3210019551172536`},{{0.21`,5.`,0.94368`,1.1666`},0.32315838402117664`},{{0.21`,5.`,0.94368`,1.1711`},0.32315838402117664`},{{0.21`,5.`,0.94368`,1.1621000000000001`},0.32315838402117664`},{{0.21`,5.`,0.93668`,1.1666`},0.3188726373897213`},{{0.21`,5.`,0.93668`,1.1711`},0.3188726373897213`},{{0.21`,5.`,0.93668`,1.1621000000000001`},0.3188726373897213`},{{0.21`,5.4`,0.94018`,1.1666`},0.3248334554661633`},{{0.21`,5.4`,0.94018`,1.1711`},0.3248334554661633`},{{0.21`,5.4`,0.94018`,1.1621000000000001`},0.3248334554661633`},{{0.21`,5.4`,0.94368`,1.1666`},0.3270774006320455`},{{0.21`,5.4`,0.94368`,1.1711`},0.3270774006320455`},{{0.21`,5.4`,0.94368`,1.1621000000000001`},0.3270774006320455`},{{0.21`,5.4`,0.93668`,1.1666`},0.32261777362284166`},{{0.21`,5.4`,0.93668`,1.1711`},0.32261777362284166`},{{0.21`,5.4`,0.93668`,1.1621000000000001`},0.32261777362284166`},{{0.21`,5.8`,0.94018`,1.1666`},0.32829437158365454`},{{0.21`,5.8`,0.94018`,1.1711`},0.32829437158365454`},{{0.21`,5.8`,0.94018`,1.1621000000000001`},0.32829437158365454`},{{0.21`,5.8`,0.94368`,1.1666`},0.3306191689167988`},{{0.21`,5.8`,0.94368`,1.1711`},0.3306191689167988`},{{0.21`,5.8`,0.94368`,1.1621000000000001`},0.3306191689167988`},{{0.21`,5.8`,0.93668`,1.1666`},0.3259989046040966`},{{0.21`,5.8`,0.93668`,1.1711`},0.3259989046040966`},{{0.21`,5.8`,0.93668`,1.1621000000000001`},0.3259989046040966`},{{0.21`,6.2`,0.94018`,1.1666`},0.3314246976449877`},{{0.21`,6.2`,0.94018`,1.1711`},0.3314246976449877`},{{0.21`,6.2`,0.94018`,1.1621000000000001`},0.3314246976449877`},{{0.21`,6.2`,0.94368`,1.1666`},0.3338243472786303`},{{0.21`,6.2`,0.94368`,1.1711`},0.3338243472786303`},{{0.21`,6.2`,0.94368`,1.1621000000000001`},0.3338243472786303`},{{0.21`,6.2`,0.93668`,1.1666`},0.32905536835181126`},{{0.21`,6.2`,0.93668`,1.1711`},0.32905536835181126`},{{0.21`,6.2`,0.93668`,1.1621000000000001`},0.32905536835181126`},{{0.21`,6.8`,0.94018`,1.1666`},0.335575240127646`},{{0.21`,6.8`,0.94018`,1.1711`},0.335575240127646`},{{0.21`,6.8`,0.94018`,1.1621000000000001`},0.335575240127646`},{{0.21`,6.8`,0.94368`,1.1666`},0.33807717757344097`},{{0.21`,6.8`,0.94368`,1.1711`},0.33807717757344097`},{{0.21`,6.8`,0.94368`,1.1621000000000001`},0.33807717757344097`},{{0.21`,6.8`,0.93668`,1.1666`},0.3331049790853834`},{{0.21`,6.8`,0.93668`,1.1711`},0.3331049790853834`},{{0.21`,6.8`,0.93668`,1.1621000000000001`},0.3331049790853834`},{{0.21`,7.4`,0.94018`,1.1666`},0.3391593497729416`},{{0.21`,7.4`,0.94018`,1.1711`},0.3391593497729416`},{{0.21`,7.4`,0.94018`,1.1621000000000001`},0.3391593497729416`},{{0.21`,7.4`,0.94368`,1.1666`},0.3417530714629576`},{{0.21`,7.4`,0.94368`,1.1711`},0.3417530714629576`},{{0.21`,7.4`,0.94368`,1.1621000000000001`},0.3417530714629576`},{{0.21`,7.4`,0.93668`,1.1666`},0.33659852433113674`},{{0.21`,7.4`,0.93668`,1.1711`},0.33659852433113674`},{{0.21`,7.4`,0.93668`,1.1621000000000001`},0.33659852433113674`},{{0.21`,8.`,0.94018`,1.1666`},0.34225975390822305`},{{0.21`,8.`,0.94018`,1.1711`},0.34225975390822305`},{{0.21`,8.`,0.94018`,1.1621000000000001`},0.34225975390822305`},{{0.21`,8.`,0.94368`,1.1666`},0.3449361701906865`},{{0.21`,8.`,0.94368`,1.1711`},0.3449361701906865`},{{0.21`,8.`,0.94368`,1.1621000000000001`},0.3449361701906865`},{{0.21`,8.`,0.93668`,1.1666`},0.33961733526905985`},{{0.21`,8.`,0.93668`,1.1711`},0.33961733526905985`},{{0.21`,8.`,0.93668`,1.1621000000000001`},0.33961733526905985`},{{0.21`,8.6`,0.94018`,1.1666`},0.34494562376173743`},{{0.21`,8.6`,0.94018`,1.1711`},0.34494562376173743`},{{0.21`,8.6`,0.94018`,1.1621000000000001`},0.34494562376173743`},{{0.21`,8.6`,0.94368`,1.1666`},0.3476968336682344`},{{0.21`,8.6`,0.94368`,1.1711`},0.3476968336682344`},{{0.21`,8.6`,0.94368`,1.1621000000000001`},0.3476968336682344`},{{0.21`,8.6`,0.93668`,1.1666`},0.3422294094854273`},{{0.21`,8.6`,0.93668`,1.1711`},0.3422294094854273`},{{0.21`,8.6`,0.93668`,1.1621000000000001`},0.3422294094854273`},{{0.21`,9.2`,0.94018`,1.1666`},0.3472743024922835`},{{0.21`,9.2`,0.94018`,1.1711`},0.3472743024922835`},{{0.21`,9.2`,0.94018`,1.1621000000000001`},0.3472743024922835`},{{0.21`,9.2`,0.94368`,1.1666`},0.35009340823382123`},{{0.21`,9.2`,0.94368`,1.1711`},0.35009340823382123`},{{0.21`,9.2`,0.94368`,1.1621000000000001`},0.35009340823382123`},{{0.21`,9.2`,0.93668`,1.1666`},0.3444910998183598`},{{0.21`,9.2`,0.93668`,1.1711`},0.3444910998183598`},{{0.21`,9.2`,0.93668`,1.1621000000000001`},0.3444910998183598`},{{0.21`,9.8`,0.94018`,1.1666`},0.3492942914041602`},{{0.21`,9.8`,0.94018`,1.1711`},0.3492942914041602`},{{0.21`,9.8`,0.94018`,1.1621000000000001`},0.3492942914041602`},{{0.21`,9.8`,0.94368`,1.1666`},0.3521752452748677`},{{0.21`,9.8`,0.94368`,1.1711`},0.3521752452748677`},{{0.21`,9.8`,0.94368`,1.1621000000000001`},0.3521752452748677`},{{0.21`,9.8`,0.93668`,1.1666`},0.34645006842402876`},{{0.21`,9.8`,0.93668`,1.1711`},0.34645006842402876`},{{0.21`,9.8`,0.93668`,1.1621000000000001`},0.34645006842402876`},{{0.21`,10.4`,0.94018`,1.1666`},0.35104600534514013`},{{0.21`,10.4`,0.94018`,1.1711`},0.35104600534514013`},{{0.21`,10.4`,0.94018`,1.1621000000000001`},0.35104600534514013`},{{0.21`,10.4`,0.94368`,1.1666`},0.3539834825339322`},{{0.21`,10.4`,0.94368`,1.1711`},0.3539834825339322`},{{0.21`,10.4`,0.94368`,1.1621000000000001`},0.3539834825339322`},{{0.21`,10.4`,0.93668`,1.1666`},0.3481460167528756`},{{0.21`,10.4`,0.93668`,1.1711`},0.3481460167528756`},{{0.21`,10.4`,0.93668`,1.1621000000000001`},0.3481460167528756`},{{0.21`,11.`,0.94018`,1.1666`},0.35256449774248283`},{{0.21`,11.`,0.94018`,1.1711`},0.35256449774248283`},{{0.21`,11.`,0.94018`,1.1621000000000001`},0.35256449774248283`},{{0.21`,11.`,0.94368`,1.1666`},0.3555537978268575`},{{0.21`,11.`,0.94368`,1.1711`},0.3555537978268575`},{{0.21`,11.`,0.94368`,1.1621000000000001`},0.3555537978268575`},{{0.21`,11.`,0.93668`,1.1666`},0.3496133818370324`},{{0.21`,11.`,0.93668`,1.1711`},0.3496133818370324`},{{0.21`,11.`,0.93668`,1.1621000000000001`},0.3496133818370324`},{{0.21`,11.6`,0.94018`,1.1666`},0.35387928511110467`},{{0.21`,11.6`,0.94018`,1.1711`},0.35387928511110467`},{{0.21`,11.6`,0.94018`,1.1621000000000001`},0.35387928511110467`},{{0.21`,11.6`,0.94368`,1.1666`},0.35691623940852574`},{{0.21`,11.6`,0.94368`,1.1711`},0.35691623940852574`},{{0.21`,11.6`,0.94368`,1.1621000000000001`},0.35691623940852574`},{{0.21`,11.6`,0.93668`,1.1666`},0.3508811554833113`},{{0.21`,11.6`,0.93668`,1.1711`},0.3508811554833113`},{{0.21`,11.6`,0.93668`,1.1621000000000001`},0.3508811554833113`},{{0.21`,12.2`,0.94018`,1.1666`},0.3550149397488594`},{{0.21`,12.2`,0.94018`,1.1711`},0.3550149397488594`},{{0.21`,12.2`,0.94018`,1.1621000000000001`},0.3550149397488594`},{{0.21`,12.2`,0.94368`,1.1666`},0.3580958412405499`},{{0.21`,12.2`,0.94368`,1.1711`},0.3580958412405499`},{{0.21`,12.2`,0.94368`,1.1621000000000001`},0.3580958412405499`},{{0.21`,12.2`,0.93668`,1.1666`},0.3519734532741696`},{{0.21`,12.2`,0.93668`,1.1711`},0.3519734532741696`},{{0.21`,12.2`,0.93668`,1.1621000000000001`},0.3519734532741696`},{{0.21`,12.8`,0.94018`,1.1666`},0.35599395943966683`},{{0.21`,12.8`,0.94018`,1.1711`},0.35599395943966683`},{{0.21`,12.8`,0.94018`,1.1621000000000001`},0.35599395943966683`},{{0.21`,12.8`,0.94368`,1.1666`},0.3591155060426748`},{{0.21`,12.8`,0.94368`,1.1711`},0.3591155060426748`},{{0.21`,12.8`,0.94368`,1.1621000000000001`},0.3591155060426748`},{{0.21`,12.8`,0.93668`,1.1666`},0.3529123774315762`},{{0.21`,12.8`,0.93668`,1.1711`},0.3529123774315762`},{{0.21`,12.8`,0.93668`,1.1621000000000001`},0.3529123774315762`},{{0.21`,13.4`,0.94018`,1.1666`},0.35683473654741604`},{{0.21`,13.4`,0.94018`,1.1711`},0.35683473654741604`},{{0.21`,13.4`,0.94018`,1.1621000000000001`},0.35683473654741604`},{{0.21`,13.4`,0.94368`,1.1666`},0.35999396741013884`},{{0.21`,13.4`,0.94368`,1.1711`},0.35999396741013884`},{{0.21`,13.4`,0.94368`,1.1621000000000001`},0.35999396741013884`},{{0.21`,13.4`,0.93668`,1.1666`},0.35371597790113446`},{{0.21`,13.4`,0.93668`,1.1711`},0.35371597790113446`},{{0.21`,13.4`,0.93668`,1.1621000000000001`},0.35371597790113446`},{{0.21`,14.`,0.94018`,1.1666`},0.35755383440718835`},{{0.21`,14.`,0.94018`,1.1711`},0.35755383440718835`},{{0.21`,14.`,0.94018`,1.1621000000000001`},0.35755383440718835`},{{0.21`,14.`,0.94368`,1.1666`},0.3607480966664532`},{{0.21`,14.`,0.94368`,1.1711`},0.3607480966664532`},{{0.21`,14.`,0.94368`,1.1621000000000001`},0.3607480966664532`},{{0.21`,14.`,0.93668`,1.1666`},0.35440051758235885`},{{0.21`,14.`,0.93668`,1.1711`},0.35440051758235885`},{{0.21`,14.`,0.93668`,1.1621000000000001`},0.35440051758235885`},{{0.21`,14.6`,0.94018`,1.1666`},0.3581654315758397`},{{0.21`,14.6`,0.94018`,1.1711`},0.3581654315758397`},{{0.21`,14.6`,0.94018`,1.1621000000000001`},0.3581654315758397`},{{0.21`,14.6`,0.94368`,1.1666`},0.36139233663828046`},{{0.21`,14.6`,0.94368`,1.1711`},0.36139233663828046`},{{0.21`,14.6`,0.94368`,1.1621000000000001`},0.36139233663828046`},{{0.21`,14.6`,0.93668`,1.1666`},0.35497991339944673`},{{0.21`,14.6`,0.93668`,1.1711`},0.35497991339944673`},{{0.21`,14.6`,0.93668`,1.1621000000000001`},0.35497991339944673`},{{0.21`,15.2`,0.94018`,1.1666`},0.3586812470732163`},{{0.21`,15.2`,0.94018`,1.1711`},0.3586812470732163`},{{0.21`,15.2`,0.94018`,1.1621000000000001`},0.3586812470732163`},{{0.21`,15.2`,0.94368`,1.1666`},0.3619386380535765`},{{0.21`,15.2`,0.94368`,1.1711`},0.3619386380535765`},{{0.21`,15.2`,0.94368`,1.1621000000000001`},0.3619386380535765`},{{0.21`,15.2`,0.93668`,1.1666`},0.3554656559634868`},{{0.21`,15.2`,0.93668`,1.1711`},0.3554656559634868`},{{0.21`,15.2`,0.93668`,1.1621000000000001`},0.3554656559634868`},{{0.21`,15.8`,0.94018`,1.1666`},0.3591125722872775`},{{0.21`,15.8`,0.94018`,1.1711`},0.3591125722872775`},{{0.21`,15.8`,0.94018`,1.1621000000000001`},0.3591125722872775`},{{0.21`,15.8`,0.94368`,1.1666`},0.3623985029290192`},{{0.21`,15.8`,0.94368`,1.1711`},0.3623985029290192`},{{0.21`,15.8`,0.94368`,1.1621000000000001`},0.3623985029290192`},{{0.21`,15.8`,0.93668`,1.1666`},0.3558688285157055`},{{0.21`,15.8`,0.93668`,1.1711`},0.3558688285157055`},{{0.21`,15.8`,0.93668`,1.1621000000000001`},0.3558688285157055`},{{0.21`,16.4`,0.94018`,1.1666`},0.3594687706707585`},{{0.21`,16.4`,0.94018`,1.1711`},0.3594687706707585`},{{0.21`,16.4`,0.94018`,1.1621000000000001`},0.3594687706707585`},{{0.21`,16.4`,0.94368`,1.1666`},0.3627814745734959`},{{0.21`,16.4`,0.94368`,1.1711`},0.3627814745734959`},{{0.21`,16.4`,0.94368`,1.1621000000000001`},0.3627814745734959`},{{0.21`,16.4`,0.93668`,1.1666`},0.3561986171010538`},{{0.21`,16.4`,0.93668`,1.1711`},0.3561986171010538`},{{0.21`,16.4`,0.93668`,1.1621000000000001`},0.3561986171010538`},{{0.21`,17.`,0.94018`,1.1666`},0.3597578615327111`},{{0.21`,17.`,0.94018`,1.1711`},0.3597578615327111`},{{0.21`,17.`,0.94018`,1.1621000000000001`},0.3597578615327111`},{{0.21`,17.`,0.94368`,1.1666`},0.36309573148871377`},{{0.21`,17.`,0.94368`,1.1711`},0.36309573148871377`},{{0.21`,17.`,0.94368`,1.1621000000000001`},0.36309573148871377`},{{0.21`,17.`,0.93668`,1.1666`},0.3564628840956875`},{{0.21`,17.`,0.93668`,1.1711`},0.3564628840956875`},{{0.21`,17.`,0.93668`,1.1621000000000001`},0.3564628840956875`},{{0.21`,17.6`,0.94018`,1.1666`},0.3599872039443257`},{{0.21`,17.6`,0.94018`,1.1711`},0.3599872039443257`},{{0.21`,17.6`,0.94018`,1.1621000000000001`},0.3599872039443257`},{{0.21`,17.6`,0.94368`,1.1666`},0.36334878127584586`},{{0.21`,17.6`,0.94368`,1.1711`},0.36334878127584586`},{{0.21`,17.6`,0.94368`,1.1621000000000001`},0.36334878127584586`},{{0.21`,17.6`,0.93668`,1.1666`},0.3566688418251022`},{{0.21`,17.6`,0.93668`,1.1711`},0.3566688418251022`},{{0.21`,17.6`,0.93668`,1.1621000000000001`},0.3566688418251022`},{{0.21`,18.2`,0.94018`,1.1666`},0.3601637967555026`},{{0.21`,18.2`,0.94018`,1.1711`},0.3601637967555026`},{{0.21`,18.2`,0.94018`,1.1621000000000001`},0.3601637967555026`},{{0.21`,18.2`,0.94368`,1.1666`},0.3635477429024892`},{{0.21`,18.2`,0.94368`,1.1711`},0.3635477429024892`},{{0.21`,18.2`,0.94368`,1.1621000000000001`},0.3635477429024892`},{{0.21`,18.2`,0.93668`,1.1666`},0.35682337033810796`},{{0.21`,18.2`,0.93668`,1.1711`},0.35682337033810796`},{{0.21`,18.2`,0.93668`,1.1621000000000001`},0.35682337033810796`},{{0.21`,18.8`,0.94018`,1.1666`},0.3602924735710829`},{{0.21`,18.8`,0.94018`,1.1711`},0.3602924735710829`},{{0.21`,18.8`,0.94018`,1.1621000000000001`},0.3602924735710829`},{{0.21`,18.8`,0.94368`,1.1666`},0.36369757389113905`},{{0.21`,18.8`,0.94368`,1.1711`},0.36369757389113905`},{{0.21`,18.8`,0.94368`,1.1621000000000001`},0.36369757389113905`},{{0.21`,18.8`,0.93668`,1.1666`},0.35693118150754954`},{{0.21`,18.8`,0.93668`,1.1711`},0.35693118150754954`},{{0.21`,18.8`,0.93668`,1.1621000000000001`},0.35693118150754954`},{{0.21`,19.4`,0.94018`,1.1666`},0.36037827690059115`},{{0.21`,19.4`,0.94018`,1.1711`},0.36037827690059115`},{{0.21`,19.4`,0.94018`,1.1621000000000001`},0.36037827690059115`},{{0.21`,19.4`,0.94368`,1.1666`},0.36380341414859024`},{{0.21`,19.4`,0.94368`,1.1711`},0.36380341414859024`},{{0.21`,19.4`,0.94368`,1.1621000000000001`},0.36380341414859024`},{{0.21`,19.4`,0.93668`,1.1666`},0.35699722166941067`},{{0.21`,19.4`,0.93668`,1.1711`},0.35699722166941067`},{{0.21`,19.4`,0.93668`,1.1621000000000001`},0.35699722166941067`},{{0.21`,20.`,0.94018`,1.1666`},0.3604261001412302`},{{0.21`,20.`,0.94018`,1.1711`},0.3604261001412302`},{{0.21`,20.`,0.94018`,1.1621000000000001`},0.3604261001412302`},{{0.21`,20.`,0.94368`,1.1666`},0.36387025133051853`},{{0.21`,20.`,0.94368`,1.1711`},0.36387025133051853`},{{0.21`,20.`,0.94368`,1.1621000000000001`},0.36387025133051853`},{{0.21`,20.`,0.93668`,1.1666`},0.3570262909165061`},{{0.21`,20.`,0.93668`,1.1711`},0.3570262909165061`},{{0.21`,20.`,0.93668`,1.1621000000000001`},0.3570262909165061`},{{0.21`,20.6`,0.94018`,1.1666`},0.3604398750329299`},{{0.21`,20.6`,0.94018`,1.1711`},0.3604398750329299`},{{0.21`,20.6`,0.94018`,1.1621000000000001`},0.3604398750329299`},{{0.21`,20.6`,0.94368`,1.1666`},0.3639020980991026`},{{0.21`,20.6`,0.94368`,1.1711`},0.3639020980991026`},{{0.21`,20.6`,0.94368`,1.1621000000000001`},0.3639020980991026`},{{0.21`,20.6`,0.93668`,1.1666`},0.35702224121641174`},{{0.21`,20.6`,0.93668`,1.1711`},0.35702224121641174`},{{0.21`,20.6`,0.93668`,1.1621000000000001`},0.35702224121641174`},{{0.21`,21.2`,0.94018`,1.1666`},0.3604227992497344`},{{0.21`,21.2`,0.94018`,1.1711`},0.3604227992497344`},{{0.21`,21.2`,0.94018`,1.1621000000000001`},0.3604227992497344`},{{0.21`,21.2`,0.94368`,1.1666`},0.3639022264895155`},{{0.21`,21.2`,0.94368`,1.1711`},0.3639022264895155`},{{0.21`,21.2`,0.94368`,1.1621000000000001`},0.3639022264895155`},{{0.21`,21.2`,0.93668`,1.1666`},0.35698819701135087`},{{0.21`,21.2`,0.93668`,1.1711`},0.35698819701135087`},{{0.21`,21.2`,0.93668`,1.1621000000000001`},0.35698819701135087`},{{0.21`,21.8`,0.94018`,1.1666`},0.36037844266391966`},{{0.21`,21.8`,0.94018`,1.1711`},0.36037844266391966`},{{0.21`,21.8`,0.94018`,1.1621000000000001`},0.36037844266391966`},{{0.21`,21.8`,0.94368`,1.1666`},0.36387427474346395`},{{0.21`,21.8`,0.94368`,1.1711`},0.36387427474346395`},{{0.21`,21.8`,0.94368`,1.1621000000000001`},0.36387427474346395`},{{0.21`,21.8`,0.93668`,1.1666`},0.3569276604731664`},{{0.21`,21.8`,0.93668`,1.1711`},0.3569276604731664`},{{0.21`,21.8`,0.93668`,1.1621000000000001`},0.3569276604731664`},{{0.21`,22.4`,0.94018`,1.1666`},0.36030955671726805`},{{0.21`,22.4`,0.94018`,1.1711`},0.36030955671726805`},{{0.21`,22.4`,0.94018`,1.1621000000000001`},0.36030955671726805`},{{0.21`,22.4`,0.94368`,1.1666`},0.36382105410965065`},{{0.21`,22.4`,0.94368`,1.1711`},0.36382105410965065`},{{0.21`,22.4`,0.94368`,1.1621000000000001`},0.36382105410965065`},{{0.21`,22.4`,0.93668`,1.1666`},0.35684332408417474`},{{0.21`,22.4`,0.93668`,1.1711`},0.35684332408417474`},{{0.21`,22.4`,0.93668`,1.1621000000000001`},0.35684332408417474`},{{0.21`,23.`,0.94018`,1.1666`},0.36021871386186577`},{{0.21`,23.`,0.94018`,1.1711`},0.36021871386186577`},{{0.21`,23.`,0.94018`,1.1621000000000001`},0.36021871386186577`},{{0.21`,23.`,0.94368`,1.1666`},0.3637451918639532`},{{0.21`,23.`,0.94368`,1.1711`},0.3637451918639532`},{{0.21`,23.`,0.94368`,1.1621000000000001`},0.3637451918639532`},{{0.21`,23.`,0.93668`,1.1666`},0.35673770617405326`},{{0.21`,23.`,0.93668`,1.1711`},0.35673770617405326`},{{0.21`,23.`,0.93668`,1.1621000000000001`},0.35673770617405326`},{{0.21`,23.6`,0.94018`,1.1666`},0.3601082325812322`},{{0.21`,23.6`,0.94018`,1.1711`},0.3601082325812322`},{{0.21`,23.6`,0.94018`,1.1621000000000001`},0.3601082325812322`},{{0.21`,23.6`,0.94368`,1.1666`},0.36364905613260273`},{{0.21`,23.6`,0.94368`,1.1711`},0.36364905613260273`},{{0.21`,23.6`,0.94368`,1.1621000000000001`},0.36364905613260273`},{{0.21`,23.6`,0.93668`,1.1666`},0.3566130762144048`},{{0.21`,23.6`,0.93668`,1.1711`},0.3566130762144048`},{{0.21`,23.6`,0.93668`,1.1621000000000001`},0.3566130762144048`},{{0.21`,24.2`,0.94018`,1.1666`},0.3599793592212231`},{{0.21`,24.2`,0.94018`,1.1711`},0.3599793592212231`},{{0.21`,24.2`,0.94018`,1.1621000000000001`},0.3599793592212231`},{{0.21`,24.2`,0.94368`,1.1666`},0.3635339403827485`},{{0.21`,24.2`,0.94368`,1.1711`},0.3635339403827485`},{{0.21`,24.2`,0.94368`,1.1621000000000001`},0.3635339403827485`},{{0.21`,24.2`,0.93668`,1.1666`},0.35647063447322047`},{{0.21`,24.2`,0.93668`,1.1711`},0.35647063447322047`},{{0.21`,24.2`,0.93668`,1.1621000000000001`},0.35647063447322047`},{{0.21`,24.8`,0.94018`,1.1666`},0.35983492487567037`},{{0.21`,24.8`,0.94018`,1.1711`},0.35983492487567037`},{{0.21`,24.8`,0.94018`,1.1621000000000001`},0.35983492487567037`},{{0.21`,24.8`,0.94368`,1.1666`},0.3634027173351038`},{{0.21`,24.8`,0.94368`,1.1711`},0.3634027173351038`},{{0.21`,24.8`,0.94368`,1.1621000000000001`},0.3634027173351038`},{{0.21`,24.8`,0.93668`,1.1666`},0.35631317033626736`},{{0.21`,24.8`,0.93668`,1.1711`},0.35631317033626736`},{{0.21`,24.8`,0.93668`,1.1621000000000001`},0.35631317033626736`},{{0.21`,25.4`,0.94018`,1.1666`},0.3596762859823218`},{{0.21`,25.4`,0.94018`,1.1711`},0.3596762859823218`},{{0.21`,25.4`,0.94018`,1.1621000000000001`},0.3596762859823218`},{{0.21`,25.4`,0.94368`,1.1666`},0.36325678023895264`},{{0.21`,25.4`,0.94368`,1.1711`},0.36325678023895264`},{{0.21`,25.4`,0.94368`,1.1621000000000001`},0.36325678023895264`},{{0.21`,25.4`,0.93668`,1.1666`},0.3561420041325119`},{{0.21`,25.4`,0.93668`,1.1711`},0.3561420041325119`},{{0.21`,25.4`,0.93668`,1.1621000000000001`},0.3561420041325119`},{{0.21`,26.`,0.94018`,1.1666`},0.35950495648844766`},{{0.21`,26.`,0.94018`,1.1711`},0.35950495648844766`},{{0.21`,26.`,0.94018`,1.1621000000000001`},0.35950495648844766`},{{0.21`,26.`,0.94368`,1.1666`},0.3630976774153689`},{{0.21`,26.`,0.94368`,1.1711`},0.3630976774153689`},{{0.21`,26.`,0.94368`,1.1621000000000001`},0.3630976774153689`},{{0.21`,26.`,0.93668`,1.1666`},0.35595861587265554`},{{0.21`,26.`,0.93668`,1.1711`},0.35595861587265554`},{{0.21`,26.`,0.93668`,1.1621000000000001`},0.35595861587265554`},{{0.21`,26.6`,0.94018`,1.1666`},0.35932229012821665`},{{0.21`,26.6`,0.94018`,1.1711`},0.35932229012821665`},{{0.21`,26.6`,0.94018`,1.1621000000000001`},0.35932229012821665`},{{0.21`,26.6`,0.94368`,1.1666`},0.3629267942763414`},{{0.21`,26.6`,0.94368`,1.1711`},0.3629267942763414`},{{0.21`,26.6`,0.94368`,1.1621000000000001`},0.3629267942763414`},{{0.21`,26.6`,0.93668`,1.1666`},0.3557643280186164`},{{0.21`,26.6`,0.93668`,1.1711`},0.3557643280186164`},{{0.21`,26.6`,0.93668`,1.1621000000000001`},0.3557643280186164`},{{0.21`,27.2`,0.94018`,1.1666`},0.35912885234372866`},{{0.21`,27.2`,0.94018`,1.1711`},0.35912885234372866`},{{0.21`,27.2`,0.94018`,1.1621000000000001`},0.35912885234372866`},{{0.21`,27.2`,0.94368`,1.1666`},0.3627447266099035`},{{0.21`,27.2`,0.94368`,1.1711`},0.3627447266099035`},{{0.21`,27.2`,0.94368`,1.1621000000000001`},0.3627447266099035`},{{0.21`,27.2`,0.93668`,1.1666`},0.3555596764826332`},{{0.21`,27.2`,0.93668`,1.1711`},0.3555596764826332`},{{0.21`,27.2`,0.93668`,1.1621000000000001`},0.3555596764826332`},{{0.21`,27.8`,0.94018`,1.1666`},0.35892652344480364`},{{0.21`,27.8`,0.94018`,1.1711`},0.35892652344480364`},{{0.21`,27.8`,0.94018`,1.1621000000000001`},0.35892652344480364`},{{0.21`,27.8`,0.94368`,1.1666`},0.36255338244313196`},{{0.21`,27.8`,0.94368`,1.1711`},0.36255338244313196`},{{0.21`,27.8`,0.94368`,1.1621000000000001`},0.36255338244313196`},{{0.21`,27.8`,0.93668`,1.1666`},0.35534651359414315`},{{0.21`,27.8`,0.93668`,1.1711`},0.35534651359414315`},{{0.21`,27.8`,0.93668`,1.1621000000000001`},0.35534651359414315`},{{0.21`,28.4`,0.94018`,1.1666`},0.3587161122220758`},{{0.21`,28.4`,0.94018`,1.1711`},0.3587161122220758`},{{0.21`,28.4`,0.94018`,1.1621000000000001`},0.3587161122220758`},{{0.21`,28.4`,0.94368`,1.1666`},0.36235359322155347`},{{0.21`,28.4`,0.94368`,1.1711`},0.36235359322155347`},{{0.21`,28.4`,0.94368`,1.1621000000000001`},0.36235359322155347`},{{0.21`,28.4`,0.93668`,1.1666`},0.3551256260143241`},{{0.21`,28.4`,0.93668`,1.1711`},0.3551256260143241`},{{0.21`,28.4`,0.93668`,1.1621000000000001`},0.3551256260143241`},{{0.21`,29.`,0.94018`,1.1666`},0.35849853793969105`},{{0.21`,29.`,0.94018`,1.1711`},0.35849853793969105`},{{0.21`,29.`,0.94018`,1.1621000000000001`},0.35849853793969105`},{{0.21`,29.`,0.94368`,1.1666`},0.3621463006044051`},{{0.21`,29.`,0.94368`,1.1711`},0.3621463006044051`},{{0.21`,29.`,0.94368`,1.1621000000000001`},0.3621463006044051`},{{0.21`,29.`,0.93668`,1.1666`},0.35489791090543277`},{{0.21`,29.`,0.93668`,1.1711`},0.35489791090543277`},{{0.21`,29.`,0.93668`,1.1621000000000001`},0.35489791090543277`},{{0.21`,29.6`,0.94018`,1.1666`},0.35827432125689257`},{{0.21`,29.6`,0.94018`,1.1711`},0.35827432125689257`},{{0.21`,29.6`,0.94018`,1.1621000000000001`},0.35827432125689257`},{{0.21`,29.6`,0.94368`,1.1666`},0.36193204610760743`},{{0.21`,29.6`,0.94368`,1.1711`},0.36193204610760743`},{{0.21`,29.6`,0.94368`,1.1621000000000001`},0.36193204610760743`},{{0.21`,29.6`,0.93668`,1.1666`},0.3546638685969116`},{{0.21`,29.6`,0.93668`,1.1711`},0.3546638685969116`},{{0.21`,29.6`,0.93668`,1.1621000000000001`},0.3546638685969116`},{{0.21`,30.2`,0.94018`,1.1666`},0.35804447247886706`},{{0.21`,30.2`,0.94018`,1.1711`},0.35804447247886706`},{{0.21`,30.2`,0.94018`,1.1621000000000001`},0.35804447247886706`},{{0.21`,30.2`,0.94368`,1.1666`},0.3617118614706421`},{{0.21`,30.2`,0.94368`,1.1711`},0.3617118614706421`},{{0.21`,30.2`,0.94368`,1.1621000000000001`},0.3617118614706421`},{{0.21`,30.2`,0.93668`,1.1666`},0.35442448794376596`},{{0.21`,30.2`,0.93668`,1.1711`},0.35442448794376596`},{{0.21`,30.2`,0.93668`,1.1621000000000001`},0.35442448794376596`},{{0.21`,30.8`,0.94018`,1.1666`},0.3578096266586481`},{{0.21`,30.8`,0.94018`,1.1711`},0.3578096266586481`},{{0.21`,30.8`,0.94018`,1.1621000000000001`},0.3578096266586481`},{{0.21`,30.8`,0.94368`,1.1666`},0.36148639792139936`},{{0.21`,30.8`,0.94368`,1.1711`},0.36148639792139936`},{{0.21`,30.8`,0.94368`,1.1621000000000001`},0.36148639792139936`},{{0.21`,30.8`,0.93668`,1.1666`},0.35418038817823694`},{{0.21`,30.8`,0.93668`,1.1711`},0.35418038817823694`},{{0.21`,30.8`,0.93668`,1.1621000000000001`},0.35418038817823694`},{{0.21`,31.4`,0.94018`,1.1666`},0.35757040198152906`},{{0.21`,31.4`,0.94018`,1.1711`},0.35757040198152906`},{{0.21`,31.4`,0.94018`,1.1621000000000001`},0.35757040198152906`},{{0.21`,31.4`,0.94368`,1.1666`},0.36125629008153554`},{{0.21`,31.4`,0.94368`,1.1711`},0.36125629008153554`},{{0.21`,31.4`,0.94368`,1.1621000000000001`},0.36125629008153554`},{{0.21`,31.4`,0.93668`,1.1666`},0.35393217131227495`},{{0.21`,31.4`,0.93668`,1.1711`},0.35393217131227495`},{{0.21`,31.4`,0.93668`,1.1621000000000001`},0.35393217131227495`},{{0.21`,32.`,0.94018`,1.1666`},0.35732723326636656`},{{0.21`,32.`,0.94018`,1.1711`},0.35732723326636656`},{{0.21`,32.`,0.94018`,1.1621000000000001`},0.35732723326636656`},{{0.21`,32.`,0.94368`,1.1666`},0.3610219811719241`},{{0.21`,32.`,0.94368`,1.1711`},0.3610219811719241`},{{0.21`,32.`,0.94368`,1.1621000000000001`},0.3610219811719241`},{{0.21`,32.`,0.93668`,1.1666`},0.35368025767268885`},{{0.21`,32.`,0.93668`,1.1711`},0.35368025767268885`},{{0.21`,32.`,0.93668`,1.1621000000000001`},0.35368025767268885`},{{0.21`,32.6`,0.94018`,1.1666`},0.3570806823311453`},{{0.21`,32.6`,0.94018`,1.1711`},0.3570806823311453`},{{0.21`,32.6`,0.94018`,1.1621000000000001`},0.3570806823311453`},{{0.21`,32.6`,0.94368`,1.1666`},0.36078405954099907`},{{0.21`,32.6`,0.94368`,1.1711`},0.36078405954099907`},{{0.21`,32.6`,0.94368`,1.1621000000000001`},0.36078405954099907`},{{0.21`,32.6`,0.93668`,1.1666`},0.3534251928566174`},{{0.21`,32.6`,0.93668`,1.1711`},0.3534251928566174`},{{0.21`,32.6`,0.93668`,1.1621000000000001`},0.3534251928566174`},{{0.21`,33.2`,0.94018`,1.1666`},0.35683122503615106`},{{0.21`,33.2`,0.94018`,1.1711`},0.35683122503615106`},{{0.21`,33.2`,0.94018`,1.1621000000000001`},0.35683122503615106`},{{0.21`,33.2`,0.94368`,1.1666`},0.3605430083495781`},{{0.21`,33.2`,0.94368`,1.1711`},0.3605430083495781`},{{0.21`,33.2`,0.94368`,1.1621000000000001`},0.3605430083495781`},{{0.21`,33.2`,0.93668`,1.1666`},0.35316744099361297`},{{0.21`,33.2`,0.93668`,1.1711`},0.35316744099361297`},{{0.21`,33.2`,0.93668`,1.1621000000000001`},0.35316744099361297`},{{0.21`,33.8`,0.94018`,1.1666`},0.35657927409459467`},{{0.21`,33.8`,0.94018`,1.1711`},0.35657927409459467`},{{0.21`,33.8`,0.94018`,1.1621000000000001`},0.35657927409459467`},{{0.21`,33.8`,0.94368`,1.1666`},0.3602992580650309`},{{0.21`,33.8`,0.94368`,1.1711`},0.3602992580650309`},{{0.21`,33.8`,0.94368`,1.1621000000000001`},0.3602992580650309`},{{0.21`,33.8`,0.93668`,1.1666`},0.35290740835897666`},{{0.21`,33.8`,0.93668`,1.1711`},0.35290740835897666`},{{0.21`,33.8`,0.93668`,1.1621000000000001`},0.35290740835897666`},{{0.21`,34.4`,0.94018`,1.1666`},0.35632522078623025`},{{0.21`,34.4`,0.94018`,1.1711`},0.35632522078623025`},{{0.21`,34.4`,0.94018`,1.1621000000000001`},0.35632522078623025`},{{0.21`,34.4`,0.94368`,1.1666`},0.3600532019918185`},{{0.21`,34.4`,0.94368`,1.1711`},0.3600532019918185`},{{0.21`,34.4`,0.94368`,1.1621000000000001`},0.3600532019918185`},{{0.21`,34.4`,0.93668`,1.1666`},0.35264546578697487`},{{0.21`,34.4`,0.93668`,1.1711`},0.35264546578697487`},{{0.21`,34.4`,0.93668`,1.1621000000000001`},0.35264546578697487`},{{0.21`,35.`,0.94018`,1.1666`},0.3560694155924224`},{{0.21`,35.`,0.94018`,1.1711`},0.3560694155924224`},{{0.21`,35.`,0.94018`,1.1621000000000001`},0.3560694155924224`},{{0.21`,35.`,0.94368`,1.1666`},0.3598052055105666`},{{0.21`,35.`,0.94368`,1.1711`},0.3598052055105666`},{{0.21`,35.`,0.94368`,1.1621000000000001`},0.3598052055105666`},{{0.21`,35.`,0.93668`,1.1666`},0.35238195714621434`},{{0.21`,35.`,0.93668`,1.1711`},0.35238195714621434`},{{0.21`,35.`,0.93668`,1.1621000000000001`},0.35238195714621434`},{{0.21`,35.6`,0.94018`,1.1666`},0.35581182895725283`},{{0.21`,35.6`,0.94018`,1.1711`},0.35581182895725283`},{{0.21`,35.6`,0.94018`,1.1621000000000001`},0.35581182895725283`},{{0.21`,35.6`,0.94368`,1.1666`},0.3595552495724825`},{{0.21`,35.6`,0.94368`,1.1711`},0.3595552495724825`},{{0.21`,35.6`,0.94368`,1.1621000000000001`},0.3595552495724825`},{{0.21`,35.6`,0.93668`,1.1666`},0.35211684283840383`},{{0.21`,35.6`,0.93668`,1.1711`},0.35211684283840383`},{{0.21`,35.6`,0.93668`,1.1621000000000001`},0.35211684283840383`},{{0.21`,36.2`,0.94018`,1.1666`},0.3555532100957076`},{{0.21`,36.2`,0.94018`,1.1711`},0.3555532100957076`},{{0.21`,36.2`,0.94018`,1.1621000000000001`},0.3555532100957076`},{{0.21`,36.2`,0.94368`,1.1666`},0.35930409208708225`},{{0.21`,36.2`,0.94368`,1.1711`},0.35930409208708225`},{{0.21`,36.2`,0.94368`,1.1621000000000001`},0.35930409208708225`},{{0.21`,36.2`,0.93668`,1.1666`},0.3518508631754776`},{{0.21`,36.2`,0.93668`,1.1711`},0.3518508631754776`},{{0.21`,36.2`,0.93668`,1.1621000000000001`},0.3518508631754776`},{{0.21`,36.8`,0.94018`,1.1666`},0.3552936461224744`},{{0.21`,36.8`,0.94018`,1.1711`},0.3552936461224744`},{{0.21`,36.8`,0.94018`,1.1621000000000001`},0.3552936461224744`},{{0.21`,36.8`,0.94368`,1.1666`},0.35905182884018866`},{{0.21`,36.8`,0.94368`,1.1711`},0.35905182884018866`},{{0.21`,36.8`,0.94368`,1.1621000000000001`},0.35905182884018866`},{{0.21`,36.8`,0.93668`,1.1666`},0.3515840894859762`},{{0.21`,36.8`,0.93668`,1.1711`},0.3515840894859762`},{{0.21`,36.8`,0.93668`,1.1621000000000001`},0.3515840894859762`},{{0.21`,37.4`,0.94018`,1.1666`},0.3550333723438853`},{{0.21`,37.4`,0.94018`,1.1711`},0.3550333723438853`},{{0.21`,37.4`,0.94018`,1.1621000000000001`},0.3550333723438853`},{{0.21`,37.4`,0.94368`,1.1666`},0.3587987032207966`},{{0.21`,37.4`,0.94368`,1.1711`},0.3587987032207966`},{{0.21`,37.4`,0.94368`,1.1621000000000001`},0.3587987032207966`},{{0.21`,37.4`,0.93668`,1.1666`},0.3513167617150884`},{{0.21`,37.4`,0.93668`,1.1711`},0.3513167617150884`},{{0.21`,37.4`,0.93668`,1.1621000000000001`},0.3513167617150884`},{{0.21`,38.`,0.94018`,1.1666`},0.35477260342012196`},{{0.21`,38.`,0.94018`,1.1711`},0.35477260342012196`},{{0.21`,38.`,0.94018`,1.1621000000000001`},0.35477260342012196`},{{0.21`,38.`,0.94368`,1.1666`},0.358544937451105`},{{0.21`,38.`,0.94368`,1.1711`},0.358544937451105`},{{0.21`,38.`,0.94368`,1.1621000000000001`},0.358544937451105`},{{0.21`,38.`,0.93668`,1.1666`},0.35104908145797425`},{{0.21`,38.`,0.93668`,1.1711`},0.35104908145797425`},{{0.21`,38.`,0.93668`,1.1621000000000001`},0.35104908145797425`},{{0.21`,38.6`,0.94018`,1.1666`},0.3545115352135598`},{{0.21`,38.6`,0.94018`,1.1711`},0.3545115352135598`},{{0.21`,38.6`,0.94018`,1.1621000000000001`},0.3545115352135598`},{{0.21`,38.6`,0.94368`,1.1666`},0.3582907344736782`},{{0.21`,38.6`,0.94368`,1.1711`},0.3582907344736782`},{{0.21`,38.6`,0.94368`,1.1621000000000001`},0.3582907344736782`},{{0.21`,38.6`,0.93668`,1.1666`},0.3507812375810006`},{{0.21`,38.6`,0.93668`,1.1711`},0.3507812375810006`},{{0.21`,38.6`,0.93668`,1.1621000000000001`},0.3507812375810006`},{{0.21`,39.2`,0.94018`,1.1666`},0.3542503464531757`},{{0.21`,39.2`,0.94018`,1.1711`},0.3542503464531757`},{{0.21`,39.2`,0.94018`,1.1621000000000001`},0.3542503464531757`},{{0.21`,39.2`,0.94368`,1.1666`},0.35803627965139967`},{{0.21`,39.2`,0.94368`,1.1711`},0.35803627965139967`},{{0.21`,39.2`,0.94368`,1.1621000000000001`},0.35803627965139967`},{{0.21`,39.2`,0.93668`,1.1666`},0.3505134022571033`},{{0.21`,39.2`,0.93668`,1.1711`},0.3505134022571033`},{{0.21`,39.2`,0.93668`,1.1621000000000001`},0.3505134022571033`},{{0.21`,39.8`,0.94018`,1.1666`},0.3539892002339224`},{{0.21`,39.8`,0.94018`,1.1711`},0.3539892002339224`},{{0.21`,39.8`,0.94018`,1.1621000000000001`},0.3539892002339224`},{{0.21`,39.8`,0.94368`,1.1666`},0.35778174229944004`},{{0.21`,39.8`,0.94368`,1.1711`},0.35778174229944004`},{{0.21`,39.8`,0.94368`,1.1621000000000001`},0.35778174229944004`},{{0.21`,39.8`,0.93668`,1.1666`},0.350245732432983`},{{0.21`,39.8`,0.93668`,1.1711`},0.350245732432983`},{{0.21`,39.8`,0.93668`,1.1621000000000001`},0.350245732432983`},{{0.24000000000000002`,0.4`,0.94018`,1.1666`},0.25553753680647767`},{{0.24000000000000002`,0.4`,0.94018`,1.1711`},0.25553753680647767`},{{0.24000000000000002`,0.4`,0.94018`,1.1621000000000001`},0.25553753680647767`},{{0.24000000000000002`,0.4`,0.94368`,1.1666`},0.2558251667840771`},{{0.24000000000000002`,0.4`,0.94368`,1.1711`},0.2558251667840771`},{{0.24000000000000002`,0.4`,0.94368`,1.1621000000000001`},0.2558251667840771`},{{0.24000000000000002`,0.4`,0.93668`,1.1666`},0.25525340460306645`},{{0.24000000000000002`,0.4`,0.93668`,1.1711`},0.25525340460306645`},{{0.24000000000000002`,0.4`,0.93668`,1.1621000000000001`},0.25525340460306645`},{{0.24000000000000002`,0.6`,0.94018`,1.1666`},0.2625215149215479`},{{0.24000000000000002`,0.6`,0.94018`,1.1711`},0.2625215149215479`},{{0.24000000000000002`,0.6`,0.94018`,1.1621000000000001`},0.2625215149215479`},{{0.24000000000000002`,0.6`,0.94368`,1.1666`},0.26294072221462117`},{{0.24000000000000002`,0.6`,0.94368`,1.1711`},0.26294072221462117`},{{0.24000000000000002`,0.6`,0.94368`,1.1621000000000001`},0.26294072221462117`},{{0.24000000000000002`,0.6`,0.93668`,1.1666`},0.2621074266776336`},{{0.24000000000000002`,0.6`,0.93668`,1.1711`},0.2621074266776336`},{{0.24000000000000002`,0.6`,0.93668`,1.1621000000000001`},0.2621074266776336`},{{0.24000000000000002`,0.8`,0.94018`,1.1666`},0.2690388121751506`},{{0.24000000000000002`,0.8`,0.94018`,1.1711`},0.2690388121751506`},{{0.24000000000000002`,0.8`,0.94018`,1.1621000000000001`},0.2690388121751506`},{{0.24000000000000002`,0.8`,0.94368`,1.1666`},0.2695822201449396`},{{0.24000000000000002`,0.8`,0.94368`,1.1711`},0.2695822201449396`},{{0.24000000000000002`,0.8`,0.94368`,1.1621000000000001`},0.2695822201449396`},{{0.24000000000000002`,0.8`,0.93668`,1.1666`},0.26850206560494433`},{{0.24000000000000002`,0.8`,0.93668`,1.1711`},0.26850206560494433`},{{0.24000000000000002`,0.8`,0.93668`,1.1621000000000001`},0.26850206560494433`},{{0.24000000000000002`,1.`,0.94018`,1.1666`},0.27512667292358806`},{{0.24000000000000002`,1.`,0.94018`,1.1711`},0.27512667292358806`},{{0.24000000000000002`,1.`,0.94018`,1.1621000000000001`},0.27512667292358806`},{{0.24000000000000002`,1.`,0.94368`,1.1666`},0.2757874294674435`},{{0.24000000000000002`,1.`,0.94368`,1.1711`},0.2757874294674435`},{{0.24000000000000002`,1.`,0.94368`,1.1621000000000001`},0.2757874294674435`},{{0.24000000000000002`,1.`,0.93668`,1.1666`},0.2744740455675807`},{{0.24000000000000002`,1.`,0.93668`,1.1711`},0.2744740455675807`},{{0.24000000000000002`,1.`,0.93668`,1.1621000000000001`},0.2744740455675807`},{{0.24000000000000002`,1.2`,0.94018`,1.1666`},0.2808187870564494`},{{0.24000000000000002`,1.2`,0.94018`,1.1711`},0.2808187870564494`},{{0.24000000000000002`,1.2`,0.94018`,1.1621000000000001`},0.2808187870564494`},{{0.24000000000000002`,1.2`,0.94368`,1.1666`},0.2815905207224266`},{{0.24000000000000002`,1.2`,0.94368`,1.1711`},0.2815905207224266`},{{0.24000000000000002`,1.2`,0.94368`,1.1621000000000001`},0.2815905207224266`},{{0.24000000000000002`,1.2`,0.93668`,1.1666`},0.28005657995637556`},{{0.24000000000000002`,1.2`,0.93668`,1.1711`},0.28005657995637556`},{{0.24000000000000002`,1.2`,0.93668`,1.1621000000000001`},0.28005657995637556`},{{0.24000000000000002`,1.4`,0.94018`,1.1666`},0.28614568513904226`},{{0.24000000000000002`,1.4`,0.94018`,1.1711`},0.28614568513904226`},{{0.24000000000000002`,1.4`,0.94018`,1.1621000000000001`},0.28614568513904226`},{{0.24000000000000002`,1.4`,0.94368`,1.1666`},0.28702246533940445`},{{0.24000000000000002`,1.4`,0.94368`,1.1711`},0.28702246533940445`},{{0.24000000000000002`,1.4`,0.94368`,1.1621000000000001`},0.28702246533940445`},{{0.24000000000000002`,1.4`,0.93668`,1.1666`},0.28527976241378517`},{{0.24000000000000002`,1.4`,0.93668`,1.1711`},0.28527976241378517`},{{0.24000000000000002`,1.4`,0.93668`,1.1621000000000001`},0.28527976241378517`},{{0.24000000000000002`,1.6`,0.94018`,1.1666`},0.29113508337446986`},{{0.24000000000000002`,1.6`,0.94018`,1.1711`},0.29113508337446986`},{{0.24000000000000002`,1.6`,0.94018`,1.1621000000000001`},0.29113508337446986`},{{0.24000000000000002`,1.6`,0.94368`,1.1666`},0.2921113843481704`},{{0.24000000000000002`,1.6`,0.94368`,1.1711`},0.2921113843481704`},{{0.24000000000000002`,1.6`,0.94368`,1.1621000000000001`},0.2921113843481704`},{{0.24000000000000002`,1.6`,0.93668`,1.1666`},0.290170908040159`},{{0.24000000000000002`,1.6`,0.93668`,1.1711`},0.290170908040159`},{{0.24000000000000002`,1.6`,0.93668`,1.1621000000000001`},0.290170908040159`},{{0.24000000000000002`,1.8`,0.94018`,1.1666`},0.2958121862934591`},{{0.24000000000000002`,1.8`,0.94018`,1.1711`},0.2958121862934591`},{{0.24000000000000002`,1.8`,0.94018`,1.1621000000000001`},0.2958121862934591`},{{0.24000000000000002`,1.8`,0.94368`,1.1666`},0.29688285431649813`},{{0.24000000000000002`,1.8`,0.94368`,1.1711`},0.29688285431649813`},{{0.24000000000000002`,1.8`,0.94368`,1.1621000000000001`},0.29688285431649813`},{{0.24000000000000002`,1.8`,0.93668`,1.1666`},0.29475485285278247`},{{0.24000000000000002`,1.8`,0.93668`,1.1711`},0.29475485285278247`},{{0.24000000000000002`,1.8`,0.93668`,1.1621000000000001`},0.29475485285278247`},{{0.24000000000000002`,2.`,0.94018`,1.1666`},0.3001999517508591`},{{0.24000000000000002`,2.`,0.94018`,1.1711`},0.3001999517508591`},{{0.24000000000000002`,2.`,0.94018`,1.1621000000000001`},0.3001999517508591`},{{0.24000000000000002`,2.`,0.94368`,1.1666`},0.3013601754107131`},{{0.24000000000000002`,2.`,0.94368`,1.1711`},0.3013601754107131`},{{0.24000000000000002`,2.`,0.94368`,1.1621000000000001`},0.3013601754107131`},{{0.24000000000000002`,2.`,0.93668`,1.1666`},0.2990542157173471`},{{0.24000000000000002`,2.`,0.93668`,1.1711`},0.2990542157173471`},{{0.24000000000000002`,2.`,0.93668`,1.1621000000000001`},0.2990542157173471`},{{0.24000000000000002`,2.2`,0.94018`,1.1666`},0.30431932448039295`},{{0.24000000000000002`,2.2`,0.94018`,1.1711`},0.30431932448039295`},{{0.24000000000000002`,2.2`,0.94018`,1.1621000000000001`},0.30431932448039295`},{{0.24000000000000002`,2.2`,0.94368`,1.1666`},0.3055646076401046`},{{0.24000000000000002`,2.2`,0.94368`,1.1711`},0.3055646076401046`},{{0.24000000000000002`,2.2`,0.94368`,1.1621000000000001`},0.3055646076401046`},{{0.24000000000000002`,2.2`,0.93668`,1.1666`},0.303089629222877`},{{0.24000000000000002`,2.2`,0.93668`,1.1711`},0.303089629222877`},{{0.24000000000000002`,2.2`,0.93668`,1.1621000000000001`},0.303089629222877`},{{0.24000000000000002`,2.6`,0.94018`,1.1666`},0.311825912494262`},{{0.24000000000000002`,2.6`,0.94018`,1.1711`},0.311825912494262`},{{0.24000000000000002`,2.6`,0.94018`,1.1621000000000001`},0.311825912494262`},{{0.24000000000000002`,2.6`,0.94368`,1.1666`},0.31322896001831024`},{{0.24000000000000002`,2.6`,0.94368`,1.1711`},0.31322896001831024`},{{0.24000000000000002`,2.6`,0.94368`,1.1621000000000001`},0.31322896001831024`},{{0.24000000000000002`,2.6`,0.93668`,1.1666`},0.3104405072680141`},{{0.24000000000000002`,2.6`,0.93668`,1.1711`},0.3104405072680141`},{{0.24000000000000002`,2.6`,0.93668`,1.1621000000000001`},0.3104405072680141`},{{0.24000000000000002`,3.`,0.94018`,1.1666`},0.3184675120685497`},{{0.24000000000000002`,3.`,0.94018`,1.1711`},0.3184675120685497`},{{0.24000000000000002`,3.`,0.94018`,1.1621000000000001`},0.3184675120685497`},{{0.24000000000000002`,3.`,0.94368`,1.1666`},0.32001355558852984`},{{0.24000000000000002`,3.`,0.94368`,1.1711`},0.32001355558852984`},{{0.24000000000000002`,3.`,0.94368`,1.1621000000000001`},0.32001355558852984`},{{0.24000000000000002`,3.`,0.93668`,1.1666`},0.31694098725528247`},{{0.24000000000000002`,3.`,0.93668`,1.1711`},0.31694098725528247`},{{0.24000000000000002`,3.`,0.93668`,1.1621000000000001`},0.31694098725528247`},{{0.24000000000000002`,3.4`,0.94018`,1.1666`},0.324357855133122`},{{0.24000000000000002`,3.4`,0.94018`,1.1711`},0.324357855133122`},{{0.24000000000000002`,3.4`,0.94018`,1.1621000000000001`},0.324357855133122`},{{0.24000000000000002`,3.4`,0.94368`,1.1666`},0.3260338897273733`},{{0.24000000000000002`,3.4`,0.94368`,1.1711`},0.3260338897273733`},{{0.24000000000000002`,3.4`,0.94368`,1.1621000000000001`},0.3260338897273733`},{{0.24000000000000002`,3.4`,0.93668`,1.1666`},0.3227030569229881`},{{0.24000000000000002`,3.4`,0.93668`,1.1711`},0.3227030569229881`},{{0.24000000000000002`,3.4`,0.93668`,1.1621000000000001`},0.3227030569229881`},{{0.24000000000000002`,3.8`,0.94018`,1.1666`},0.3295927584239483`},{{0.24000000000000002`,3.8`,0.94018`,1.1711`},0.3295927584239483`},{{0.24000000000000002`,3.8`,0.94018`,1.1621000000000001`},0.3295927584239483`},{{0.24000000000000002`,3.8`,0.94368`,1.1666`},0.33138729710144477`},{{0.24000000000000002`,3.8`,0.94368`,1.1711`},0.33138729710144477`},{{0.24000000000000002`,3.8`,0.94368`,1.1621000000000001`},0.33138729710144477`},{{0.24000000000000002`,3.8`,0.93668`,1.1666`},0.32782103172185084`},{{0.24000000000000002`,3.8`,0.93668`,1.1711`},0.32782103172185084`},{{0.24000000000000002`,3.8`,0.93668`,1.1621000000000001`},0.32782103172185084`},{{0.24000000000000002`,4.2`,0.94018`,1.1666`},0.33425376519361366`},{{0.24000000000000002`,4.2`,0.94018`,1.1711`},0.33425376519361366`},{{0.24000000000000002`,4.2`,0.94018`,1.1621000000000001`},0.33425376519361366`},{{0.24000000000000002`,4.2`,0.94368`,1.1666`},0.33615662931117674`},{{0.24000000000000002`,4.2`,0.94368`,1.1711`},0.33615662931117674`},{{0.24000000000000002`,4.2`,0.94368`,1.1621000000000001`},0.33615662931117674`},{{0.24000000000000002`,4.2`,0.93668`,1.1666`},0.3323751613356141`},{{0.24000000000000002`,4.2`,0.93668`,1.1711`},0.3323751613356141`},{{0.24000000000000002`,4.2`,0.93668`,1.1621000000000001`},0.3323751613356141`},{{0.24000000000000002`,4.6`,0.94018`,1.1666`},0.3384111505481803`},{{0.24000000000000002`,4.6`,0.94018`,1.1711`},0.3384111505481803`},{{0.24000000000000002`,4.6`,0.94018`,1.1621000000000001`},0.3384111505481803`},{{0.24000000000000002`,4.6`,0.94368`,1.1666`},0.34041329583399393`},{{0.24000000000000002`,4.6`,0.94368`,1.1711`},0.34041329583399393`},{{0.24000000000000002`,4.6`,0.94368`,1.1621000000000001`},0.34041329583399393`},{{0.24000000000000002`,4.6`,0.93668`,1.1666`},0.3364345993847449`},{{0.24000000000000002`,4.6`,0.93668`,1.1711`},0.3364345993847449`},{{0.24000000000000002`,4.6`,0.93668`,1.1621000000000001`},0.3364345993847449`},{{0.24000000000000002`,5.`,0.94018`,1.1666`},0.3421247026636282`},{{0.24000000000000002`,5.`,0.94018`,1.1711`},0.3421247026636282`},{{0.24000000000000002`,5.`,0.94018`,1.1621000000000001`},0.3421247026636282`},{{0.24000000000000002`,5.`,0.94368`,1.1666`},0.34421805741512523`},{{0.24000000000000002`,5.`,0.94368`,1.1711`},0.34421805741512523`},{{0.24000000000000002`,5.`,0.94368`,1.1621000000000001`},0.34421805741512523`},{{0.24000000000000002`,5.`,0.93668`,1.1666`},0.34005817306993186`},{{0.24000000000000002`,5.`,0.93668`,1.1711`},0.34005817306993186`},{{0.24000000000000002`,5.`,0.93668`,1.1621000000000001`},0.34005817306993186`},{{0.24000000000000002`,5.4`,0.94018`,1.1666`},0.34544541531366757`},{{0.24000000000000002`,5.4`,0.94018`,1.1711`},0.34544541531366757`},{{0.24000000000000002`,5.4`,0.94018`,1.1621000000000001`},0.34544541531366757`},{{0.24000000000000002`,5.4`,0.94368`,1.1666`},0.34762276729598784`},{{0.24000000000000002`,5.4`,0.94368`,1.1711`},0.34762276729598784`},{{0.24000000000000002`,5.4`,0.94368`,1.1621000000000001`},0.34762276729598784`},{{0.24000000000000002`,5.4`,0.93668`,1.1666`},0.34329602693860295`},{{0.24000000000000002`,5.4`,0.93668`,1.1711`},0.34329602693860295`},{{0.24000000000000002`,5.4`,0.93668`,1.1621000000000001`},0.34329602693860295`},{{0.24000000000000002`,5.8`,0.94018`,1.1666`},0.3484178913016698`},{{0.24000000000000002`,5.8`,0.94018`,1.1711`},0.3484178913016698`},{{0.24000000000000002`,5.8`,0.94018`,1.1621000000000001`},0.3484178913016698`},{{0.24000000000000002`,5.8`,0.94368`,1.1666`},0.350672774895893`},{{0.24000000000000002`,5.8`,0.94368`,1.1711`},0.350672774895893`},{{0.24000000000000002`,5.8`,0.94368`,1.1621000000000001`},0.350672774895893`},{{0.24000000000000002`,5.8`,0.93668`,1.1666`},0.34619202619653533`},{{0.24000000000000002`,5.8`,0.93668`,1.1711`},0.34619202619653533`},{{0.24000000000000002`,5.8`,0.93668`,1.1621000000000001`},0.34619202619653533`},{{0.24000000000000002`,6.2`,0.94018`,1.1666`},0.35108085130538125`},{{0.24000000000000002`,6.2`,0.94018`,1.1711`},0.35108085130538125`},{{0.24000000000000002`,6.2`,0.94018`,1.1621000000000001`},0.35108085130538125`},{{0.24000000000000002`,6.2`,0.94368`,1.1666`},0.35340745526161116`},{{0.24000000000000002`,6.2`,0.94368`,1.1711`},0.35340745526161116`},{{0.24000000000000002`,6.2`,0.94368`,1.1621000000000001`},0.35340745526161116`},{{0.24000000000000002`,6.2`,0.93668`,1.1666`},0.3487842451513632`},{{0.24000000000000002`,6.2`,0.93668`,1.1711`},0.3487842451513632`},{{0.24000000000000002`,6.2`,0.93668`,1.1621000000000001`},0.3487842451513632`},{{0.24000000000000002`,6.8`,0.94018`,1.1666`},0.35456726638857106`},{{0.24000000000000002`,6.8`,0.94018`,1.1711`},0.35456726638857106`},{{0.24000000000000002`,6.8`,0.94018`,1.1621000000000001`},0.35456726638857106`},{{0.24000000000000002`,6.8`,0.94368`,1.1666`},0.3569917927024098`},{{0.24000000000000002`,6.8`,0.94368`,1.1711`},0.3569917927024098`},{{0.24000000000000002`,6.8`,0.94368`,1.1621000000000001`},0.3569917927024098`},{{0.24000000000000002`,6.8`,0.93668`,1.1666`},0.3521740805265995`},{{0.24000000000000002`,6.8`,0.93668`,1.1711`},0.3521740805265995`},{{0.24000000000000002`,6.8`,0.93668`,1.1621000000000001`},0.3521740805265995`},{{0.24000000000000002`,7.4`,0.94018`,1.1666`},0.3575282553361838`},{{0.24000000000000002`,7.4`,0.94018`,1.1711`},0.3575282553361838`},{{0.24000000000000002`,7.4`,0.94018`,1.1621000000000001`},0.3575282553361838`},{{0.24000000000000002`,7.4`,0.94368`,1.1666`},0.3600405712714265`},{{0.24000000000000002`,7.4`,0.94368`,1.1711`},0.3600405712714265`},{{0.24000000000000002`,7.4`,0.94368`,1.1621000000000001`},0.3600405712714265`},{{0.24000000000000002`,7.4`,0.93668`,1.1666`},0.35504848916286325`},{{0.24000000000000002`,7.4`,0.93668`,1.1711`},0.35504848916286325`},{{0.24000000000000002`,7.4`,0.93668`,1.1621000000000001`},0.35504848916286325`},{{0.24000000000000002`,8.`,0.94018`,1.1666`},0.3600431709356702`},{{0.24000000000000002`,8.`,0.94018`,1.1711`},0.3600431709356702`},{{0.24000000000000002`,8.`,0.94018`,1.1621000000000001`},0.3600431709356702`},{{0.24000000000000002`,8.`,0.94368`,1.1666`},0.3626345278725297`},{{0.24000000000000002`,8.`,0.94368`,1.1711`},0.3626345278725297`},{{0.24000000000000002`,8.`,0.94368`,1.1621000000000001`},0.3626345278725297`},{{0.24000000000000002`,8.`,0.93668`,1.1666`},0.3574854572318692`},{{0.24000000000000002`,8.`,0.93668`,1.1711`},0.3574854572318692`},{{0.24000000000000002`,8.`,0.93668`,1.1621000000000001`},0.3574854572318692`},{{0.24000000000000002`,8.6`,0.94018`,1.1666`},0.3621781153753193`},{{0.24000000000000002`,8.6`,0.94018`,1.1711`},0.3621781153753193`},{{0.24000000000000002`,8.6`,0.94018`,1.1621000000000001`},0.3621781153753193`},{{0.24000000000000002`,8.6`,0.94368`,1.1666`},0.3648409255294139`},{{0.24000000000000002`,8.6`,0.94368`,1.1711`},0.3648409255294139`},{{0.24000000000000002`,8.6`,0.94368`,1.1621000000000001`},0.3648409255294139`},{{0.24000000000000002`,8.6`,0.93668`,1.1666`},0.3595499408696436`},{{0.24000000000000002`,8.6`,0.93668`,1.1711`},0.3595499408696436`},{{0.24000000000000002`,8.6`,0.93668`,1.1621000000000001`},0.3595499408696436`},{{0.24000000000000002`,9.2`,0.94018`,1.1666`},0.363987664620694`},{{0.24000000000000002`,9.2`,0.94018`,1.1711`},0.363987664620694`},{{0.24000000000000002`,9.2`,0.94018`,1.1621000000000001`},0.363987664620694`},{{0.24000000000000002`,9.2`,0.94368`,1.1666`},0.36671531753469844`},{{0.24000000000000002`,9.2`,0.94368`,1.1711`},0.36671531753469844`},{{0.24000000000000002`,9.2`,0.94368`,1.1621000000000001`},0.36671531753469844`},{{0.24000000000000002`,9.2`,0.93668`,1.1666`},0.36129555133198726`},{{0.24000000000000002`,9.2`,0.93668`,1.1711`},0.36129555133198726`},{{0.24000000000000002`,9.2`,0.93668`,1.1621000000000001`},0.36129555133198726`},{{0.24000000000000002`,9.8`,0.94018`,1.1666`},0.36551781054702787`},{{0.24000000000000002`,9.8`,0.94018`,1.1711`},0.36551781054702787`},{{0.24000000000000002`,9.8`,0.94018`,1.1621000000000001`},0.36551781054702787`},{{0.24000000000000002`,9.8`,0.94368`,1.1666`},0.36830452216388654`},{{0.24000000000000002`,9.8`,0.94368`,1.1711`},0.36830452216388654`},{{0.24000000000000002`,9.8`,0.94368`,1.1621000000000001`},0.36830452216388654`},{{0.24000000000000002`,9.8`,0.93668`,1.1666`},0.3627674648049`},{{0.24000000000000002`,9.8`,0.93668`,1.1711`},0.3627674648049`},{{0.24000000000000002`,9.8`,0.93668`,1.1621000000000001`},0.3627674648049`},{{0.24000000000000002`,10.4`,0.94018`,1.1666`},0.3668067126051966`},{{0.24000000000000002`,10.4`,0.94018`,1.1711`},0.3668067126051966`},{{0.24000000000000002`,10.4`,0.94018`,1.1621000000000001`},0.3668067126051966`},{{0.24000000000000002`,10.4`,0.94368`,1.1666`},0.36964739861837065`},{{0.24000000000000002`,10.4`,0.94368`,1.1711`},0.36964739861837065`},{{0.24000000000000002`,10.4`,0.94368`,1.1621000000000001`},0.36964739861837065`},{{0.24000000000000002`,10.4`,0.93668`,1.1666`},0.36400314897592817`},{{0.24000000000000002`,10.4`,0.93668`,1.1711`},0.36400314897592817`},{{0.24000000000000002`,10.4`,0.93668`,1.1621000000000001`},0.36400314897592817`},{{0.24000000000000002`,11.`,0.94018`,1.1666`},0.36788735463286903`},{{0.24000000000000002`,11.`,0.94018`,1.1711`},0.36788735463286903`},{{0.24000000000000002`,11.`,0.94018`,1.1621000000000001`},0.36788735463286903`},{{0.24000000000000002`,11.`,0.94368`,1.1666`},0.3707775384523352`},{{0.24000000000000002`,11.`,0.94368`,1.1711`},0.3707775384523352`},{{0.24000000000000002`,11.`,0.94368`,1.1621000000000001`},0.3707775384523352`},{{0.24000000000000002`,11.`,0.93668`,1.1666`},0.36503499148402746`},{{0.24000000000000002`,11.`,0.93668`,1.1711`},0.36503499148402746`},{{0.24000000000000002`,11.`,0.93668`,1.1621000000000001`},0.36503499148402746`},{{0.24000000000000002`,11.6`,0.94018`,1.1666`},0.3687873944308421`},{{0.24000000000000002`,11.6`,0.94018`,1.1711`},0.3687873944308421`},{{0.24000000000000002`,11.6`,0.94018`,1.1621000000000001`},0.3687873944308421`},{{0.24000000000000002`,11.6`,0.94368`,1.1666`},0.37172311005417324`},{{0.24000000000000002`,11.6`,0.94368`,1.1711`},0.37172311005417324`},{{0.24000000000000002`,11.6`,0.94368`,1.1621000000000001`},0.37172311005417324`},{{0.24000000000000002`,11.6`,0.93668`,1.1666`},0.36589014275089893`},{{0.24000000000000002`,11.6`,0.93668`,1.1711`},0.36589014275089893`},{{0.24000000000000002`,11.6`,0.93668`,1.1621000000000001`},0.36589014275089893`},{{0.24000000000000002`,12.2`,0.94018`,1.1666`},0.369529724633216`},{{0.24000000000000002`,12.2`,0.94018`,1.1711`},0.369529724633216`},{{0.24000000000000002`,12.2`,0.94018`,1.1621000000000001`},0.369529724633216`},{{0.24000000000000002`,12.2`,0.94368`,1.1666`},0.37250745301946975`},{{0.24000000000000002`,12.2`,0.94368`,1.1711`},0.37250745301946975`},{{0.24000000000000002`,12.2`,0.94368`,1.1621000000000001`},0.37250745301946975`},{{0.24000000000000002`,12.2`,0.93668`,1.1666`},0.366591055654914`},{{0.24000000000000002`,12.2`,0.93668`,1.1711`},0.366591055654914`},{{0.24000000000000002`,12.2`,0.93668`,1.1621000000000001`},0.366591055654914`},{{0.24000000000000002`,12.8`,0.94018`,1.1666`},0.37013528654992467`},{{0.24000000000000002`,12.8`,0.94018`,1.1711`},0.37013528654992467`},{{0.24000000000000002`,12.8`,0.94018`,1.1621000000000001`},0.37013528654992467`},{{0.24000000000000002`,12.8`,0.94368`,1.1666`},0.373151895692982`},{{0.24000000000000002`,12.8`,0.94368`,1.1711`},0.373151895692982`},{{0.24000000000000002`,12.8`,0.94368`,1.1621000000000001`},0.373151895692982`},{{0.24000000000000002`,12.8`,0.93668`,1.1666`},0.36715828939791084`},{{0.24000000000000002`,12.8`,0.93668`,1.1711`},0.36715828939791084`},{{0.24000000000000002`,12.8`,0.93668`,1.1621000000000001`},0.36715828939791084`},{{0.24000000000000002`,13.4`,0.94018`,1.1666`},0.3706210858910586`},{{0.24000000000000002`,13.4`,0.94018`,1.1711`},0.3706210858910586`},{{0.24000000000000002`,13.4`,0.94018`,1.1621000000000001`},0.3706210858910586`},{{0.24000000000000002`,13.4`,0.94368`,1.1666`},0.37367377371192173`},{{0.24000000000000002`,13.4`,0.94368`,1.1711`},0.37367377371192173`},{{0.24000000000000002`,13.4`,0.94368`,1.1621000000000001`},0.37367377371192173`},{{0.24000000000000002`,13.4`,0.93668`,1.1666`},0.36760852435302543`},{{0.24000000000000002`,13.4`,0.93668`,1.1711`},0.36760852435302543`},{{0.24000000000000002`,13.4`,0.93668`,1.1621000000000001`},0.36760852435302543`},{{0.24000000000000002`,14.`,0.94018`,1.1666`},0.3710023953618272`},{{0.24000000000000002`,14.`,0.94018`,1.1711`},0.3710023953618272`},{{0.24000000000000002`,14.`,0.94018`,1.1621000000000001`},0.3710023953618272`},{{0.24000000000000002`,14.`,0.94368`,1.1666`},0.3740886544618608`},{{0.24000000000000002`,14.`,0.94368`,1.1711`},0.3740886544618608`},{{0.24000000000000002`,14.`,0.94368`,1.1621000000000001`},0.3740886544618608`},{{0.24000000000000002`,14.`,0.93668`,1.1666`},0.36795674230749204`},{{0.24000000000000002`,14.`,0.93668`,1.1711`},0.36795674230749204`},{{0.24000000000000002`,14.`,0.93668`,1.1621000000000001`},0.36795674230749204`},{{0.24000000000000002`,14.6`,0.94018`,1.1666`},0.37129222597133754`},{{0.24000000000000002`,14.6`,0.94018`,1.1711`},0.37129222597133754`},{{0.24000000000000002`,14.6`,0.94018`,1.1621000000000001`},0.37129222597133754`},{{0.24000000000000002`,14.6`,0.94368`,1.1666`},0.37440980182164835`},{{0.24000000000000002`,14.6`,0.94368`,1.1711`},0.37440980182164835`},{{0.24000000000000002`,14.6`,0.94368`,1.1621000000000001`},0.37440980182164835`},{{0.24000000000000002`,14.6`,0.93668`,1.1666`},0.3682157047995467`},{{0.24000000000000002`,14.6`,0.93668`,1.1711`},0.3682157047995467`},{{0.24000000000000002`,14.6`,0.93668`,1.1621000000000001`},0.3682157047995467`},{{0.24000000000000002`,15.2`,0.94018`,1.1666`},0.371501254478618`},{{0.24000000000000002`,15.2`,0.94018`,1.1711`},0.371501254478618`},{{0.24000000000000002`,15.2`,0.94018`,1.1621000000000001`},0.371501254478618`},{{0.24000000000000002`,15.2`,0.94368`,1.1666`},0.37464811353679983`},{{0.24000000000000002`,15.2`,0.94368`,1.1711`},0.37464811353679983`},{{0.24000000000000002`,15.2`,0.94368`,1.1621000000000001`},0.37464811353679983`},{{0.24000000000000002`,15.2`,0.93668`,1.1666`},0.36839587079686376`},{{0.24000000000000002`,15.2`,0.93668`,1.1711`},0.36839587079686376`},{{0.24000000000000002`,15.2`,0.93668`,1.1621000000000001`},0.36839587079686376`},{{0.24000000000000002`,15.8`,0.94018`,1.1666`},0.37163976947228894`},{{0.24000000000000002`,15.8`,0.94018`,1.1711`},0.37163976947228894`},{{0.24000000000000002`,15.8`,0.94018`,1.1621000000000001`},0.37163976947228894`},{{0.24000000000000002`,15.8`,0.94368`,1.1666`},0.37481407940822253`},{{0.24000000000000002`,15.8`,0.94368`,1.1711`},0.37481407940822253`},{{0.24000000000000002`,15.8`,0.94368`,1.1621000000000001`},0.37481407940822253`},{{0.24000000000000002`,15.8`,0.93668`,1.1666`},0.3685073300865904`},{{0.24000000000000002`,15.8`,0.93668`,1.1711`},0.3685073300865904`},{{0.24000000000000002`,15.8`,0.93668`,1.1621000000000001`},0.3685073300865904`},{{0.24000000000000002`,16.4`,0.94018`,1.1666`},0.37171624204304393`},{{0.24000000000000002`,16.4`,0.94018`,1.1711`},0.37171624204304393`},{{0.24000000000000002`,16.4`,0.94018`,1.1621000000000001`},0.37171624204304393`},{{0.24000000000000002`,16.4`,0.94368`,1.1666`},0.3749163416704275`},{{0.24000000000000002`,16.4`,0.94368`,1.1711`},0.3749163416704275`},{{0.24000000000000002`,16.4`,0.94368`,1.1621000000000001`},0.3749163416704275`},{{0.24000000000000002`,16.4`,0.93668`,1.1666`},0.3685583849838753`},{{0.24000000000000002`,16.4`,0.93668`,1.1711`},0.3685583849838753`},{{0.24000000000000002`,16.4`,0.93668`,1.1621000000000001`},0.3685583849838753`},{{0.24000000000000002`,17.`,0.94018`,1.1666`},0.37173788229747784`},{{0.24000000000000002`,17.`,0.94018`,1.1711`},0.37173788229747784`},{{0.24000000000000002`,17.`,0.94018`,1.1621000000000001`},0.37173788229747784`},{{0.24000000000000002`,17.`,0.94368`,1.1666`},0.37496226152329226`},{{0.24000000000000002`,17.`,0.94368`,1.1711`},0.37496226152329226`},{{0.24000000000000002`,17.`,0.94368`,1.1621000000000001`},0.37496226152329226`},{{0.24000000000000002`,17.`,0.93668`,1.1666`},0.3685560966855302`},{{0.24000000000000002`,17.`,0.93668`,1.1711`},0.3685560966855302`},{{0.24000000000000002`,17.`,0.93668`,1.1621000000000001`},0.3685560966855302`},{{0.24000000000000002`,17.6`,0.94018`,1.1666`},0.37171128249543417`},{{0.24000000000000002`,17.6`,0.94018`,1.1711`},0.37171128249543417`},{{0.24000000000000002`,17.6`,0.94018`,1.1621000000000001`},0.37171128249543417`},{{0.24000000000000002`,17.6`,0.94368`,1.1666`},0.3749585723291431`},{{0.24000000000000002`,17.6`,0.94368`,1.1711`},0.3749585723291431`},{{0.24000000000000002`,17.6`,0.94368`,1.1621000000000001`},0.3749585723291431`},{{0.24000000000000002`,17.6`,0.93668`,1.1666`},0.3685069180850027`},{{0.24000000000000002`,17.6`,0.93668`,1.1711`},0.3685069180850027`},{{0.24000000000000002`,17.6`,0.93668`,1.1621000000000001`},0.3685069180850027`},{{0.24000000000000002`,18.2`,0.94018`,1.1666`},0.3716427805999936`},{{0.24000000000000002`,18.2`,0.94018`,1.1711`},0.3716427805999936`},{{0.24000000000000002`,18.2`,0.94018`,1.1621000000000001`},0.3716427805999936`},{{0.24000000000000002`,18.2`,0.94368`,1.1666`},0.3749117260631888`},{{0.24000000000000002`,18.2`,0.94368`,1.1711`},0.3749117260631888`},{{0.24000000000000002`,18.2`,0.94368`,1.1621000000000001`},0.3749117260631888`},{{0.24000000000000002`,18.2`,0.93668`,1.1666`},0.36841707438908217`},{{0.24000000000000002`,18.2`,0.93668`,1.1711`},0.36841707438908217`},{{0.24000000000000002`,18.2`,0.93668`,1.1621000000000001`},0.36841707438908217`},{{0.24000000000000002`,18.8`,0.94018`,1.1666`},0.3715365076337374`},{{0.24000000000000002`,18.8`,0.94018`,1.1711`},0.3715365076337374`},{{0.24000000000000002`,18.8`,0.94018`,1.1621000000000001`},0.3715365076337374`},{{0.24000000000000002`,18.8`,0.94368`,1.1666`},0.37482597046957494`},{{0.24000000000000002`,18.8`,0.94368`,1.1711`},0.37482597046957494`},{{0.24000000000000002`,18.8`,0.94368`,1.1621000000000001`},0.37482597046957494`},{{0.24000000000000002`,18.8`,0.93668`,1.1666`},0.3682905820420188`},{{0.24000000000000002`,18.8`,0.93668`,1.1711`},0.3682905820420188`},{{0.24000000000000002`,18.8`,0.93668`,1.1621000000000001`},0.3682905820420188`},{{0.24000000000000002`,19.4`,0.94018`,1.1666`},0.37139695171499043`},{{0.24000000000000002`,19.4`,0.94018`,1.1711`},0.37139695171499043`},{{0.24000000000000002`,19.4`,0.94018`,1.1621000000000001`},0.37139695171499043`},{{0.24000000000000002`,19.4`,0.94368`,1.1666`},0.3747058856622635`},{{0.24000000000000002`,19.4`,0.94368`,1.1711`},0.3747058856622635`},{{0.24000000000000002`,19.4`,0.94368`,1.1621000000000001`},0.3747058856622635`},{{0.24000000000000002`,19.4`,0.93668`,1.1666`},0.36813183833421376`},{{0.24000000000000002`,19.4`,0.93668`,1.1711`},0.36813183833421376`},{{0.24000000000000002`,19.4`,0.93668`,1.1621000000000001`},0.36813183833421376`},{{0.24000000000000002`,20.`,0.94018`,1.1666`},0.37122843102898856`},{{0.24000000000000002`,20.`,0.94018`,1.1711`},0.37122843102898856`},{{0.24000000000000002`,20.`,0.94018`,1.1621000000000001`},0.37122843102898856`},{{0.24000000000000002`,20.`,0.94368`,1.1666`},0.37455587908853133`},{{0.24000000000000002`,20.`,0.94368`,1.1711`},0.37455587908853133`},{{0.24000000000000002`,20.`,0.94368`,1.1621000000000001`},0.37455587908853133`},{{0.24000000000000002`,20.`,0.93668`,1.1666`},0.3679450731231842`},{{0.24000000000000002`,20.`,0.93668`,1.1711`},0.3679450731231842`},{{0.24000000000000002`,20.`,0.93668`,1.1621000000000001`},0.3679450731231842`},{{0.24000000000000002`,20.6`,0.94018`,1.1666`},0.3710343724301254`},{{0.24000000000000002`,20.6`,0.94018`,1.1711`},0.3710343724301254`},{{0.24000000000000002`,20.6`,0.94018`,1.1621000000000001`},0.3710343724301254`},{{0.24000000000000002`,20.6`,0.94368`,1.1666`},0.3743794537291151`},{{0.24000000000000002`,20.6`,0.94368`,1.1711`},0.3743794537291151`},{{0.24000000000000002`,20.6`,0.94368`,1.1621000000000001`},0.3743794537291151`},{{0.24000000000000002`,20.6`,0.93668`,1.1666`},0.367733638247609`},{{0.24000000000000002`,20.6`,0.93668`,1.1711`},0.367733638247609`},{{0.24000000000000002`,20.6`,0.93668`,1.1621000000000001`},0.367733638247609`},{{0.24000000000000002`,21.2`,0.94018`,1.1666`},0.3708175226809142`},{{0.24000000000000002`,21.2`,0.94018`,1.1711`},0.3708175226809142`},{{0.24000000000000002`,21.2`,0.94018`,1.1621000000000001`},0.3708175226809142`},{{0.24000000000000002`,21.2`,0.94368`,1.1666`},0.3741794260562523`},{{0.24000000000000002`,21.2`,0.94368`,1.1711`},0.3741794260562523`},{{0.24000000000000002`,21.2`,0.94368`,1.1621000000000001`},0.3741794260562523`},{{0.24000000000000002`,21.2`,0.93668`,1.1666`},0.3675002118491455`},{{0.24000000000000002`,21.2`,0.93668`,1.1711`},0.3675002118491455`},{{0.24000000000000002`,21.2`,0.93668`,1.1621000000000001`},0.3675002118491455`},{{0.24000000000000002`,21.8`,0.94018`,1.1666`},0.37058098757223107`},{{0.24000000000000002`,21.8`,0.94018`,1.1711`},0.37058098757223107`},{{0.24000000000000002`,21.8`,0.94018`,1.1621000000000001`},0.37058098757223107`},{{0.24000000000000002`,21.8`,0.94368`,1.1666`},0.37395896637263615`},{{0.24000000000000002`,21.8`,0.94368`,1.1711`},0.37395896637263615`},{{0.24000000000000002`,21.8`,0.94368`,1.1621000000000001`},0.37395896637263615`},{{0.24000000000000002`,21.8`,0.93668`,1.1666`},0.36724783586759974`},{{0.24000000000000002`,21.8`,0.93668`,1.1711`},0.36724783586759974`},{{0.24000000000000002`,21.8`,0.93668`,1.1621000000000001`},0.36724783586759974`},{{0.24000000000000002`,22.4`,0.94018`,1.1666`},0.3703271171704621`},{{0.24000000000000002`,22.4`,0.94018`,1.1711`},0.3703271171704621`},{{0.24000000000000002`,22.4`,0.94018`,1.1621000000000001`},0.3703271171704621`},{{0.24000000000000002`,22.4`,0.94368`,1.1666`},0.3737204807757451`},{{0.24000000000000002`,22.4`,0.94368`,1.1711`},0.3737204807757451`},{{0.24000000000000002`,22.4`,0.94368`,1.1621000000000001`},0.3737204807757451`},{{0.24000000000000002`,22.4`,0.93668`,1.1666`},0.36697880515843156`},{{0.24000000000000002`,22.4`,0.93668`,1.1711`},0.36697880515843156`},{{0.24000000000000002`,22.4`,0.93668`,1.1621000000000001`},0.36697880515843156`},{{0.24000000000000002`,23.`,0.94018`,1.1666`},0.3700581028828409`},{{0.24000000000000002`,23.`,0.94018`,1.1711`},0.3700581028828409`},{{0.24000000000000002`,23.`,0.94018`,1.1621000000000001`},0.3700581028828409`},{{0.24000000000000002`,23.`,0.94368`,1.1666`},0.3734662120583828`},{{0.24000000000000002`,23.`,0.94368`,1.1711`},0.3734662120583828`},{{0.24000000000000002`,23.`,0.94368`,1.1621000000000001`},0.3734662120583828`},{{0.24000000000000002`,23.`,0.93668`,1.1666`},0.36669526042757933`},{{0.24000000000000002`,23.`,0.93668`,1.1711`},0.36669526042757933`},{{0.24000000000000002`,23.`,0.93668`,1.1621000000000001`},0.36669526042757933`},{{0.24000000000000002`,23.6`,0.94018`,1.1666`},0.36977590766256224`},{{0.24000000000000002`,23.6`,0.94018`,1.1711`},0.36977590766256224`},{{0.24000000000000002`,23.6`,0.94018`,1.1621000000000001`},0.36977590766256224`},{{0.24000000000000002`,23.6`,0.94368`,1.1666`},0.3731981696540695`},{{0.24000000000000002`,23.6`,0.94368`,1.1711`},0.3731981696540695`},{{0.24000000000000002`,23.6`,0.94368`,1.1621000000000001`},0.3731981696540695`},{{0.24000000000000002`,23.6`,0.93668`,1.1666`},0.3663991187657048`},{{0.24000000000000002`,23.6`,0.93668`,1.1711`},0.3663991187657048`},{{0.24000000000000002`,23.6`,0.93668`,1.1621000000000001`},0.3663991187657048`},{{0.24000000000000002`,24.2`,0.94018`,1.1666`},0.36948150271365054`},{{0.24000000000000002`,24.2`,0.94018`,1.1711`},0.36948150271365054`},{{0.24000000000000002`,24.2`,0.94018`,1.1621000000000001`},0.36948150271365054`},{{0.24000000000000002`,24.2`,0.94368`,1.1666`},0.37291736811846826`},{{0.24000000000000002`,24.2`,0.94368`,1.1711`},0.37291736811846826`},{{0.24000000000000002`,24.2`,0.94368`,1.1621000000000001`},0.37291736811846826`},{{0.24000000000000002`,24.2`,0.93668`,1.1666`},0.3660913090292897`},{{0.24000000000000002`,24.2`,0.93668`,1.1711`},0.3660913090292897`},{{0.24000000000000002`,24.2`,0.93668`,1.1621000000000001`},0.3660913090292897`},{{0.24000000000000002`,24.8`,0.94018`,1.1666`},0.36917734057466584`},{{0.24000000000000002`,24.8`,0.94018`,1.1711`},0.36917734057466584`},{{0.24000000000000002`,24.8`,0.94018`,1.1621000000000001`},0.36917734057466584`},{{0.24000000000000002`,24.8`,0.94368`,1.1666`},0.3726262997663056`},{{0.24000000000000002`,24.8`,0.94368`,1.1711`},0.3726262997663056`},{{0.24000000000000002`,24.8`,0.94368`,1.1621000000000001`},0.3726262997663056`},{{0.24000000000000002`,24.8`,0.93668`,1.1666`},0.36577424394235863`},{{0.24000000000000002`,24.8`,0.93668`,1.1711`},0.36577424394235863`},{{0.24000000000000002`,24.8`,0.93668`,1.1621000000000001`},0.36577424394235863`},{{0.24000000000000002`,25.4`,0.94018`,1.1666`},0.3688645132462211`},{{0.24000000000000002`,25.4`,0.94018`,1.1711`},0.3688645132462211`},{{0.24000000000000002`,25.4`,0.94018`,1.1621000000000001`},0.3688645132462211`},{{0.24000000000000002`,25.4`,0.94368`,1.1666`},0.37232609063270355`},{{0.24000000000000002`,25.4`,0.94368`,1.1711`},0.37232609063270355`},{{0.24000000000000002`,25.4`,0.94368`,1.1621000000000001`},0.37232609063270355`},{{0.24000000000000002`,25.4`,0.93668`,1.1666`},0.36544898215929356`},{{0.24000000000000002`,25.4`,0.93668`,1.1711`},0.36544898215929356`},{{0.24000000000000002`,25.4`,0.93668`,1.1621000000000001`},0.36544898215929356`},{{0.24000000000000002`,26.`,0.94018`,1.1666`},0.36854426454205724`},{{0.24000000000000002`,26.`,0.94018`,1.1711`},0.36854426454205724`},{{0.24000000000000002`,26.`,0.94018`,1.1621000000000001`},0.36854426454205724`},{{0.24000000000000002`,26.`,0.94368`,1.1666`},0.37201801658722045`},{{0.24000000000000002`,26.`,0.94368`,1.1711`},0.37201801658722045`},{{0.24000000000000002`,26.`,0.94368`,1.1621000000000001`},0.37201801658722045`},{{0.24000000000000002`,26.`,0.93668`,1.1666`},0.3651167358885028`},{{0.24000000000000002`,26.`,0.93668`,1.1711`},0.3651167358885028`},{{0.24000000000000002`,26.`,0.93668`,1.1621000000000001`},0.3651167358885028`},{{0.24000000000000002`,26.6`,0.94018`,1.1666`},0.3682176946836092`},{{0.24000000000000002`,26.6`,0.94018`,1.1711`},0.3682176946836092`},{{0.24000000000000002`,26.6`,0.94018`,1.1621000000000001`},0.3682176946836092`},{{0.24000000000000002`,26.6`,0.94368`,1.1666`},0.37170320738257384`},{{0.24000000000000002`,26.6`,0.94368`,1.1711`},0.37170320738257384`},{{0.24000000000000002`,26.6`,0.94368`,1.1621000000000001`},0.37170320738257384`},{{0.24000000000000002`,26.6`,0.93668`,1.1666`},0.36477857625243504`},{{0.24000000000000002`,26.6`,0.93668`,1.1711`},0.36477857625243504`},{{0.24000000000000002`,26.6`,0.93668`,1.1621000000000001`},0.36477857625243504`},{{0.24000000000000002`,27.2`,0.94018`,1.1666`},0.36788518679509047`},{{0.24000000000000002`,27.2`,0.94018`,1.1711`},0.36788518679509047`},{{0.24000000000000002`,27.2`,0.94018`,1.1621000000000001`},0.36788518679509047`},{{0.24000000000000002`,27.2`,0.94368`,1.1666`},0.37138207378875454`},{{0.24000000000000002`,27.2`,0.94368`,1.1711`},0.37138207378875454`},{{0.24000000000000002`,27.2`,0.94368`,1.1621000000000001`},0.37138207378875454`},{{0.24000000000000002`,27.2`,0.93668`,1.1666`},0.3644348595523568`},{{0.24000000000000002`,27.2`,0.93668`,1.1711`},0.3644348595523568`},{{0.24000000000000002`,27.2`,0.93668`,1.1621000000000001`},0.3644348595523568`},{{0.24000000000000002`,27.8`,0.94018`,1.1666`},0.36754833122302133`},{{0.24000000000000002`,27.8`,0.94018`,1.1711`},0.36754833122302133`},{{0.24000000000000002`,27.8`,0.94018`,1.1621000000000001`},0.36754833122302133`},{{0.24000000000000002`,27.8`,0.94368`,1.1666`},0.3710562274979618`},{{0.24000000000000002`,27.8`,0.94368`,1.1711`},0.3710562274979618`},{{0.24000000000000002`,27.8`,0.94368`,1.1621000000000001`},0.3710562274979618`},{{0.24000000000000002`,27.8`,0.93668`,1.1666`},0.3640871493683456`},{{0.24000000000000002`,27.8`,0.93668`,1.1711`},0.3640871493683456`},{{0.24000000000000002`,27.8`,0.93668`,1.1621000000000001`},0.3640871493683456`},{{0.24000000000000002`,28.4`,0.94018`,1.1666`},0.36720774882931484`},{{0.24000000000000002`,28.4`,0.94018`,1.1711`},0.36720774882931484`},{{0.24000000000000002`,28.4`,0.94018`,1.1621000000000001`},0.36720774882931484`},{{0.24000000000000002`,28.4`,0.94368`,1.1666`},0.3707263181164034`},{{0.24000000000000002`,28.4`,0.94368`,1.1711`},0.3707263181164034`},{{0.24000000000000002`,28.4`,0.94368`,1.1621000000000001`},0.3707263181164034`},{{0.24000000000000002`,28.4`,0.93668`,1.1666`},0.36373604622588335`},{{0.24000000000000002`,28.4`,0.93668`,1.1711`},0.36373604622588335`},{{0.24000000000000002`,28.4`,0.93668`,1.1621000000000001`},0.36373604622588335`},{{0.24000000000000002`,29.`,0.94018`,1.1666`},0.36686415793682803`},{{0.24000000000000002`,29.`,0.94018`,1.1711`},0.36686415793682803`},{{0.24000000000000002`,29.`,0.94018`,1.1621000000000001`},0.36686415793682803`},{{0.24000000000000002`,29.`,0.94368`,1.1666`},0.370393085687407`},{{0.24000000000000002`,29.`,0.94368`,1.1711`},0.370393085687407`},{{0.24000000000000002`,29.`,0.94368`,1.1621000000000001`},0.370393085687407`},{{0.24000000000000002`,29.`,0.93668`,1.1666`},0.36338225246570494`},{{0.24000000000000002`,29.`,0.93668`,1.1711`},0.36338225246570494`},{{0.24000000000000002`,29.`,0.93668`,1.1621000000000001`},0.36338225246570494`},{{0.24000000000000002`,29.6`,0.94018`,1.1666`},0.36651793176795233`},{{0.24000000000000002`,29.6`,0.94018`,1.1711`},0.36651793176795233`},{{0.24000000000000002`,29.6`,0.94018`,1.1621000000000001`},0.36651793176795233`},{{0.24000000000000002`,29.6`,0.94368`,1.1666`},0.3700569152406077`},{{0.24000000000000002`,29.6`,0.94368`,1.1711`},0.3700569152406077`},{{0.24000000000000002`,29.6`,0.94368`,1.1621000000000001`},0.3700569152406077`},{{0.24000000000000002`,29.6`,0.93668`,1.1666`},0.36302611575088484`},{{0.24000000000000002`,29.6`,0.93668`,1.1711`},0.36302611575088484`},{{0.24000000000000002`,29.6`,0.93668`,1.1621000000000001`},0.36302611575088484`},{{0.24000000000000002`,30.2`,0.94018`,1.1666`},0.3661698734984874`},{{0.24000000000000002`,30.2`,0.94018`,1.1711`},0.3661698734984874`},{{0.24000000000000002`,30.2`,0.94018`,1.1621000000000001`},0.3661698734984874`},{{0.24000000000000002`,30.2`,0.94368`,1.1666`},0.36971863307303693`},{{0.24000000000000002`,30.2`,0.94368`,1.1711`},0.36971863307303693`},{{0.24000000000000002`,30.2`,0.94368`,1.1621000000000001`},0.36971863307303693`},{{0.24000000000000002`,30.2`,0.93668`,1.1666`},0.3626684223264328`},{{0.24000000000000002`,30.2`,0.93668`,1.1711`},0.3626684223264328`},{{0.24000000000000002`,30.2`,0.93668`,1.1621000000000001`},0.3626684223264328`},{{0.24000000000000002`,30.8`,0.94018`,1.1666`},0.3658204624376427`},{{0.24000000000000002`,30.8`,0.94018`,1.1711`},0.3658204624376427`},{{0.24000000000000002`,30.8`,0.94018`,1.1621000000000001`},0.3658204624376427`},{{0.24000000000000002`,30.8`,0.94368`,1.1666`},0.3693787333073203`},{{0.24000000000000002`,30.8`,0.94368`,1.1711`},0.3693787333073203`},{{0.24000000000000002`,30.8`,0.94368`,1.1621000000000001`},0.3693787333073203`},{{0.24000000000000002`,30.8`,0.93668`,1.1666`},0.36230963201833977`},{{0.24000000000000002`,30.8`,0.93668`,1.1711`},0.36230963201833977`},{{0.24000000000000002`,30.8`,0.93668`,1.1621000000000001`},0.36230963201833977`},{{0.24000000000000002`,31.4`,0.94018`,1.1666`},0.36547016267451177`},{{0.24000000000000002`,31.4`,0.94018`,1.1711`},0.36547016267451177`},{{0.24000000000000002`,31.4`,0.94018`,1.1621000000000001`},0.36547016267451177`},{{0.24000000000000002`,31.4`,0.94368`,1.1666`},0.36903769511404827`},{{0.24000000000000002`,31.4`,0.94368`,1.1711`},0.36903769511404827`},{{0.24000000000000002`,31.4`,0.94368`,1.1621000000000001`},0.36903769511404827`},{{0.24000000000000002`,31.4`,0.93668`,1.1666`},0.36195020222382185`},{{0.24000000000000002`,31.4`,0.93668`,1.1711`},0.36195020222382185`},{{0.24000000000000002`,31.4`,0.93668`,1.1621000000000001`},0.36195020222382185`},{{0.24000000000000002`,32.`,0.94018`,1.1666`},0.36511927888527873`},{{0.24000000000000002`,32.`,0.94018`,1.1711`},0.36511927888527873`},{{0.24000000000000002`,32.`,0.94018`,1.1621000000000001`},0.36511927888527873`},{{0.24000000000000002`,32.`,0.94368`,1.1666`},0.36869583664441`},{{0.24000000000000002`,32.`,0.94368`,1.1711`},0.36869583664441`},{{0.24000000000000002`,32.`,0.94368`,1.1621000000000001`},0.36869583664441`},{{0.24000000000000002`,32.`,0.93668`,1.1666`},0.3615904208968734`},{{0.24000000000000002`,32.`,0.93668`,1.1711`},0.3615904208968734`},{{0.24000000000000002`,32.`,0.93668`,1.1621000000000001`},0.3615904208968734`},{{0.24000000000000002`,32.6`,0.94018`,1.1666`},0.3647682247270997`},{{0.24000000000000002`,32.6`,0.94018`,1.1711`},0.3647682247270997`},{{0.24000000000000002`,32.6`,0.94018`,1.1621000000000001`},0.3647682247270997`},{{0.24000000000000002`,32.6`,0.94368`,1.1666`},0.3683535865538727`},{{0.24000000000000002`,32.6`,0.94368`,1.1711`},0.3683535865538727`},{{0.24000000000000002`,32.6`,0.94368`,1.1621000000000001`},0.3683535865538727`},{{0.24000000000000002`,32.6`,0.93668`,1.1666`},0.3612306867697529`},{{0.24000000000000002`,32.6`,0.93668`,1.1711`},0.3612306867697529`},{{0.24000000000000002`,32.6`,0.93668`,1.1621000000000001`},0.3612306867697529`},{{0.24000000000000002`,33.2`,0.94018`,1.1666`},0.36441734780126467`},{{0.24000000000000002`,33.2`,0.94018`,1.1711`},0.36441734780126467`},{{0.24000000000000002`,33.2`,0.94018`,1.1621000000000001`},0.36441734780126467`},{{0.24000000000000002`,33.2`,0.94368`,1.1666`},0.3680113033631919`},{{0.24000000000000002`,33.2`,0.94368`,1.1711`},0.3680113033631919`},{{0.24000000000000002`,33.2`,0.94368`,1.1621000000000001`},0.3680113033631919`},{{0.24000000000000002`,33.2`,0.93668`,1.1666`},0.36087133671209354`},{{0.24000000000000002`,33.2`,0.93668`,1.1711`},0.36087133671209354`},{{0.24000000000000002`,33.2`,0.93668`,1.1621000000000001`},0.36087133671209354`},{{0.24000000000000002`,33.8`,0.94018`,1.1666`},0.36406694428492997`},{{0.24000000000000002`,33.8`,0.94018`,1.1711`},0.36406694428492997`},{{0.24000000000000002`,33.8`,0.94018`,1.1621000000000001`},0.36406694428492997`},{{0.24000000000000002`,33.8`,0.94368`,1.1666`},0.3676692944418001`},{{0.24000000000000002`,33.8`,0.94368`,1.1711`},0.3676692944418001`},{{0.24000000000000002`,33.8`,0.94368`,1.1621000000000001`},0.3676692944418001`},{{0.24000000000000002`,33.8`,0.93668`,1.1666`},0.3605126558607716`},{{0.24000000000000002`,33.8`,0.93668`,1.1711`},0.3605126558607716`},{{0.24000000000000002`,33.8`,0.93668`,1.1621000000000001`},0.3605126558607716`},{{0.24000000000000002`,34.4`,0.94018`,1.1666`},0.36371728055919544`},{{0.24000000000000002`,34.4`,0.94018`,1.1711`},0.36371728055919544`},{{0.24000000000000002`,34.4`,0.94018`,1.1621000000000001`},0.36371728055919544`},{{0.24000000000000002`,34.4`,0.94368`,1.1666`},0.36732783656203977`},{{0.24000000000000002`,34.4`,0.94368`,1.1711`},0.36732783656203977`},{{0.24000000000000002`,34.4`,0.94368`,1.1621000000000001`},0.36732783656203977`},{{0.24000000000000002`,34.4`,0.93668`,1.1666`},0.36015490034622544`},{{0.24000000000000002`,34.4`,0.93668`,1.1711`},0.36015490034622544`},{{0.24000000000000002`,34.4`,0.93668`,1.1621000000000001`},0.36015490034622544`},{{0.24000000000000002`,35.`,0.94018`,1.1666`},0.3633685993498576`},{{0.24000000000000002`,35.`,0.94018`,1.1711`},0.3633685993498576`},{{0.24000000000000002`,35.`,0.94018`,1.1621000000000001`},0.3633685993498576`},{{0.24000000000000002`,35.`,0.94368`,1.1666`},0.3669871823748861`},{{0.24000000000000002`,35.`,0.94368`,1.1711`},0.3669871823748861`},{{0.24000000000000002`,35.`,0.94368`,1.1621000000000001`},0.3669871823748861`},{{0.24000000000000002`,35.`,0.93668`,1.1666`},0.3597983030960614`},{{0.24000000000000002`,35.`,0.93668`,1.1711`},0.3597983030960614`},{{0.24000000000000002`,35.`,0.93668`,1.1621000000000001`},0.3597983030960614`},{{0.24000000000000002`,35.6`,0.94018`,1.1666`},0.3630208126691596`},{{0.24000000000000002`,35.6`,0.94018`,1.1711`},0.3630208126691596`},{{0.24000000000000002`,35.6`,0.94018`,1.1621000000000001`},0.3630208126691596`},{{0.24000000000000002`,35.6`,0.94368`,1.1666`},0.3666472531988482`},{{0.24000000000000002`,35.6`,0.94368`,1.1711`},0.3666472531988482`},{{0.24000000000000002`,35.6`,0.94368`,1.1621000000000001`},0.3666472531988482`},{{0.24000000000000002`,35.6`,0.93668`,1.1666`},0.3594427671814216`},{{0.24000000000000002`,35.6`,0.93668`,1.1711`},0.3594427671814216`},{{0.24000000000000002`,35.6`,0.93668`,1.1621000000000001`},0.3594427671814216`},{{0.24000000000000002`,36.2`,0.94018`,1.1666`},0.36267451097530007`},{{0.24000000000000002`,36.2`,0.94018`,1.1711`},0.36267451097530007`},{{0.24000000000000002`,36.2`,0.94018`,1.1621000000000001`},0.36267451097530007`},{{0.24000000000000002`,36.2`,0.94368`,1.1666`},0.36630864800746527`},{{0.24000000000000002`,36.2`,0.94368`,1.1711`},0.36630864800746527`},{{0.24000000000000002`,36.2`,0.94368`,1.1621000000000001`},0.36630864800746527`},{{0.24000000000000002`,36.2`,0.93668`,1.1666`},0.35908887443726223`},{{0.24000000000000002`,36.2`,0.93668`,1.1711`},0.35908887443726223`},{{0.24000000000000002`,36.2`,0.93668`,1.1621000000000001`},0.35908887443726223`},{{0.24000000000000002`,36.8`,0.94018`,1.1666`},0.36232971157334976`},{{0.24000000000000002`,36.8`,0.94018`,1.1711`},0.36232971157334976`},{{0.24000000000000002`,36.8`,0.94018`,1.1621000000000001`},0.36232971157334976`},{{0.24000000000000002`,36.8`,0.94368`,1.1666`},0.3659713918118833`},{{0.24000000000000002`,36.8`,0.94368`,1.1711`},0.3659713918118833`},{{0.24000000000000002`,36.8`,0.94368`,1.1621000000000001`},0.3659713918118833`},{{0.24000000000000002`,36.8`,0.93668`,1.1666`},0.3587366346525489`},{{0.24000000000000002`,36.8`,0.93668`,1.1711`},0.3587366346525489`},{{0.24000000000000002`,36.8`,0.93668`,1.1621000000000001`},0.3587366346525489`},{{0.24000000000000002`,37.4`,0.94018`,1.1666`},0.3619865619102636`},{{0.24000000000000002`,37.4`,0.94018`,1.1711`},0.3619865619102636`},{{0.24000000000000002`,37.4`,0.94018`,1.1621000000000001`},0.3619865619102636`},{{0.24000000000000002`,37.4`,0.94368`,1.1666`},0.36563563962641626`},{{0.24000000000000002`,37.4`,0.94368`,1.1711`},0.36563563962641626`},{{0.24000000000000002`,37.4`,0.94368`,1.1621000000000001`},0.36563563962641626`},{{0.24000000000000002`,37.4`,0.93668`,1.1666`},0.35838618799886424`},{{0.24000000000000002`,37.4`,0.93668`,1.1711`},0.35838618799886424`},{{0.24000000000000002`,37.4`,0.93668`,1.1621000000000001`},0.35838618799886424`},{{0.24000000000000002`,38.`,0.94018`,1.1666`},0.3616451933105797`},{{0.24000000000000002`,38.`,0.94018`,1.1711`},0.3616451933105797`},{{0.24000000000000002`,38.`,0.94018`,1.1621000000000001`},0.3616451933105797`},{{0.24000000000000002`,38.`,0.94368`,1.1666`},0.3653015281253915`},{{0.24000000000000002`,38.`,0.94368`,1.1711`},0.3653015281253915`},{{0.24000000000000002`,38.`,0.94368`,1.1621000000000001`},0.3653015281253915`},{{0.24000000000000002`,38.`,0.93668`,1.1666`},0.3580376589333278`},{{0.24000000000000002`,38.`,0.93668`,1.1711`},0.3580376589333278`},{{0.24000000000000002`,38.`,0.93668`,1.1621000000000001`},0.3580376589333278`},{{0.24000000000000002`,38.6`,0.94018`,1.1666`},0.36130572238965775`},{{0.24000000000000002`,38.6`,0.94018`,1.1711`},0.36130572238965775`},{{0.24000000000000002`,38.6`,0.94018`,1.1621000000000001`},0.36130572238965775`},{{0.24000000000000002`,38.6`,0.94368`,1.1666`},0.36496918239763554`},{{0.24000000000000002`,38.6`,0.94368`,1.1711`},0.36496918239763554`},{{0.24000000000000002`,38.6`,0.94368`,1.1621000000000001`},0.36496918239763554`},{{0.24000000000000002`,38.6`,0.93668`,1.1666`},0.35769115775042654`},{{0.24000000000000002`,38.6`,0.93668`,1.1711`},0.35769115775042654`},{{0.24000000000000002`,38.6`,0.93668`,1.1621000000000001`},0.35769115775042654`},{{0.24000000000000002`,39.2`,0.94018`,1.1666`},0.36096825271535693`},{{0.24000000000000002`,39.2`,0.94018`,1.1711`},0.36096825271535693`},{{0.24000000000000002`,39.2`,0.94018`,1.1621000000000001`},0.36096825271535693`},{{0.24000000000000002`,39.2`,0.94368`,1.1666`},0.36463871127139175`},{{0.24000000000000002`,39.2`,0.94368`,1.1711`},0.36463871127139175`},{{0.24000000000000002`,39.2`,0.94368`,1.1621000000000001`},0.36463871127139175`},{{0.24000000000000002`,39.2`,0.93668`,1.1666`},0.3573467819726148`},{{0.24000000000000002`,39.2`,0.93668`,1.1711`},0.3573467819726148`},{{0.24000000000000002`,39.2`,0.93668`,1.1621000000000001`},0.3573467819726148`},{{0.24000000000000002`,39.8`,0.94018`,1.1666`},0.3606328759875005`},{{0.24000000000000002`,39.8`,0.94018`,1.1711`},0.3606328759875005`},{{0.24000000000000002`,39.8`,0.94018`,1.1621000000000001`},0.3606328759875005`},{{0.24000000000000002`,39.8`,0.94368`,1.1666`},0.3643102125637735`},{{0.24000000000000002`,39.8`,0.94368`,1.1711`},0.3643102125637735`},{{0.24000000000000002`,39.8`,0.94368`,1.1621000000000001`},0.3643102125637735`},{{0.24000000000000002`,39.8`,0.93668`,1.1666`},0.357004617596619`},{{0.24000000000000002`,39.8`,0.93668`,1.1711`},0.357004617596619`},{{0.24000000000000002`,39.8`,0.93668`,1.1621000000000001`},0.357004617596619`},{{0.27`,0.4`,0.94018`,1.1666`},0.2845735925873635`},{{0.27`,0.4`,0.94018`,1.1711`},0.2845735925873635`},{{0.27`,0.4`,0.94018`,1.1621000000000001`},0.2845735925873635`},{{0.27`,0.4`,0.94368`,1.1666`},0.28485505303935194`},{{0.27`,0.4`,0.94368`,1.1711`},0.28485505303935194`},{{0.27`,0.4`,0.94368`,1.1621000000000001`},0.28485505303935194`},{{0.27`,0.4`,0.93668`,1.1666`},0.2842956059955271`},{{0.27`,0.4`,0.93668`,1.1711`},0.2842956059955271`},{{0.27`,0.4`,0.93668`,1.1621000000000001`},0.2842956059955271`},{{0.27`,0.6`,0.94018`,1.1666`},0.29109181666595724`},{{0.27`,0.6`,0.94018`,1.1711`},0.29109181666595724`},{{0.27`,0.6`,0.94018`,1.1621000000000001`},0.29109181666595724`},{{0.27`,0.6`,0.94368`,1.1666`},0.2915018142727751`},{{0.27`,0.6`,0.94368`,1.1711`},0.2915018142727751`},{{0.27`,0.6`,0.94368`,1.1621000000000001`},0.2915018142727751`},{{0.27`,0.6`,0.93668`,1.1666`},0.2906869013854285`},{{0.27`,0.6`,0.93668`,1.1711`},0.2906869013854285`},{{0.27`,0.6`,0.93668`,1.1621000000000001`},0.2906869013854285`},{{0.27`,0.8`,0.94018`,1.1666`},0.2971541576749495`},{{0.27`,0.8`,0.94018`,1.1711`},0.2971541576749495`},{{0.27`,0.8`,0.94018`,1.1621000000000001`},0.2971541576749495`},{{0.27`,0.8`,0.94368`,1.1666`},0.29768535661738754`},{{0.27`,0.8`,0.94368`,1.1711`},0.29768535661738754`},{{0.27`,0.8`,0.94368`,1.1621000000000001`},0.29768535661738754`},{{0.27`,0.8`,0.93668`,1.1666`},0.29662957025411424`},{{0.27`,0.8`,0.93668`,1.1711`},0.29662957025411424`},{{0.27`,0.8`,0.93668`,1.1621000000000001`},0.29662957025411424`},{{0.27`,1.`,0.94018`,1.1666`},0.30279778056603196`},{{0.27`,1.`,0.94018`,1.1711`},0.30279778056603196`},{{0.27`,1.`,0.94018`,1.1621000000000001`},0.30279778056603196`},{{0.27`,1.`,0.94368`,1.1666`},0.3034433759369506`},{{0.27`,1.`,0.94368`,1.1711`},0.3034433759369506`},{{0.27`,1.`,0.94368`,1.1621000000000001`},0.3034433759369506`},{{0.27`,1.`,0.93668`,1.1666`},0.3021602511402084`},{{0.27`,1.`,0.93668`,1.1711`},0.3021602511402084`},{{0.27`,1.`,0.93668`,1.1621000000000001`},0.3021602511402084`},{{0.27`,1.2`,0.94018`,1.1666`},0.3080562541189268`},{{0.27`,1.2`,0.94018`,1.1711`},0.3080562541189268`},{{0.27`,1.2`,0.94018`,1.1621000000000001`},0.3080562541189268`},{{0.27`,1.2`,0.94368`,1.1666`},0.30880992676882507`},{{0.27`,1.2`,0.94368`,1.1711`},0.30880992676882507`},{{0.27`,1.2`,0.94368`,1.1621000000000001`},0.30880992676882507`},{{0.27`,1.2`,0.93668`,1.1666`},0.30731203133443846`},{{0.27`,1.2`,0.93668`,1.1711`},0.30731203133443846`},{{0.27`,1.2`,0.93668`,1.1621000000000001`},0.30731203133443846`},{{0.27`,1.4`,0.94018`,1.1666`},0.3129599548565105`},{{0.27`,1.4`,0.94018`,1.1711`},0.3129599548565105`},{{0.27`,1.4`,0.94018`,1.1621000000000001`},0.3129599548565105`},{{0.27`,1.4`,0.94368`,1.1666`},0.3138158305446869`},{{0.27`,1.4`,0.94368`,1.1711`},0.3138158305446869`},{{0.27`,1.4`,0.94368`,1.1621000000000001`},0.3138158305446869`},{{0.27`,1.4`,0.93668`,1.1666`},0.3121148464899191`},{{0.27`,1.4`,0.93668`,1.1711`},0.3121148464899191`},{{0.27`,1.4`,0.93668`,1.1621000000000001`},0.3121148464899191`},{{0.27`,1.6`,0.94018`,1.1666`},0.3175364193344712`},{{0.27`,1.6`,0.94018`,1.1711`},0.3175364193344712`},{{0.27`,1.6`,0.94018`,1.1621000000000001`},0.3175364193344712`},{{0.27`,1.6`,0.94368`,1.1666`},0.318489031707299`},{{0.27`,1.6`,0.94368`,1.1711`},0.318489031707299`},{{0.27`,1.6`,0.94368`,1.1621000000000001`},0.318489031707299`},{{0.27`,1.6`,0.93668`,1.1666`},0.31659582908217526`},{{0.27`,1.6`,0.93668`,1.1711`},0.31659582908217526`},{{0.27`,1.6`,0.93668`,1.1621000000000001`},0.31659582908217526`},{{0.27`,1.8`,0.94018`,1.1666`},0.32181065273196885`},{{0.27`,1.8`,0.94018`,1.1711`},0.32181065273196885`},{{0.27`,1.8`,0.94018`,1.1621000000000001`},0.32181065273196885`},{{0.27`,1.8`,0.94368`,1.1666`},0.3228549098623357`},{{0.27`,1.8`,0.94368`,1.1711`},0.3228549098623357`},{{0.27`,1.8`,0.94368`,1.1621000000000001`},0.3228549098623357`},{{0.27`,1.8`,0.93668`,1.1666`},0.32077961346109146`},{{0.27`,1.8`,0.93668`,1.1711`},0.32077961346109146`},{{0.27`,1.8`,0.93668`,1.1621000000000001`},0.32077961346109146`},{{0.27`,2.`,0.94018`,1.1666`},0.32580539878544157`},{{0.27`,2.`,0.94018`,1.1711`},0.32580539878544157`},{{0.27`,2.`,0.94018`,1.1621000000000001`},0.32580539878544157`},{{0.27`,2.`,0.94368`,1.1666`},0.3269365527352445`},{{0.27`,2.`,0.94368`,1.1711`},0.3269365527352445`},{{0.27`,2.`,0.94368`,1.1621000000000001`},0.3269365527352445`},{{0.27`,2.`,0.93668`,1.1666`},0.3246886027518942`},{{0.27`,2.`,0.93668`,1.1711`},0.3246886027518942`},{{0.27`,2.`,0.93668`,1.1621000000000001`},0.3246886027518942`},{{0.27`,2.2`,0.94018`,1.1666`},0.3295413774511425`},{{0.27`,2.2`,0.94018`,1.1711`},0.3295413774511425`},{{0.27`,2.2`,0.94018`,1.1621000000000001`},0.3295413774511425`},{{0.27`,2.2`,0.94368`,1.1666`},0.3307549966870715`},{{0.27`,2.2`,0.94368`,1.1711`},0.3307549966870715`},{{0.27`,2.2`,0.94368`,1.1621000000000001`},0.3307549966870715`},{{0.27`,2.2`,0.93668`,1.1666`},0.32834320368292735`},{{0.27`,2.2`,0.93668`,1.1711`},0.32834320368292735`},{{0.27`,2.2`,0.93668`,1.1621000000000001`},0.32834320368292735`},{{0.27`,2.6`,0.94018`,1.1666`},0.3363091094752067`},{{0.27`,2.6`,0.94018`,1.1711`},0.3363091094752067`},{{0.27`,2.6`,0.94018`,1.1621000000000001`},0.3363091094752067`},{{0.27`,2.6`,0.94368`,1.1666`},0.337675499787381`},{{0.27`,2.6`,0.94368`,1.1711`},0.337675499787381`},{{0.27`,2.6`,0.94368`,1.1621000000000001`},0.337675499787381`},{{0.27`,2.6`,0.93668`,1.1666`},0.3349601943937429`},{{0.27`,2.6`,0.93668`,1.1711`},0.3349601943937429`},{{0.27`,2.6`,0.93668`,1.1621000000000001`},0.3349601943937429`},{{0.27`,3.`,0.94018`,1.1666`},0.3422475007752552`},{{0.27`,3.`,0.94018`,1.1711`},0.3422475007752552`},{{0.27`,3.`,0.94018`,1.1621000000000001`},0.3422475007752552`},{{0.27`,3.`,0.94368`,1.1666`},0.3437521550206659`},{{0.27`,3.`,0.94368`,1.1711`},0.3437521550206659`},{{0.27`,3.`,0.94368`,1.1621000000000001`},0.3437521550206659`},{{0.27`,3.`,0.93668`,1.1666`},0.34076217520192253`},{{0.27`,3.`,0.93668`,1.1711`},0.34076217520192253`},{{0.27`,3.`,0.93668`,1.1621000000000001`},0.34076217520192253`},{{0.27`,3.4`,0.94018`,1.1666`},0.34746837516826545`},{{0.27`,3.4`,0.94018`,1.1711`},0.34746837516826545`},{{0.27`,3.4`,0.94018`,1.1621000000000001`},0.34746837516826545`},{{0.27`,3.4`,0.94368`,1.1666`},0.3490985465036597`},{{0.27`,3.4`,0.94368`,1.1711`},0.3490985465036597`},{{0.27`,3.4`,0.94368`,1.1621000000000001`},0.3490985465036597`},{{0.27`,3.4`,0.93668`,1.1666`},0.3458592286818759`},{{0.27`,3.4`,0.93668`,1.1711`},0.3458592286818759`},{{0.27`,3.4`,0.93668`,1.1621000000000001`},0.3458592286818759`},{{0.27`,3.8`,0.94018`,1.1666`},0.3520656678611503`},{{0.27`,3.8`,0.94018`,1.1711`},0.3520656678611503`},{{0.27`,3.8`,0.94018`,1.1621000000000001`},0.3520656678611503`},{{0.27`,3.8`,0.94368`,1.1666`},0.3538101209612375`},{{0.27`,3.8`,0.94368`,1.1711`},0.3538101209612375`},{{0.27`,3.8`,0.94368`,1.1621000000000001`},0.3538101209612375`},{{0.27`,3.8`,0.93668`,1.1666`},0.35034379535330595`},{{0.27`,3.8`,0.93668`,1.1711`},0.35034379535330595`},{{0.27`,3.8`,0.93668`,1.1621000000000001`},0.35034379535330595`},{{0.27`,4.2`,0.94018`,1.1666`},0.3561190995851242`},{{0.27`,4.2`,0.94018`,1.1711`},0.3561190995851242`},{{0.27`,4.2`,0.94018`,1.1621000000000001`},0.3561190995851242`},{{0.27`,4.2`,0.94368`,1.1666`},0.35796789904800214`},{{0.27`,4.2`,0.94368`,1.1711`},0.35796789904800214`},{{0.27`,4.2`,0.94368`,1.1621000000000001`},0.35796789904800214`},{{0.27`,4.2`,0.93668`,1.1666`},0.35429431082559454`},{{0.27`,4.2`,0.93668`,1.1711`},0.35429431082559454`},{{0.27`,4.2`,0.93668`,1.1621000000000001`},0.35429431082559454`},{{0.27`,4.6`,0.94018`,1.1666`},0.3596972051095162`},{{0.27`,4.6`,0.94018`,1.1711`},0.3596972051095162`},{{0.27`,4.6`,0.94018`,1.1621000000000001`},0.3596972051095162`},{{0.27`,4.6`,0.94368`,1.1666`},0.36164154048917757`},{{0.27`,4.6`,0.94368`,1.1711`},0.36164154048917757`},{{0.27`,4.6`,0.94368`,1.1621000000000001`},0.36164154048917757`},{{0.27`,4.6`,0.93668`,1.1666`},0.3577781977885502`},{{0.27`,4.6`,0.93668`,1.1711`},0.3577781977885502`},{{0.27`,4.6`,0.93668`,1.1621000000000001`},0.3577781977885502`},{{0.27`,5.`,0.94018`,1.1666`},0.3628581215928531`},{{0.27`,5.`,0.94018`,1.1711`},0.3628581215928531`},{{0.27`,5.`,0.94018`,1.1621000000000001`},0.3628581215928531`},{{0.27`,5.`,0.94368`,1.1666`},0.36489014448404455`},{{0.27`,5.`,0.94368`,1.1711`},0.36489014448404455`},{{0.27`,5.`,0.94368`,1.1621000000000001`},0.36489014448404455`},{{0.27`,5.`,0.93668`,1.1666`},0.3608526429070928`},{{0.27`,5.`,0.93668`,1.1711`},0.3608526429070928`},{{0.27`,5.`,0.93668`,1.1621000000000001`},0.3608526429070928`},{{0.27`,5.4`,0.94018`,1.1666`},0.3656512701316001`},{{0.27`,5.4`,0.94018`,1.1711`},0.3656512701316001`},{{0.27`,5.4`,0.94018`,1.1621000000000001`},0.3656512701316001`},{{0.27`,5.4`,0.94368`,1.1666`},0.36776398070281824`},{{0.27`,5.4`,0.94368`,1.1711`},0.36776398070281824`},{{0.27`,5.4`,0.94368`,1.1621000000000001`},0.36776398070281824`},{{0.27`,5.4`,0.93668`,1.1666`},0.36356622889217294`},{{0.27`,5.4`,0.93668`,1.1711`},0.36356622889217294`},{{0.27`,5.4`,0.93668`,1.1621000000000001`},0.36356622889217294`},{{0.27`,5.8`,0.94018`,1.1666`},0.3681197784749692`},{{0.27`,5.8`,0.94018`,1.1711`},0.3681197784749692`},{{0.27`,5.8`,0.94018`,1.1621000000000001`},0.3681197784749692`},{{0.27`,5.8`,0.94368`,1.1666`},0.3703069126815264`},{{0.27`,5.8`,0.94368`,1.1711`},0.3703069126815264`},{{0.27`,5.8`,0.94368`,1.1621000000000001`},0.3703069126815264`},{{0.27`,5.8`,0.93668`,1.1666`},0.3659613566562922`},{{0.27`,5.8`,0.93668`,1.1711`},0.3659613566562922`},{{0.27`,5.8`,0.93668`,1.1621000000000001`},0.3659613566562922`},{{0.27`,6.2`,0.94018`,1.1666`},0.37030098299475084`},{{0.27`,6.2`,0.94018`,1.1711`},0.37030098299475084`},{{0.27`,6.2`,0.94018`,1.1621000000000001`},0.37030098299475084`},{{0.27`,6.2`,0.94368`,1.1666`},0.3725569204570348`},{{0.27`,6.2`,0.94368`,1.1711`},0.3725569204570348`},{{0.27`,6.2`,0.94368`,1.1621000000000001`},0.3725569204570348`},{{0.27`,6.2`,0.93668`,1.1666`},0.36807472682960646`},{{0.27`,6.2`,0.93668`,1.1711`},0.36807472682960646`},{{0.27`,6.2`,0.93668`,1.1621000000000001`},0.36807472682960646`},{{0.27`,6.8`,0.94018`,1.1666`},0.3731036060444667`},{{0.27`,6.8`,0.94018`,1.1711`},0.3731036060444667`},{{0.27`,6.8`,0.94018`,1.1621000000000001`},0.3731036060444667`},{{0.27`,6.8`,0.94368`,1.1666`},0.3754534253089706`},{{0.27`,6.8`,0.94368`,1.1711`},0.3754534253089706`},{{0.27`,6.8`,0.94368`,1.1621000000000001`},0.3754534253089706`},{{0.27`,6.8`,0.93668`,1.1666`},0.37078479761264643`},{{0.27`,6.8`,0.93668`,1.1711`},0.37078479761264643`},{{0.27`,6.8`,0.93668`,1.1621000000000001`},0.37078479761264643`},{{0.27`,7.4`,0.94018`,1.1666`},0.37542385665332345`},{{0.27`,7.4`,0.94018`,1.1711`},0.37542385665332345`},{{0.27`,7.4`,0.94018`,1.1621000000000001`},0.37542385665332345`},{{0.27`,7.4`,0.94368`,1.1666`},0.3778577971927003`},{{0.27`,7.4`,0.94368`,1.1711`},0.3778577971927003`},{{0.27`,7.4`,0.94368`,1.1621000000000001`},0.3778577971927003`},{{0.27`,7.4`,0.93668`,1.1666`},0.37302212589169725`},{{0.27`,7.4`,0.93668`,1.1711`},0.37302212589169725`},{{0.27`,7.4`,0.93668`,1.1621000000000001`},0.37302212589169725`},{{0.27`,8.`,0.94018`,1.1666`},0.3773374627033736`},{{0.27`,8.`,0.94018`,1.1711`},0.3773374627033736`},{{0.27`,8.`,0.94018`,1.1621000000000001`},0.3773374627033736`},{{0.27`,8.`,0.94368`,1.1666`},0.3798471166439838`},{{0.27`,8.`,0.94368`,1.1711`},0.3798471166439838`},{{0.27`,8.`,0.94368`,1.1621000000000001`},0.3798471166439838`},{{0.27`,8.`,0.93668`,1.1666`},0.3748611041280943`},{{0.27`,8.`,0.93668`,1.1711`},0.3748611041280943`},{{0.27`,8.`,0.93668`,1.1621000000000001`},0.3748611041280943`},{{0.27`,8.6`,0.94018`,1.1666`},0.37890724339479065`},{{0.27`,8.6`,0.94018`,1.1711`},0.37890724339479065`},{{0.27`,8.6`,0.94018`,1.1621000000000001`},0.37890724339479065`},{{0.27`,8.6`,0.94368`,1.1666`},0.3814853336654399`},{{0.27`,8.6`,0.94368`,1.1711`},0.3814853336654399`},{{0.27`,8.6`,0.94368`,1.1621000000000001`},0.3814853336654399`},{{0.27`,8.6`,0.93668`,1.1666`},0.37636343438797965`},{{0.27`,8.6`,0.93668`,1.1711`},0.37636343438797965`},{{0.27`,8.6`,0.93668`,1.1621000000000001`},0.37636343438797965`},{{0.27`,9.2`,0.94018`,1.1666`},0.3801848220902254`},{{0.27`,9.2`,0.94018`,1.1711`},0.3801848220902254`},{{0.27`,9.2`,0.94018`,1.1621000000000001`},0.3801848220902254`},{{0.27`,9.2`,0.94368`,1.1666`},0.38282502419552517`},{{0.27`,9.2`,0.94368`,1.1711`},0.38282502419552517`},{{0.27`,9.2`,0.94368`,1.1621000000000001`},0.38282502419552517`},{{0.27`,9.2`,0.93668`,1.1666`},0.3775798023240759`},{{0.27`,9.2`,0.93668`,1.1711`},0.3775798023240759`},{{0.27`,9.2`,0.93668`,1.1621000000000001`},0.3775798023240759`},{{0.27`,9.8`,0.94018`,1.1666`},0.38121352392943814`},{{0.27`,9.8`,0.94018`,1.1711`},0.38121352392943814`},{{0.27`,9.8`,0.94018`,1.1621000000000001`},0.38121352392943814`},{{0.27`,9.8`,0.94368`,1.1666`},0.3839103131453729`},{{0.27`,9.8`,0.94368`,1.1711`},0.3839103131453729`},{{0.27`,9.8`,0.94368`,1.1621000000000001`},0.3839103131453729`},{{0.27`,9.8`,0.93668`,1.1666`},0.378552741322004`},{{0.27`,9.8`,0.93668`,1.1711`},0.378552741322004`},{{0.27`,9.8`,0.93668`,1.1621000000000001`},0.378552741322004`},{{0.27`,10.4`,0.94018`,1.1666`},0.38202911418758534`},{{0.27`,10.4`,0.94018`,1.1711`},0.38202911418758534`},{{0.27`,10.4`,0.94018`,1.1621000000000001`},0.38202911418758534`},{{0.27`,10.4`,0.94368`,1.1666`},0.3847776449258704`},{{0.27`,10.4`,0.94368`,1.1711`},0.3847776449258704`},{{0.27`,10.4`,0.94368`,1.1621000000000001`},0.3847776449258704`},{{0.27`,10.4`,0.93668`,1.1666`},0.3793173474068031`},{{0.27`,10.4`,0.93668`,1.1711`},0.3793173474068031`},{{0.27`,10.4`,0.93668`,1.1621000000000001`},0.3793173474068031`},{{0.27`,11.`,0.94018`,1.1666`},0.3826623911012855`},{{0.27`,11.`,0.94018`,1.1711`},0.3826623911012855`},{{0.27`,11.`,0.94018`,1.1621000000000001`},0.3826623911012855`},{{0.27`,11.`,0.94368`,1.1666`},0.3854584018536327`},{{0.27`,11.`,0.94368`,1.1711`},0.3854584018536327`},{{0.27`,11.`,0.94368`,1.1621000000000001`},0.3854584018536327`},{{0.27`,11.`,0.93668`,1.1666`},0.37990384234843216`},{{0.27`,11.`,0.93668`,1.1711`},0.37990384234843216`},{{0.27`,11.`,0.93668`,1.1621000000000001`},0.37990384234843216`},{{0.27`,11.6`,0.94018`,1.1666`},0.38313904475324834`},{{0.27`,11.6`,0.94018`,1.1711`},0.38313904475324834`},{{0.27`,11.6`,0.94018`,1.1621000000000001`},0.38313904475324834`},{{0.27`,11.6`,0.94368`,1.1666`},0.38597876893548777`},{{0.27`,11.6`,0.94368`,1.1711`},0.38597876893548777`},{{0.27`,11.6`,0.94368`,1.1621000000000001`},0.38597876893548777`},{{0.27`,11.6`,0.93668`,1.1666`},0.3803374279774933`},{{0.27`,11.6`,0.93668`,1.1711`},0.3803374279774933`},{{0.27`,11.6`,0.93668`,1.1621000000000001`},0.3803374279774933`},{{0.27`,12.2`,0.94018`,1.1666`},0.3834801988936239`},{{0.27`,12.2`,0.94018`,1.1711`},0.3834801988936239`},{{0.27`,12.2`,0.94018`,1.1621000000000001`},0.3834801988936239`},{{0.27`,12.2`,0.94368`,1.1666`},0.38636029887624085`},{{0.27`,12.2`,0.94368`,1.1711`},0.38636029887624085`},{{0.27`,12.2`,0.94368`,1.1621000000000001`},0.38636029887624085`},{{0.27`,12.2`,0.93668`,1.1666`},0.3806388049473263`},{{0.27`,12.2`,0.93668`,1.1711`},0.3806388049473263`},{{0.27`,12.2`,0.93668`,1.1621000000000001`},0.3806388049473263`},{{0.27`,12.8`,0.94018`,1.1666`},0.38370515713386144`},{{0.27`,12.8`,0.94018`,1.1711`},0.38370515713386144`},{{0.27`,12.8`,0.94018`,1.1621000000000001`},0.38370515713386144`},{{0.27`,12.8`,0.94368`,1.1666`},0.38662266711486876`},{{0.27`,12.8`,0.94368`,1.1711`},0.38662266711486876`},{{0.27`,12.8`,0.94368`,1.1621000000000001`},0.38662266711486876`},{{0.27`,12.8`,0.93668`,1.1666`},0.3808269098368464`},{{0.27`,12.8`,0.93668`,1.1711`},0.3808269098368464`},{{0.27`,12.8`,0.93668`,1.1621000000000001`},0.3808269098368464`},{{0.27`,13.4`,0.94018`,1.1666`},0.38382946948911656`},{{0.27`,13.4`,0.94018`,1.1711`},0.38382946948911656`},{{0.27`,13.4`,0.94018`,1.1621000000000001`},0.38382946948911656`},{{0.27`,13.4`,0.94368`,1.1666`},0.3867817395886523`},{{0.27`,13.4`,0.94368`,1.1711`},0.3867817395886523`},{{0.27`,13.4`,0.94368`,1.1621000000000001`},0.3867817395886523`},{{0.27`,13.4`,0.93668`,1.1666`},0.3809169811974008`},{{0.27`,13.4`,0.93668`,1.1711`},0.3809169811974008`},{{0.27`,13.4`,0.93668`,1.1621000000000001`},0.3809169811974008`},{{0.27`,14.`,0.94018`,1.1666`},0.3838670553339262`},{{0.27`,14.`,0.94018`,1.1711`},0.3838670553339262`},{{0.27`,14.`,0.94018`,1.1621000000000001`},0.3838670553339262`},{{0.27`,14.`,0.94368`,1.1666`},0.3868517177033647`},{{0.27`,14.`,0.94368`,1.1711`},0.3868517177033647`},{{0.27`,14.`,0.94368`,1.1621000000000001`},0.3868517177033647`},{{0.27`,14.`,0.93668`,1.1666`},0.38092266003183645`},{{0.27`,14.`,0.93668`,1.1711`},0.38092266003183645`},{{0.27`,14.`,0.93668`,1.1621000000000001`},0.38092266003183645`},{{0.27`,14.6`,0.94018`,1.1666`},0.3838297028667746`},{{0.27`,14.6`,0.94018`,1.1711`},0.3838297028667746`},{{0.27`,14.6`,0.94018`,1.1621000000000001`},0.3838297028667746`},{{0.27`,14.6`,0.94368`,1.1666`},0.38684463106943684`},{{0.27`,14.6`,0.94368`,1.1711`},0.38684463106943684`},{{0.27`,14.6`,0.94368`,1.1621000000000001`},0.38684463106943684`},{{0.27`,14.6`,0.93668`,1.1666`},0.3808554964251008`},{{0.27`,14.6`,0.93668`,1.1711`},0.3808554964251008`},{{0.27`,14.6`,0.93668`,1.1621000000000001`},0.3808554964251008`},{{0.27`,15.2`,0.94018`,1.1666`},0.38372699729893367`},{{0.27`,15.2`,0.94018`,1.1711`},0.38372699729893367`},{{0.27`,15.2`,0.94018`,1.1621000000000001`},0.38372699729893367`},{{0.27`,15.2`,0.94368`,1.1666`},0.38677027518472423`},{{0.27`,15.2`,0.94368`,1.1711`},0.38677027518472423`},{{0.27`,15.2`,0.94368`,1.1621000000000001`},0.38677027518472423`},{{0.27`,15.2`,0.93668`,1.1666`},0.38072486839888986`},{{0.27`,15.2`,0.93668`,1.1711`},0.38072486839888986`},{{0.27`,15.2`,0.93668`,1.1621000000000001`},0.38072486839888986`},{{0.27`,15.8`,0.94018`,1.1666`},0.3835681811565537`},{{0.27`,15.8`,0.94018`,1.1711`},0.3835681811565537`},{{0.27`,15.8`,0.94018`,1.1621000000000001`},0.3835681811565537`},{{0.27`,15.8`,0.94368`,1.1666`},0.38663808434159924`},{{0.27`,15.8`,0.94368`,1.1711`},0.38663808434159924`},{{0.27`,15.8`,0.94368`,1.1621000000000001`},0.38663808434159924`},{{0.27`,15.8`,0.93668`,1.1666`},0.38053982905973704`},{{0.27`,15.8`,0.93668`,1.1711`},0.38053982905973704`},{{0.27`,15.8`,0.93668`,1.1621000000000001`},0.38053982905973704`},{{0.27`,16.4`,0.94018`,1.1666`},0.38336079411895807`},{{0.27`,16.4`,0.94018`,1.1711`},0.38336079411895807`},{{0.27`,16.4`,0.94018`,1.1621000000000001`},0.38336079411895807`},{{0.27`,16.4`,0.94368`,1.1666`},0.38645576069102927`},{{0.27`,16.4`,0.94368`,1.1711`},0.38645576069102927`},{{0.27`,16.4`,0.94368`,1.1621000000000001`},0.38645576069102927`},{{0.27`,16.4`,0.93668`,1.1666`},0.38030775790957616`},{{0.27`,16.4`,0.93668`,1.1711`},0.38030775790957616`},{{0.27`,16.4`,0.93668`,1.1621000000000001`},0.38030775790957616`},{{0.27`,17.`,0.94018`,1.1666`},0.38311120228913925`},{{0.27`,17.`,0.94018`,1.1711`},0.38311120228913925`},{{0.27`,17.`,0.94018`,1.1621000000000001`},0.38311120228913925`},{{0.27`,17.`,0.94368`,1.1666`},0.38622981341181667`},{{0.27`,17.`,0.94368`,1.1711`},0.38622981341181667`},{{0.27`,17.`,0.94368`,1.1621000000000001`},0.38622981341181667`},{{0.27`,17.`,0.93668`,1.1666`},0.38003488008819925`},{{0.27`,17.`,0.93668`,1.1711`},0.38003488008819925`},{{0.27`,17.`,0.93668`,1.1621000000000001`},0.38003488008819925`},{{0.27`,17.6`,0.94018`,1.1666`},0.3828251999341654`},{{0.27`,17.6`,0.94018`,1.1711`},0.3828251999341654`},{{0.27`,17.6`,0.94018`,1.1621000000000001`},0.3828251999341654`},{{0.27`,17.6`,0.94368`,1.1666`},0.3859661704972154`},{{0.27`,17.6`,0.94368`,1.1711`},0.3859661704972154`},{{0.27`,17.6`,0.94368`,1.1621000000000001`},0.3859661704972154`},{{0.27`,17.6`,0.93668`,1.1666`},0.3797268578296046`},{{0.27`,17.6`,0.93668`,1.1711`},0.3797268578296046`},{{0.27`,17.6`,0.93668`,1.1621000000000001`},0.3797268578296046`},{{0.27`,18.2`,0.94018`,1.1666`},0.3825084385558194`},{{0.27`,18.2`,0.94018`,1.1711`},0.3825084385558194`},{{0.27`,18.2`,0.94018`,1.1621000000000001`},0.3825084385558194`},{{0.27`,18.2`,0.94368`,1.1666`},0.38567059140177495`},{{0.27`,18.2`,0.94368`,1.1711`},0.38567059140177495`},{{0.27`,18.2`,0.94368`,1.1621000000000001`},0.38567059140177495`},{{0.27`,18.2`,0.93668`,1.1666`},0.3793892358829262`},{{0.27`,18.2`,0.93668`,1.1711`},0.3793892358829262`},{{0.27`,18.2`,0.93668`,1.1621000000000001`},0.3793892358829262`},{{0.27`,18.8`,0.94018`,1.1666`},0.38216431590538796`},{{0.27`,18.8`,0.94018`,1.1711`},0.38216431590538796`},{{0.27`,18.8`,0.94018`,1.1621000000000001`},0.38216431590538796`},{{0.27`,18.8`,0.94368`,1.1666`},0.3853465835611416`},{{0.27`,18.8`,0.94368`,1.1711`},0.3853465835611416`},{{0.27`,18.8`,0.94368`,1.1621000000000001`},0.3853465835611416`},{{0.27`,18.8`,0.93668`,1.1666`},0.3790253044225003`},{{0.27`,18.8`,0.93668`,1.1711`},0.3790253044225003`},{{0.27`,18.8`,0.93668`,1.1621000000000001`},0.3790253044225003`},{{0.27`,19.4`,0.94018`,1.1666`},0.3817967459526294`},{{0.27`,19.4`,0.94018`,1.1711`},0.3817967459526294`},{{0.27`,19.4`,0.94018`,1.1621000000000001`},0.3817967459526294`},{{0.27`,19.4`,0.94368`,1.1666`},0.3849981476597942`},{{0.27`,19.4`,0.94368`,1.1711`},0.3849981476597942`},{{0.27`,19.4`,0.94368`,1.1621000000000001`},0.3849981476597942`},{{0.27`,19.4`,0.93668`,1.1666`},0.3786388918194345`},{{0.27`,19.4`,0.93668`,1.1711`},0.3786388918194345`},{{0.27`,19.4`,0.93668`,1.1621000000000001`},0.3786388918194345`},{{0.27`,20.`,0.94018`,1.1666`},0.3814094507994298`},{{0.27`,20.`,0.94018`,1.1711`},0.3814094507994298`},{{0.27`,20.`,0.94018`,1.1621000000000001`},0.3814094507994298`},{{0.27`,20.`,0.94368`,1.1666`},0.38462909010800134`},{{0.27`,20.`,0.94368`,1.1711`},0.38462909010800134`},{{0.27`,20.`,0.94368`,1.1621000000000001`},0.38462909010800134`},{{0.27`,20.`,0.93668`,1.1666`},0.37823363678786287`},{{0.27`,20.`,0.93668`,1.1711`},0.37823363678786287`},{{0.27`,20.`,0.93668`,1.1621000000000001`},0.37823363678786287`},{{0.27`,20.6`,0.94018`,1.1666`},0.381005333674783`},{{0.27`,20.6`,0.94018`,1.1711`},0.381005333674783`},{{0.27`,20.6`,0.94018`,1.1621000000000001`},0.381005333674783`},{{0.27`,20.6`,0.94368`,1.1666`},0.38424238559392326`},{{0.27`,20.6`,0.94368`,1.1711`},0.38424238559392326`},{{0.27`,20.6`,0.94368`,1.1621000000000001`},0.38424238559392326`},{{0.27`,20.6`,0.93668`,1.1666`},0.3778123721756336`},{{0.27`,20.6`,0.93668`,1.1711`},0.3778123721756336`},{{0.27`,20.6`,0.93668`,1.1621000000000001`},0.3778123721756336`},{{0.27`,21.2`,0.94018`,1.1666`},0.3805866739298784`},{{0.27`,21.2`,0.94018`,1.1711`},0.3805866739298784`},{{0.27`,21.2`,0.94018`,1.1621000000000001`},0.3805866739298784`},{{0.27`,21.2`,0.94368`,1.1666`},0.3838403787018211`},{{0.27`,21.2`,0.94368`,1.1711`},0.3838403787018211`},{{0.27`,21.2`,0.94368`,1.1621000000000001`},0.3838403787018211`},{{0.27`,21.2`,0.93668`,1.1666`},0.37737731315681194`},{{0.27`,21.2`,0.93668`,1.1711`},0.37737731315681194`},{{0.27`,21.2`,0.93668`,1.1621000000000001`},0.37737731315681194`},{{0.27`,21.8`,0.94018`,1.1666`},0.3801560971745151`},{{0.27`,21.8`,0.94018`,1.1711`},0.3801560971745151`},{{0.27`,21.8`,0.94018`,1.1621000000000001`},0.3801560971745151`},{{0.27`,21.8`,0.94368`,1.1666`},0.3834257557558018`},{{0.27`,21.8`,0.94368`,1.1711`},0.3834257557558018`},{{0.27`,21.8`,0.94368`,1.1621000000000001`},0.3834257557558018`},{{0.27`,21.8`,0.93668`,1.1666`},0.3769310252902362`},{{0.27`,21.8`,0.93668`,1.1711`},0.3769310252902362`},{{0.27`,21.8`,0.93668`,1.1621000000000001`},0.3769310252902362`},{{0.27`,22.4`,0.94018`,1.1666`},0.37971553809020187`},{{0.27`,22.4`,0.94018`,1.1711`},0.37971553809020187`},{{0.27`,22.4`,0.94018`,1.1621000000000001`},0.37971553809020187`},{{0.27`,22.4`,0.94368`,1.1666`},0.3830005038461334`},{{0.27`,22.4`,0.94368`,1.1711`},0.3830005038461334`},{{0.27`,22.4`,0.94368`,1.1621000000000001`},0.3830005038461334`},{{0.27`,22.4`,0.93668`,1.1666`},0.3764753916551917`},{{0.27`,22.4`,0.93668`,1.1711`},0.3764753916551917`},{{0.27`,22.4`,0.93668`,1.1621000000000001`},0.3764753916551917`},{{0.27`,23.`,0.94018`,1.1666`},0.3792667940654614`},{{0.27`,23.`,0.94018`,1.1711`},0.3792667940654614`},{{0.27`,23.`,0.94018`,1.1621000000000001`},0.3792667940654614`},{{0.27`,23.`,0.94368`,1.1666`},0.3825664684526816`},{{0.27`,23.`,0.94368`,1.1711`},0.3825664684526816`},{{0.27`,23.`,0.94368`,1.1621000000000001`},0.3825664684526816`},{{0.27`,23.`,0.93668`,1.1666`},0.37601216223639117`},{{0.27`,23.`,0.93668`,1.1711`},0.37601216223639117`},{{0.27`,23.`,0.93668`,1.1621000000000001`},0.37601216223639117`},{{0.27`,23.6`,0.94018`,1.1666`},0.37881146062971227`},{{0.27`,23.6`,0.94018`,1.1711`},0.37881146062971227`},{{0.27`,23.6`,0.94018`,1.1621000000000001`},0.37881146062971227`},{{0.27`,23.6`,0.94368`,1.1666`},0.3821252885830343`},{{0.27`,23.6`,0.94368`,1.1711`},0.3821252885830343`},{{0.27`,23.6`,0.94368`,1.1621000000000001`},0.3821252885830343`},{{0.27`,23.6`,0.93668`,1.1666`},0.3755428897213036`},{{0.27`,23.6`,0.93668`,1.1711`},0.3755428897213036`},{{0.27`,23.6`,0.93668`,1.1621000000000001`},0.3755428897213036`},{{0.27`,24.2`,0.94018`,1.1666`},0.3783502256749296`},{{0.27`,24.2`,0.94018`,1.1711`},0.3783502256749296`},{{0.27`,24.2`,0.94018`,1.1621000000000001`},0.3783502256749296`},{{0.27`,24.2`,0.94368`,1.1666`},0.38167769206581265`},{{0.27`,24.2`,0.94368`,1.1711`},0.38167769206581265`},{{0.27`,24.2`,0.94368`,1.1621000000000001`},0.38167769206581265`},{{0.27`,24.2`,0.93668`,1.1666`},0.37506822307246956`},{{0.27`,24.2`,0.93668`,1.1711`},0.37506822307246956`},{{0.27`,24.2`,0.93668`,1.1621000000000001`},0.37506822307246956`},{{0.27`,24.8`,0.94018`,1.1666`},0.37788514957783703`},{{0.27`,24.8`,0.94018`,1.1711`},0.37788514957783703`},{{0.27`,24.8`,0.94018`,1.1621000000000001`},0.37788514957783703`},{{0.27`,24.8`,0.94368`,1.1666`},0.3812257719323475`},{{0.27`,24.8`,0.94368`,1.1711`},0.3812257719323475`},{{0.27`,24.8`,0.94368`,1.1621000000000001`},0.3812257719323475`},{{0.27`,24.8`,0.93668`,1.1666`},0.37459018479345707`},{{0.27`,24.8`,0.93668`,1.1711`},0.37459018479345707`},{{0.27`,24.8`,0.93668`,1.1621000000000001`},0.37459018479345707`},{{0.27`,25.4`,0.94018`,1.1666`},0.3774170484051215`},{{0.27`,25.4`,0.94018`,1.1711`},0.3774170484051215`},{{0.27`,25.4`,0.94018`,1.1621000000000001`},0.3774170484051215`},{{0.27`,25.4`,0.94368`,1.1666`},0.38077038704629107`},{{0.27`,25.4`,0.94368`,1.1711`},0.38077038704629107`},{{0.27`,25.4`,0.94368`,1.1621000000000001`},0.38077038704629107`},{{0.27`,25.4`,0.93668`,1.1666`},0.3741095638554934`},{{0.27`,25.4`,0.93668`,1.1711`},0.3741095638554934`},{{0.27`,25.4`,0.93668`,1.1621000000000001`},0.3741095638554934`},{{0.27`,26.`,0.94018`,1.1666`},0.3769468928671051`},{{0.27`,26.`,0.94018`,1.1711`},0.3769468928671051`},{{0.27`,26.`,0.94018`,1.1621000000000001`},0.3769468928671051`},{{0.27`,26.`,0.94368`,1.1666`},0.3803125289849124`},{{0.27`,26.`,0.94368`,1.1711`},0.3803125289849124`},{{0.27`,26.`,0.94368`,1.1621000000000001`},0.3803125289849124`},{{0.27`,26.`,0.93668`,1.1666`},0.37362729608185236`},{{0.27`,26.`,0.93668`,1.1711`},0.37362729608185236`},{{0.27`,26.`,0.93668`,1.1621000000000001`},0.37362729608185236`},{{0.27`,26.6`,0.94018`,1.1666`},0.3764755191859872`},{{0.27`,26.6`,0.94018`,1.1711`},0.3764755191859872`},{{0.27`,26.6`,0.94018`,1.1621000000000001`},0.3764755191859872`},{{0.27`,26.6`,0.94368`,1.1666`},0.37985306372313504`},{{0.27`,26.6`,0.94368`,1.1711`},0.37985306372313504`},{{0.27`,26.6`,0.94368`,1.1621000000000001`},0.37985306372313504`},{{0.27`,26.6`,0.93668`,1.1666`},0.37314418934813964`},{{0.27`,26.6`,0.93668`,1.1711`},0.37314418934813964`},{{0.27`,26.6`,0.93668`,1.1621000000000001`},0.37314418934813964`},{{0.27`,27.2`,0.94018`,1.1666`},0.37600312487132304`},{{0.27`,27.2`,0.94018`,1.1711`},0.37600312487132304`},{{0.27`,27.2`,0.94018`,1.1621000000000001`},0.37600312487132304`},{{0.27`,27.2`,0.94368`,1.1666`},0.37939221383131`},{{0.27`,27.2`,0.94368`,1.1711`},0.37939221383131`},{{0.27`,27.2`,0.94368`,1.1621000000000001`},0.37939221383131`},{{0.27`,27.2`,0.93668`,1.1666`},0.37266042277711475`},{{0.27`,27.2`,0.93668`,1.1711`},0.37266042277711475`},{{0.27`,27.2`,0.93668`,1.1621000000000001`},0.37266042277711475`},{{0.27`,27.8`,0.94018`,1.1666`},0.37553099825204445`},{{0.27`,27.8`,0.94018`,1.1711`},0.37553099825204445`},{{0.27`,27.8`,0.94018`,1.1621000000000001`},0.37553099825204445`},{{0.27`,27.8`,0.94368`,1.1666`},0.37893129280252835`},{{0.27`,27.8`,0.94368`,1.1711`},0.37893129280252835`},{{0.27`,27.8`,0.94368`,1.1621000000000001`},0.37893129280252835`},{{0.27`,27.8`,0.93668`,1.1666`},0.3721772568363314`},{{0.27`,27.8`,0.93668`,1.1711`},0.3721772568363314`},{{0.27`,27.8`,0.93668`,1.1621000000000001`},0.3721772568363314`},{{0.27`,28.4`,0.94018`,1.1666`},0.37505956725120915`},{{0.27`,28.4`,0.94018`,1.1711`},0.37505956725120915`},{{0.27`,28.4`,0.94018`,1.1621000000000001`},0.37505956725120915`},{{0.27`,28.4`,0.94368`,1.1666`},0.37847074762276695`},{{0.27`,28.4`,0.94368`,1.1711`},0.37847074762276695`},{{0.27`,28.4`,0.94368`,1.1621000000000001`},0.37847074762276695`},{{0.27`,28.4`,0.93668`,1.1666`},0.37169510085031193`},{{0.27`,28.4`,0.93668`,1.1711`},0.37169510085031193`},{{0.27`,28.4`,0.93668`,1.1621000000000001`},0.37169510085031193`},{{0.27`,29.`,0.94018`,1.1666`},0.37458935217095096`},{{0.27`,29.`,0.94018`,1.1711`},0.37458935217095096`},{{0.27`,29.`,0.94018`,1.1621000000000001`},0.37458935217095096`},{{0.27`,29.`,0.94368`,1.1666`},0.3780111177808284`},{{0.27`,29.`,0.94368`,1.1711`},0.3780111177808284`},{{0.27`,29.`,0.94368`,1.1621000000000001`},0.3780111177808284`},{{0.27`,29.`,0.93668`,1.1666`},0.37121445620677596`},{{0.27`,29.`,0.93668`,1.1711`},0.37121445620677596`},{{0.27`,29.`,0.93668`,1.1621000000000001`},0.37121445620677596`},{{0.27`,29.6`,0.94018`,1.1666`},0.3741205620812799`},{{0.27`,29.6`,0.94018`,1.1711`},0.3741205620812799`},{{0.27`,29.6`,0.94018`,1.1621000000000001`},0.3741205620812799`},{{0.27`,29.6`,0.94368`,1.1666`},0.3775526296473189`},{{0.27`,29.6`,0.94368`,1.1711`},0.3775526296473189`},{{0.27`,29.6`,0.94368`,1.1621000000000001`},0.3775526296473189`},{{0.27`,29.6`,0.93668`,1.1666`},0.37073551512737757`},{{0.27`,29.6`,0.93668`,1.1711`},0.37073551512737757`},{{0.27`,29.6`,0.93668`,1.1621000000000001`},0.37073551512737757`},{{0.27`,30.2`,0.94018`,1.1666`},0.3736537904202264`},{{0.27`,30.2`,0.94018`,1.1711`},0.3736537904202264`},{{0.27`,30.2`,0.94018`,1.1621000000000001`},0.3736537904202264`},{{0.27`,30.2`,0.94368`,1.1666`},0.37709589537291593`},{{0.27`,30.2`,0.94368`,1.1711`},0.37709589537291593`},{{0.27`,30.2`,0.94368`,1.1621000000000001`},0.37709589537291593`},{{0.27`,30.2`,0.93668`,1.1666`},0.37025885235445977`},{{0.27`,30.2`,0.93668`,1.1711`},0.37025885235445977`},{{0.27`,30.2`,0.93668`,1.1621000000000001`},0.37025885235445977`},{{0.27`,30.8`,0.94018`,1.1666`},0.37318935689310423`},{{0.27`,30.8`,0.94018`,1.1711`},0.37318935689310423`},{{0.27`,30.8`,0.94018`,1.1621000000000001`},0.37318935689310423`},{{0.27`,30.8`,0.94368`,1.1666`},0.3766412483180529`},{{0.27`,30.8`,0.94368`,1.1711`},0.3766412483180529`},{{0.27`,30.8`,0.94368`,1.1621000000000001`},0.3766412483180529`},{{0.27`,30.8`,0.93668`,1.1666`},0.3697847742225758`},{{0.27`,30.8`,0.93668`,1.1711`},0.3697847742225758`},{{0.27`,30.8`,0.93668`,1.1621000000000001`},0.3697847742225758`},{{0.27`,31.4`,0.94018`,1.1666`},0.3727275669499697`},{{0.27`,31.4`,0.94018`,1.1711`},0.3727275669499697`},{{0.27`,31.4`,0.94018`,1.1621000000000001`},0.3727275669499697`},{{0.27`,31.4`,0.94368`,1.1666`},0.37618900784520387`},{{0.27`,31.4`,0.94368`,1.1711`},0.37618900784520387`},{{0.27`,31.4`,0.94368`,1.1621000000000001`},0.37618900784520387`},{{0.27`,31.4`,0.93668`,1.1666`},0.3693135724717603`},{{0.27`,31.4`,0.93668`,1.1711`},0.3693135724717603`},{{0.27`,31.4`,0.93668`,1.1621000000000001`},0.3693135724717603`},{{0.27`,32.`,0.94018`,1.1666`},0.37226859329865747`},{{0.27`,32.`,0.94018`,1.1711`},0.37226859329865747`},{{0.27`,32.`,0.94018`,1.1621000000000001`},0.37226859329865747`},{{0.27`,32.`,0.94368`,1.1666`},0.3757393590173467`},{{0.27`,32.`,0.94368`,1.1711`},0.3757393590173467`},{{0.27`,32.`,0.94368`,1.1621000000000001`},0.3757393590173467`},{{0.27`,32.`,0.93668`,1.1666`},0.36884540775447566`},{{0.27`,32.`,0.93668`,1.1711`},0.36884540775447566`},{{0.27`,32.`,0.93668`,1.1621000000000001`},0.36884540775447566`},{{0.27`,32.6`,0.94018`,1.1666`},0.37181269495096464`},{{0.27`,32.6`,0.94018`,1.1711`},0.37181269495096464`},{{0.27`,32.6`,0.94018`,1.1621000000000001`},0.37181269495096464`},{{0.27`,32.6`,0.94368`,1.1666`},0.3752925747639503`},{{0.27`,32.6`,0.94368`,1.1711`},0.3752925747639503`},{{0.27`,32.6`,0.94368`,1.1621000000000001`},0.3752925747639503`},{{0.27`,32.6`,0.93668`,1.1666`},0.36838052536956256`},{{0.27`,32.6`,0.93668`,1.1711`},0.36838052536956256`},{{0.27`,32.6`,0.93668`,1.1621000000000001`},0.36838052536956256`},{{0.27`,33.2`,0.94018`,1.1666`},0.3713600880181228`},{{0.27`,33.2`,0.94018`,1.1711`},0.3713600880181228`},{{0.27`,33.2`,0.94018`,1.1621000000000001`},0.3713600880181228`},{{0.27`,33.2`,0.94368`,1.1666`},0.3748488813192679`},{{0.27`,33.2`,0.94368`,1.1711`},0.3748488813192679`},{{0.27`,33.2`,0.94368`,1.1621000000000001`},0.3748488813192679`},{{0.27`,33.2`,0.93668`,1.1666`},0.3679191315209921`},{{0.27`,33.2`,0.93668`,1.1711`},0.3679191315209921`},{{0.27`,33.2`,0.93668`,1.1621000000000001`},0.3679191315209921`},{{0.27`,33.8`,0.94018`,1.1666`},0.37091094298476934`},{{0.27`,33.8`,0.94018`,1.1711`},0.37091094298476934`},{{0.27`,33.8`,0.94018`,1.1621000000000001`},0.37091094298476934`},{{0.27`,33.8`,0.94368`,1.1666`},0.3744084597174518`},{{0.27`,33.8`,0.94368`,1.1711`},0.3744084597174518`},{{0.27`,33.8`,0.94368`,1.1621000000000001`},0.3744084597174518`},{{0.27`,33.8`,0.93668`,1.1666`},0.3674613864784165`},{{0.27`,33.8`,0.93668`,1.1711`},0.3674613864784165`},{{0.27`,33.8`,0.93668`,1.1621000000000001`},0.3674613864784165`},{{0.27`,34.4`,0.94018`,1.1666`},0.37046540712011894`},{{0.27`,34.4`,0.94018`,1.1711`},0.37046540712011894`},{{0.27`,34.4`,0.94018`,1.1621000000000001`},0.37046540712011894`},{{0.27`,34.4`,0.94368`,1.1666`},0.3739714642224271`},{{0.27`,34.4`,0.94368`,1.1711`},0.3739714642224271`},{{0.27`,34.4`,0.94368`,1.1621000000000001`},0.3739714642224271`},{{0.27`,34.4`,0.93668`,1.1666`},0.3670074281196178`},{{0.27`,34.4`,0.93668`,1.1711`},0.3670074281196178`},{{0.27`,34.4`,0.93668`,1.1621000000000001`},0.3670074281196178`},{{0.27`,35.`,0.94018`,1.1666`},0.37002360759880165`},{{0.27`,35.`,0.94018`,1.1711`},0.37002360759880165`},{{0.27`,35.`,0.94018`,1.1621000000000001`},0.37002360759880165`},{{0.27`,35.`,0.94368`,1.1666`},0.3735380344075731`},{{0.27`,35.`,0.94368`,1.1711`},0.3735380344075731`},{{0.27`,35.`,0.94368`,1.1621000000000001`},0.3735380344075731`},{{0.27`,35.`,0.93668`,1.1666`},0.366557374517241`},{{0.27`,35.`,0.93668`,1.1711`},0.366557374517241`},{{0.27`,35.`,0.93668`,1.1621000000000001`},0.366557374517241`},{{0.27`,35.6`,0.94018`,1.1666`},0.36958540340027896`},{{0.27`,35.6`,0.94018`,1.1711`},0.36958540340027896`},{{0.27`,35.6`,0.94018`,1.1621000000000001`},0.36958540340027896`},{{0.27`,35.6`,0.94368`,1.1666`},0.3731080370387588`},{{0.27`,35.6`,0.94368`,1.1711`},0.3731080370387588`},{{0.27`,35.6`,0.94368`,1.1621000000000001`},0.3731080370387588`},{{0.27`,35.6`,0.93668`,1.1666`},0.3661110764287227`},{{0.27`,35.6`,0.93668`,1.1711`},0.3661110764287227`},{{0.27`,35.6`,0.93668`,1.1621000000000001`},0.3661110764287227`},{{0.27`,36.2`,0.94018`,1.1666`},0.3691512087817324`},{{0.27`,36.2`,0.94018`,1.1711`},0.3691512087817324`},{{0.27`,36.2`,0.94018`,1.1621000000000001`},0.3691512087817324`},{{0.27`,36.2`,0.94368`,1.1666`},0.3726818934771003`},{{0.27`,36.2`,0.94368`,1.1711`},0.3726818934771003`},{{0.27`,36.2`,0.94368`,1.1621000000000001`},0.3726818934771003`},{{0.27`,36.2`,0.93668`,1.1666`},0.3656689425727399`},{{0.27`,36.2`,0.93668`,1.1711`},0.3656689425727399`},{{0.27`,36.2`,0.93668`,1.1621000000000001`},0.3656689425727399`},{{0.27`,36.8`,0.94018`,1.1666`},0.3687209763769978`},{{0.27`,36.8`,0.94018`,1.1711`},0.3687209763769978`},{{0.27`,36.8`,0.94018`,1.1621000000000001`},0.3687209763769978`},{{0.27`,36.8`,0.94368`,1.1666`},0.3722595634838545`},{{0.27`,36.8`,0.94368`,1.1711`},0.3722595634838545`},{{0.27`,36.8`,0.94368`,1.1621000000000001`},0.3722595634838545`},{{0.27`,36.8`,0.93668`,1.1666`},0.3652309153070893`},{{0.27`,36.8`,0.93668`,1.1711`},0.3652309153070893`},{{0.27`,36.8`,0.93668`,1.1621000000000001`},0.3652309153070893`},{{0.27`,37.4`,0.94018`,1.1666`},0.3682947621206081`},{{0.27`,37.4`,0.94018`,1.1711`},0.3682947621206081`},{{0.27`,37.4`,0.94018`,1.1621000000000001`},0.3682947621206081`},{{0.27`,37.4`,0.94368`,1.1666`},0.37184110929208497`},{{0.27`,37.4`,0.94368`,1.1711`},0.37184110929208497`},{{0.27`,37.4`,0.94368`,1.1621000000000001`},0.37184110929208497`},{{0.27`,37.4`,0.93668`,1.1666`},0.3647970448749941`},{{0.27`,37.4`,0.93668`,1.1711`},0.3647970448749941`},{{0.27`,37.4`,0.93668`,1.1621000000000001`},0.3647970448749941`},{{0.27`,38.`,0.94018`,1.1666`},0.3678726135085967`},{{0.27`,38.`,0.94018`,1.1711`},0.3678726135085967`},{{0.27`,38.`,0.94018`,1.1621000000000001`},0.3678726135085967`},{{0.27`,38.`,0.94368`,1.1666`},0.37142658231454123`},{{0.27`,38.`,0.94368`,1.1711`},0.37142658231454123`},{{0.27`,38.`,0.94368`,1.1621000000000001`},0.37142658231454123`},{{0.27`,38.`,0.93668`,1.1666`},0.36436736833267225`},{{0.27`,38.`,0.93668`,1.1711`},0.36436736833267225`},{{0.27`,38.`,0.93668`,1.1621000000000001`},0.36436736833267225`},{{0.27`,38.6`,0.94018`,1.1666`},0.3674545541941345`},{{0.27`,38.6`,0.94018`,1.1711`},0.3674545541941345`},{{0.27`,38.6`,0.94018`,1.1621000000000001`},0.3674545541941345`},{{0.27`,38.6`,0.94368`,1.1666`},0.3710160232335974`},{{0.27`,38.6`,0.94368`,1.1711`},0.3710160232335974`},{{0.27`,38.6`,0.94368`,1.1621000000000001`},0.3710160232335974`},{{0.27`,38.6`,0.93668`,1.1666`},0.363941917143626`},{{0.27`,38.6`,0.93668`,1.1711`},0.363941917143626`},{{0.27`,38.6`,0.93668`,1.1621000000000001`},0.363941917143626`},{{0.27`,39.2`,0.94018`,1.1666`},0.3670406223323272`},{{0.27`,39.2`,0.94018`,1.1711`},0.3670406223323272`},{{0.27`,39.2`,0.94018`,1.1621000000000001`},0.3670406223323272`},{{0.27`,39.2`,0.94368`,1.1666`},0.37060946318509763`},{{0.27`,39.2`,0.94368`,1.1711`},0.37060946318509763`},{{0.27`,39.2`,0.94368`,1.1621000000000001`},0.37060946318509763`},{{0.27`,39.2`,0.93668`,1.1666`},0.3635207106313716`},{{0.27`,39.2`,0.93668`,1.1711`},0.3635207106313716`},{{0.27`,39.2`,0.93668`,1.1621000000000001`},0.3635207106313716`},{{0.27`,39.8`,0.94018`,1.1666`},0.3666308310267146`},{{0.27`,39.8`,0.94018`,1.1711`},0.3666308310267146`},{{0.27`,39.8`,0.94018`,1.1621000000000001`},0.3666308310267146`},{{0.27`,39.8`,0.94368`,1.1666`},0.37020692487965756`},{{0.27`,39.8`,0.94368`,1.1711`},0.37020692487965756`},{{0.27`,39.8`,0.94368`,1.1621000000000001`},0.37020692487965756`},{{0.27`,39.8`,0.93668`,1.1666`},0.3631037618530479`},{{0.27`,39.8`,0.93668`,1.1711`},0.3631037618530479`},{{0.27`,39.8`,0.93668`,1.1621000000000001`},0.3631037618530479`},{{0.3`,0.4`,0.94018`,1.1666`},0.31356004786461183`},{{0.3`,0.4`,0.94018`,1.1711`},0.31356004786461183`},{{0.3`,0.4`,0.94018`,1.1621000000000001`},0.31356004786461183`},{{0.3`,0.4`,0.94368`,1.1666`},0.31383536421681857`},{{0.3`,0.4`,0.94368`,1.1711`},0.31383536421681857`},{{0.3`,0.4`,0.94368`,1.1621000000000001`},0.31383536421681857`},{{0.3`,0.4`,0.93668`,1.1666`},0.3132881815293391`},{{0.3`,0.4`,0.93668`,1.1711`},0.3132881815293391`},{{0.3`,0.4`,0.93668`,1.1621000000000001`},0.3132881815293391`},{{0.3`,0.6`,0.94018`,1.1666`},0.3195895368846266`},{{0.3`,0.6`,0.94018`,1.1711`},0.3195895368846266`},{{0.3`,0.6`,0.94018`,1.1621000000000001`},0.3195895368846266`},{{0.3`,0.6`,0.94368`,1.1666`},0.31999037425157356`},{{0.3`,0.6`,0.94368`,1.1711`},0.31999037425157356`},{{0.3`,0.6`,0.94368`,1.1621000000000001`},0.31999037425157356`},{{0.3`,0.6`,0.93668`,1.1666`},0.3191937452730519`},{{0.3`,0.6`,0.93668`,1.1711`},0.3191937452730519`},{{0.3`,0.6`,0.93668`,1.1621000000000001`},0.3191937452730519`},{{0.3`,0.8`,0.94018`,1.1666`},0.32517506506388894`},{{0.3`,0.8`,0.94018`,1.1711`},0.32517506506388894`},{{0.3`,0.8`,0.94018`,1.1621000000000001`},0.32517506506388894`},{{0.3`,0.8`,0.94368`,1.1666`},0.32569413536812397`},{{0.3`,0.8`,0.94368`,1.1711`},0.32569413536812397`},{{0.3`,0.8`,0.94368`,1.1621000000000001`},0.32569413536812397`},{{0.3`,0.8`,0.93668`,1.1666`},0.324662556664174`},{{0.3`,0.8`,0.93668`,1.1711`},0.324662556664174`},{{0.3`,0.8`,0.93668`,1.1621000000000001`},0.324662556664174`},{{0.3`,1.`,0.94018`,1.1666`},0.33035365605005573`},{{0.3`,1.`,0.94018`,1.1711`},0.33035365605005573`},{{0.3`,1.`,0.94018`,1.1621000000000001`},0.33035365605005573`},{{0.3`,1.`,0.94368`,1.1666`},0.33098420805218365`},{{0.3`,1.`,0.94368`,1.1711`},0.33098420805218365`},{{0.3`,1.`,0.94368`,1.1621000000000001`},0.33098420805218365`},{{0.3`,1.`,0.93668`,1.1666`},0.32973110714579523`},{{0.3`,1.`,0.93668`,1.1711`},0.32973110714579523`},{{0.3`,1.`,0.93668`,1.1621000000000001`},0.32973110714579523`},{{0.3`,1.2`,0.94018`,1.1666`},0.335158698948325`},{{0.3`,1.2`,0.94018`,1.1711`},0.335158698948325`},{{0.3`,1.2`,0.94018`,1.1621000000000001`},0.335158698948325`},{{0.3`,1.2`,0.94368`,1.1666`},0.3358944718274068`},{{0.3`,1.2`,0.94368`,1.1711`},0.3358944718274068`},{{0.3`,1.2`,0.94368`,1.1621000000000001`},0.3358944718274068`},{{0.3`,1.2`,0.93668`,1.1666`},0.33443229978684`},{{0.3`,1.2`,0.93668`,1.1711`},0.33443229978684`},{{0.3`,1.2`,0.93668`,1.1621000000000001`},0.33443229978684`},{{0.3`,1.4`,0.94018`,1.1666`},0.33962036097949866`},{{0.3`,1.4`,0.94018`,1.1711`},0.33962036097949866`},{{0.3`,1.4`,0.94018`,1.1621000000000001`},0.33962036097949866`},{{0.3`,1.4`,0.94368`,1.1666`},0.3404555424171196`},{{0.3`,1.4`,0.94368`,1.1711`},0.3404555424171196`},{{0.3`,1.4`,0.94368`,1.1621000000000001`},0.3404555424171196`},{{0.3`,1.4`,0.93668`,1.1666`},0.3387958574398692`},{{0.3`,1.4`,0.93668`,1.1711`},0.3387958574398692`},{{0.3`,1.4`,0.93668`,1.1621000000000001`},0.3387958574398692`},{{0.3`,1.6`,0.94018`,1.1666`},0.34376594703434715`},{{0.3`,1.6`,0.94018`,1.1711`},0.34376594703434715`},{{0.3`,1.6`,0.94018`,1.1621000000000001`},0.34376594703434715`},{{0.3`,1.6`,0.94368`,1.1666`},0.3446951353291373`},{{0.3`,1.6`,0.94368`,1.1711`},0.3446951353291373`},{{0.3`,1.6`,0.94368`,1.1621000000000001`},0.3446951353291373`},{{0.3`,1.6`,0.93668`,1.1666`},0.3428486782711208`},{{0.3`,1.6`,0.93668`,1.1711`},0.3428486782711208`},{{0.3`,1.6`,0.93668`,1.1621000000000001`},0.3428486782711208`},{{0.3`,1.8`,0.94018`,1.1666`},0.34762021378893243`},{{0.3`,1.8`,0.94018`,1.1711`},0.34762021378893243`},{{0.3`,1.8`,0.94018`,1.1621000000000001`},0.34762021378893243`},{{0.3`,1.8`,0.94368`,1.1666`},0.3486383835845001`},{{0.3`,1.8`,0.94368`,1.1711`},0.3486383835845001`},{{0.3`,1.8`,0.94368`,1.1621000000000001`},0.3486383835845001`},{{0.3`,1.8`,0.93668`,1.1666`},0.34661514627081613`},{{0.3`,1.8`,0.93668`,1.1711`},0.34661514627081613`},{{0.3`,1.8`,0.93668`,1.1621000000000001`},0.34661514627081613`},{{0.3`,2.`,0.94018`,1.1666`},0.35120564475814375`},{{0.3`,2.`,0.94018`,1.1711`},0.35120564475814375`},{{0.3`,2.`,0.94018`,1.1621000000000001`},0.35120564475814375`},{{0.3`,2.`,0.94368`,1.1666`},0.35230811601049655`},{{0.3`,2.`,0.94368`,1.1711`},0.35230811601049655`},{{0.3`,2.`,0.94368`,1.1621000000000001`},0.35230811601049655`},{{0.3`,2.`,0.93668`,1.1666`},0.35011740307701894`},{{0.3`,2.`,0.93668`,1.1711`},0.35011740307701894`},{{0.3`,2.`,0.93668`,1.1621000000000001`},0.35011740307701894`},{{0.3`,2.2`,0.94018`,1.1666`},0.3545426916935058`},{{0.3`,2.2`,0.94018`,1.1711`},0.3545426916935058`},{{0.3`,2.2`,0.94018`,1.1621000000000001`},0.3545426916935058`},{{0.3`,2.2`,0.94368`,1.1666`},0.355725101544003`},{{0.3`,2.2`,0.94368`,1.1711`},0.355725101544003`},{{0.3`,2.2`,0.94368`,1.1621000000000001`},0.355725101544003`},{{0.3`,2.2`,0.93668`,1.1666`},0.3533755864785848`},{{0.3`,2.2`,0.93668`,1.1711`},0.3533755864785848`},{{0.3`,2.2`,0.93668`,1.1621000000000001`},0.3533755864785848`},{{0.3`,2.6`,0.94018`,1.1666`},0.36054260683276845`},{{0.3`,2.6`,0.94018`,1.1711`},0.36054260683276845`},{{0.3`,2.6`,0.94018`,1.1621000000000001`},0.36054260683276845`},{{0.3`,2.6`,0.94368`,1.1666`},0.36187294045882695`},{{0.3`,2.6`,0.94368`,1.1711`},0.36187294045882695`},{{0.3`,2.6`,0.94368`,1.1621000000000001`},0.36187294045882695`},{{0.3`,2.6`,0.93668`,1.1666`},0.35922958357851803`},{{0.3`,2.6`,0.93668`,1.1711`},0.35922958357851803`},{{0.3`,2.6`,0.93668`,1.1621000000000001`},0.35922958357851803`},{{0.3`,3.`,0.94018`,1.1666`},0.36575140374869897`},{{0.3`,3.`,0.94018`,1.1711`},0.36575140374869897`},{{0.3`,3.`,0.94018`,1.1621000000000001`},0.36575140374869897`},{{0.3`,3.`,0.94368`,1.1666`},0.3672154277726414`},{{0.3`,3.`,0.94368`,1.1711`},0.3672154277726414`},{{0.3`,3.`,0.94368`,1.1621000000000001`},0.3672154277726414`},{{0.3`,3.`,0.93668`,1.1666`},0.3643065209685842`},{{0.3`,3.`,0.93668`,1.1711`},0.3643065209685842`},{{0.3`,3.`,0.93668`,1.1621000000000001`},0.3643065209685842`},{{0.3`,3.4`,0.94018`,1.1666`},0.3702787342297755`},{{0.3`,3.4`,0.94018`,1.1711`},0.3702787342297755`},{{0.3`,3.4`,0.94018`,1.1621000000000001`},0.3702787342297755`},{{0.3`,3.4`,0.94368`,1.1666`},0.37186397025162343`},{{0.3`,3.4`,0.94368`,1.1711`},0.37186397025162343`},{{0.3`,3.4`,0.94368`,1.1621000000000001`},0.37186397025162343`},{{0.3`,3.4`,0.93668`,1.1666`},0.3687143146412484`},{{0.3`,3.4`,0.93668`,1.1711`},0.3687143146412484`},{{0.3`,3.4`,0.93668`,1.1621000000000001`},0.3687143146412484`},{{0.3`,3.8`,0.94018`,1.1666`},0.37421641915416`},{{0.3`,3.8`,0.94018`,1.1711`},0.37421641915416`},{{0.3`,3.8`,0.94018`,1.1621000000000001`},0.37421641915416`},{{0.3`,3.8`,0.94368`,1.1666`},0.375911891983204`},{{0.3`,3.8`,0.94368`,1.1711`},0.375911891983204`},{{0.3`,3.8`,0.94368`,1.1621000000000001`},0.375911891983204`},{{0.3`,3.8`,0.93668`,1.1666`},0.3725432991559067`},{{0.3`,3.8`,0.93668`,1.1711`},0.3725432991559067`},{{0.3`,3.8`,0.93668`,1.1621000000000001`},0.3725432991559067`},{{0.3`,4.2`,0.94018`,1.1666`},0.37764215075459695`},{{0.3`,4.2`,0.94018`,1.1711`},0.37764215075459695`},{{0.3`,4.2`,0.94018`,1.1621000000000001`},0.37764215075459695`},{{0.3`,4.2`,0.94368`,1.1666`},0.3794381750442179`},{{0.3`,4.2`,0.94368`,1.1711`},0.3794381750442179`},{{0.3`,4.2`,0.94368`,1.1621000000000001`},0.3794381750442179`},{{0.3`,4.2`,0.93668`,1.1666`},0.3758698917151205`},{{0.3`,4.2`,0.93668`,1.1711`},0.3758698917151205`},{{0.3`,4.2`,0.93668`,1.1621000000000001`},0.3758698917151205`},{{0.3`,4.6`,0.94018`,1.1666`},0.38062254052312167`},{{0.3`,4.6`,0.94018`,1.1711`},0.38062254052312167`},{{0.3`,4.6`,0.94018`,1.1621000000000001`},0.38062254052312167`},{{0.3`,4.6`,0.94368`,1.1666`},0.38251054500546844`},{{0.3`,4.6`,0.94368`,1.1711`},0.38251054500546844`},{{0.3`,4.6`,0.94368`,1.1621000000000001`},0.38251054500546844`},{{0.3`,4.6`,0.93668`,1.1666`},0.3787596025901189`},{{0.3`,4.6`,0.93668`,1.1711`},0.3787596025901189`},{{0.3`,4.6`,0.93668`,1.1621000000000001`},0.3787596025901189`},{{0.3`,5.`,0.94018`,1.1666`},0.3832139124410555`},{{0.3`,5.`,0.94018`,1.1711`},0.3832139124410555`},{{0.3`,5.`,0.94018`,1.1621000000000001`},0.3832139124410555`},{{0.3`,5.`,0.94368`,1.1666`},0.3851862761221804`},{{0.3`,5.`,0.94368`,1.1711`},0.3851862761221804`},{{0.3`,5.`,0.94368`,1.1621000000000001`},0.3851862761221804`},{{0.3`,5.`,0.93668`,1.1666`},0.3812678169823063`},{{0.3`,5.`,0.93668`,1.1711`},0.3812678169823063`},{{0.3`,5.`,0.93668`,1.1621000000000001`},0.3812678169823063`},{{0.3`,5.4`,0.94018`,1.1666`},0.3854639713723078`},{{0.3`,5.4`,0.94018`,1.1711`},0.3854639713723078`},{{0.3`,5.4`,0.94018`,1.1621000000000001`},0.3854639713723078`},{{0.3`,5.4`,0.94368`,1.1666`},0.38751390986827877`},{{0.3`,5.4`,0.94368`,1.1711`},0.38751390986827877`},{{0.3`,5.4`,0.94368`,1.1621000000000001`},0.38751390986827877`},{{0.3`,5.4`,0.93668`,1.1666`},0.3834414132753451`},{{0.3`,5.4`,0.93668`,1.1711`},0.3834414132753451`},{{0.3`,5.4`,0.93668`,1.1621000000000001`},0.3834414132753451`},{{0.3`,5.8`,0.94018`,1.1666`},0.38741424184285345`},{{0.3`,5.8`,0.94018`,1.1711`},0.38741424184285345`},{{0.3`,5.8`,0.94018`,1.1621000000000001`},0.38741424184285345`},{{0.3`,5.8`,0.94368`,1.1666`},0.38953569479520933`},{{0.3`,5.8`,0.94368`,1.1711`},0.38953569479520933`},{{0.3`,5.8`,0.94368`,1.1621000000000001`},0.38953569479520933`},{{0.3`,5.8`,0.93668`,1.1666`},0.3853212008477117`},{{0.3`,5.8`,0.93668`,1.1711`},0.3853212008477117`},{{0.3`,5.8`,0.93668`,1.1621000000000001`},0.3853212008477117`},{{0.3`,6.2`,0.94018`,1.1666`},0.3891005616090873`},{{0.3`,6.2`,0.94018`,1.1711`},0.3891005616090873`},{{0.3`,6.2`,0.94018`,1.1621000000000001`},0.3891005616090873`},{{0.3`,6.2`,0.94368`,1.1666`},0.3912881008178696`},{{0.3`,6.2`,0.94368`,1.1711`},0.3912881008178696`},{{0.3`,6.2`,0.94368`,1.1621000000000001`},0.3912881008178696`},{{0.3`,6.2`,0.93668`,1.1666`},0.3869423931426422`},{{0.3`,6.2`,0.93668`,1.1711`},0.3869423931426422`},{{0.3`,6.2`,0.93668`,1.1621000000000001`},0.3869423931426422`},{{0.3`,6.8`,0.94018`,1.1666`},0.39120161744422105`},{{0.3`,6.8`,0.94018`,1.1711`},0.39120161744422105`},{{0.3`,6.8`,0.94018`,1.1621000000000001`},0.39120161744422105`},{{0.3`,6.8`,0.94368`,1.1666`},0.39347929903691164`},{{0.3`,6.8`,0.94368`,1.1711`},0.39347929903691164`},{{0.3`,6.8`,0.94368`,1.1621000000000001`},0.39347929903691164`},{{0.3`,6.8`,0.93668`,1.1666`},0.3889546233413483`},{{0.3`,6.8`,0.93668`,1.1711`},0.3889546233413483`},{{0.3`,6.8`,0.93668`,1.1621000000000001`},0.3889546233413483`},{{0.3`,7.4`,0.94018`,1.1666`},0.39286539317885616`},{{0.3`,7.4`,0.94018`,1.1711`},0.39286539317885616`},{{0.3`,7.4`,0.94018`,1.1621000000000001`},0.39286539317885616`},{{0.3`,7.4`,0.94368`,1.1666`},0.39522382818109025`},{{0.3`,7.4`,0.94368`,1.1711`},0.39522382818109025`},{{0.3`,7.4`,0.94368`,1.1621000000000001`},0.39522382818109025`},{{0.3`,7.4`,0.93668`,1.1666`},0.3905388349613814`},{{0.3`,7.4`,0.93668`,1.1711`},0.3905388349613814`},{{0.3`,7.4`,0.93668`,1.1621000000000001`},0.3905388349613814`},{{0.3`,8.`,0.94018`,1.1666`},0.3941637362702705`},{{0.3`,8.`,0.94018`,1.1711`},0.3941637362702705`},{{0.3`,8.`,0.94018`,1.1621000000000001`},0.3941637362702705`},{{0.3`,8.`,0.94368`,1.1666`},0.39659485550251034`},{{0.3`,8.`,0.94368`,1.1711`},0.39659485550251034`},{{0.3`,8.`,0.94368`,1.1621000000000001`},0.39659485550251034`},{{0.3`,8.`,0.93668`,1.1666`},0.3917655710592949`},{{0.3`,8.`,0.93668`,1.1711`},0.3917655710592949`},{{0.3`,8.`,0.93668`,1.1621000000000001`},0.3917655710592949`},{{0.3`,8.6`,0.94018`,1.1666`},0.39515596411640697`},{{0.3`,8.6`,0.94018`,1.1711`},0.39515596411640697`},{{0.3`,8.6`,0.94018`,1.1621000000000001`},0.39515596411640697`},{{0.3`,8.6`,0.94368`,1.1666`},0.3976527995651661`},{{0.3`,8.6`,0.94368`,1.1711`},0.3976527995651661`},{{0.3`,8.6`,0.94368`,1.1621000000000001`},0.3976527995651661`},{{0.3`,8.6`,0.93668`,1.1666`},0.3926930637166508`},{{0.3`,8.6`,0.93668`,1.1711`},0.3926930637166508`},{{0.3`,8.6`,0.93668`,1.1621000000000001`},0.3926930637166508`},{{0.3`,9.2`,0.94018`,1.1666`},0.39589056265623745`},{{0.3`,9.2`,0.94018`,1.1711`},0.39589056265623745`},{{0.3`,9.2`,0.94018`,1.1621000000000001`},0.39589056265623745`},{{0.3`,9.2`,0.94368`,1.1666`},0.3984470688210742`},{{0.3`,9.2`,0.94368`,1.1711`},0.3984470688210742`},{{0.3`,9.2`,0.94368`,1.1621000000000001`},0.3984470688210742`},{{0.3`,9.2`,0.93668`,1.1666`},0.39336888796061487`},{{0.3`,9.2`,0.93668`,1.1711`},0.39336888796061487`},{{0.3`,9.2`,0.93668`,1.1621000000000001`},0.39336888796061487`},{{0.3`,9.8`,0.94018`,1.1666`},0.3964080258363516`},{{0.3`,9.8`,0.94018`,1.1711`},0.3964080258363516`},{{0.3`,9.8`,0.94018`,1.1621000000000001`},0.3964080258363516`},{{0.3`,9.8`,0.94368`,1.1666`},0.3990189337550214`},{{0.3`,9.8`,0.94368`,1.1711`},0.3990189337550214`},{{0.3`,9.8`,0.94368`,1.1621000000000001`},0.3990189337550214`},{{0.3`,9.8`,0.93668`,1.1666`},0.3938327714582869`},{{0.3`,9.8`,0.93668`,1.1711`},0.3938327714582869`},{{0.3`,9.8`,0.93668`,1.1621000000000001`},0.3938327714582869`},{{0.3`,10.4`,0.94018`,1.1666`},0.3967415868253724`},{{0.3`,10.4`,0.94018`,1.1711`},0.3967415868253724`},{{0.3`,10.4`,0.94018`,1.1621000000000001`},0.3967415868253724`},{{0.3`,10.4`,0.94368`,1.1666`},0.3994022829466163`},{{0.3`,10.4`,0.94368`,1.1711`},0.3994022829466163`},{{0.3`,10.4`,0.94368`,1.1621000000000001`},0.3994022829466163`},{{0.3`,10.4`,0.93668`,1.1666`},0.39411730083585444`},{{0.3`,10.4`,0.93668`,1.1711`},0.39411730083585444`},{{0.3`,10.4`,0.93668`,1.1621000000000001`},0.39411730083585444`},{{0.3`,11.`,0.94018`,1.1666`},0.39691973617429305`},{{0.3`,11.`,0.94018`,1.1711`},0.39691973617429305`},{{0.3`,11.`,0.94018`,1.1621000000000001`},0.39691973617429305`},{{0.3`,11.`,0.94368`,1.1666`},0.3996261701962911`},{{0.3`,11.`,0.94368`,1.1711`},0.3996261701962911`},{{0.3`,11.`,0.94368`,1.1621000000000001`},0.3996261701962911`},{{0.3`,11.`,0.93668`,1.1666`},0.39425041083109524`},{{0.3`,11.`,0.93668`,1.1711`},0.39425041083109524`},{{0.3`,11.`,0.93668`,1.1621000000000001`},0.39425041083109524`},{{0.3`,11.6`,0.94018`,1.1666`},0.3969660934517602`},{{0.3`,11.6`,0.94018`,1.1711`},0.3969660934517602`},{{0.3`,11.6`,0.94018`,1.1621000000000001`},0.3969660934517602`},{{0.3`,11.6`,0.94368`,1.1666`},0.3997146911114069`},{{0.3`,11.6`,0.94368`,1.1711`},0.3997146911114069`},{{0.3`,11.6`,0.94368`,1.1621000000000001`},0.3997146911114069`},{{0.3`,11.6`,0.93668`,1.1666`},0.39425525148044027`},{{0.3`,11.6`,0.93668`,1.1711`},0.39425525148044027`},{{0.3`,11.6`,0.93668`,1.1621000000000001`},0.39425525148044027`},{{0.3`,12.2`,0.94018`,1.1666`},0.3968999214724482`},{{0.3`,12.2`,0.94018`,1.1711`},0.3968999214724482`},{{0.3`,12.2`,0.94018`,1.1621000000000001`},0.3968999214724482`},{{0.3`,12.2`,0.94368`,1.1666`},0.39968752017568804`},{{0.3`,12.2`,0.94368`,1.1711`},0.39968752017568804`},{{0.3`,12.2`,0.94368`,1.1621000000000001`},0.39968752017568804`},{{0.3`,12.2`,0.93668`,1.1666`},0.3941506796386324`},{{0.3`,12.2`,0.93668`,1.1711`},0.3941506796386324`},{{0.3`,12.2`,0.93668`,1.1621000000000001`},0.3941506796386324`},{{0.3`,12.8`,0.94018`,1.1666`},0.39673880574508874`},{{0.3`,12.8`,0.94018`,1.1711`},0.39673880574508874`},{{0.3`,12.8`,0.94018`,1.1621000000000001`},0.39673880574508874`},{{0.3`,12.8`,0.94368`,1.1666`},0.3995625993656178`},{{0.3`,12.8`,0.94368`,1.1711`},0.3995625993656178`},{{0.3`,12.8`,0.94368`,1.1621000000000001`},0.3995625993656178`},{{0.3`,12.8`,0.93668`,1.1666`},0.3939539290176901`},{{0.3`,12.8`,0.93668`,1.1711`},0.3939539290176901`},{{0.3`,12.8`,0.93668`,1.1621000000000001`},0.3939539290176901`},{{0.3`,13.4`,0.94018`,1.1666`},0.3964967701545596`},{{0.3`,13.4`,0.94018`,1.1711`},0.3964967701545596`},{{0.3`,13.4`,0.94018`,1.1621000000000001`},0.3964967701545596`},{{0.3`,13.4`,0.94368`,1.1666`},0.3993542544332606`},{{0.3`,13.4`,0.94368`,1.1711`},0.3993542544332606`},{{0.3`,13.4`,0.94368`,1.1621000000000001`},0.3993542544332606`},{{0.3`,13.4`,0.93668`,1.1666`},0.39367872596795656`},{{0.3`,13.4`,0.93668`,1.1711`},0.39367872596795656`},{{0.3`,13.4`,0.93668`,1.1621000000000001`},0.39367872596795656`},{{0.3`,14.`,0.94018`,1.1666`},0.3961863186661275`},{{0.3`,14.`,0.94018`,1.1711`},0.3961863186661275`},{{0.3`,14.`,0.94018`,1.1621000000000001`},0.3961863186661275`},{{0.3`,14.`,0.94368`,1.1666`},0.3990752586844184`},{{0.3`,14.`,0.94368`,1.1711`},0.3990752586844184`},{{0.3`,14.`,0.94368`,1.1621000000000001`},0.3990752586844184`},{{0.3`,14.`,0.93668`,1.1666`},0.39333730867773625`},{{0.3`,14.`,0.93668`,1.1711`},0.39333730867773625`},{{0.3`,14.`,0.93668`,1.1621000000000001`},0.39333730867773625`},{{0.3`,14.6`,0.94018`,1.1666`},0.39581796172639166`},{{0.3`,14.6`,0.94018`,1.1711`},0.39581796172639166`},{{0.3`,14.6`,0.94018`,1.1621000000000001`},0.39581796172639166`},{{0.3`,14.6`,0.94368`,1.1666`},0.39873635253389655`},{{0.3`,14.6`,0.94368`,1.1711`},0.39873635253389655`},{{0.3`,14.6`,0.94368`,1.1621000000000001`},0.39873635253389655`},{{0.3`,14.6`,0.93668`,1.1666`},0.3929399608298855`},{{0.3`,14.6`,0.93668`,1.1711`},0.3929399608298855`},{{0.3`,14.6`,0.93668`,1.1621000000000001`},0.3929399608298855`},{{0.3`,15.2`,0.94018`,1.1666`},0.39540014498699216`},{{0.3`,15.2`,0.94018`,1.1711`},0.39540014498699216`},{{0.3`,15.2`,0.94018`,1.1621000000000001`},0.39540014498699216`},{{0.3`,15.2`,0.94368`,1.1666`},0.398346181304569`},{{0.3`,15.2`,0.94368`,1.1711`},0.398346181304569`},{{0.3`,15.2`,0.94368`,1.1621000000000001`},0.398346181304569`},{{0.3`,15.2`,0.93668`,1.1666`},0.3924949314087079`},{{0.3`,15.2`,0.93668`,1.1711`},0.3924949314087079`},{{0.3`,15.2`,0.93668`,1.1621000000000001`},0.3924949314087079`},{{0.3`,15.8`,0.94018`,1.1666`},0.3949410212051371`},{{0.3`,15.8`,0.94018`,1.1711`},0.3949410212051371`},{{0.3`,15.8`,0.94018`,1.1621000000000001`},0.3949410212051371`},{{0.3`,15.8`,0.94368`,1.1666`},0.3979130801047552`},{{0.3`,15.8`,0.94368`,1.1711`},0.3979130801047552`},{{0.3`,15.8`,0.94368`,1.1621000000000001`},0.3979130801047552`},{{0.3`,15.8`,0.93668`,1.1666`},0.39201019310932717`},{{0.3`,15.8`,0.93668`,1.1711`},0.39201019310932717`},{{0.3`,15.8`,0.93668`,1.1621000000000001`},0.39201019310932717`},{{0.3`,16.4`,0.94018`,1.1666`},0.3944471603081905`},{{0.3`,16.4`,0.94018`,1.1711`},0.3944471603081905`},{{0.3`,16.4`,0.94018`,1.1621000000000001`},0.3944471603081905`},{{0.3`,16.4`,0.94368`,1.1666`},0.3974437727592877`},{{0.3`,16.4`,0.94368`,1.1711`},0.3974437727592877`},{{0.3`,16.4`,0.94368`,1.1621000000000001`},0.3974437727592877`},{{0.3`,16.4`,0.93668`,1.1666`},0.3914921641875563`},{{0.3`,16.4`,0.93668`,1.1711`},0.3914921641875563`},{{0.3`,16.4`,0.93668`,1.1621000000000001`},0.3914921641875563`},{{0.3`,17.`,0.94018`,1.1666`},0.39392405085352883`},{{0.3`,17.`,0.94018`,1.1711`},0.39392405085352883`},{{0.3`,17.`,0.94018`,1.1621000000000001`},0.39392405085352883`},{{0.3`,17.`,0.94368`,1.1666`},0.3969438830191469`},{{0.3`,17.`,0.94368`,1.1711`},0.3969438830191469`},{{0.3`,17.`,0.94368`,1.1621000000000001`},0.3969438830191469`},{{0.3`,17.`,0.93668`,1.1666`},0.39094620005405345`},{{0.3`,17.`,0.93668`,1.1711`},0.39094620005405345`},{{0.3`,17.`,0.93668`,1.1621000000000001`},0.39094620005405345`},{{0.3`,17.6`,0.94018`,1.1666`},0.39337665790602905`},{{0.3`,17.6`,0.94018`,1.1711`},0.39337665790602905`},{{0.3`,17.6`,0.94018`,1.1621000000000001`},0.39337665790602905`},{{0.3`,17.6`,0.94368`,1.1666`},0.39641850239579896`},{{0.3`,17.6`,0.94368`,1.1711`},0.39641850239579896`},{{0.3`,17.6`,0.94368`,1.1621000000000001`},0.39641850239579896`},{{0.3`,17.6`,0.93668`,1.1666`},0.39037714098274834`},{{0.3`,17.6`,0.93668`,1.1711`},0.39037714098274834`},{{0.3`,17.6`,0.93668`,1.1621000000000001`},0.39037714098274834`},{{0.3`,18.2`,0.94018`,1.1666`},0.3928099214989309`},{{0.3`,18.2`,0.94018`,1.1711`},0.3928099214989309`},{{0.3`,18.2`,0.94018`,1.1621000000000001`},0.3928099214989309`},{{0.3`,18.2`,0.94368`,1.1666`},0.3958726729140653`},{{0.3`,18.2`,0.94368`,1.1711`},0.3958726729140653`},{{0.3`,18.2`,0.94368`,1.1621000000000001`},0.3958726729140653`},{{0.3`,18.2`,0.93668`,1.1666`},0.38978982616547836`},{{0.3`,18.2`,0.93668`,1.1711`},0.38978982616547836`},{{0.3`,18.2`,0.93668`,1.1621000000000001`},0.38978982616547836`},{{0.3`,18.8`,0.94018`,1.1666`},0.392226476196214`},{{0.3`,18.8`,0.94018`,1.1711`},0.392226476196214`},{{0.3`,18.8`,0.94018`,1.1621000000000001`},0.392226476196214`},{{0.3`,18.8`,0.94368`,1.1666`},0.3953091319889348`},{{0.3`,18.8`,0.94368`,1.1711`},0.3953091319889348`},{{0.3`,18.8`,0.94368`,1.1621000000000001`},0.3953091319889348`},{{0.3`,18.8`,0.93668`,1.1666`},0.38918678939489504`},{{0.3`,18.8`,0.93668`,1.1711`},0.38918678939489504`},{{0.3`,18.8`,0.93668`,1.1621000000000001`},0.38918678939489504`},{{0.3`,19.4`,0.94018`,1.1666`},0.3916296437272028`},{{0.3`,19.4`,0.94018`,1.1711`},0.3916296437272028`},{{0.3`,19.4`,0.94018`,1.1621000000000001`},0.3916296437272028`},{{0.3`,19.4`,0.94368`,1.1666`},0.39473128294949145`},{{0.3`,19.4`,0.94368`,1.1711`},0.39473128294949145`},{{0.3`,19.4`,0.94368`,1.1621000000000001`},0.39473128294949145`},{{0.3`,19.4`,0.93668`,1.1666`},0.38857127187288754`},{{0.3`,19.4`,0.93668`,1.1711`},0.38857127187288754`},{{0.3`,19.4`,0.93668`,1.1621000000000001`},0.38857127187288754`},{{0.3`,20.`,0.94018`,1.1666`},0.39102252829177575`},{{0.3`,20.`,0.94018`,1.1711`},0.39102252829177575`},{{0.3`,20.`,0.94018`,1.1621000000000001`},0.39102252829177575`},{{0.3`,20.`,0.94368`,1.1666`},0.39414230944579853`},{{0.3`,20.`,0.94368`,1.1711`},0.39414230944579853`},{{0.3`,20.`,0.94368`,1.1621000000000001`},0.39414230944579853`},{{0.3`,20.`,0.93668`,1.1666`},0.38794629926875535`},{{0.3`,20.`,0.93668`,1.1711`},0.38794629926875535`},{{0.3`,20.`,0.93668`,1.1621000000000001`},0.38794629926875535`},{{0.3`,20.6`,0.94018`,1.1666`},0.3904074916775946`},{{0.3`,20.6`,0.94018`,1.1711`},0.3904074916775946`},{{0.3`,20.6`,0.94018`,1.1621000000000001`},0.3904074916775946`},{{0.3`,20.6`,0.94368`,1.1666`},0.3935446402447994`},{{0.3`,20.6`,0.94368`,1.1711`},0.3935446402447994`},{{0.3`,20.6`,0.94368`,1.1621000000000001`},0.3935446402447994`},{{0.3`,20.6`,0.93668`,1.1666`},0.3873141674540494`},{{0.3`,20.6`,0.93668`,1.1711`},0.3873141674540494`},{{0.3`,20.6`,0.93668`,1.1621000000000001`},0.3873141674540494`},{{0.3`,21.2`,0.94018`,1.1666`},0.38978633146351566`},{{0.3`,21.2`,0.94018`,1.1711`},0.38978633146351566`},{{0.3`,21.2`,0.94018`,1.1621000000000001`},0.38978633146351566`},{{0.3`,21.2`,0.94368`,1.1666`},0.39294013392807714`},{{0.3`,21.2`,0.94368`,1.1711`},0.39294013392807714`},{{0.3`,21.2`,0.94368`,1.1621000000000001`},0.39294013392807714`},{{0.3`,21.2`,0.93668`,1.1666`},0.38667661405425163`},{{0.3`,21.2`,0.93668`,1.1711`},0.38667661405425163`},{{0.3`,21.2`,0.93668`,1.1621000000000001`},0.38667661405425163`},{{0.3`,21.8`,0.94018`,1.1666`},0.38916117569246433`},{{0.3`,21.8`,0.94018`,1.1711`},0.38916117569246433`},{{0.3`,21.8`,0.94018`,1.1621000000000001`},0.38916117569246433`},{{0.3`,21.8`,0.94368`,1.1666`},0.39233097240982745`},{{0.3`,21.8`,0.94368`,1.1711`},0.39233097240982745`},{{0.3`,21.8`,0.94368`,1.1621000000000001`},0.39233097240982745`},{{0.3`,21.8`,0.93668`,1.1666`},0.38603571074989707`},{{0.3`,21.8`,0.93668`,1.1711`},0.38603571074989707`},{{0.3`,21.8`,0.93668`,1.1621000000000001`},0.38603571074989707`},{{0.3`,22.4`,0.94018`,1.1666`},0.3885335308114099`},{{0.3`,22.4`,0.94018`,1.1711`},0.3885335308114099`},{{0.3`,22.4`,0.94018`,1.1621000000000001`},0.3885335308114099`},{{0.3`,22.4`,0.94368`,1.1666`},0.3917187153892111`},{{0.3`,22.4`,0.94368`,1.1711`},0.3917187153892111`},{{0.3`,22.4`,0.94368`,1.1621000000000001`},0.3917187153892111`},{{0.3`,22.4`,0.93668`,1.1666`},0.3853929157729125`},{{0.3`,22.4`,0.93668`,1.1711`},0.3853929157729125`},{{0.3`,22.4`,0.93668`,1.1621000000000001`},0.3853929157729125`},{{0.3`,23.`,0.94018`,1.1666`},0.3879047833027174`},{{0.3`,23.`,0.94018`,1.1711`},0.3879047833027174`},{{0.3`,23.`,0.94018`,1.1621000000000001`},0.3879047833027174`},{{0.3`,23.`,0.94368`,1.1666`},0.3911047966151014`},{{0.3`,23.`,0.94368`,1.1711`},0.3911047966151014`},{{0.3`,23.`,0.94368`,1.1621000000000001`},0.3911047966151014`},{{0.3`,23.`,0.93668`,1.1666`},0.38474957578547775`},{{0.3`,23.`,0.93668`,1.1711`},0.38474957578547775`},{{0.3`,23.`,0.93668`,1.1621000000000001`},0.38474957578547775`},{{0.3`,23.6`,0.94018`,1.1666`},0.38727615624244244`},{{0.3`,23.6`,0.94018`,1.1711`},0.38727615624244244`},{{0.3`,23.6`,0.94018`,1.1621000000000001`},0.38727615624244244`},{{0.3`,23.6`,0.94368`,1.1666`},0.3904904730804986`},{{0.3`,23.6`,0.94368`,1.1711`},0.3904904730804986`},{{0.3`,23.6`,0.94368`,1.1621000000000001`},0.3904904730804986`},{{0.3`,23.6`,0.93668`,1.1666`},0.384106863966671`},{{0.3`,23.6`,0.93668`,1.1711`},0.384106863966671`},{{0.3`,23.6`,0.93668`,1.1621000000000001`},0.384106863966671`},{{0.3`,24.2`,0.94018`,1.1666`},0.38664804795188107`},{{0.3`,24.2`,0.94018`,1.1711`},0.38664804795188107`},{{0.3`,24.2`,0.94018`,1.1621000000000001`},0.38664804795188107`},{{0.3`,24.2`,0.94368`,1.1666`},0.3898761824595309`},{{0.3`,24.2`,0.94368`,1.1711`},0.3898761824595309`},{{0.3`,24.2`,0.94368`,1.1621000000000001`},0.3898761824595309`},{{0.3`,24.2`,0.93668`,1.1666`},0.38346515099163936`},{{0.3`,24.2`,0.93668`,1.1711`},0.38346515099163936`},{{0.3`,24.2`,0.93668`,1.1621000000000001`},0.38346515099163936`},{{0.3`,24.8`,0.94018`,1.1666`},0.38602210722471353`},{{0.3`,24.8`,0.94018`,1.1711`},0.38602210722471353`},{{0.3`,24.8`,0.94018`,1.1621000000000001`},0.38602210722471353`},{{0.3`,24.8`,0.94368`,1.1666`},0.38926360931704257`},{{0.3`,24.8`,0.94368`,1.1711`},0.38926360931704257`},{{0.3`,24.8`,0.94368`,1.1621000000000001`},0.38926360931704257`},{{0.3`,24.8`,0.93668`,1.1666`},0.3828260476802262`},{{0.3`,24.8`,0.93668`,1.1711`},0.3828260476802262`},{{0.3`,24.8`,0.93668`,1.1621000000000001`},0.3828260476802262`},{{0.3`,25.4`,0.94018`,1.1666`},0.3853988760942851`},{{0.3`,25.4`,0.94018`,1.1711`},0.3853988760942851`},{{0.3`,25.4`,0.94018`,1.1621000000000001`},0.3853988760942851`},{{0.3`,25.4`,0.94368`,1.1666`},0.3886533246665426`},{{0.3`,25.4`,0.94368`,1.1711`},0.3886533246665426`},{{0.3`,25.4`,0.94368`,1.1621000000000001`},0.3886533246665426`},{{0.3`,25.4`,0.93668`,1.1666`},0.3821900677031302`},{{0.3`,25.4`,0.93668`,1.1711`},0.3821900677031302`},{{0.3`,25.4`,0.93668`,1.1621000000000001`},0.3821900677031302`},{{0.3`,26.`,0.94018`,1.1666`},0.38477903280270803`},{{0.3`,26.`,0.94018`,1.1711`},0.38477903280270803`},{{0.3`,26.`,0.94018`,1.1621000000000001`},0.38477903280270803`},{{0.3`,26.`,0.94368`,1.1666`},0.388046034404049`},{{0.3`,26.`,0.94368`,1.1711`},0.388046034404049`},{{0.3`,26.`,0.94368`,1.1621000000000001`},0.388046034404049`},{{0.3`,26.`,0.93668`,1.1666`},0.3815578620609385`},{{0.3`,26.`,0.93668`,1.1711`},0.3815578620609385`},{{0.3`,26.`,0.93668`,1.1621000000000001`},0.3815578620609385`},{{0.3`,26.6`,0.94018`,1.1666`},0.38416314652626865`},{{0.3`,26.6`,0.94018`,1.1711`},0.38416314652626865`},{{0.3`,26.6`,0.94018`,1.1621000000000001`},0.38416314652626865`},{{0.3`,26.6`,0.94368`,1.1666`},0.38744233312753684`},{{0.3`,26.6`,0.94368`,1.1711`},0.38744233312753684`},{{0.3`,26.6`,0.94368`,1.1621000000000001`},0.38744233312753684`},{{0.3`,26.6`,0.93668`,1.1666`},0.38092997489429037`},{{0.3`,26.6`,0.93668`,1.1711`},0.38092997489429037`},{{0.3`,26.6`,0.93668`,1.1621000000000001`},0.38092997489429037`},{{0.3`,27.2`,0.94018`,1.1666`},0.3835512313718859`},{{0.3`,27.2`,0.94018`,1.1711`},0.3835512313718859`},{{0.3`,27.2`,0.94018`,1.1621000000000001`},0.3835512313718859`},{{0.3`,27.2`,0.94368`,1.1666`},0.386842257780199`},{{0.3`,27.2`,0.94368`,1.1711`},0.386842257780199`},{{0.3`,27.2`,0.94368`,1.1621000000000001`},0.386842257780199`},{{0.3`,27.2`,0.93668`,1.1666`},0.38030639815708056`},{{0.3`,27.2`,0.93668`,1.1711`},0.38030639815708056`},{{0.3`,27.2`,0.93668`,1.1621000000000001`},0.38030639815708056`},{{0.3`,27.8`,0.94018`,1.1666`},0.3829442558296774`},{{0.3`,27.8`,0.94018`,1.1711`},0.3829442558296774`},{{0.3`,27.8`,0.94018`,1.1621000000000001`},0.3829442558296774`},{{0.3`,27.8`,0.94368`,1.1666`},0.38624680059779026`},{{0.3`,27.8`,0.94368`,1.1711`},0.38624680059779026`},{{0.3`,27.8`,0.94368`,1.1621000000000001`},0.38624680059779026`},{{0.3`,27.8`,0.93668`,1.1666`},0.3796880764765248`},{{0.3`,27.8`,0.93668`,1.1711`},0.3796880764765248`},{{0.3`,27.8`,0.93668`,1.1621000000000001`},0.3796880764765248`},{{0.3`,28.4`,0.94018`,1.1666`},0.3823424525532136`},{{0.3`,28.4`,0.94018`,1.1711`},0.3823424525532136`},{{0.3`,28.4`,0.94018`,1.1621000000000001`},0.3823424525532136`},{{0.3`,28.4`,0.94368`,1.1666`},0.3856562117924893`},{{0.3`,28.4`,0.94368`,1.1711`},0.3856562117924893`},{{0.3`,28.4`,0.94368`,1.1621000000000001`},0.3856562117924893`},{{0.3`,28.4`,0.93668`,1.1666`},0.3790752253896665`},{{0.3`,28.4`,0.93668`,1.1711`},0.3790752253896665`},{{0.3`,28.4`,0.93668`,1.1621000000000001`},0.3790752253896665`},{{0.3`,29.`,0.94018`,1.1666`},0.38174613383393563`},{{0.3`,29.`,0.94018`,1.1711`},0.38174613383393563`},{{0.3`,29.`,0.94018`,1.1621000000000001`},0.38174613383393563`},{{0.3`,29.`,0.94368`,1.1666`},0.38507082141634136`},{{0.3`,29.`,0.94368`,1.1711`},0.38507082141634136`},{{0.3`,29.`,0.94368`,1.1621000000000001`},0.38507082141634136`},{{0.3`,29.`,0.93668`,1.1666`},0.3784681396988815`},{{0.3`,29.`,0.93668`,1.1711`},0.3784681396988815`},{{0.3`,29.`,0.93668`,1.1621000000000001`},0.3784681396988815`},{{0.3`,29.6`,0.94018`,1.1666`},0.38115535316234567`},{{0.3`,29.6`,0.94018`,1.1711`},0.38115535316234567`},{{0.3`,29.6`,0.94018`,1.1621000000000001`},0.38115535316234567`},{{0.3`,29.6`,0.94368`,1.1666`},0.3844906989700007`},{{0.3`,29.6`,0.94368`,1.1711`},0.3844906989700007`},{{0.3`,29.6`,0.94368`,1.1621000000000001`},0.3844906989700007`},{{0.3`,29.6`,0.93668`,1.1666`},0.3778668574734714`},{{0.3`,29.6`,0.93668`,1.1711`},0.3778668574734714`},{{0.3`,29.6`,0.93668`,1.1621000000000001`},0.3778668574734714`},{{0.3`,30.2`,0.94018`,1.1666`},0.38057047859468696`},{{0.3`,30.2`,0.94018`,1.1711`},0.38057047859468696`},{{0.3`,30.2`,0.94018`,1.1621000000000001`},0.38057047859468696`},{{0.3`,30.2`,0.94368`,1.1666`},0.3839162299151946`},{{0.3`,30.2`,0.94368`,1.1711`},0.3839162299151946`},{{0.3`,30.2`,0.94368`,1.1621000000000001`},0.3839162299151946`},{{0.3`,30.2`,0.93668`,1.1666`},0.3772717294577477`},{{0.3`,30.2`,0.93668`,1.1711`},0.3772717294577477`},{{0.3`,30.2`,0.93668`,1.1621000000000001`},0.3772717294577477`},{{0.3`,30.8`,0.94018`,1.1666`},0.3799916681081694`},{{0.3`,30.8`,0.94018`,1.1711`},0.3799916681081694`},{{0.3`,30.8`,0.94018`,1.1621000000000001`},0.3799916681081694`},{{0.3`,30.8`,0.94368`,1.1666`},0.38334758521877543`},{{0.3`,30.8`,0.94368`,1.1711`},0.38334758521877543`},{{0.3`,30.8`,0.94368`,1.1621000000000001`},0.38334758521877543`},{{0.3`,30.8`,0.93668`,1.1666`},0.37668290111810576`},{{0.3`,30.8`,0.93668`,1.1711`},0.37668290111810576`},{{0.3`,30.8`,0.93668`,1.1621000000000001`},0.37668290111810576`},{{0.3`,31.4`,0.94018`,1.1666`},0.37941906430314426`},{{0.3`,31.4`,0.94018`,1.1711`},0.37941906430314426`},{{0.3`,31.4`,0.94018`,1.1621000000000001`},0.37941906430314426`},{{0.3`,31.4`,0.94368`,1.1666`},0.38278491697670397`},{{0.3`,31.4`,0.94368`,1.1711`},0.38278491697670397`},{{0.3`,31.4`,0.94368`,1.1621000000000001`},0.38278491697670397`},{{0.3`,31.4`,0.93668`,1.1666`},0.3761005024008564`},{{0.3`,31.4`,0.93668`,1.1711`},0.3761005024008564`},{{0.3`,31.4`,0.93668`,1.1621000000000001`},0.3761005024008564`},{{0.3`,32.`,0.94018`,1.1666`},0.3788527091453834`},{{0.3`,32.`,0.94018`,1.1711`},0.3788527091453834`},{{0.3`,32.`,0.94018`,1.1621000000000001`},0.3788527091453834`},{{0.3`,32.`,0.94368`,1.1666`},0.3822282829867554`},{{0.3`,32.`,0.94368`,1.1711`},0.3822282829867554`},{{0.3`,32.`,0.94368`,1.1621000000000001`},0.3822282829867554`},{{0.3`,32.`,0.93668`,1.1666`},0.37552456393370814`},{{0.3`,32.`,0.93668`,1.1711`},0.37552456393370814`},{{0.3`,32.`,0.93668`,1.1621000000000001`},0.37552456393370814`},{{0.3`,32.6`,0.94018`,1.1666`},0.3782926958395609`},{{0.3`,32.6`,0.94018`,1.1711`},0.3782926958395609`},{{0.3`,32.6`,0.94018`,1.1621000000000001`},0.3782926958395609`},{{0.3`,32.6`,0.94368`,1.1666`},0.38167779367065746`},{{0.3`,32.6`,0.94368`,1.1711`},0.38167779367065746`},{{0.3`,32.6`,0.94368`,1.1621000000000001`},0.38167779367065746`},{{0.3`,32.6`,0.93668`,1.1666`},0.3749551688539756`},{{0.3`,32.6`,0.93668`,1.1711`},0.3749551688539756`},{{0.3`,32.6`,0.93668`,1.1621000000000001`},0.3749551688539756`},{{0.3`,33.2`,0.94018`,1.1666`},0.377739109992038`},{{0.3`,33.2`,0.94018`,1.1711`},0.377739109992038`},{{0.3`,33.2`,0.94018`,1.1621000000000001`},0.377739109992038`},{{0.3`,33.2`,0.94368`,1.1666`},0.3811335261814943`},{{0.3`,33.2`,0.94368`,1.1711`},0.3811335261814943`},{{0.3`,33.2`,0.94368`,1.1621000000000001`},0.3811335261814943`},{{0.3`,33.2`,0.93668`,1.1666`},0.3743923903924498`},{{0.3`,33.2`,0.93668`,1.1711`},0.3743923903924498`},{{0.3`,33.2`,0.93668`,1.1621000000000001`},0.3743923903924498`},{{0.3`,33.8`,0.94018`,1.1666`},0.3771919931015457`},{{0.3`,33.8`,0.94018`,1.1711`},0.3771919931015457`},{{0.3`,33.8`,0.94018`,1.1621000000000001`},0.3771919931015457`},{{0.3`,33.8`,0.94368`,1.1666`},0.3805955469922923`},{{0.3`,33.8`,0.94368`,1.1711`},0.3805955469922923`},{{0.3`,33.8`,0.94368`,1.1621000000000001`},0.3805955469922923`},{{0.3`,33.8`,0.93668`,1.1666`},0.3738362592194074`},{{0.3`,33.8`,0.93668`,1.1711`},0.3738362592194074`},{{0.3`,33.8`,0.93668`,1.1621000000000001`},0.3738362592194074`},{{0.3`,34.4`,0.94018`,1.1666`},0.3766513651760741`},{{0.3`,34.4`,0.94018`,1.1711`},0.3766513651760741`},{{0.3`,34.4`,0.94018`,1.1621000000000001`},0.3766513651760741`},{{0.3`,34.4`,0.94368`,1.1666`},0.38006388456309786`},{{0.3`,34.4`,0.94368`,1.1711`},0.38006388456309786`},{{0.3`,34.4`,0.94368`,1.1621000000000001`},0.38006388456309786`},{{0.3`,34.4`,0.93668`,1.1666`},0.37328679331236886`},{{0.3`,34.4`,0.93668`,1.1711`},0.37328679331236886`},{{0.3`,34.4`,0.93668`,1.1621000000000001`},0.37328679331236886`},{{0.3`,35.`,0.94018`,1.1666`},0.37611723873750336`},{{0.3`,35.`,0.94018`,1.1711`},0.37611723873750336`},{{0.3`,35.`,0.94018`,1.1621000000000001`},0.37611723873750336`},{{0.3`,35.`,0.94368`,1.1666`},0.37953855437707557`},{{0.3`,35.`,0.94368`,1.1711`},0.37953855437707557`},{{0.3`,35.`,0.94368`,1.1621000000000001`},0.37953855437707557`},{{0.3`,35.`,0.93668`,1.1666`},0.37274399147201726`},{{0.3`,35.`,0.93668`,1.1711`},0.37274399147201726`},{{0.3`,35.`,0.93668`,1.1621000000000001`},0.37274399147201726`},{{0.3`,35.6`,0.94018`,1.1666`},0.3755894306475954`},{{0.3`,35.6`,0.94018`,1.1711`},0.3755894306475954`},{{0.3`,35.6`,0.94018`,1.1621000000000001`},0.3755894306475954`},{{0.3`,35.6`,0.94368`,1.1666`},0.37901938276857033`},{{0.3`,35.6`,0.94368`,1.1711`},0.37901938276857033`},{{0.3`,35.6`,0.94368`,1.1621000000000001`},0.37901938276857033`},{{0.3`,35.6`,0.93668`,1.1666`},0.37220766638760944`},{{0.3`,35.6`,0.93668`,1.1711`},0.37220766638760944`},{{0.3`,35.6`,0.93668`,1.1621000000000001`},0.37220766638760944`},{{0.3`,36.2`,0.94018`,1.1666`},0.3750681590199162`},{{0.3`,36.2`,0.94018`,1.1711`},0.3750681590199162`},{{0.3`,36.2`,0.94018`,1.1621000000000001`},0.3750681590199162`},{{0.3`,36.2`,0.94368`,1.1666`},0.37850659530314185`},{{0.3`,36.2`,0.94368`,1.1711`},0.37850659530314185`},{{0.3`,36.2`,0.94368`,1.1621000000000001`},0.37850659530314185`},{{0.3`,36.2`,0.93668`,1.1666`},0.3716780227587058`},{{0.3`,36.2`,0.93668`,1.1711`},0.3716780227587058`},{{0.3`,36.2`,0.93668`,1.1621000000000001`},0.3716780227587058`},{{0.3`,36.8`,0.94018`,1.1666`},0.3745533106897924`},{{0.3`,36.8`,0.94018`,1.1711`},0.3745533106897924`},{{0.3`,36.8`,0.94018`,1.1621000000000001`},0.3745533106897924`},{{0.3`,36.8`,0.94368`,1.1666`},0.37800008525098505`},{{0.3`,36.8`,0.94368`,1.1711`},0.37800008525098505`},{{0.3`,36.8`,0.94368`,1.1621000000000001`},0.37800008525098505`},{{0.3`,36.8`,0.93668`,1.1666`},0.37115494756143946`},{{0.3`,36.8`,0.93668`,1.1711`},0.37115494756143946`},{{0.3`,36.8`,0.93668`,1.1621000000000001`},0.37115494756143946`},{{0.3`,37.4`,0.94018`,1.1666`},0.3740448491978426`},{{0.3`,37.4`,0.94018`,1.1711`},0.3740448491978426`},{{0.3`,37.4`,0.94018`,1.1621000000000001`},0.3740448491978426`},{{0.3`,37.4`,0.94368`,1.1666`},0.3774998224144889`},{{0.3`,37.4`,0.94368`,1.1711`},0.3774998224144889`},{{0.3`,37.4`,0.94368`,1.1621000000000001`},0.3774998224144889`},{{0.3`,37.4`,0.93668`,1.1666`},0.3706383960216977`},{{0.3`,37.4`,0.93668`,1.1711`},0.3706383960216977`},{{0.3`,37.4`,0.93668`,1.1621000000000001`},0.3706383960216977`},{{0.3`,38.`,0.94018`,1.1666`},0.3735427311362228`},{{0.3`,38.`,0.94018`,1.1711`},0.3735427311362228`},{{0.3`,38.`,0.94018`,1.1621000000000001`},0.3735427311362228`},{{0.3`,38.`,0.94368`,1.1666`},0.3770057695951241`},{{0.3`,38.`,0.94368`,1.1711`},0.3770057695951241`},{{0.3`,38.`,0.94368`,1.1621000000000001`},0.3770057695951241`},{{0.3`,38.`,0.93668`,1.1666`},0.3701283189845243`},{{0.3`,38.`,0.93668`,1.1711`},0.3701283189845243`},{{0.3`,38.`,0.93668`,1.1621000000000001`},0.3701283189845243`},{{0.3`,38.6`,0.94018`,1.1666`},0.3730469071096396`},{{0.3`,38.6`,0.94018`,1.1711`},0.3730469071096396`},{{0.3`,38.6`,0.94018`,1.1621000000000001`},0.3730469071096396`},{{0.3`,38.6`,0.94368`,1.1666`},0.37651788257290425`},{{0.3`,38.6`,0.94368`,1.1711`},0.37651788257290425`},{{0.3`,38.6`,0.94368`,1.1621000000000001`},0.37651788257290425`},{{0.3`,38.6`,0.93668`,1.1666`},0.36962466171471847`},{{0.3`,38.6`,0.93668`,1.1711`},0.36962466171471847`},{{0.3`,38.6`,0.93668`,1.1621000000000001`},0.36962466171471847`},{{0.3`,39.2`,0.94018`,1.1666`},0.37255732270303754`},{{0.3`,39.2`,0.94018`,1.1711`},0.37255732270303754`},{{0.3`,39.2`,0.94018`,1.1621000000000001`},0.37255732270303754`},{{0.3`,39.2`,0.94368`,1.1666`},0.3760361107523551`},{{0.3`,39.2`,0.94368`,1.1711`},0.3760361107523551`},{{0.3`,39.2`,0.94368`,1.1621000000000001`},0.3760361107523551`},{{0.3`,39.2`,0.93668`,1.1666`},0.3691273647718176`},{{0.3`,39.2`,0.93668`,1.1711`},0.3691273647718176`},{{0.3`,39.2`,0.93668`,1.1621000000000001`},0.3691273647718176`},{{0.3`,39.8`,0.94018`,1.1666`},0.37207391956017416`},{{0.3`,39.8`,0.94018`,1.1711`},0.37207391956017416`},{{0.3`,39.8`,0.94018`,1.1621000000000001`},0.37207391956017416`},{{0.3`,39.8`,0.94368`,1.1666`},0.37556040148067904`},{{0.3`,39.8`,0.94368`,1.1711`},0.37556040148067904`},{{0.3`,39.8`,0.94368`,1.1621000000000001`},0.37556040148067904`},{{0.3`,39.8`,0.93668`,1.1666`},0.3686363648399515`},{{0.3`,39.8`,0.93668`,1.1711`},0.3686363648399515`},{{0.3`,39.8`,0.93668`,1.1621000000000001`},0.3686363648399515`},{{0.36`,0.4`,0.94018`,1.1666`},0.37138529001139814`},{{0.36`,0.4`,0.94018`,1.1711`},0.37138529001139814`},{{0.36`,0.4`,0.94018`,1.1621000000000001`},0.37138529001139814`},{{0.36`,0.4`,0.94368`,1.1666`},0.37164839353982604`},{{0.36`,0.4`,0.94368`,1.1711`},0.37164839353982604`},{{0.36`,0.4`,0.94368`,1.1621000000000001`},0.37164839353982604`},{{0.36`,0.4`,0.93668`,1.1666`},0.37112558902291587`},{{0.36`,0.4`,0.93668`,1.1711`},0.37112558902291587`},{{0.36`,0.4`,0.93668`,1.1621000000000001`},0.37112558902291587`},{{0.36`,0.6`,0.94018`,1.1666`},0.37636924016174517`},{{0.36`,0.6`,0.94018`,1.1711`},0.37636924016174517`},{{0.36`,0.6`,0.94018`,1.1621000000000001`},0.37636924016174517`},{{0.36`,0.6`,0.94368`,1.1666`},0.37675190330411884`},{{0.36`,0.6`,0.94368`,1.1711`},0.37675190330411884`},{{0.36`,0.6`,0.94368`,1.1621000000000001`},0.37675190330411884`},{{0.36`,0.6`,0.93668`,1.1666`},0.3759915500815523`},{{0.36`,0.6`,0.93668`,1.1711`},0.3759915500815523`},{{0.36`,0.6`,0.93668`,1.1621000000000001`},0.3759915500815523`},{{0.36`,0.8`,0.94018`,1.1666`},0.38093662423365376`},{{0.36`,0.8`,0.94018`,1.1711`},0.38093662423365376`},{{0.36`,0.8`,0.94018`,1.1621000000000001`},0.38093662423365376`},{{0.36`,0.8`,0.94368`,1.1666`},0.38143167454420607`},{{0.36`,0.8`,0.94368`,1.1711`},0.38143167454420607`},{{0.36`,0.8`,0.94368`,1.1621000000000001`},0.38143167454420607`},{{0.36`,0.8`,0.93668`,1.1666`},0.38044803736355187`},{{0.36`,0.8`,0.93668`,1.1711`},0.38044803736355187`},{{0.36`,0.8`,0.93668`,1.1621000000000001`},0.38044803736355187`},{{0.36`,1.`,0.94018`,1.1666`},0.3851239786145073`},{{0.36`,1.`,0.94018`,1.1711`},0.3851239786145073`},{{0.36`,1.`,0.94018`,1.1621000000000001`},0.3851239786145073`},{{0.36`,1.`,0.94368`,1.1666`},0.3857247908765332`},{{0.36`,1.`,0.94368`,1.1711`},0.3857247908765332`},{{0.36`,1.`,0.94368`,1.1621000000000001`},0.3857247908765332`},{{0.36`,1.`,0.93668`,1.1666`},0.3845310449220417`},{{0.36`,1.`,0.93668`,1.1711`},0.3845310449220417`},{{0.36`,1.`,0.93668`,1.1621000000000001`},0.3845310449220417`},{{0.36`,1.2`,0.94018`,1.1666`},0.388964140556244`},{{0.36`,1.2`,0.94018`,1.1711`},0.388964140556244`},{{0.36`,1.2`,0.94018`,1.1621000000000001`},0.388964140556244`},{{0.36`,1.2`,0.94368`,1.1666`},0.38966458789587316`},{{0.36`,1.2`,0.94368`,1.1711`},0.38966458789587316`},{{0.36`,1.2`,0.94368`,1.1621000000000001`},0.38966458789587316`},{{0.36`,1.2`,0.93668`,1.1666`},0.3882729162687366`},{{0.36`,1.2`,0.93668`,1.1711`},0.3882729162687366`},{{0.36`,1.2`,0.93668`,1.1621000000000001`},0.3882729162687366`},{{0.36`,1.4`,0.94018`,1.1666`},0.3924866776956254`},{{0.36`,1.4`,0.94018`,1.1711`},0.3924866776956254`},{{0.36`,1.4`,0.94018`,1.1621000000000001`},0.3924866776956254`},{{0.36`,1.4`,0.94368`,1.1666`},0.39328108759446245`},{{0.36`,1.4`,0.94368`,1.1711`},0.39328108759446245`},{{0.36`,1.4`,0.94368`,1.1621000000000001`},0.39328108759446245`},{{0.36`,1.4`,0.93668`,1.1666`},0.39170276900388945`},{{0.36`,1.4`,0.93668`,1.1711`},0.39170276900388945`},{{0.36`,1.4`,0.93668`,1.1621000000000001`},0.39170276900388945`},{{0.36`,1.6`,0.94018`,1.1666`},0.39571826136241844`},{{0.36`,1.6`,0.94018`,1.1711`},0.39571826136241844`},{{0.36`,1.6`,0.94018`,1.1621000000000001`},0.39571826136241844`},{{0.36`,1.6`,0.94368`,1.1666`},0.39660137604028883`},{{0.36`,1.6`,0.94368`,1.1711`},0.39660137604028883`},{{0.36`,1.6`,0.94368`,1.1621000000000001`},0.39660137604028883`},{{0.36`,1.6`,0.93668`,1.1666`},0.3948468637654158`},{{0.36`,1.6`,0.93668`,1.1711`},0.3948468637654158`},{{0.36`,1.6`,0.93668`,1.1621000000000001`},0.3948468637654158`},{{0.36`,1.8`,0.94018`,1.1666`},0.3986829918299058`},{{0.36`,1.8`,0.94018`,1.1711`},0.3986829918299058`},{{0.36`,1.8`,0.94018`,1.1621000000000001`},0.3986829918299058`},{{0.36`,1.8`,0.94368`,1.1666`},0.3996499325272378`},{{0.36`,1.8`,0.94368`,1.1711`},0.3996499325272378`},{{0.36`,1.8`,0.94368`,1.1621000000000001`},0.3996499325272378`},{{0.36`,1.8`,0.93668`,1.1666`},0.3977289255923793`},{{0.36`,1.8`,0.93668`,1.1711`},0.3977289255923793`},{{0.36`,1.8`,0.93668`,1.1621000000000001`},0.3977289255923793`},{{0.36`,2.`,0.94018`,1.1666`},0.40140268236967236`},{{0.36`,2.`,0.94018`,1.1711`},0.40140268236967236`},{{0.36`,2.`,0.94018`,1.1621000000000001`},0.40140268236967236`},{{0.36`,2.`,0.94368`,1.1666`},0.40244891711143926`},{{0.36`,2.`,0.94368`,1.1711`},0.40244891711143926`},{{0.36`,2.`,0.94368`,1.1621000000000001`},0.40244891711143926`},{{0.36`,2.`,0.93668`,1.1666`},0.40037042451171556`},{{0.36`,2.`,0.93668`,1.1711`},0.40037042451171556`},{{0.36`,2.`,0.93668`,1.1621000000000001`},0.40037042451171556`},{{0.36`,2.2`,0.94018`,1.1666`},0.403897107901245`},{{0.36`,2.2`,0.94018`,1.1711`},0.403897107901245`},{{0.36`,2.2`,0.94018`,1.1621000000000001`},0.403897107901245`},{{0.36`,2.2`,0.94368`,1.1666`},0.4050184223712193`},{{0.36`,2.2`,0.94368`,1.1711`},0.4050184223712193`},{{0.36`,2.2`,0.94368`,1.1621000000000001`},0.4050184223712193`},{{0.36`,2.2`,0.93668`,1.1666`},0.40279082109143277`},{{0.36`,2.2`,0.93668`,1.1711`},0.40279082109143277`},{{0.36`,2.2`,0.93668`,1.1621000000000001`},0.40279082109143277`},{{0.36`,2.6`,0.94018`,1.1666`},0.40827841824260597`},{{0.36`,2.6`,0.94018`,1.1711`},0.40827841824260597`},{{0.36`,2.6`,0.94018`,1.1621000000000001`},0.40827841824260597`},{{0.36`,2.6`,0.94368`,1.1666`},0.40953838064208387`},{{0.36`,2.6`,0.94368`,1.1711`},0.40953838064208387`},{{0.36`,2.6`,0.94368`,1.1621000000000001`},0.40953838064208387`},{{0.36`,2.6`,0.93668`,1.1666`},0.40703544262613794`},{{0.36`,2.6`,0.93668`,1.1711`},0.40703544262613794`},{{0.36`,2.6`,0.93668`,1.1621000000000001`},0.40703544262613794`},{{0.36`,3.`,0.94018`,1.1666`},0.41195299450915107`},{{0.36`,3.`,0.94018`,1.1711`},0.41195299450915107`},{{0.36`,3.`,0.94018`,1.1621000000000001`},0.41195299450915107`},{{0.36`,3.`,0.94368`,1.1666`},0.4133379524138034`},{{0.36`,3.`,0.94368`,1.1711`},0.4133379524138034`},{{0.36`,3.`,0.94368`,1.1621000000000001`},0.4133379524138034`},{{0.36`,3.`,0.93668`,1.1666`},0.4105868106073354`},{{0.36`,3.`,0.93668`,1.1711`},0.4105868106073354`},{{0.36`,3.`,0.93668`,1.1621000000000001`},0.4105868106073354`},{{0.36`,3.4`,0.94018`,1.1666`},0.4150253001322075`},{{0.36`,3.4`,0.94018`,1.1711`},0.4150253001322075`},{{0.36`,3.4`,0.94018`,1.1621000000000001`},0.4150253001322075`},{{0.36`,3.4`,0.94368`,1.1666`},0.4165233389478312`},{{0.36`,3.4`,0.94368`,1.1711`},0.4165233389478312`},{{0.36`,3.4`,0.94368`,1.1621000000000001`},0.4165233389478312`},{{0.36`,3.4`,0.93668`,1.1666`},0.4135476700258033`},{{0.36`,3.4`,0.93668`,1.1711`},0.4135476700258033`},{{0.36`,3.4`,0.93668`,1.1621000000000001`},0.4135476700258033`},{{0.36`,3.8`,0.94018`,1.1666`},0.4175821864097483`},{{0.36`,3.8`,0.94018`,1.1711`},0.4175821864097483`},{{0.36`,3.8`,0.94018`,1.1621000000000001`},0.4175821864097483`},{{0.36`,3.8`,0.94368`,1.1666`},0.4191828725121163`},{{0.36`,3.8`,0.94368`,1.1711`},0.4191828725121163`},{{0.36`,3.8`,0.94368`,1.1621000000000001`},0.4191828725121163`},{{0.36`,3.8`,0.93668`,1.1666`},0.41600340818472475`},{{0.36`,3.8`,0.93668`,1.1711`},0.41600340818472475`},{{0.36`,3.8`,0.93668`,1.1621000000000001`},0.41600340818472475`},{{0.36`,4.2`,0.94018`,1.1666`},0.4196966357940909`},{{0.36`,4.2`,0.94018`,1.1711`},0.4196966357940909`},{{0.36`,4.2`,0.94018`,1.1621000000000001`},0.4196966357940909`},{{0.36`,4.2`,0.94368`,1.1666`},0.4213908003889061`},{{0.36`,4.2`,0.94368`,1.1711`},0.4213908003889061`},{{0.36`,4.2`,0.94368`,1.1621000000000001`},0.4213908003889061`},{{0.36`,4.2`,0.93668`,1.1666`},0.41802575751638654`},{{0.36`,4.2`,0.93668`,1.1711`},0.41802575751638654`},{{0.36`,4.2`,0.93668`,1.1621000000000001`},0.41802575751638654`},{{0.36`,4.6`,0.94018`,1.1666`},0.4214308360099733`},{{0.36`,4.6`,0.94018`,1.1711`},0.4214308360099733`},{{0.36`,4.6`,0.94018`,1.1621000000000001`},0.4214308360099733`},{{0.36`,4.6`,0.94368`,1.1666`},0.4232103983917911`},{{0.36`,4.6`,0.94368`,1.1711`},0.4232103983917911`},{{0.36`,4.6`,0.94368`,1.1621000000000001`},0.4232103983917911`},{{0.36`,4.6`,0.93668`,1.1666`},0.4196758304547011`},{{0.36`,4.6`,0.93668`,1.1711`},0.4196758304547011`},{{0.36`,4.6`,0.93668`,1.1621000000000001`},0.4196758304547011`},{{0.36`,5.`,0.94018`,1.1666`},0.4228369749676453`},{{0.36`,5.`,0.94018`,1.1711`},0.4228369749676453`},{{0.36`,5.`,0.94018`,1.1621000000000001`},0.4228369749676453`},{{0.36`,5.`,0.94368`,1.1666`},0.42469477761460744`},{{0.36`,5.`,0.94368`,1.1711`},0.42469477761460744`},{{0.36`,5.`,0.94368`,1.1621000000000001`},0.42469477761460744`},{{0.36`,5.`,0.93668`,1.1666`},0.4210049030976244`},{{0.36`,5.`,0.93668`,1.1711`},0.4210049030976244`},{{0.36`,5.`,0.93668`,1.1621000000000001`},0.4210049030976244`},{{0.36`,5.4`,0.94018`,1.1666`},0.4239588746775349`},{{0.36`,5.4`,0.94018`,1.1711`},0.4239588746775349`},{{0.36`,5.4`,0.94018`,1.1621000000000001`},0.4239588746775349`},{{0.36`,5.4`,0.94368`,1.1666`},0.42588856964511035`},{{0.36`,5.4`,0.94368`,1.1711`},0.42588856964511035`},{{0.36`,5.4`,0.94368`,1.1621000000000001`},0.42588856964511035`},{{0.36`,5.4`,0.93668`,1.1666`},0.4220559982747506`},{{0.36`,5.4`,0.93668`,1.1711`},0.4220559982747506`},{{0.36`,5.4`,0.93668`,1.1621000000000001`},0.4220559982747506`},{{0.36`,5.8`,0.94018`,1.1666`},0.42483445356296695`},{{0.36`,5.8`,0.94018`,1.1711`},0.42483445356296695`},{{0.36`,5.8`,0.94018`,1.1621000000000001`},0.42483445356296695`},{{0.36`,5.8`,0.94368`,1.1666`},0.4268303908647716`},{{0.36`,5.8`,0.94368`,1.1711`},0.4268303908647716`},{{0.36`,5.8`,0.94368`,1.1621000000000001`},0.4268303908647716`},{{0.36`,5.8`,0.93668`,1.1666`},0.4228663439679941`},{{0.36`,5.8`,0.93668`,1.1711`},0.4228663439679941`},{{0.36`,5.8`,0.93668`,1.1621000000000001`},0.4228663439679941`},{{0.36`,6.2`,0.94018`,1.1666`},0.42549619613511075`},{{0.36`,6.2`,0.94018`,1.1711`},0.42549619613511075`},{{0.36`,6.2`,0.94018`,1.1621000000000001`},0.42549619613511075`},{{0.36`,6.2`,0.94368`,1.1666`},0.4275533326614904`},{{0.36`,6.2`,0.94368`,1.1711`},0.4275533326614904`},{{0.36`,6.2`,0.94368`,1.1621000000000001`},0.4275533326614904`},{{0.36`,6.2`,0.93668`,1.1666`},0.42346782670511285`},{{0.36`,6.2`,0.93668`,1.1711`},0.42346782670511285`},{{0.36`,6.2`,0.93668`,1.1621000000000001`},0.42346782670511285`},{{0.36`,6.8`,0.94018`,1.1666`},0.4261476123892407`},{{0.36`,6.8`,0.94018`,1.1711`},0.4261476123892407`},{{0.36`,6.8`,0.94018`,1.1621000000000001`},0.4261476123892407`},{{0.36`,6.8`,0.94368`,1.1666`},0.4282882301986583`},{{0.36`,6.8`,0.94368`,1.1711`},0.4282882301986583`},{{0.36`,6.8`,0.94368`,1.1621000000000001`},0.4282882301986583`},{{0.36`,6.8`,0.93668`,1.1666`},0.4240370538637583`},{{0.36`,6.8`,0.93668`,1.1711`},0.4240370538637583`},{{0.36`,6.8`,0.93668`,1.1621000000000001`},0.4240370538637583`},{{0.36`,7.4`,0.94018`,1.1666`},0.4264579689868483`},{{0.36`,7.4`,0.94018`,1.1711`},0.4264579689868483`},{{0.36`,7.4`,0.94018`,1.1621000000000001`},0.4264579689868483`},{{0.36`,7.4`,0.94368`,1.1666`},0.4286734148596132`},{{0.36`,7.4`,0.94368`,1.1711`},0.4286734148596132`},{{0.36`,7.4`,0.94368`,1.1621000000000001`},0.4286734148596132`},{{0.36`,7.4`,0.93668`,1.1666`},0.42427375157259417`},{{0.36`,7.4`,0.93668`,1.1711`},0.42427375157259417`},{{0.36`,7.4`,0.93668`,1.1621000000000001`},0.42427375157259417`},{{0.36`,8.`,0.94018`,1.1666`},0.42649056309615635`},{{0.36`,8.`,0.94018`,1.1711`},0.42649056309615635`},{{0.36`,8.`,0.94018`,1.1621000000000001`},0.42649056309615635`},{{0.36`,8.`,0.94368`,1.1666`},0.42877343340216556`},{{0.36`,8.`,0.94368`,1.1711`},0.42877343340216556`},{{0.36`,8.`,0.94368`,1.1621000000000001`},0.42877343340216556`},{{0.36`,8.`,0.93668`,1.1666`},0.4242399838275347`},{{0.36`,8.`,0.93668`,1.1711`},0.4242399838275347`},{{0.36`,8.`,0.93668`,1.1621000000000001`},0.4242399838275347`},{{0.36`,8.6`,0.94018`,1.1666`},0.4262970401526203`},{{0.36`,8.6`,0.94018`,1.1711`},0.4262970401526203`},{{0.36`,8.6`,0.94018`,1.1621000000000001`},0.4262970401526203`},{{0.36`,8.6`,0.94368`,1.1666`},0.42864096862521284`},{{0.36`,8.6`,0.94368`,1.1711`},0.42864096862521284`},{{0.36`,8.6`,0.94368`,1.1621000000000001`},0.42864096862521284`},{{0.36`,8.6`,0.93668`,1.1666`},0.423986372465184`},{{0.36`,8.6`,0.93668`,1.1711`},0.423986372465184`},{{0.36`,8.6`,0.93668`,1.1621000000000001`},0.423986372465184`},{{0.36`,9.2`,0.94018`,1.1666`},0.42591903761099575`},{{0.36`,9.2`,0.94018`,1.1711`},0.42591903761099575`},{{0.36`,9.2`,0.94018`,1.1621000000000001`},0.42591903761099575`},{{0.36`,9.2`,0.94368`,1.1666`},0.42831852246398594`},{{0.36`,9.2`,0.94368`,1.1711`},0.42831852246398594`},{{0.36`,9.2`,0.94368`,1.1621000000000001`},0.42831852246398594`},{{0.36`,9.2`,0.93668`,1.1666`},0.42355370212845306`},{{0.36`,9.2`,0.93668`,1.1711`},0.42355370212845306`},{{0.36`,9.2`,0.93668`,1.1621000000000001`},0.42355370212845306`},{{0.36`,9.8`,0.94018`,1.1666`},0.42539090037421323`},{{0.36`,9.8`,0.94018`,1.1711`},0.42539090037421323`},{{0.36`,9.8`,0.94018`,1.1621000000000001`},0.42539090037421323`},{{0.36`,9.8`,0.94368`,1.1666`},0.42784116410024586`},{{0.36`,9.8`,0.94368`,1.1711`},0.42784116410024586`},{{0.36`,9.8`,0.94368`,1.1621000000000001`},0.42784116410024586`},{{0.36`,9.8`,0.93668`,1.1666`},0.4229756032771533`},{{0.36`,9.8`,0.93668`,1.1711`},0.4229756032771533`},{{0.36`,9.8`,0.93668`,1.1621000000000001`},0.4229756032771533`},{{0.36`,10.4`,0.94018`,1.1666`},0.42474037566280903`},{{0.36`,10.4`,0.94018`,1.1711`},0.42474037566280903`},{{0.36`,10.4`,0.94018`,1.1621000000000001`},0.42474037566280903`},{{0.36`,10.4`,0.94368`,1.1666`},0.4272372488468246`},{{0.36`,10.4`,0.94368`,1.1711`},0.4272372488468246`},{{0.36`,10.4`,0.94368`,1.1621000000000001`},0.4272372488468246`},{{0.36`,10.4`,0.93668`,1.1666`},0.42227922351704`},{{0.36`,10.4`,0.93668`,1.1711`},0.42227922351704`},{{0.36`,10.4`,0.93668`,1.1621000000000001`},0.42227922351704`},{{0.36`,11.`,0.94018`,1.1666`},0.4239909741224427`},{{0.36`,11.`,0.94018`,1.1711`},0.4239909741224427`},{{0.36`,11.`,0.94018`,1.1621000000000001`},0.4239909741224427`},{{0.36`,11.`,0.94368`,1.1666`},0.4265308080915597`},{{0.36`,11.`,0.94368`,1.1711`},0.4265308080915597`},{{0.36`,11.`,0.94368`,1.1621000000000001`},0.4265308080915597`},{{0.36`,11.`,0.93668`,1.1666`},0.42148755985389885`},{{0.36`,11.`,0.93668`,1.1711`},0.42148755985389885`},{{0.36`,11.`,0.93668`,1.1621000000000001`},0.42148755985389885`},{{0.36`,11.6`,0.94018`,1.1666`},0.42316185890563207`},{{0.36`,11.6`,0.94018`,1.1711`},0.42316185890563207`},{{0.36`,11.6`,0.94018`,1.1621000000000001`},0.42316185890563207`},{{0.36`,11.6`,0.94368`,1.1666`},0.4257414427603593`},{{0.36`,11.6`,0.94368`,1.1711`},0.4257414427603593`},{{0.36`,11.6`,0.94368`,1.1621000000000001`},0.4257414427603593`},{{0.36`,11.6`,0.93668`,1.1666`},0.4206193435255973`},{{0.36`,11.6`,0.93668`,1.1711`},0.4206193435255973`},{{0.36`,11.6`,0.93668`,1.1621000000000001`},0.4206193435255973`},{{0.36`,12.2`,0.94018`,1.1666`},0.42226830028255397`},{{0.36`,12.2`,0.94018`,1.1711`},0.42226830028255397`},{{0.36`,12.2`,0.94018`,1.1621000000000001`},0.42226830028255397`},{{0.36`,12.2`,0.94368`,1.1666`},0.42488480000882856`},{{0.36`,12.2`,0.94368`,1.1711`},0.42488480000882856`},{{0.36`,12.2`,0.94368`,1.1621000000000001`},0.42488480000882856`},{{0.36`,12.2`,0.93668`,1.1666`},0.41968947435249393`},{{0.36`,12.2`,0.93668`,1.1711`},0.41968947435249393`},{{0.36`,12.2`,0.93668`,1.1621000000000001`},0.41968947435249393`},{{0.36`,12.8`,0.94018`,1.1666`},0.42132420527067077`},{{0.36`,12.8`,0.94018`,1.1711`},0.42132420527067077`},{{0.36`,12.8`,0.94018`,1.1621000000000001`},0.42132420527067077`},{{0.36`,12.8`,0.94368`,1.1666`},0.42397511245758884`},{{0.36`,12.8`,0.94368`,1.1711`},0.42397511245758884`},{{0.36`,12.8`,0.94368`,1.1621000000000001`},0.42397511245758884`},{{0.36`,12.8`,0.93668`,1.1666`},0.41871153718587983`},{{0.36`,12.8`,0.93668`,1.1711`},0.41871153718587983`},{{0.36`,12.8`,0.93668`,1.1621000000000001`},0.41871153718587983`},{{0.36`,13.4`,0.94018`,1.1666`},0.4203403389085503`},{{0.36`,13.4`,0.94018`,1.1711`},0.4203403389085503`},{{0.36`,13.4`,0.94018`,1.1621000000000001`},0.4203403389085503`},{{0.36`,13.4`,0.94368`,1.1666`},0.4230234190652216`},{{0.36`,13.4`,0.94368`,1.1711`},0.4230234190652216`},{{0.36`,13.4`,0.94368`,1.1621000000000001`},0.4230234190652216`},{{0.36`,13.4`,0.93668`,1.1666`},0.41769602757863`},{{0.36`,13.4`,0.93668`,1.1711`},0.41769602757863`},{{0.36`,13.4`,0.93668`,1.1621000000000001`},0.41769602757863`},{{0.36`,14.`,0.94018`,1.1666`},0.4193261882982057`},{{0.36`,14.`,0.94018`,1.1711`},0.4193261882982057`},{{0.36`,14.`,0.94018`,1.1621000000000001`},0.4193261882982057`},{{0.36`,14.`,0.94368`,1.1666`},0.42203945102681034`},{{0.36`,14.`,0.94368`,1.1711`},0.42203945102681034`},{{0.36`,14.`,0.94368`,1.1621000000000001`},0.42203945102681034`},{{0.36`,14.`,0.93668`,1.1666`},0.41665219193030034`},{{0.36`,14.`,0.93668`,1.1711`},0.41665219193030034`},{{0.36`,14.`,0.93668`,1.1621000000000001`},0.41665219193030034`},{{0.36`,14.6`,0.94018`,1.1666`},0.4182895463092975`},{{0.36`,14.6`,0.94018`,1.1711`},0.4182895463092975`},{{0.36`,14.6`,0.94018`,1.1621000000000001`},0.4182895463092975`},{{0.36`,14.6`,0.94368`,1.1666`},0.4210312085953381`},{{0.36`,14.6`,0.94368`,1.1711`},0.4210312085953381`},{{0.36`,14.6`,0.94368`,1.1621000000000001`},0.4210312085953381`},{{0.36`,14.6`,0.93668`,1.1666`},0.41558761876188094`},{{0.36`,14.6`,0.93668`,1.1711`},0.41558761876188094`},{{0.36`,14.6`,0.93668`,1.1621000000000001`},0.41558761876188094`},{{0.36`,15.2`,0.94018`,1.1666`},0.4172364433883753`},{{0.36`,15.2`,0.94018`,1.1711`},0.4172364433883753`},{{0.36`,15.2`,0.94018`,1.1621000000000001`},0.4172364433883753`},{{0.36`,15.2`,0.94368`,1.1666`},0.42000490116053085`},{{0.36`,15.2`,0.94368`,1.1711`},0.42000490116053085`},{{0.36`,15.2`,0.94368`,1.1621000000000001`},0.42000490116053085`},{{0.36`,15.2`,0.93668`,1.1666`},0.41450816240955257`},{{0.36`,15.2`,0.93668`,1.1711`},0.41450816240955257`},{{0.36`,15.2`,0.93668`,1.1621000000000001`},0.41450816240955257`},{{0.36`,15.8`,0.94018`,1.1666`},0.4161727194469623`},{{0.36`,15.8`,0.94018`,1.1711`},0.4161727194469623`},{{0.36`,15.8`,0.94018`,1.1621000000000001`},0.4161727194469623`},{{0.36`,15.8`,0.94368`,1.1666`},0.41896653243760135`},{{0.36`,15.8`,0.94368`,1.1711`},0.41896653243760135`},{{0.36`,15.8`,0.94368`,1.1621000000000001`},0.41896653243760135`},{{0.36`,15.8`,0.93668`,1.1666`},0.41341950117602794`},{{0.36`,15.8`,0.93668`,1.1711`},0.41341950117602794`},{{0.36`,15.8`,0.93668`,1.1621000000000001`},0.41341950117602794`},{{0.36`,16.4`,0.94018`,1.1666`},0.41510289426272934`},{{0.36`,16.4`,0.94018`,1.1711`},0.41510289426272934`},{{0.36`,16.4`,0.94018`,1.1621000000000001`},0.41510289426272934`},{{0.36`,16.4`,0.94368`,1.1666`},0.41792075947264345`},{{0.36`,16.4`,0.94368`,1.1711`},0.41792075947264345`},{{0.36`,16.4`,0.94368`,1.1621000000000001`},0.41792075947264345`},{{0.36`,16.4`,0.93668`,1.1666`},0.4123260196813214`},{{0.36`,16.4`,0.93668`,1.1711`},0.4123260196813214`},{{0.36`,16.4`,0.93668`,1.1621000000000001`},0.4123260196813214`},{{0.36`,17.`,0.94018`,1.1666`},0.41403060796679786`},{{0.36`,17.`,0.94018`,1.1711`},0.41403060796679786`},{{0.36`,17.`,0.94018`,1.1621000000000001`},0.41403060796679786`},{{0.36`,17.`,0.94368`,1.1666`},0.4168713424610457`},{{0.36`,17.`,0.94368`,1.1711`},0.4168713424610457`},{{0.36`,17.`,0.94368`,1.1621000000000001`},0.4168713424610457`},{{0.36`,17.`,0.93668`,1.1666`},0.41123123993391525`},{{0.36`,17.`,0.93668`,1.1711`},0.41123123993391525`},{{0.36`,17.`,0.93668`,1.1621000000000001`},0.41123123993391525`},{{0.36`,17.6`,0.94018`,1.1666`},0.41295907349666955`},{{0.36`,17.6`,0.94018`,1.1711`},0.41295907349666955`},{{0.36`,17.6`,0.94018`,1.1621000000000001`},0.41295907349666955`},{{0.36`,17.6`,0.94368`,1.1666`},0.41582160669851126`},{{0.36`,17.6`,0.94368`,1.1711`},0.41582160669851126`},{{0.36`,17.6`,0.94368`,1.1621000000000001`},0.41582160669851126`},{{0.36`,17.6`,0.93668`,1.1666`},0.41013826413240007`},{{0.36`,17.6`,0.93668`,1.1711`},0.41013826413240007`},{{0.36`,17.6`,0.93668`,1.1621000000000001`},0.41013826413240007`},{{0.36`,18.2`,0.94018`,1.1666`},0.41189173677845364`},{{0.36`,18.2`,0.94018`,1.1711`},0.41189173677845364`},{{0.36`,18.2`,0.94018`,1.1621000000000001`},0.41189173677845364`},{{0.36`,18.2`,0.94368`,1.1666`},0.4147750854330952`},{{0.36`,18.2`,0.94368`,1.1711`},0.4147750854330952`},{{0.36`,18.2`,0.94368`,1.1621000000000001`},0.4147750854330952`},{{0.36`,18.2`,0.93668`,1.1666`},0.4090504486600303`},{{0.36`,18.2`,0.93668`,1.1711`},0.4090504486600303`},{{0.36`,18.2`,0.93668`,1.1621000000000001`},0.4090504486600303`},{{0.36`,18.8`,0.94018`,1.1666`},0.4108296160652675`},{{0.36`,18.8`,0.94018`,1.1711`},0.4108296160652675`},{{0.36`,18.8`,0.94018`,1.1621000000000001`},0.4108296160652675`},{{0.36`,18.8`,0.94368`,1.1666`},0.4137328945322447`},{{0.36`,18.8`,0.94368`,1.1711`},0.4137328945322447`},{{0.36`,18.8`,0.94368`,1.1621000000000001`},0.4137328945322447`},{{0.36`,18.8`,0.93668`,1.1666`},0.4079687274789369`},{{0.36`,18.8`,0.93668`,1.1711`},0.4079687274789369`},{{0.36`,18.8`,0.93668`,1.1621000000000001`},0.4079687274789369`},{{0.36`,19.4`,0.94018`,1.1666`},0.40977480834900415`},{{0.36`,19.4`,0.94018`,1.1711`},0.40977480834900415`},{{0.36`,19.4`,0.94018`,1.1621000000000001`},0.40977480834900415`},{{0.36`,19.4`,0.94368`,1.1666`},0.41269719620653245`},{{0.36`,19.4`,0.94368`,1.1711`},0.41269719620653245`},{{0.36`,19.4`,0.94368`,1.1621000000000001`},0.41269719620653245`},{{0.36`,19.4`,0.93668`,1.1666`},0.40689511805117673`},{{0.36`,19.4`,0.93668`,1.1711`},0.40689511805117673`},{{0.36`,19.4`,0.93668`,1.1621000000000001`},0.40689511805117673`},{{0.36`,20.`,0.94018`,1.1666`},0.40872910937857754`},{{0.36`,20.`,0.94018`,1.1711`},0.40872910937857754`},{{0.36`,20.`,0.94018`,1.1621000000000001`},0.40872910937857754`},{{0.36`,20.`,0.94368`,1.1666`},0.41166985819421037`},{{0.36`,20.`,0.94368`,1.1711`},0.41166985819421037`},{{0.36`,20.`,0.94368`,1.1621000000000001`},0.41166985819421037`},{{0.36`,20.`,0.93668`,1.1666`},0.4058313544224123`},{{0.36`,20.`,0.93668`,1.1711`},0.4058313544224123`},{{0.36`,20.`,0.93668`,1.1621000000000001`},0.4058313544224123`},{{0.36`,20.6`,0.94018`,1.1666`},0.40769374909773465`},{{0.36`,20.6`,0.94018`,1.1711`},0.40769374909773465`},{{0.36`,20.6`,0.94018`,1.1621000000000001`},0.40769374909773465`},{{0.36`,20.6`,0.94368`,1.1666`},0.41065216893624934`},{{0.36`,20.6`,0.94368`,1.1711`},0.41065216893624934`},{{0.36`,20.6`,0.94368`,1.1621000000000001`},0.41065216893624934`},{{0.36`,20.6`,0.93668`,1.1666`},0.40477860683332084`},{{0.36`,20.6`,0.93668`,1.1711`},0.40477860683332084`},{{0.36`,20.6`,0.93668`,1.1621000000000001`},0.40477860683332084`},{{0.36`,21.2`,0.94018`,1.1666`},0.4066695288130672`},{{0.36`,21.2`,0.94018`,1.1711`},0.4066695288130672`},{{0.36`,21.2`,0.94018`,1.1621000000000001`},0.4066695288130672`},{{0.36`,21.2`,0.94368`,1.1666`},0.4096449828159544`},{{0.36`,21.2`,0.94368`,1.1711`},0.4096449828159544`},{{0.36`,21.2`,0.94368`,1.1621000000000001`},0.4096449828159544`},{{0.36`,21.2`,0.93668`,1.1666`},0.4037376244649715`},{{0.36`,21.2`,0.93668`,1.1711`},0.4037376244649715`},{{0.36`,21.2`,0.93668`,1.1621000000000001`},0.4037376244649715`},{{0.36`,21.8`,0.94018`,1.1666`},0.4056575217629701`},{{0.36`,21.8`,0.94018`,1.1711`},0.4056575217629701`},{{0.36`,21.8`,0.94018`,1.1621000000000001`},0.4056575217629701`},{{0.36`,21.8`,0.94368`,1.1666`},0.40864942281173344`},{{0.36`,21.8`,0.94368`,1.1711`},0.40864942281173344`},{{0.36`,21.8`,0.94368`,1.1621000000000001`},0.40864942281173344`},{{0.36`,21.8`,0.93668`,1.1666`},0.40270943147203475`},{{0.36`,21.8`,0.93668`,1.1711`},0.40270943147203475`},{{0.36`,21.8`,0.93668`,1.1621000000000001`},0.40270943147203475`},{{0.36`,22.4`,0.94018`,1.1666`},0.40465834393713546`},{{0.36`,22.4`,0.94018`,1.1711`},0.40465834393713546`},{{0.36`,22.4`,0.94018`,1.1621000000000001`},0.40465834393713546`},{{0.36`,22.4`,0.94368`,1.1666`},0.40766614744131885`},{{0.36`,22.4`,0.94368`,1.1711`},0.40766614744131885`},{{0.36`,22.4`,0.94368`,1.1621000000000001`},0.40766614744131885`},{{0.36`,22.4`,0.93668`,1.1666`},0.401694602046674`},{{0.36`,22.4`,0.93668`,1.1711`},0.401694602046674`},{{0.36`,22.4`,0.93668`,1.1621000000000001`},0.401694602046674`},{{0.36`,23.`,0.94018`,1.1666`},0.4036725374197947`},{{0.36`,23.`,0.94018`,1.1711`},0.4036725374197947`},{{0.36`,23.`,0.94018`,1.1621000000000001`},0.4036725374197947`},{{0.36`,23.`,0.94368`,1.1666`},0.40669573774191853`},{{0.36`,23.`,0.94368`,1.1711`},0.40669573774191853`},{{0.36`,23.`,0.94368`,1.1621000000000001`},0.40669573774191853`},{{0.36`,23.`,0.93668`,1.1666`},0.40069363994879964`},{{0.36`,23.`,0.93668`,1.1711`},0.40069363994879964`},{{0.36`,23.`,0.93668`,1.1621000000000001`},0.40069363994879964`},{{0.36`,23.6`,0.94018`,1.1666`},0.4027005283757831`},{{0.36`,23.6`,0.94018`,1.1711`},0.4027005283757831`},{{0.36`,23.6`,0.94018`,1.1621000000000001`},0.4027005283757831`},{{0.36`,23.6`,0.94368`,1.1666`},0.4057386549882028`},{{0.36`,23.6`,0.94368`,1.1711`},0.4057386549882028`},{{0.36`,23.6`,0.94368`,1.1621000000000001`},0.4057386549882028`},{{0.36`,23.6`,0.93668`,1.1666`},0.3997069368025756`},{{0.36`,23.6`,0.93668`,1.1711`},0.3997069368025756`},{{0.36`,23.6`,0.93668`,1.1621000000000001`},0.3997069368025756`},{{0.36`,24.2`,0.94018`,1.1666`},0.40174215805080915`},{{0.36`,24.2`,0.94018`,1.1711`},0.40174215805080915`},{{0.36`,24.2`,0.94018`,1.1621000000000001`},0.40174215805080915`},{{0.36`,24.2`,0.94368`,1.1666`},0.4047947714852459`},{{0.36`,24.2`,0.94368`,1.1711`},0.4047947714852459`},{{0.36`,24.2`,0.94368`,1.1621000000000001`},0.4047947714852459`},{{0.36`,24.2`,0.93668`,1.1666`},0.39873430361020273`},{{0.36`,24.2`,0.93668`,1.1711`},0.39873430361020273`},{{0.36`,24.2`,0.93668`,1.1621000000000001`},0.39873430361020273`},{{0.36`,24.8`,0.94018`,1.1666`},0.4007981670566931`},{{0.36`,24.8`,0.94018`,1.1711`},0.4007981670566931`},{{0.36`,24.8`,0.94018`,1.1621000000000001`},0.4007981670566931`},{{0.36`,24.8`,0.94368`,1.1666`},0.403864859449785`},{{0.36`,24.8`,0.94368`,1.1711`},0.403864859449785`},{{0.36`,24.8`,0.94368`,1.1621000000000001`},0.403864859449785`},{{0.36`,24.8`,0.93668`,1.1666`},0.39777644952924673`},{{0.36`,24.8`,0.93668`,1.1711`},0.39777644952924673`},{{0.36`,24.8`,0.93668`,1.1621000000000001`},0.39777644952924673`},{{0.36`,25.4`,0.94018`,1.1666`},0.3998685392347322`},{{0.36`,25.4`,0.94018`,1.1711`},0.3998685392347322`},{{0.36`,25.4`,0.94018`,1.1621000000000001`},0.3998685392347322`},{{0.36`,25.4`,0.94368`,1.1666`},0.4029489278521709`},{{0.36`,25.4`,0.94368`,1.1711`},0.4029489278521709`},{{0.36`,25.4`,0.94368`,1.1621000000000001`},0.4029489278521709`},{{0.36`,25.4`,0.93668`,1.1666`},0.3968333341330965`},{{0.36`,25.4`,0.93668`,1.1711`},0.3968333341330965`},{{0.36`,25.4`,0.93668`,1.1621000000000001`},0.3968333341330965`},{{0.36`,26.`,0.94018`,1.1666`},0.3989533563135677`},{{0.36`,26.`,0.94018`,1.1711`},0.3989533563135677`},{{0.36`,26.`,0.94018`,1.1621000000000001`},0.3989533563135677`},{{0.36`,26.`,0.94368`,1.1666`},0.402047082435645`},{{0.36`,26.`,0.94368`,1.1711`},0.402047082435645`},{{0.36`,26.`,0.94368`,1.1621000000000001`},0.402047082435645`},{{0.36`,26.`,0.93668`,1.1666`},0.3959050157996609`},{{0.36`,26.`,0.93668`,1.1711`},0.3959050157996609`},{{0.36`,26.`,0.93668`,1.1621000000000001`},0.3959050157996609`},{{0.36`,26.6`,0.94018`,1.1666`},0.3980526280216605`},{{0.36`,26.6`,0.94018`,1.1711`},0.3980526280216605`},{{0.36`,26.6`,0.94018`,1.1621000000000001`},0.3980526280216605`},{{0.36`,26.6`,0.94368`,1.1666`},0.4011593516007694`},{{0.36`,26.6`,0.94368`,1.1711`},0.4011593516007694`},{{0.36`,26.6`,0.94368`,1.1621000000000001`},0.4011593516007694`},{{0.36`,26.6`,0.93668`,1.1666`},0.3949914816935508`},{{0.36`,26.6`,0.93668`,1.1711`},0.3949914816935508`},{{0.36`,26.6`,0.93668`,1.1621000000000001`},0.3949914816935508`},{{0.36`,27.2`,0.94018`,1.1666`},0.3971660311907409`},{{0.36`,27.2`,0.94018`,1.1711`},0.3971660311907409`},{{0.36`,27.2`,0.94018`,1.1621000000000001`},0.3971660311907409`},{{0.36`,27.2`,0.94368`,1.1666`},0.40028543919660936`},{{0.36`,27.2`,0.94368`,1.1711`},0.40028543919660936`},{{0.36`,27.2`,0.94368`,1.1621000000000001`},0.40028543919660936`},{{0.36`,27.2`,0.93668`,1.1666`},0.394092393045022`},{{0.36`,27.2`,0.93668`,1.1711`},0.394092393045022`},{{0.36`,27.2`,0.93668`,1.1621000000000001`},0.394092393045022`},{{0.36`,27.8`,0.94018`,1.1666`},0.3962938138799592`},{{0.36`,27.8`,0.94018`,1.1711`},0.3962938138799592`},{{0.36`,27.8`,0.94018`,1.1621000000000001`},0.3962938138799592`},{{0.36`,27.8`,0.94368`,1.1666`},0.3994256027424336`},{{0.36`,27.8`,0.94368`,1.1711`},0.3994256027424336`},{{0.36`,27.8`,0.94368`,1.1621000000000001`},0.3994256027424336`},{{0.36`,27.8`,0.93668`,1.1666`},0.3932079743126718`},{{0.36`,27.8`,0.93668`,1.1711`},0.3932079743126718`},{{0.36`,27.8`,0.93668`,1.1621000000000001`},0.3932079743126718`},{{0.36`,28.4`,0.94018`,1.1666`},0.395435820591208`},{{0.36`,28.4`,0.94018`,1.1711`},0.395435820591208`},{{0.36`,28.4`,0.94018`,1.1621000000000001`},0.395435820591208`},{{0.36`,28.4`,0.94368`,1.1666`},0.39857971158842204`},{{0.36`,28.4`,0.94368`,1.1711`},0.39857971158842204`},{{0.36`,28.4`,0.94368`,1.1621000000000001`},0.39857971158842204`},{{0.36`,28.4`,0.93668`,1.1666`},0.39233805494231433`},{{0.36`,28.4`,0.93668`,1.1711`},0.39233805494231433`},{{0.36`,28.4`,0.93668`,1.1621000000000001`},0.39233805494231433`},{{0.36`,29.`,0.94018`,1.1666`},0.39459193402338577`},{{0.36`,29.`,0.94018`,1.1711`},0.39459193402338577`},{{0.36`,29.`,0.94018`,1.1621000000000001`},0.39459193402338577`},{{0.36`,29.`,0.94368`,1.1666`},0.39774765971064396`},{{0.36`,29.`,0.94368`,1.1711`},0.39774765971064396`},{{0.36`,29.`,0.94368`,1.1621000000000001`},0.39774765971064396`},{{0.36`,29.`,0.93668`,1.1666`},0.3914825054109323`},{{0.36`,29.`,0.93668`,1.1711`},0.3914825054109323`},{{0.36`,29.`,0.93668`,1.1621000000000001`},0.3914825054109323`},{{0.36`,29.6`,0.94018`,1.1666`},0.39376191929455856`},{{0.36`,29.6`,0.94018`,1.1711`},0.39376191929455856`},{{0.36`,29.6`,0.94018`,1.1621000000000001`},0.39376191929455856`},{{0.36`,29.6`,0.94368`,1.1666`},0.396929226225791`},{{0.36`,29.6`,0.94368`,1.1711`},0.396929226225791`},{{0.36`,29.6`,0.94368`,1.1621000000000001`},0.396929226225791`},{{0.36`,29.6`,0.93668`,1.1666`},0.3906410741707304`},{{0.36`,29.6`,0.93668`,1.1711`},0.3906410741707304`},{{0.36`,29.6`,0.93668`,1.1621000000000001`},0.3906410741707304`},{{0.36`,30.2`,0.94018`,1.1666`},0.3929456354143213`},{{0.36`,30.2`,0.94018`,1.1711`},0.3929456354143213`},{{0.36`,30.2`,0.94018`,1.1621000000000001`},0.3929456354143213`},{{0.36`,30.2`,0.94368`,1.1666`},0.3961242848288354`},{{0.36`,30.2`,0.94368`,1.1711`},0.3961242848288354`},{{0.36`,30.2`,0.94368`,1.1621000000000001`},0.3961242848288354`},{{0.36`,30.2`,0.93668`,1.1666`},0.38981360847305596`},{{0.36`,30.2`,0.93668`,1.1711`},0.38981360847305596`},{{0.36`,30.2`,0.93668`,1.1621000000000001`},0.38981360847305596`},{{0.36`,30.8`,0.94018`,1.1666`},0.39214291826833547`},{{0.36`,30.8`,0.94018`,1.1711`},0.39214291826833547`},{{0.36`,30.8`,0.94018`,1.1621000000000001`},0.39214291826833547`},{{0.36`,30.8`,0.94368`,1.1666`},0.39533268249540643`},{{0.36`,30.8`,0.94368`,1.1711`},0.39533268249540643`},{{0.36`,30.8`,0.94368`,1.1621000000000001`},0.39533268249540643`},{{0.36`,30.8`,0.93668`,1.1666`},0.38899993240351766`},{{0.36`,30.8`,0.93668`,1.1711`},0.38899993240351766`},{{0.36`,30.8`,0.93668`,1.1621000000000001`},0.38899993240351766`},{{0.36`,31.4`,0.94018`,1.1666`},0.39135357358122735`},{{0.36`,31.4`,0.94018`,1.1711`},0.39135357358122735`},{{0.36`,31.4`,0.94018`,1.1621000000000001`},0.39135357358122735`},{{0.36`,31.4`,0.94368`,1.1666`},0.39455423604964635`},{{0.36`,31.4`,0.94368`,1.1711`},0.39455423604964635`},{{0.36`,31.4`,0.94368`,1.1621000000000001`},0.39455423604964635`},{{0.36`,31.4`,0.93668`,1.1666`},0.3881998408815884`},{{0.36`,31.4`,0.93668`,1.1711`},0.3881998408815884`},{{0.36`,31.4`,0.93668`,1.1621000000000001`},0.3881998408815884`},{{0.36`,32.`,0.94018`,1.1666`},0.39057740257025036`},{{0.36`,32.`,0.94018`,1.1711`},0.39057740257025036`},{{0.36`,32.`,0.94018`,1.1621000000000001`},0.39057740257025036`},{{0.36`,32.`,0.94368`,1.1666`},0.39378875125836993`},{{0.36`,32.`,0.94368`,1.1711`},0.39378875125836993`},{{0.36`,32.`,0.94368`,1.1621000000000001`},0.39378875125836993`},{{0.36`,32.`,0.93668`,1.1666`},0.38741312012557516`},{{0.36`,32.`,0.93668`,1.1711`},0.38741312012557516`},{{0.36`,32.`,0.93668`,1.1621000000000001`},0.38741312012557516`},{{0.36`,32.6`,0.94018`,1.1666`},0.38981411975724845`},{{0.36`,32.6`,0.94018`,1.1711`},0.38981411975724845`},{{0.36`,32.6`,0.94018`,1.1621000000000001`},0.38981411975724845`},{{0.36`,32.6`,0.94368`,1.1666`},0.3930359705610211`},{{0.36`,32.6`,0.94368`,1.1711`},0.3930359705610211`},{{0.36`,32.6`,0.94368`,1.1621000000000001`},0.3930359705610211`},{{0.36`,32.6`,0.93668`,1.1666`},0.38663949042204765`},{{0.36`,32.6`,0.93668`,1.1711`},0.38663949042204765`},{{0.36`,32.6`,0.93668`,1.1621000000000001`},0.38663949042204765`},{{0.36`,33.2`,0.94018`,1.1666`},0.3890635537985906`},{{0.36`,33.2`,0.94018`,1.1711`},0.3890635537985906`},{{0.36`,33.2`,0.94018`,1.1621000000000001`},0.3890635537985906`},{{0.36`,33.2`,0.94368`,1.1666`},0.3922957108293052`},{{0.36`,33.2`,0.94368`,1.1711`},0.3922957108293052`},{{0.36`,33.2`,0.94368`,1.1621000000000001`},0.3922957108293052`},{{0.36`,33.2`,0.93668`,1.1666`},0.3858787561332613`},{{0.36`,33.2`,0.93668`,1.1711`},0.3858787561332613`},{{0.36`,33.2`,0.93668`,1.1621000000000001`},0.3858787561332613`},{{0.36`,33.8`,0.94018`,1.1666`},0.3883254753973115`},{{0.36`,33.8`,0.94018`,1.1711`},0.3883254753973115`},{{0.36`,33.8`,0.94018`,1.1621000000000001`},0.3883254753973115`},{{0.36`,33.8`,0.94368`,1.1666`},0.39156775756609064`},{{0.36`,33.8`,0.94368`,1.1711`},0.39156775756609064`},{{0.36`,33.8`,0.94368`,1.1621000000000001`},0.39156775756609064`},{{0.36`,33.8`,0.93668`,1.1666`},0.3851306839967494`},{{0.36`,33.8`,0.93668`,1.1711`},0.3851306839967494`},{{0.36`,33.8`,0.93668`,1.1621000000000001`},0.3851306839967494`},{{0.36`,34.4`,0.94018`,1.1666`},0.3875996541692969`},{{0.36`,34.4`,0.94018`,1.1711`},0.3875996541692969`},{{0.36`,34.4`,0.94018`,1.1621000000000001`},0.3875996541692969`},{{0.36`,34.4`,0.94368`,1.1666`},0.3908518918372164`},{{0.36`,34.4`,0.94368`,1.1711`},0.3908518918372164`},{{0.36`,34.4`,0.94368`,1.1621000000000001`},0.3908518918372164`},{{0.36`,34.4`,0.93668`,1.1666`},0.38439503923133234`},{{0.36`,34.4`,0.93668`,1.1711`},0.38439503923133234`},{{0.36`,34.4`,0.93668`,1.1621000000000001`},0.38439503923133234`},{{0.36`,35.`,0.94018`,1.1666`},0.3868858110282275`},{{0.36`,35.`,0.94018`,1.1711`},0.3868858110282275`},{{0.36`,35.`,0.94018`,1.1621000000000001`},0.3868858110282275`},{{0.36`,35.`,0.94368`,1.1666`},0.39014783978592915`},{{0.36`,35.`,0.94368`,1.1711`},0.39014783978592915`},{{0.36`,35.`,0.94368`,1.1621000000000001`},0.39014783978592915`},{{0.36`,35.`,0.93668`,1.1666`},0.3836715362779778`},{{0.36`,35.`,0.93668`,1.1711`},0.3836715362779778`},{{0.36`,35.`,0.93668`,1.1621000000000001`},0.3836715362779778`},{{0.36`,35.6`,0.94018`,1.1666`},0.38618386497255003`},{{0.36`,35.6`,0.94018`,1.1711`},0.38618386497255003`},{{0.36`,35.6`,0.94018`,1.1621000000000001`},0.38618386497255003`},{{0.36`,35.6`,0.94368`,1.1666`},0.3894555241322569`},{{0.36`,35.6`,0.94368`,1.1711`},0.3894555241322569`},{{0.36`,35.6`,0.94368`,1.1621000000000001`},0.3894555241322569`},{{0.36`,35.6`,0.93668`,1.1666`},0.38296008200733145`},{{0.36`,35.6`,0.93668`,1.1711`},0.38296008200733145`},{{0.36`,35.6`,0.93668`,1.1621000000000001`},0.38296008200733145`},{{0.36`,36.2`,0.94018`,1.1666`},0.385493406113365`},{{0.36`,36.2`,0.94018`,1.1711`},0.385493406113365`},{{0.36`,36.2`,0.94018`,1.1621000000000001`},0.385493406113365`},{{0.36`,36.2`,0.94368`,1.1666`},0.3887745478820792`},{{0.36`,36.2`,0.94368`,1.1711`},0.3887745478820792`},{{0.36`,36.2`,0.94368`,1.1621000000000001`},0.3887745478820792`},{{0.36`,36.2`,0.93668`,1.1666`},0.3822602659253049`},{{0.36`,36.2`,0.93668`,1.1711`},0.3822602659253049`},{{0.36`,36.2`,0.93668`,1.1621000000000001`},0.3822602659253049`},{{0.36`,36.8`,0.94018`,1.1666`},0.3848142739692086`},{{0.36`,36.8`,0.94018`,1.1711`},0.3848142739692086`},{{0.36`,36.8`,0.94018`,1.1621000000000001`},0.3848142739692086`},{{0.36`,36.8`,0.94368`,1.1666`},0.3881047500094508`},{{0.36`,36.8`,0.94368`,1.1711`},0.3881047500094508`},{{0.36`,36.8`,0.94368`,1.1621000000000001`},0.3881047500094508`},{{0.36`,36.8`,0.93668`,1.1666`},0.3815719174770014`},{{0.36`,36.8`,0.93668`,1.1711`},0.3815719174770014`},{{0.36`,36.8`,0.93668`,1.1621000000000001`},0.3815719174770014`},{{0.36`,37.4`,0.94018`,1.1666`},0.38414623823882865`},{{0.36`,37.4`,0.94018`,1.1711`},0.38414623823882865`},{{0.36`,37.4`,0.94018`,1.1621000000000001`},0.38414623823882865`},{{0.36`,37.4`,0.94368`,1.1666`},0.387445906622706`},{{0.36`,37.4`,0.94368`,1.1711`},0.387445906622706`},{{0.36`,37.4`,0.94368`,1.1621000000000001`},0.387445906622706`},{{0.36`,37.4`,0.93668`,1.1666`},0.3808948044741118`},{{0.36`,37.4`,0.93668`,1.1711`},0.3808948044741118`},{{0.36`,37.4`,0.93668`,1.1621000000000001`},0.3808948044741118`},{{0.36`,38.`,0.94018`,1.1666`},0.38348907436191254`},{{0.36`,38.`,0.94018`,1.1711`},0.38348907436191254`},{{0.36`,38.`,0.94018`,1.1621000000000001`},0.38348907436191254`},{{0.36`,38.`,0.94368`,1.1666`},0.3867977974116894`},{{0.36`,38.`,0.94368`,1.1711`},0.3867977974116894`},{{0.36`,38.`,0.94368`,1.1621000000000001`},0.3867977974116894`},{{0.36`,38.`,0.93668`,1.1666`},0.38022869451476077`},{{0.36`,38.`,0.93668`,1.1711`},0.38022869451476077`},{{0.36`,38.`,0.93668`,1.1621000000000001`},0.38022869451476077`},{{0.36`,38.6`,0.94018`,1.1666`},0.38284255568717906`},{{0.36`,38.6`,0.94018`,1.1711`},0.38284255568717906`},{{0.36`,38.6`,0.94018`,1.1621000000000001`},0.38284255568717906`},{{0.36`,38.6`,0.94368`,1.1666`},0.38616020401237144`},{{0.36`,38.6`,0.94368`,1.1711`},0.38616020401237144`},{{0.36`,38.6`,0.94368`,1.1621000000000001`},0.38616020401237144`},{{0.36`,38.6`,0.93668`,1.1666`},0.37957335982306173`},{{0.36`,38.6`,0.93668`,1.1711`},0.37957335982306173`},{{0.36`,38.6`,0.93668`,1.1621000000000001`},0.37957335982306173`},{{0.36`,39.2`,0.94018`,1.1666`},0.3822064643247958`},{{0.36`,39.2`,0.94018`,1.1711`},0.3822064643247958`},{{0.36`,39.2`,0.94018`,1.1621000000000001`},0.3822064643247958`},{{0.36`,39.2`,0.94368`,1.1666`},0.3855329112617591`},{{0.36`,39.2`,0.94368`,1.1711`},0.3855329112617591`},{{0.36`,39.2`,0.94368`,1.1621000000000001`},0.3855329112617591`},{{0.36`,39.2`,0.93668`,1.1666`},0.37892857653914136`},{{0.36`,39.2`,0.93668`,1.1711`},0.37892857653914136`},{{0.36`,39.2`,0.93668`,1.1621000000000001`},0.37892857653914136`},{{0.36`,39.8`,0.94018`,1.1666`},0.38158071202612703`},{{0.36`,39.8`,0.94018`,1.1711`},0.38158071202612703`},{{0.36`,39.8`,0.94018`,1.1621000000000001`},0.38158071202612703`},{{0.36`,39.8`,0.94368`,1.1666`},0.38491583365117393`},{{0.36`,39.8`,0.94368`,1.1711`},0.38491583365117393`},{{0.36`,39.8`,0.94368`,1.1621000000000001`},0.38491583365117393`},{{0.36`,39.8`,0.93668`,1.1666`},0.37829425520854937`},{{0.36`,39.8`,0.93668`,1.1711`},0.37829425520854937`},{{0.36`,39.8`,0.93668`,1.1621000000000001`},0.37829425520854937`}};


(* ::Text:: *)
(*The table of in the cell above contains the solution of the renormalization group equations of the SM (allowing for different boundary conditions for the quartic coupling). The solution is interpolated to avoid slow numerical integrations.*)


\[Lambda]atMTint=Quiet@Interpolation[tableint];


(* ::Subsection::Closed:: *)
(*High - Scale*)


positiveQ[x_]:=If[Im[x]==0,x>0,False]
Options[MhpoleHSS]={hiOrd->{1,1,1,1},scheme->"DRbar"};
MhpoleHSS[mtilde_?positiveQ,mQ1_?positiveQ,mQ2_?positiveQ,mQ3_?positiveQ,mU1_?positiveQ,mU2_?positiveQ,mU3_?positiveQ,mD1_?positiveQ,mD2_?positiveQ,mD3_?positiveQ,mE1_?positiveQ,mE2_?positiveQ,mE3_?positiveQ,mL1_?positiveQ,mL2_?positiveQ,mL3_?positiveQ,mA_?positiveQ,Q\[Mu]_?NumericQ,M1_?NumericQ,M2_?NumericQ,M3_?NumericQ,tan\[Beta]_?NumericQ,Xt_?NumericQ,opts:OptionsPattern[]]:=Block[{tmax=Rationalize[Log[mtilde/MT],10^-5],\[Lambda]mtilde,\[Lambda]MT},
\[Lambda]mtilde=\[Lambda]HSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt,opts]/.{Subscript[g, 1]->Subscript[g, 1][tmax],Subscript[g, 2]->Subscript[g, 2][tmax],Subscript[g, 3]->Subscript[g, 3][tmax],Subscript[g, t]->Subscript[g, t][tmax],\[Lambda]->\[Lambda][tmax],Subscript[g, \[Tau]]->Subscript[g, \[Tau]][tmax],Subscript[g, b]->Subscript[g, b][tmax]};
\[Lambda]MT=(2\[Lambda][0]/.SMrun[{Subscript[g, 1],Subscript[g, 2],Subscript[g, 3],Subscript[g, t],\[Lambda],Subscript[g, \[Tau]],Subscript[g, b]},{Subscript[g, 1][0]==g1MT,Subscript[g, 2][0]==g2MT,Subscript[g, 3][0]==g3MT,Subscript[g, t][0]==If[OptionValue[hiOrd][[4]]==0,gtMT2l,gtMT3l],\[Lambda][tmax]==1/2 \[Lambda]mtilde,Subscript[g, b][0]==gbMT,Subscript[g, \[Tau]][0]==g\[Tau]MT},0,tmax,optsSMrun]);
Mhpole[\[Lambda]MT]
]


Options[MhpoleHSSfast]={hiOrd->{1,1,1,1},scheme->"DRbar"};
solSM2l=SMrun[{Subscript[g, 1],Subscript[g, 2],Subscript[g, 3],Subscript[g, t],\[Lambda],Subscript[g, \[Tau]],Subscript[g, b]},{Subscript[g, 1][0]==g1MT,Subscript[g, 2][0]==g2MT,Subscript[g, 3][0]==g3MT,Subscript[g, t][0]==gtMT2l,\[Lambda][0]==1/2 \[Lambda]MT,Subscript[g, b][0]==gbMT,Subscript[g, \[Tau]][0]==g\[Tau]MT},0,40,optsSMrun];
solSM3l=SMrun[{Subscript[g, 1],Subscript[g, 2],Subscript[g, 3],Subscript[g, t],\[Lambda],Subscript[g, \[Tau]],Subscript[g, b]},{Subscript[g, 1][0]==g1MT,Subscript[g, 2][0]==g2MT,Subscript[g, 3][0]==g3MT,Subscript[g, t][0]==gtMT3l,\[Lambda][0]==1/2 \[Lambda]MT,Subscript[g, b][0]==gbMT,Subscript[g, \[Tau]][0]==g\[Tau]MT},0,40,optsSMrun];
solutionSMRGEs=solSM3l/.{g1->"g1",g2->"g2",g3->"g3",gt->"gt",\[Lambda]->"\[Lambda]",g\[Tau]->"g\[Tau]",gb->"gb"};
(*This solution is an external variable for convenience.*)
MhpoleHSSfast[mtilde_?positiveQ,mQ1_?positiveQ,mQ2_?positiveQ,mQ3_?positiveQ,mU1_?positiveQ,mU2_?positiveQ,mU3_?positiveQ,mD1_?positiveQ,mD2_?positiveQ,mD3_?positiveQ,mE1_?positiveQ,mE2_?positiveQ,mE3_?positiveQ,mL1_?positiveQ,mL2_?positiveQ,mL3_?positiveQ,mA_?positiveQ,Q\[Mu]_?NumericQ,M1_?NumericQ,M2_?NumericQ,M3_?NumericQ,tan\[Beta]_?NumericQ,Xt_?NumericQ,opts:OptionsPattern[]]:=Block[{\[Lambda]mtilde,evaluate,tmtilde,\[Lambda]\[Lambda]},(tmtilde=Log[mtilde/MT];
evaluate={\[Lambda]\[Lambda]->\[Lambda][tmtilde],Subscript[g, t]->gt[tmtilde],Subscript[g, 3]->g3[tmtilde],Subscript[g, 2]->g2[tmtilde],Subscript[g, 1]->g1[tmtilde],Subscript[g, b]->gb[tmtilde],Subscript[g, \[Tau]]->g\[Tau][tmtilde]}/.If[OptionValue[hiOrd][[4]]==0,solSM2l,solSM3l];
\[Lambda]mtilde=(\[Lambda]HSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt,opts]/.evaluate/.{\[Lambda]\[Lambda]->\[Lambda]});
Mhpole[Quiet@\[Lambda]atMTint[\[Lambda]mtilde,tmtilde,If[OptionValue[hiOrd][[4]]==0,gtMT2l,gtMT3l],g3MT]])]


(* ::Subsection::Closed:: *)
(*Split*)


Module[{g1SM,g2SM,g3SM,gtSM,evaluateintmtilde,evaluateintmsplit,\[Lambda]Splitmtilde,gtSplitmsplit,g1utmtilde,g2utmtilde,g1dtmtilde,g2dtmtilde,\[Lambda]Splitsplit,tmtilde,tmsplit,solsplit,rules,\[Lambda]SMtmsplit,\[Lambda]SMMT},
rules={Subscript[g, 1]->g1,Subscript[g, 2]->g2,Subscript[g, 3]->g3,Subscript[g, t]->gt,Subscript[g, \[Tau]]->g\[Tau],Subscript[g, b]->gb,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u]->gtildeu,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u]->gtilde2u,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d]->gtilded,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d]->gtilde2d};
g1SM[Qtup_]:=g1[Qtup]/.solSM3l;
g2SM[Qtup_]:=g2[Qtup]/.solSM3l;
g3SM[Qtup_]:=g3[Qtup]/.solSM3l;
gtSM[Qtup_]:=gt[Qtup]/.solSM3l;
evaluateintmtilde=(#->#[tmtilde]&/@{\[Lambda],Subscript[g, t],Subscript[g, 3],Subscript[g, 2],Subscript[g, 1],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1u],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2u],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1d],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2d],Subscript[g, b],Subscript[g, \[Tau]]});
evaluateintmsplit=(#->#[tmsplit]&/@{\[Lambda],Subscript[g, t],Subscript[g, 3],Subscript[g, 2],Subscript[g, 1],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1u],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2u],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1d],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2d],Subscript[g, b],Subscript[g, \[Tau]]});
MhpoleSplit[mtilde_?positiveQ,msplit_?positiveQ,mQ1_?positiveQ,mQ2_?positiveQ,mQ3_?positiveQ,mU1_?positiveQ,mU2_?positiveQ,mU3_?positiveQ,mD1_?positiveQ,mD2_?positiveQ,mD3_?positiveQ,mE1_?positiveQ,mE2_?positiveQ,mE3_?positiveQ,mL1_?positiveQ,mL2_?positiveQ,mL3_?positiveQ,mA_?positiveQ,Q\[Mu]_?NumericQ,M1_?NumericQ,M2_?NumericQ,M3_?NumericQ,tan\[Beta]_?NumericQ,Xt_?NumericQ]:=(
(*Avoids instability of the solution for small running, when tmtilde and tmsplit are close.*)
tmtilde=Rationalize[Log[mtilde/MT],10^-5];
tmsplit=Rationalize[Log[msplit/MT],10^-5];
\[Lambda]Splitmtilde=\[Lambda]Splitscalars[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]/.evaluateintmtilde;
gtSplitmsplit=(gtSplitsplit[msplit,Q\[Mu],M1,M2,M3]/.evaluateintmsplit/.{Subscript[g, t]->gtSM});
g1utmtilde=g1umtilde[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]/.evaluateintmtilde;
g2utmtilde=g2umtilde[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]/.evaluateintmtilde;
g1dtmtilde=g1dmtilde[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]/.evaluateintmtilde;
g2dtmtilde=g2dmtilde[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]/.evaluateintmtilde;
solsplit=Splitrun[{\[Lambda],Subscript[g, 3],Subscript[g, 2],Subscript[g, 1],Subscript[g, t],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 u],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 u],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1 d],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2 d],Subscript[g, b],Subscript[g, \[Tau]]},{\[Lambda][tmtilde]==\[Lambda]Splitmtilde,Subscript[g, t][tmsplit]==gtSplitmsplit,Subscript[g, 3][tmsplit]==g3SM[tmsplit],Subscript[g, 2][tmsplit]==g2SM[tmsplit],Subscript[g, 1][tmsplit]==g1SM[tmsplit],Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1u][tmtilde]==g1utmtilde,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2u][tmtilde]==g2utmtilde,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 1d][tmtilde]==g1dtmtilde,Subscript[
\!\(\*OverscriptBox[\(g\), \(~\)]\), 2d][tmtilde]==g2dtmtilde,Subscript[g, b][tmsplit]==gbMT,Subscript[g, \[Tau]][tmsplit]==g\[Tau]MT},tmsplit,tmtilde,optsSplitrun];
\[Lambda]SMtmsplit=(\[Lambda]SMsplit[msplit,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]/.evaluateintmsplit/.rules)/.solsplit;
\[Lambda]SMMT=2\[Lambda][0]/.SMrun[{Subscript[g, 1],Subscript[g, 2],Subscript[g, 3],Subscript[g, t],\[Lambda],Subscript[g, \[Tau]],Subscript[g, b]},{Subscript[g, 1][0]==g1MT,Subscript[g, 2][0]==g2MT,Subscript[g, 3][0]==g3MT,Subscript[g, t][0]==gtMT3l,\[Lambda][tmsplit]==1/2 \[Lambda]SMtmsplit,Subscript[g, b][0]==gbMT,Subscript[g, \[Tau]][0]==g\[Tau]MT},0,tmsplit,optsSMrun];Mhpole[\[Lambda]SMMT]
)]


(* ::Subsection::Closed:: *)
(*MHiggs Function*)


(* ::Subsubsection::Closed:: *)
(*Tests*)


(*It returns a list to be used as the argument for function which computes the Higgs mass.*)
getList[x_]:=Block[{list},Switch[Length[x],2,With[{tan\[Beta]=x[[1]],m0=x[[2]]},list={tan\[Beta],m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0}],
3,With[{tan\[Beta]=x[[1]],m0=x[[2]],At=x[[3]]},list={tan\[Beta],m0,m0,m0,m0,At,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0}],
4,With[{tan\[Beta]=x[[1]],m0=x[[2]],At=x[[3]],m12=x[[4]]},list={tan\[Beta],m12,m12,m12,m12,At,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0}],
5,With[{tan\[Beta]=x[[1]],m0=x[[2]],At=x[[3]],m12=x[[4]],\[Mu]=x[[5]]},list={tan\[Beta],m12,m12,m12,\[Mu],At,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0}],
6,With[{tan\[Beta]=x[[1]],mQ3=x[[2]],mU3=x[[3]],At=x[[4]],m12=x[[5]],\[Mu]=x[[6]],m0=Sqrt[x[[2]]x[[3]]]},list={tan\[Beta],m12,m12,m12,\[Mu],At,mQ3,mU3,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0}],
8,With[{tan\[Beta]=x[[1]],mQ3=x[[2]],mU3=x[[3]],At=x[[4]],M1=x[[5]],M2=x[[6]],M3=x[[7]],\[Mu]=x[[8]],m0=Sqrt[x[[2]]x[[3]]]},list={tan\[Beta],M1,M2,M3,\[Mu],At,mQ3,mU3,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0,m0}],
22,list=x,
_,list=Table[0,{i,22}]
];
list
]


gtMSSM[Q_,tan\[Beta]_]:=((gt[Log[Q/MT]]/.solSM3l)/Sin[ArcTan[tan\[Beta]]])
gbMSSM[Q_,mQ3_,mU3_,mD3_,M3_,\[Mu]_,tan\[Beta]_,Xt_]:=Block[{gbDRbar,tRG,evaluate},
tRG=Log[Q/MT];
evaluate={Subscript[g, t]->gt[tRG],Subscript[g, 3]->g3[tRG],Subscript[g, b]->gb[tRG]}/.solSM3l;
gbDRbar=gbDR[mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]/.evaluate
]
testgbDR[Q_,mQ3_,mU3_,mD3_,M3_,\[Mu]_,tan\[Beta]_,Xt_]:=With[{gbDRbar=gbMSSM[Q,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]},
Which[4<Abs@gbDRbar<4\[Pi],Message[MHiggs::bottomYukawa],
Abs@gbDRbar>=4\[Pi],Message[MHiggs::bottomYukawa];True]]


gtauMSSM[Q_,mL3_,mE3_,M2_,M1_,\[Mu]_,tan\[Beta]_]:=Block[{gtauDRbar,tRG,evaluate},
tRG=Log[Q/MT];
evaluate={Subscript[g, 1]->g1[tRG],Subscript[g, 2]->g2[tRG],Subscript[g, \[Tau]]->g\[Tau][tRG]}/.solSM3l;
gtauDRbar=gtauDR[mL3,mE3,M2,M1,\[Mu],tan\[Beta]]/.evaluate
]
testgtauDR[Q_,mL3_,mE3_,M2_,M1_,\[Mu]_,tan\[Beta]_]:=
With[{gtauDRbar=gtauMSSM[Q,mL3,mE3,M2,M1,\[Mu],tan\[Beta]]},Which[4<Abs@gtauDRbar<4\[Pi],Message[MHiggs::tauYukawa],
Abs@gtauDRbar>=4\[Pi],Message[MHiggs::tauYukawa];True]]


(* ::Subsubsection::Closed:: *)
(*Function*)


numericListQ[list_]:=(If[Not@ListQ[list],Return[False]];And@@Table[If[NumericQ[element],True,False],{element,list}])
(*ensure a numeric list as a variable for MHiggs*)
cond[m_]:=(NumericQ[m]&&Im[m]==0&&Abs[m]>175);(*condition for the soft masses*)
Options[MHiggs]={hiOrd->{1,1,1,1},numerical->False,split->False,Rscale->0,RscaleSplit->0,scheme->"DRbar"};
MHiggs[shortList_?numericListQ,opts:OptionsPattern[]]:=Block[{tan\[Beta],M1,M2,M3,\[Mu],At,mQ3,mU3,mD3,mQ2,mU2,mD2,mQ1,mU1,mD1,mL3,mE3,mL2,mE2,mL1,mE1,mA,Xt,mtilde,msplit,mh},
{tan\[Beta],M1,M2,M3,\[Mu],At,mQ3,mU3,mD3,mQ2,mU2,mD2,mQ1,mU1,mD1,mL3,mE3,mL2,mE2,mL1,mE1,mA}=getList[shortList];
Xt=At-\[Mu] /tan\[Beta];msplit=If[OptionValue[RscaleSplit]<200,Max[\[Mu],M2],OptionValue[RscaleSplit]];mtilde=If[OptionValue[Rscale]<200,Sqrt[mQ3 mU3],OptionValue[Rscale]];
If[NumericQ[tan\[Beta]]&&tan\[Beta]>=1&&cond[M1]&&cond[M2]&&cond[M3]&&cond[\[Mu]]&&Im[At]==0&&NumericQ[At]&&cond[mQ3]&&cond[mU3]&&cond[mD3]&&cond[mQ2]&&cond[mU2]&&cond[mD2]&&cond[mQ1]&&cond[mU1]&&cond[mD1]&&cond[mL3]&&cond[mE3]&&cond[mL2]&&cond[mE2]&&cond[mL1]&&cond[mE1]&&cond[mA],1,Message[MHiggs::variables];Return[0]];
If[Not[1/10<=mtilde/Sqrt[mQ3 mU3]<=10]||0<OptionValue[Rscale]<200,Message[MHiggs::warning]];
If[testgbDR[mtilde,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt],Return[0]];
If[testgtauDR[mtilde,mL3,mE3,M2,M1,\[Mu],tan\[Beta]],Return[0]];
Which[
Not[OptionValue@split]&& Not[OptionValue@numerical],
mh=MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,FilterRules[{opts},{hiOrd,scheme}]],
Not[OptionValue@split]&&OptionValue@numerical,
mh=MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,FilterRules[{opts},{hiOrd,scheme}]],
OptionValue@split&&(msplit<mtilde),
mh=MhpoleSplit[mtilde,msplit,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt],
OptionValue@split&&(msplit>=mtilde),
(Message[MHiggs::warningsplit];
mh=MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,FilterRules[{opts},{hiOrd}]])
];
If[Im[mh]==0,mh,Message[MHiggs::negative](*;Print[mh]*);0]
]


(* ::Section::Closed:: *)
(*Theoretical uncertainties*)


(* ::Subsection::Closed:: *)
(*EFT: v^2/*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*StyleBox["SUSY",*)
(*FontSize->12], \(2\)]\)-suppressed corrections*)


MhpoleHSSmom[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Block[{\[Lambda]mtilde,evaluate,tmtilde,\[Lambda]\[Lambda]},(tmtilde=Log[mtilde/MT];
evaluate={\[Lambda]\[Lambda]->\[Lambda][tmtilde],Subscript[g, t]->gt[tmtilde],Subscript[g, 3]->g3[tmtilde],Subscript[g, 2]->g2[tmtilde],Subscript[g, 1]->g1[tmtilde],Subscript[g, b]->gb[tmtilde],Subscript[g, \[Tau]]->g\[Tau][tmtilde]}/.solSM3l/.{\[Lambda]\[Lambda]->\[Lambda]};
\[Lambda]mtilde=(\[Lambda]HSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,0},suppressedCorrections->True])/.evaluate);
\[Lambda]MT=(2\[Lambda][0]/.SMrun[{Subscript[g, 1],Subscript[g, 2],Subscript[g, 3],Subscript[g, t],\[Lambda],Subscript[g, \[Tau]],Subscript[g, b]},{Subscript[g, 1][0]==g1MT,Subscript[g, 2][0]==g2MT,Subscript[g, 3][0]==g3MT,Subscript[g, t][0]==gtMT3l,\[Lambda][tmax]==1/2 \[Lambda]mtilde,Subscript[g, b][0]==gbMT,Subscript[g, \[Tau]][0]==g\[Tau]MT},0,tmax,optsSMrun]);
Mhpole[\[Lambda]MT]
]


MhpoleHSSmomfast[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=Block[{\[Lambda]mtilde,evaluate,tmtilde,\[Lambda]\[Lambda]},(tmtilde=Log[mtilde/MT];
evaluate={\[Lambda]\[Lambda]->\[Lambda][tmtilde],Subscript[g, t]->gt[tmtilde],Subscript[g, 3]->g3[tmtilde],Subscript[g, 2]->g2[tmtilde],Subscript[g, 1]->g1[tmtilde],Subscript[g, b]->gb[tmtilde],Subscript[g, \[Tau]]->g\[Tau][tmtilde]}/.solSM3l/.{\[Lambda]\[Lambda]->\[Lambda]};
\[Lambda]mtilde=(\[Lambda]HSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,0},suppressedCorrections->True])/.evaluate);
Mhpole[Quiet@\[Lambda]atMTint[\[Lambda]mtilde,tmtilde,gtMT3l,g3MT]]]


\[CapitalDelta]MhpoleHSSmom[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_,opts:OptionsPattern[]]:=Abs[MhpoleHSSmom[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]-MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,0,1}]]


\[CapitalDelta]MhpoleHSSmomfast[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,Q\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_,opts:OptionsPattern[]]:=Abs[MhpoleHSSmomfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt]-MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,Q\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,0,1}]]


(* ::Subsection::Closed:: *)
(*SM higher order corrections*)


Options[\[CapitalDelta]MhpoleHSSSMfast]={scheme->"DRbar"};
\[CapitalDelta]MhpoleHSSSM[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_,opts:OptionsPattern[]]:=Abs[MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{1,0,0,1},opts]-MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{1,0,0,0},opts]]+0.15


Options[\[CapitalDelta]MhpoleHSSSMfast]={scheme->"DRbar"};
\[CapitalDelta]MhpoleHSSSMfast[mtilde_,mQ1_?NumericQ,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_,opts:OptionsPattern[]]:=Abs[MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{1,0,0,1},opts]-MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{1,0,0,0},opts]]+0.15


(* ::Subsection::Closed:: *)
(*SUSY: Variation of the renormalization scale*)


(* ::Subsubsection::Closed:: *)
(*Manipulation*)


(* ::Input:: *)
(*\[Beta]\[Beta][Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t]]:=1/(4\[Pi])^2 Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t](6Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t]^2-16/3 Subscript[g, 3]^2-3Subscript[g, 2]^2-13/15 Subscript[g, 1]^2)*)
(*\[Beta]\[Beta][\[Mu]]:=\[Mu]/(4\[Pi])^2 (3Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t]^2+3Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), b]^2+Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), \[Tau]]^2- 3Subscript[g, 2]^2- 3/5 Subscript[g, 1]^2)*)
(*\[Beta]\[Beta][Subscript[a, t]]:=1/(4\[Pi])^2 Subscript[a, t](18Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t]^2-16/3 Subscript[g, 3]^2-3Subscript[g, 2]^2-13/15 Subscript[g, 1]^2)+1/(4\[Pi])^2 Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t](32/3 Subscript[g, 3]^2 Subscript[M, 3]+6Subscript[g, 2]^2 Subscript[M, 2]+26/15 Subscript[g, 1]^2 Subscript[M, 1])*)
(*Subscript[XX, t]:=2 *)
(*\!\(\*SubsuperscriptBox[*)
(*OverscriptBox[\(g\), \(^\)], \(t\), \(2\)]\) (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(H\), \(u\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(u\), \(3\)], \(2\)]\))+2 Subscript[a, t]^2;*)
(*Subscript[XX, b]:=2 *)
(*\!\(\*SubsuperscriptBox[*)
(*OverscriptBox[\(g\), \(^\)], \(b\), \(2\)]\) (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(H\), \(u\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(u\), \(3\)], \(2\)]\))+2 Subscript[a, b]^2;*)
(*Subscript[XX, \[Tau]]:=2 *)
(*\!\(\*SubsuperscriptBox[*)
(*OverscriptBox[\(g\), \(^\)], \(\[Tau]\), \(2\)]\) (\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(H\), \(u\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(L\), \(3\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(e\), \(3\)], \(2\)]\))+2 Subscript[a, \[Tau]]^2;*)
(*Subscript[a, t]:=Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t] Subscript[A, t];Subscript[a, b]:=Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), b] Subscript[A, b];Subscript[a, \[Tau]]:=Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), \[Tau]] Subscript[A, \[Tau]];*)
(*S := \!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(H\), \(u\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(H\), \(d\)], \(2\)] + \( *)
(*\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \(3\)]\(( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(i\)], \(2\)] - *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(L\), \(i\)], \(2\)] - 2\ *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(u\), \(i\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(d\), \(i\)], \(2\)] + *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(e\), \(i\)], \(2\)])\)\)\);*)
(*\[Beta]\[Beta][*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(H\), \(u\)], \(2\)]\)]:=1/(16\[Pi]^2) (3 Subscript[XX, t]-6 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(2\), \(2\)]\)-6/5 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(1\), \(2\)]\)+ (3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) S)/5);\[Beta]\[Beta][*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(H\), \(d\)], \(2\)]\)]:=1/(16\[Pi]^2) (3 Subscript[XX, b]+Subscript[XX, \[Tau]]-6 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(2\), \(2\)]\)-6/5 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(1\), \(2\)]\)-(3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) S)/5);*)
(*\[Beta]\[Beta][*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)]\)]:=1/(16\[Pi]^2) (Subscript[XX, t]-32/3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-6 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(2\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(2\), \(2\)]\)-2/15 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(1\), \(2\)]\)+(\!\( *)
(*\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\ S\))/5);\[Beta]\[Beta][*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(u\), \(3\)], \(2\)]\)]:=1/(16\[Pi]^2) (2Subscript[XX, t]-32/3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-32/15 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(1\), \(2\)]\)-(4 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) S)/5);*)
(*\[Beta]\[Beta][*)
(*\!\(\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(d\), \(3\)], \(2\)]\)]:=1/(16\[Pi]^2) (2Subscript[XX, b]-32/3 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(3\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(3\), \(2\)]\)-8/15 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) *)
(*\!\(\*SubsuperscriptBox[\(M\), \(1\), \(2\)]\)+2/5 *)
(*\!\(\*SubsuperscriptBox[\(g\), \(1\), \(2\)]\) S);*)
(*\[Beta]\[Beta][Subscript[X, t]]:=\[Beta]\[Beta][Subscript[A, t]]-\[Beta]\[Beta][\[Mu]]/Tan[\[Beta]]+\[Mu]/(2Tan[\[Beta]]^3) \[Beta]\[Beta][tan\[Beta]^2]*)
(*\[Beta]\[Beta][Subscript[A, t]]:=Simplify[1/Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t] (\[Beta]\[Beta][Subscript[a, t]]-\[Beta]\[Beta][Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t]]Subscript[A, t])]*)
(*Subscript[\[Gamma], 2]:=1/(64\[Pi]^2) (9Subscript[g, 2]^2+3Subscript[g, 1]^2-12Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t]^2-6Subscript[g, 2]^2-2Subscript[g, 1]^2)*)
(*Subscript[\[Gamma], 1]:=1/(64\[Pi]^2) (9Subscript[g, 2]^2+3Subscript[g, 1]^2-6Subscript[g, 2]^2-2Subscript[g, 1]^2)*)
(*\[Beta]\[Beta][tan\[Beta]^2]:=2Tan[\[Beta]]^2 (Subscript[\[Gamma], 2]-Subscript[\[Gamma], 1])*)
(*replacements1:={d->D,e->E,u->U,Subscript[m, Subscript[H, u]]^2->mA^2 Cos[\[Beta]]^2-\[Mu]^2,Subscript[m, Subscript[H, d]]^2->mA^2 Sin[\[Beta]]^2-\[Mu]^2,Subscript[XX, \[Tau]]->0,Subscript[A, t]->Xt+\[Mu] Cot[\[Beta]],Subscript[A, b]->0,Subscript[A, \[Tau]]->0};*)
(*replacements2:={Subscript[m, Subscript[x_, y_]]^2:>Symbol["m"<>ToString[x]<>ToString[y]]^2,Subscript[M, x_]:>Symbol["M"<>ToString[x]],Subscript[X, t]->Xt,\[Beta]->ArcTan[tan\[Beta]],Subscript[g, 1]->g1SM[Log[mtilde/MT]],Subscript[g, 2]->g2SM[Log[mtilde/MT]],Subscript[g, 3]->g3SM[Log[mtilde/MT]],*)
(*Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), t]->gtMSSM[mtilde,tan\[Beta]],Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), b]->gbMSSM[mtilde,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt],Subscript[*)
(*\!\(\*OverscriptBox[\(g\), \(^\)]\), \[Tau]]->gtauMSSM[mtilde,mL3,mE3,M2,M1,\[Mu],tan\[Beta]]};*)


(* ::Input:: *)
(*{mQ3^2+\[Beta]\[Beta][Subscript[m, Subscript[Q, 3]]^2]Log[n],mU3^2+\[Beta]\[Beta][Subscript[m, Subscript[u, 3]]^2]Log[n],mD3^2+\[Beta]\[Beta][Subscript[m, Subscript[d, 3]]^2]Log[n],\[Mu]+\[Beta]\[Beta][\[Mu]]Log[n],Subscript[X, t]+\[Beta]\[Beta][Subscript[X, t]]Log[n]}/.replacements1/.replacements2*)


(* ::Input:: *)
(*(*OS scheme*)*)
(*\[Beta]\[Beta][XtOS]:=1/(4\[Pi])^2 Xt(8Subscript[g, 3]^2-3/2 Subscript[g, t]^2)*)
(*Xt+\[Beta]\[Beta][XtOS]Log[n]/.{Subscript[g, 3]->g3SM[Log[mtilde/MT]],Subscript[g, t]->gtSM[Log[mtilde/MT]]}*)


(* ::Subsubsection::Closed:: *)
(*Variation of the spectrum*)


(* ::Text:: *)
(*At the moment(\!\( *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(Q\), \(3\)], \(2\)], *)
(*\*SubsuperscriptBox[\(m\), *)
(*SubscriptBox[\(U\), \(3\)], \(2\)], *)
(*\*SuperscriptBox[*)
(*SubscriptBox[\(m\), *)
(*SubscriptBox[\(D\), \(3\)]], \(2\)], \[Mu], *)
(*\*SubscriptBox[\(X\), \(t\)]\))are varied.*)


Module[{g1SM,g2SM,g3SM,gtSM},
g1SM[Qtup_]:=g1[Qtup]/.solSM3l;
g2SM[Qtup_]:=g2[Qtup]/.solSM3l;
g3SM[Qtup_]:=g3[Qtup]/.solSM3l;
gtSM[Qtup_]:=gt[Qtup]/.solSM3l;
spectrum[n_,mtilde_,mQ1_,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:={mQ3^2+1/(16 \[Pi]^2) (-(2/15) M1^2 g1SM[Log[mtilde/MT]]^2+1/5 (mD1^2+mD2^2+mD3^2+mE1^2+mE2^2+mE3^2-mL1^2-mL2^2-mL3^2+mQ1^2+mQ2^2+mQ3^2-2 mU1^2-2 mU2^2-2 mU3^2+mA^2/(1+tan\[Beta]^2)-(mA^2 tan\[Beta]^2)/(1+tan\[Beta]^2)) g1SM[Log[mtilde/MT]]^2-6 M2^2 g2SM[Log[mtilde/MT]]^2-32/3 M3^2 g3SM[Log[mtilde/MT]]^2+2 (Xt+\[Mu]/tan\[Beta])^2 gtMSSM[mtilde,tan\[Beta]]^2+2 (mQ3^2+mU3^2+mA^2/(1+tan\[Beta]^2)-\[Mu]^2) gtMSSM[mtilde,tan\[Beta]]^2) Log[n],mU3^2+1/(16 \[Pi]^2) (-(32/15) M1^2 g1SM[Log[mtilde/MT]]^2-4/5 (mD1^2+mD2^2+mD3^2+mE1^2+mE2^2+mE3^2-mL1^2-mL2^2-mL3^2+mQ1^2+mQ2^2+mQ3^2-2 mU1^2-2 mU2^2-2 mU3^2+mA^2/(1+tan\[Beta]^2)-(mA^2 tan\[Beta]^2)/(1+tan\[Beta]^2)) g1SM[Log[mtilde/MT]]^2-32/3 M3^2 g3SM[Log[mtilde/MT]]^2+2 (2 (Xt+\[Mu]/tan\[Beta])^2 gtMSSM[mtilde,tan\[Beta]]^2+2 (mQ3^2+mU3^2+mA^2/(1+tan\[Beta]^2)-\[Mu]^2) gtMSSM[mtilde,tan\[Beta]]^2)) Log[n],mD3^2+1/(16 \[Pi]^2) (-(8/15) M1^2 g1SM[Log[mtilde/MT]]^2+2/5 (mD1^2+mD2^2+mD3^2+mE1^2+mE2^2+mE3^2-mL1^2-mL2^2-mL3^2+mQ1^2+mQ2^2+mQ3^2-2 mU1^2-2 mU2^2-2 mU3^2+mA^2/(1+tan\[Beta]^2)-(mA^2 tan\[Beta]^2)/(1+tan\[Beta]^2)) g1SM[Log[mtilde/MT]]^2-32/3 M3^2 g3SM[Log[mtilde/MT]]^2+4 (mQ3^2+mU3^2+mA^2/(1+tan\[Beta]^2)-\[Mu]^2) gbMSSM[mtilde,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]^2) Log[n],\[Mu]+1/(16 \[Pi]^2) \[Mu] (-(3/5) g1SM[Log[mtilde/MT]]^2-3 g2SM[Log[mtilde/MT]]^2+3 gbMSSM[mtilde,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]^2+gtauMSSM[mtilde,mL3,mE3,M2,M1,\[Mu],tan\[Beta]]^2+3 gtMSSM[mtilde,tan\[Beta]]^2) Log[n],Xt+(-(1/(16 \[Pi]^2 tan\[Beta]))\[Mu] (-(3/5) g1SM[Log[mtilde/MT]]^2-3 g2SM[Log[mtilde/MT]]^2+3 gbMSSM[mtilde,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]^2+gtauMSSM[mtilde,mL3,mE3,M2,M1,\[Mu],tan\[Beta]]^2+3 gtMSSM[mtilde,tan\[Beta]]^2)+1/(120 \[Pi]^2) (13 M1 g1SM[Log[mtilde/MT]]^2+45 M2 g2SM[Log[mtilde/MT]]^2+80 M3 g3SM[Log[mtilde/MT]]^2+90 (Xt+\[Mu]/tan\[Beta]) gtMSSM[mtilde,tan\[Beta]]^2)+1/tan\[Beta] \[Mu] (-((g1SM[Log[mtilde/MT]]^2+3 g2SM[Log[mtilde/MT]]^2)/(64 \[Pi]^2))+(g1SM[Log[mtilde/MT]]^2+3 g2SM[Log[mtilde/MT]]^2-12 gtMSSM[mtilde,tan\[Beta]]^2)/(64 \[Pi]^2))) Log[n]};
XtOS[n_,mtilde_,Xt_]:=Xt+(Xt (8 g3SM[Log[mtilde/MT]]^2-3/2 gtSM[Log[mtilde/MT]]^2) Log[n])/(16 \[Pi]^2)]


(* ::Subsubsection::Closed:: *)
(*Calculation*)


Options[\[CapitalDelta]MhpoleHSSQ]={hiOrd->{1,1,1,1},scheme->"DR"};
\[CapitalDelta]MhpoleHSSQ[n_?positiveQ,mtilde_,mQ1_,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_,opts:OptionsPattern[]]:=If[OptionValue[scheme]=="OS",MhpoleHSS[n mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],XtOS[n,mtilde,Xt],opts]-MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,opts],
Block[{mQ32new,mU32new,mD32new,\[Mu]new,Xtnew},
{mQ32new,mU32new,mD32new,\[Mu]new,Xtnew}=spectrum[n,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt];
If[Not[mQ32new>0&&mU32new>0&&mD32new>0],Message[\[CapitalDelta]MHiggs::tachyon];Return[125]];
MhpoleHSS[n mtilde,mQ1,mQ2,Sqrt[mQ32new],mU1,mU2,Sqrt[mU32new],mD1,mD2,Sqrt[mD32new],mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu]new,M1,M2,M3,tan\[Beta],Xtnew,opts]-MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,opts]]]


Options[\[CapitalDelta]MhpoleHSSQfast]={hiOrd->{1,1,1,1},scheme->"DR"};
\[CapitalDelta]MhpoleHSSQfast[n_?positiveQ,mtilde_,mQ1_,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_,opts:OptionsPattern[]]:=If[OptionValue[scheme]=="OS",MhpoleHSSfast[n mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],XtOS[n,mtilde,Xt],opts]-MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,opts],
Block[{mQ32new,mU32new,mD32new,\[Mu]new,Xtnew},
{mQ32new,mU32new,mD32new,\[Mu]new,Xtnew}=spectrum[n,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt];
(*Print["spectrum","  ",n,"  ",Sqrt[mQ32new],"  ",Sqrt[mU32new],"  ",Sqrt[mD32new],"  ",\[Mu]new,"  ",Xtnew];*)
If[Not[mQ32new>0&&mU32new>0&&mD32new>0],Message[\[CapitalDelta]MHiggs::tachyon];Return[125]];
MhpoleHSSfast[n mtilde,mQ1,mQ2,Sqrt[mQ32new],mU1,mU2,Sqrt[mU32new],mD1,mD2,Sqrt[mD32new],mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu]new,M1,M2,M3,tan\[Beta],Xtnew,opts]-MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,opts]]]


(* ::Subsection::Closed:: *)
(*Sbottom contribution *)


\[CapitalDelta]MhpoleHSSbottom[mtilde_?positiveQ,mQ1_,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=If[tan\[Beta]<30,0,Abs[MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,1,1}]-MhpoleHSS[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,0,1}]]]


\[CapitalDelta]MhpoleHSSbottomfast[mtilde_?positiveQ,mQ1_,mQ2_,mQ3_,mU1_,mU2_,mU3_,mD1_,mD2_,mD3_,mE1_,mE2_,mE3_,mL1_,mL2_,mL3_,mA_,\[Mu]_,M1_,M2_,M3_,tan\[Beta]_,Xt_]:=If[tan\[Beta]<30,0,Abs[MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,1,1}]-MhpoleHSSfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{0,0,0,1}]]]


(* ::Subsection::Closed:: *)
(*Total*)


Options[MhpoleHSSUnc]={hiOrd->{1,1,1,1},sources->{1,1,1},scheme->"DRbar"};
MhpoleHSSUnc[mtilde_?positiveQ,mQ1_?positiveQ,mQ2_?positiveQ,mQ3_?positiveQ,mU1_?positiveQ,mU2_?positiveQ,mU3_?positiveQ,mD1_?positiveQ,mD2_?positiveQ,mD3_?positiveQ,mE1_?positiveQ,mE2_?positiveQ,mE3_?positiveQ,mL1_?positiveQ,mL2_?positiveQ,mL3_?positiveQ,mA_?positiveQ,\[Mu]_?NumericQ,M1_?NumericQ,M2_?NumericQ,M3_?NumericQ,tan\[Beta]_?NumericQ,Xt_?NumericQ,opts:OptionsPattern[]]:=
If[OptionValue[sources][[1]]==1,\[CapitalDelta]MhpoleHSSSM[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,FilterRules[{opts},{scheme}]],0]+If[OptionValue[sources][[2]]==1,(Max[Abs@\[CapitalDelta]MhpoleHSSQ[2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],1,1,1}],Abs@\[CapitalDelta]MhpoleHSSQ[1/2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],1,1,1}],If[OptionValue[hiOrd][[2]]==0,Max[Abs@\[CapitalDelta]MhpoleHSSQ[2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],0,1,1}],Abs@\[CapitalDelta]MhpoleHSSQ[1/2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],0,1,1}]],0]   ]
+If[OptionValue[hiOrd][[3]]==0,\[CapitalDelta]MhpoleHSSbottom[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt],0]),0]+If[OptionValue[sources][[3]]==1,\[CapitalDelta]MhpoleHSSmom[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt],0]


Options[MhpoleHSSUncfast]={hiOrd->{1,1,1,1},sources->{1,1,1},scheme->"DRbar"};
MhpoleHSSUncfast[mtilde_?positiveQ,mQ1_?positiveQ,mQ2_?positiveQ,mQ3_?positiveQ,mU1_?positiveQ,mU2_?positiveQ,mU3_?positiveQ,mD1_?positiveQ,mD2_?positiveQ,mD3_?positiveQ,mE1_?positiveQ,mE2_?positiveQ,mE3_?positiveQ,mL1_?positiveQ,mL2_?positiveQ,mL3_?positiveQ,mA_?positiveQ,\[Mu]_?NumericQ,M1_?NumericQ,M2_?NumericQ,M3_?NumericQ,tan\[Beta]_?NumericQ,Xt_?NumericQ,opts:OptionsPattern[]]:=
If[OptionValue[sources][[1]]==1,\[CapitalDelta]MhpoleHSSSMfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,FilterRules[{opts},{scheme}]],0]+If[OptionValue[sources][[2]]==1,(Max[Abs@\[CapitalDelta]MhpoleHSSQfast[2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],1,1,1},FilterRules[{opts},{scheme}]],Abs@\[CapitalDelta]MhpoleHSSQfast[1/2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],1,1,1},FilterRules[{opts},{scheme}]],If[OptionValue[hiOrd][[2]]==0,Max[Abs@\[CapitalDelta]MhpoleHSSQfast[2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],0,1,1},FilterRules[{opts},{scheme}]],Abs@\[CapitalDelta]MhpoleHSSQfast[1/2,mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,hiOrd->{OptionValue[hiOrd][[1]],0,1,1},FilterRules[{opts},{scheme}]]],0]   ]
+If[OptionValue[hiOrd][[3]]==0,\[CapitalDelta]MhpoleHSSbottomfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt],0]),0]+If[OptionValue[sources][[3]]==1,\[CapitalDelta]MhpoleHSSmomfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt],0]


(* ::Subsection::Closed:: *)
(*\[CapitalDelta]MHiggs Function*)


Options[\[CapitalDelta]MHiggs]={hiOrd->{1,1,1,1},sources->{1,1,1},numerical->False,Rscale->0,scheme->"DR"};
\[CapitalDelta]MHiggs[shortList_?numericListQ,opts:OptionsPattern[]]:=Block[{tan\[Beta],M1,M2,M3,\[Mu],At,mQ3,mU3,mD3,mQ2,mU2,mD2,mQ1,mU1,mD1,mL3,mE3,mL2,mE2,mL1,mE1,mA,Xt,mtilde,msplit},
{tan\[Beta],M1,M2,M3,\[Mu],At,mQ3,mU3,mD3,mQ2,mU2,mD2,mQ1,mU1,mD1,mL3,mE3,mL2,mE2,mL1,mE1,mA}=getList[shortList];
If[NumericQ[tan\[Beta]]&&tan\[Beta]>=1&&cond[M1]&&cond[M2]&&cond[M3]&&cond[\[Mu]]&&Im[At]==0&&NumericQ[At]&&cond[mQ3]&&cond[mU3]&&cond[mD3]&&cond[mQ2]&&cond[mU2]&&cond[mD2]&&cond[mQ1]&&cond[mU1]&&cond[mD1]&&cond[mL3]&&cond[mE3]&&cond[mL2]&&cond[mE2]&&cond[mL1]&&cond[mE1]&&cond[mA],1,Message[MHiggs::variables];Return[0]];
Xt=At-\[Mu] /tan\[Beta];mtilde=If[OptionValue[Rscale]<200,Sqrt[mQ3 mU3],OptionValue[Rscale]];
If[Not[1/10<=mtilde/Sqrt[mQ3 mU3]<=10]||0<OptionValue[Rscale]<200,Message[MHiggs::warning]];
If[testgbDR[mtilde,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt],Return[0]];
If[testgtauDR[mtilde,mL3,mE3,M2,M1,\[Mu],tan\[Beta]],Return[0]];
Which[
Not[OptionValue@numerical],
MhpoleHSSUncfast[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,FilterRules[{opts},{hiOrd,sources,scheme}]],
OptionValue@numerical,
MhpoleHSSUnc[mtilde,mQ1,mQ2,mQ3,mU1,mU2,mU3,mD1,mD2,mD3,mE1,mE2,mE3,mL1,mL2,mL3,mA,\[Mu],M1,M2,M3,tan\[Beta],Xt,FilterRules[{opts},{hiOrd,sources}]]]];


End[]


EndPackage[]
