(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   3244202,      88406]
NotebookOptionsPosition[   3231540,      88015]
NotebookOutlinePosition[   3231904,      88031]
CellTagsIndexPosition[   3231861,      88028]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["SUSYHD v1.0",
 FontSize->48,
 FontWeight->"Bold"]], "Title",
 CellChangeTimes->{{3.620548618528109*^9, 3.620548630304783*^9}, {
  3.621159980990035*^9, 3.6211599852374477`*^9}, {3.634588041987748*^9, 
  3.6345880447545433`*^9}, {3.6386122215941267`*^9, 3.638612223207757*^9}}],

Cell["\<\
This package computes the pole mass of the Higgs boson in the MSSM using the \
effective field theory technique. 
For the details of the calculation and conventions please refer to the file \
of documentation and examples SUSYHD_Examples.nb or the paper arXiv:1504.05200\
\>", "Text",
 CellChangeTimes->{{3.636021082594895*^9, 3.636021088303729*^9}, {
  3.6363708442062397`*^9, 3.636370860197989*^9}, {3.638559039085891*^9, 
  3.63855904046786*^9}, {3.6385622606851177`*^9, 3.6385623394599657`*^9}, {
  3.638675689422168*^9, 3.638675694979369*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Preambula",
 FontSize->18]], "Section",
 CellChangeTimes->{{3.620548666864489*^9, 3.620548680682135*^9}, {
  3.6228862476687183`*^9, 3.6228862544284153`*^9}, {3.62517246758965*^9, 
  3.625172468754176*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BeginPackage", "[", "\"\<SUSYHD`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.634841959289482*^9, 3.63484196894195*^9}}],

Cell[BoxData["\<\"SUSYHD`\"\>"], "Output",
 CellChangeTimes->{3.6382510656084557`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "uncomment", " ", "this", " ", "cell", " ", "if", " ", "you", " ", "need", 
    " ", "the", " ", "values", " ", "of", " ", "the", " ", "MSSM", " ", 
    "bottom", " ", "and", " ", "tau", " ", "Yukawa", " ", "couplings", " ", 
    "in", " ", "the", " ", 
    OverscriptBox["DR", "_"], " ", "scheme"}], "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"gbMSSM", "::", "usage"}], "=", 
     "\"\<gbMSSM[Q,mQ3,mU3,mD3,M3,\[Mu],tan\[Beta],Xt]\>\""}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gtauMSSM", "::", "usage"}], "=", 
     "\"\<gtauMSSM[Q,mL3,mE3,M2,M1,\[Mu],tan\[Beta]]\>\""}], ";"}], 
   "*)"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.6381880254257603`*^9, {3.638207170517893*^9, 3.6382072578483753`*^9}, {
   3.63825106110106*^9, 3.638251062172305*^9}, {3.6382512321335983`*^9, 
   3.638251232692477*^9}, {3.6385141822379627`*^9, 3.6385142122609673`*^9}, {
   3.638562844672368*^9, 3.6385628982571077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<----------------------------------\nSUSYHD v1.0 (2015)\nJavier Pardo \
Vega and Giovanni Villadoro\nhttp://www.ictp.it/~susyhd\n\
----------------------------------\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MHiggs", "::", "usage"}], "=", 
   "\"\<MHiggs[parameterslist] computes the pole mass of the Higgs boson (in \
units of GeV) as a function of the supersymmetric parameters in the \
\!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme evaluated at the scale Q=\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", \
SubscriptBox[\"U\", \"3\"]]}]],
FontSize->10]\). \n\nThe input \!\(\*
StyleBox[\"parameterslist\",
FontSlant->\"Italic\"]\) should be a list of the following form:\n\t{tan\
\[Beta],\!\(\*SubscriptBox[\(M\), \(1\)]\),\!\(\*SubscriptBox[\(M\), \
\(2\)]\),\!\(\*SubscriptBox[\(M\), \(3\)]\),\[Mu],\!\(\*SubscriptBox[\(A\), \
\(t\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\)}.\n\nIt also accepts shorter \
lists and assign suitable values for the parameters that are not input:\n\t\
{tan\[Beta],m0}: assumes degenerate SUSY masses m0 and \!\(\*SubscriptBox[\(A\
\), \(t\)]\)=0\n\t{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\)}: like \
before but with generic \!\(\*SubscriptBox[\(A\), \(t\)]\)\n\t{tan\[Beta],m0,\
\!\(\*SubscriptBox[\(A\), \(t\)]\),m12}: like before but with generic fermion \
masses \!\(\*SubscriptBox[\(M\), \(1\)]\)=\!\(\*SubscriptBox[\(M\), \(2\)]\)=\
\!\(\*SubscriptBox[\(M\), \(3\)]\)=\[Mu]=m12 \n\t\
{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but \
with generic \[Mu]\n\t{tan\[Beta],\!\(\*SubscriptBox[\(m\), \
SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but with \
\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\)\[NotEqual]\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\), \
the other scalar masses are m0=\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", \
SubscriptBox[\"U\", \"3\"]]}]],
FontSize->10]\)\n\t{tan\[Beta],\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),\!\(\*SubscriptBox[\(M\), \(1\)]\
\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Mu]}: like before but with generic gaugino masses.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MHiggs", "::", "warning"}], "=", 
   "\"\<We recommend to choose the renormalization scale \
\!\(\*SubscriptBox[\(m\), \(SUSY\)]\) near the stop average mass \
(\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\)\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\)\!\(\*SuperscriptBox[\()\), \(1/2\)]\).\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MHiggs", "::", "warningsplit"}], "=", 
   "\"\<The Split-SUSY calculation is suitable when the scalars are heavier \
than the gauginos and higgsinos. High-Scale calculation will be used.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MHiggs", "::", "variables"}], "=", 
   "\"\<One of the variables is not well-defined.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MHiggs", "::", "negative"}], "=", 
   "\"\<The Higgs mass squared is negative. The value 0 is returned.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MHiggs", "::", "bottomYukawa"}], "=", 
   "\"\<Bottom Yukawa is non-perturbative.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MHiggs", "::", "tauYukawa"}], "=", 
   "\"\<Tau Yukawa is non-perturbative.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"split", "::", "usage"}], "=", 
   "\"\<split is an option for MHiggs. When activated (split\[Rule]True), the \
code uses the Split-SUSY effective theory to resum the logs between the \
fermion scale \!\(\*SubscriptBox[\(Q\), \
\(split\)]\)=max(\[Mu],\!\(\*SubscriptBox[\(M\), \(2\)]\)) and the SUSY \
scale. In this case the RGE are integrated numerically and the code is \
sensibly slower. In the whole range relevant for the Higgs mass the effect of \
this resummation is very small.\nDefault value: split\[Rule]False\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"numerical", "::", "usage"}], "=", "\"\<\!\(\*
StyleBox[\"numerical\",
FontSlant->\"Italic\"]\) is an option for MHiggs and \[CapitalDelta]MHiggs. \
When activated (numerical\[Rule]True) the program integrates the RGE \
numerically and is much slower. \nDefault value: numerical\[Rule] False \
(recommended)\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hiOrd", "::", "usage"}], "=", 
   "\"\<hiOrd is an option for MHiggs and \[CapitalDelta]MHiggs which \
controls what two-loop SUSY thresholds are included. It also determines if \
the \!\(\*OverscriptBox[\(MS\), \(_\)]\) running top Yukawa coupling is \
calculated at two or three loops from the pole mass of the top quark. This \
option has the form hiOrd->{t1,t2,t3,t4} where each component take values 0 \
(correction excluded) or 1 (correction included). Each component controls the \
following corrections:\nt1: two-loop O(\!\(\*SubscriptBox[\(\[Alpha]\), \
\(t\)]\)\!\(\*SubscriptBox[\(\[Alpha]\), \(S\)]\)) SUSY threshold\nt2: \
two-loop O(\!\(\*SubsuperscriptBox[\(\[Alpha]\), \(t\), \(2\)]\)) SUSY \
threshold\nt3: one-loop O(\!\(\*SubscriptBox[\(\[Alpha]\), \(b, \[Tau]\)]\)) \
including tan\[Beta]-enhanced corrections.\nt4: three-loop \
O(\!\(\*SubsuperscriptBox[\(\[Alpha]\), \(S\), \(3\)]\)) correction to the \
determination of the \!\(\*OverscriptBox[\(MS\), \(_\)]\) top Yukawa coupling\
\nBy default all corrections are included, i.e. hiOrd\[Rule]{1,1,1,1}.\>\""}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Rscale", "::", "usage"}], "=", 
   "\"\<Rscale is an option for MHiggs and \[CapitalDelta]MHiggs that allows \
to change the scale at which the MSSM parameters are given as input. The \
program does not perform any RGE resummation of the soft parameters, it is \
thus recommended to use a scale close to the default one.\nDefault value: \
Rscale\[Rule]\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", \
SubscriptBox[\"U\", \"3\"]]}]],
FontSize->10]\)\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RscaleSplit", "::", "usage"}], "=", "\"\<\!\(\*
StyleBox[\"RscaleSplit\",
FontSlant->\"Italic\"]\) is an option for MHiggs which allows to change the \
scale of the Split-SUSY effective theory. \nDefault value: Rscale\[Rule]max(\
\[Mu],\!\(\*SubscriptBox[\(M\), \(2\)]\))\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"scheme", "::", "usage"}], "=", "\"\<\!\(\*
StyleBox[\"scheme\",
FontSlant->\"Italic\"]\) is an option for MHiggs and \[CapitalDelta]MHiggs \
which allows to input the MSSM parameters in the on-shell scheme (scheme\
\[Rule]\\\"OS\\\").\nDefault value: scheme\[Rule]\\\"DRbar\\\" \>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetSMparameters", "::", "usage"}], "=", 
   "\"\<SetSMparameters[\!\(\*SubscriptBox[\(m\), \(t\)]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*SubscriptBox[\(\[Alpha]\), \
\(S\)]\)(\!\(\*SubscriptBox[\(m\), \(Z\)]\))] sets the input values for the \
OS top mass \!\(\*SubscriptBox[\(m\), \(t\)]\) and the strong coupling at the \
scale of the mass of the Z-boson \!\(\*SubscriptBox[\(\[Alpha]\), \(S\)]\)(\!\
\(\*SubscriptBox[\(M\), \(Z\)]\)). The default values are \!\(\*SubscriptBox[\
\(m\), \(t\)]\)=173.34 GeV and \!\(\*SubscriptBox[\(\[Alpha]\), \(S\)]\)(\!\(\
\*SubscriptBox[\(m\), \(Z\)]\))=0.1185.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"useMStopYukawa", "::", "usage"}], "=", 
   "\"\<useMStopYukawa is an option for SetSMparameters which allows to input \
the \!\(\*OverscriptBox[\(MS\), \(_\)]\) top Yukawa coupling \
\!\(\*SubsuperscriptBox[\(y\), \(t\), OverscriptBox[\(MS\), \
\(_\)]]\)(\!\(\*SubscriptBox[\(m\), \(t\)]\)) in place of the pole mass of \
the top quark (useMStopYukawa\[Rule]True).\nDefault value: useMStopYukawa\
\[Rule]False.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]MHiggs", "::", "usage"}], "=", "\"\<\!\(\*
StyleBox[\"\[CapitalDelta]MHiggs\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",
FontSlant->\"Italic\"]\)parameterslist\!\(\*
StyleBox[\"]\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)estimates the theoretical uncertainty in the \
calculation of the Higgs mass (in units of GeV). \n\nThe input \!\(\*
StyleBox[\"parameterslist\",
FontSlant->\"Italic\"]\) should be a list of the following form:\n\t{tan\
\[Beta],\!\(\*SubscriptBox[\(M\), \(1\)]\),\!\(\*SubscriptBox[\(M\), \
\(2\)]\),\!\(\*SubscriptBox[\(M\), \(3\)]\),\[Mu],\!\(\*SubscriptBox[\(A\), \
\(t\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\)}.\n\nIt also accepts shorter \
lists and assign suitable values for the parameters that are not input:\n\t\
{tan\[Beta],m0}: assumes degenerate SUSY masses m0 and \!\(\*SubscriptBox[\(A\
\), \(t\)]\)=0\n\t{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\)}: like \
before but with generic \!\(\*SubscriptBox[\(A\), \(t\)]\)\n\t{tan\[Beta],m0,\
\!\(\*SubscriptBox[\(A\), \(t\)]\),m12}: like before but with generic fermion \
masses \!\(\*SubscriptBox[\(M\), \(1\)]\)=\!\(\*SubscriptBox[\(M\), \(2\)]\)=\
\!\(\*SubscriptBox[\(M\), \(3\)]\)=\[Mu]=m12 \n\t\
{tan\[Beta],m0,\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but \
with generic \[Mu]\n\t{tan\[Beta],\!\(\*SubscriptBox[\(m\), \
SubscriptBox[\(Q\), \(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),m12,\[Mu]}: like before but with \
\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\)\[NotEqual]\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \(3\)]]\), \
the other scalar masses are m0=\!\(\*
StyleBox[SqrtBox[
RowBox[{SubscriptBox[\"m\", SubscriptBox[\"Q\", \"3\"]], SubscriptBox[\"m\", \
SubscriptBox[\"U\", \"3\"]]}]],
FontSize->10]\)\n\t{tan\[Beta],\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(A\), \(t\)]\),\!\(\*SubscriptBox[\(M\), \(1\)]\
\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Mu]}: like before but with generic gaugino masses.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]MHiggs", "::", "tachyon"}], "=", 
   "\"\<The stops become tachyonic when varying the renormalization scale. A \
large uncertainty in the Higgs mass using the effective field theory in the \
\!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme is expected.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sources", "::", "usage"}], "=", "\"\<\!\(\*
StyleBox[\"sources\",
FontSlant->\"Italic\"]\) is an option for \[CapitalDelta]MHiggs. It selects \
which sources of theoretical uncertainties of the Higgs mass calculation are \
included.This option has the form sources\[Rule]{t1,t2,t3} where each \
component take values 0 (source excluded) or 1 (source included). Each \
component controls the following source of uncertainty:\nt1: SM: from \
higher-order corrections in the SM thresholds and RGE\nt2: SUSY: from missing \
threshold corrections at the SUSY scale\nt3: EFT: from higher order \
correction in the effective field theory expansion.\nBy default all sources \
are included: sources\[Rule]{1,1,1}.\nThe total is taken as the linear sum.\>\
\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"solutionSMRGEs", "::", "usage"}], "=", 
    "\"\<solution of the three-loop SM renormalization group \
equations.\>\""}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "*******)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "*******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"MhpoleHSS", "::", "usage"}], "=", 
     "\"\<MhpoleHSS[\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the pole \
mass of the Higgs in High-Scale-SUSY as a function of the supersymmetric \
parameters in the \!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme.\>\""}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
       RowBox[{"MhpoleHSS", "::", "warning"}], "=", 
       "\"\<We recommend to choose the renormalization scale \
\!\(\*OverscriptBox[\(m\), \(~\)]\) near the stop average mass \
(\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\)\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\)\!\(\*SuperscriptBox[\()\), \(1/2\)]\).\>\""}], ";"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MhpoleHSSfast", "::", "usage"}], "=", 
     "\"\<MhpoleHSSfast[\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the pole \
mass of the Higgs in High-Scale-SUSY as a function of the supersymmetric \
parameters in the \!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme. It is an \
optimized version of MhpoleHSS.\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
       RowBox[{"MhpoleHSSfast", "::", "warning"}], "=", 
       "\"\<We recommend to choose the renormalization scale \
\!\(\*OverscriptBox[\(m\), \(~\)]\) near the stop average mass \
(\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\)\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\)\!\(\*SuperscriptBox[\()\), \(1/2\)]\).\>\""}], ";"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MhpoleSplit", "::", "usage"}], "=", 
     "\"\<MhpoleSplit[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the pole \
mass of the Higgs in Split Supersymmetry as a function of the supersymmetric \
parameters in the \!\(\*OverscriptBox[\(DR\), \(_\)]\) scheme.\>\""}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSmom", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSmom[\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] estimates the \
uncertainty in the Higgs mass due to effects \!\(\*SuperscriptBox[\(v\), \
\(2\)]\)/\!\(\*SuperscriptBox[OverscriptBox[\(m\), \(~\)], \
\(2\)]\)-suppressed.\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSSM", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSSM[\!\(\*OverscriptBox[\(m\), \(~\)]\),\!\(\
\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(1\)]]\),\!\(\*SubscriptBox[\(m\), \
SubscriptBox[\(Q\), \(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] estimates the \
uncertainty in the Higgs mass due to missing SM corrections in the the RGEs \
and the matching at the EW scale.\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSQ", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSQ[n,\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] calculates the shift \
in the Higgs mass induced by changing the renormalization scale by a factor \
\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\) around the SUSY scale. It depends on the two-loop \
threshold corrections that are included in the calculation through the option \
\!\(\*
StyleBox[\"hiOrd\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"->\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"{\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t1\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t2\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t3\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t4\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"}\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",
FontSlant->\"Italic\"]\)\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSbottom", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSbottom[\!\(\*OverscriptBox[\(m\), \(~\)]\),\
\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] calculates the shift \
in the Higgs mass produced by the resummation of the tan\[Beta]-enhanced \
contributions.\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MhpoleHSSUnc", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSUnc[\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] estimates the total \
uncertainty in the calculation of the Higgs mass.\>\""}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSmomfast", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSmomfast[\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] estimates the \
uncertainty in the Higgs mass due to effects \!\(\*SuperscriptBox[\(v\), \
\(2\)]\)/\!\(\*SuperscriptBox[OverscriptBox[\(m\), \(~\)], \
\(2\)]\)-suppressed.(fast version)\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSSMfast", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSSMfast[\!\(\*OverscriptBox[\(m\), \(~\)]\),\
\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] estimates the \
uncertainty in the Higgs mass due to missing SM corrections in the the RGEs \
and the matching at the EW scale.(fast version)\>\""}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSQfast", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSQfast[n,\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] calculates the shift \
in the Higgs mass induced by changing the renormalization scale by a factor \
\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\) around the SUSY scale. It depends on the two-loop \
threshold corrections that are included in the calculation thorugh the option \
\!\(\*
StyleBox[\"hiOrd\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"->\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"{\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t1\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t2\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t3\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"t4\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"}\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"fast\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"version\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]MhpoleHSSbottomfast", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSbottomfast[\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] calculates the shift \
in the Higgs mass produced by the resummation of the tan\[Beta]-enhanced \
contributions.(fast version)\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MhpoleHSSUncfast", "::", "usage"}], "=", 
     "\"\<\[CapitalDelta]MhpoleHSSUncfast[\!\(\*OverscriptBox[\(m\), \
\(~\)]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] estimates the total \
uncertainty in the calculation of the Higgs mass.(fast version)\>\""}], ";"}],
    "*)"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.62012423570925*^9, 3.620124349745171*^9}, {
   3.620124436601101*^9, 3.62012444838445*^9}, {3.620126023963554*^9, 
   3.620126025562715*^9}, {3.620306562343508*^9, 3.620306571446246*^9}, {
   3.620548442307642*^9, 3.620548488733654*^9}, {3.621158790601468*^9, 
   3.621158889590727*^9}, {3.621158945807823*^9, 3.621159069190352*^9}, {
   3.6211591791453333`*^9, 3.6211591831335783`*^9}, {3.622176198903214*^9, 
   3.622176206013554*^9}, {3.6221762416022253`*^9, 3.6221762505192747`*^9}, {
   3.622176287465514*^9, 3.622176296748691*^9}, {3.622177730959553*^9, 
   3.6221777697521467`*^9}, {3.622350564470047*^9, 3.622350753418735*^9}, {
   3.6223508044457083`*^9, 3.622350834029209*^9}, 3.622351160726162*^9, 
   3.622354695417139*^9, {3.6223612319289627`*^9, 3.622361236009192*^9}, {
   3.6224482418668013`*^9, 3.622448258600306*^9}, {3.622538948150543*^9, 
   3.6225393085873137`*^9}, {3.6225393477066317`*^9, 3.622539349242303*^9}, {
   3.6227800845275908`*^9, 3.6227802019088993`*^9}, {3.62278023580112*^9, 
   3.622780243732811*^9}, {3.622882045513792*^9, 3.622882075877798*^9}, {
   3.625167385871314*^9, 3.6251674557545223`*^9}, {3.62516749228769*^9, 
   3.625167652371477*^9}, {3.625256992601307*^9, 3.6252570344312153`*^9}, {
   3.627134241408217*^9, 3.6271342604387493`*^9}, {3.627134575953723*^9, 
   3.627134577666272*^9}, {3.627734728487554*^9, 3.627734737091936*^9}, {
   3.62782339877363*^9, 3.627823414292862*^9}, {3.627882654204236*^9, 
   3.627882657852565*^9}, {3.6278828396917953`*^9, 3.6278828434351883`*^9}, {
   3.627884070274508*^9, 3.627884075859686*^9}, 3.6278841399500647`*^9, {
   3.627884650088688*^9, 3.62788465330453*^9}, {3.627884800407105*^9, 
   3.627884804999708*^9}, {3.6278849380952597`*^9, 3.62788494247866*^9}, {
   3.627885014246978*^9, 3.627885020934647*^9}, {3.627885268165134*^9, 
   3.627885271495533*^9}, {3.628065416499617*^9, 3.628065427645873*^9}, {
   3.628065460254821*^9, 3.6280658076656103`*^9}, 3.628102449471753*^9, {
   3.628102481633204*^9, 3.6281024992400103`*^9}, {3.6281025341378717`*^9, 
   3.6281029034589453`*^9}, {3.6281029355490828`*^9, 3.628103243237732*^9}, {
   3.628103684369638*^9, 3.628103758407229*^9}, {3.628104125384872*^9, 
   3.628104149878344*^9}, {3.628151172121677*^9, 3.62815132603716*^9}, {
   3.628151734277742*^9, 3.628151740249372*^9}, {3.632488775472196*^9, 
   3.632488790602092*^9}, {3.6346292826943398`*^9, 3.634629283659505*^9}, {
   3.634639127629842*^9, 3.634639149883943*^9}, {3.634641942240657*^9, 
   3.6346419523725443`*^9}, {3.634641991455325*^9, 3.63464214519958*^9}, {
   3.6346422383500147`*^9, 3.634642242242366*^9}, {3.6346422822072363`*^9, 
   3.634642286667255*^9}, {3.634642325203068*^9, 3.634642328058836*^9}, {
   3.634642399649469*^9, 3.634642416174461*^9}, {3.634643565841268*^9, 
   3.634643567542964*^9}, {3.634643656353615*^9, 3.63464369412156*^9}, {
   3.634645497174046*^9, 3.634645732917667*^9}, {3.634645765365246*^9, 
   3.634645770665287*^9}, {3.634645821394938*^9, 3.63464589894049*^9}, {
   3.634646107197879*^9, 3.6346461155887136`*^9}, {3.6346465790231*^9, 
   3.63464666409166*^9}, {3.634646734997939*^9, 3.634646736535499*^9}, {
   3.634646903908773*^9, 3.6346469097705593`*^9}, {3.6346476613722553`*^9, 
   3.634647708737849*^9}, {3.634647796192857*^9, 3.634647801943109*^9}, {
   3.634647875316873*^9, 3.634647877047784*^9}, {3.634650880353231*^9, 
   3.634650935968624*^9}, {3.634651149561349*^9, 3.634651149852889*^9}, {
   3.6346513495426683`*^9, 3.6346513575947723`*^9}, {3.634651492925473*^9, 
   3.634651494493567*^9}, {3.634674038067194*^9, 3.634674084143424*^9}, {
   3.634674220190833*^9, 3.634674391848283*^9}, {3.6346744267496443`*^9, 
   3.634674426797288*^9}, {3.6346766209202023`*^9, 3.6346766461473217`*^9}, {
   3.634678135489751*^9, 3.6346781452724113`*^9}, {3.6347305180891733`*^9, 
   3.6347305191866207`*^9}, {3.634734362492728*^9, 3.63473436390333*^9}, {
   3.634735505962158*^9, 3.634735626252894*^9}, {3.634735670401814*^9, 
   3.634735740947466*^9}, {3.634735784415573*^9, 3.634735834168365*^9}, 
   3.6347396376237793`*^9, {3.63474025899785*^9, 3.634740282308012*^9}, {
   3.634740970420508*^9, 3.634740973986465*^9}, {3.63474107828652*^9, 
   3.634741080252207*^9}, {3.634741401375819*^9, 3.634741404089151*^9}, {
   3.634842362968074*^9, 3.6348428247669163`*^9}, {3.6348429684449778`*^9, 
   3.634842986045299*^9}, {3.635517372987871*^9, 3.635517381317177*^9}, {
   3.6355174550051622`*^9, 3.635517462106659*^9}, 3.6355181010049677`*^9, {
   3.635571991843163*^9, 3.635572045585239*^9}, {3.6355722626740313`*^9, 
   3.635572416112056*^9}, {3.635572542345324*^9, 3.635572582138996*^9}, {
   3.6355728485030193`*^9, 3.6355728657837887`*^9}, {3.635685001260427*^9, 
   3.635685014081502*^9}, {3.635685268291288*^9, 3.635685271080883*^9}, {
   3.635687036297267*^9, 3.635687041726424*^9}, {3.635687309614637*^9, 
   3.635687357635523*^9}, {3.635688183665832*^9, 3.6356881849311447`*^9}, {
   3.635688217932334*^9, 3.635688240018928*^9}, {3.635838893651476*^9, 
   3.635839023760291*^9}, {3.635839331739016*^9, 3.635839369522851*^9}, {
   3.6360185737067833`*^9, 3.636018829462906*^9}, {3.636018928307621*^9, 
   3.6360190403960447`*^9}, {3.6360190784821587`*^9, 3.6360193675892878`*^9}, 
   3.636019431793624*^9, {3.636019486061686*^9, 3.636019490208342*^9}, {
   3.63601953881717*^9, 3.636019591472085*^9}, {3.6360196241170464`*^9, 
   3.63601962472941*^9}, {3.63601967561759*^9, 3.636019731249525*^9}, {
   3.6360197791801567`*^9, 3.6360198195357656`*^9}, {3.636019876326964*^9, 
   3.636019882098193*^9}, {3.636019980967235*^9, 3.636019991868107*^9}, {
   3.636021039137774*^9, 3.63602103949411*^9}, {3.6360218697220373`*^9, 
   3.636021888976329*^9}, {3.6360219281726522`*^9, 3.636021935213709*^9}, {
   3.6360233752862463`*^9, 3.6360234543101254`*^9}, {3.636023561213835*^9, 
   3.636023566832979*^9}, {3.636023637483344*^9, 3.6360236431842737`*^9}, {
   3.636199745489441*^9, 3.636199753141395*^9}, {3.636364961916114*^9, 
   3.636364993691305*^9}, {3.636367276112648*^9, 3.636367315741884*^9}, 
   3.6363686658242826`*^9, {3.636368804840867*^9, 3.636368829185557*^9}, 
   3.636368862522758*^9, {3.636368968478587*^9, 3.6363689774690647`*^9}, {
   3.636369020939022*^9, 3.636369229772358*^9}, {3.636369279186562*^9, 
   3.6363693421921177`*^9}, {3.6363693978477917`*^9, 3.636369411568219*^9}, {
   3.636369471549017*^9, 3.636369777475278*^9}, {3.636369810441165*^9, 
   3.6363698121434927`*^9}, {3.6363698561393414`*^9, 3.636369944831711*^9}, {
   3.6363700567487507`*^9, 3.636370061865918*^9}, {3.636371887555477*^9, 
   3.636371891687995*^9}, {3.636706257240799*^9, 3.63670626521843*^9}, {
   3.636706443092705*^9, 3.636706452364359*^9}, {3.636706533344719*^9, 
   3.636706568431705*^9}, {3.636706609808872*^9, 3.63670662330564*^9}, {
   3.6367067699795227`*^9, 3.636706771131743*^9}, 3.636707698805089*^9, {
   3.638042021061042*^9, 3.638042023167804*^9}, {3.6380423986283693`*^9, 
   3.6380424068184443`*^9}, {3.638088218459539*^9, 3.638088219428979*^9}, {
   3.638118722100737*^9, 3.638118730558659*^9}, {3.638187990754784*^9, 
   3.6381880189200497`*^9}, {3.6382512831729193`*^9, 
   3.6382514328062773`*^9}, {3.6382526612432833`*^9, 3.638252665616501*^9}, {
   3.6382530048536*^9, 3.638253036620779*^9}, {3.638253084812755*^9, 
   3.638253127925576*^9}, {3.638253313513248*^9, 3.638253379908497*^9}, {
   3.638514234712426*^9, 3.638514260030158*^9}, {3.638535814002305*^9, 
   3.638535912984037*^9}, {3.638536194712614*^9, 3.6385361978680563`*^9}, {
   3.638536281584642*^9, 3.638536284528414*^9}, {3.6385363414966087`*^9, 
   3.6385364231792097`*^9}, {3.6385364855478783`*^9, 3.638536805191066*^9}, {
   3.63853683547404*^9, 3.638536841290155*^9}, {3.638536918875929*^9, 
   3.6385369239718313`*^9}, {3.638536963712347*^9, 3.6385369682568207`*^9}, {
   3.6385370048646393`*^9, 3.638537062162294*^9}, {3.638593214321789*^9, 
   3.638593236746875*^9}, {3.638593337936866*^9, 3.63859337053552*^9}, {
   3.6385934047290382`*^9, 3.638593418419115*^9}, {3.6385937923610973`*^9, 
   3.638593811831814*^9}, {3.638593847654458*^9, 3.638593947658289*^9}, {
   3.6385939940094852`*^9, 3.638594129882936*^9}, {3.6385942867817783`*^9, 
   3.638594298428479*^9}, {3.638596517475788*^9, 3.638596548758788*^9}, {
   3.638596784511484*^9, 3.638596879000292*^9}, {3.638597300748214*^9, 
   3.638597342724066*^9}, {3.638597481883065*^9, 3.638597577270734*^9}, {
   3.6385976296061974`*^9, 3.6385978221710157`*^9}, {3.638597979354765*^9, 
   3.6385980096937237`*^9}, {3.63859805439677*^9, 3.6385981452076483`*^9}, {
   3.638598446860153*^9, 3.638598530907806*^9}, 3.63859858389246*^9, {
   3.63859865759234*^9, 3.638598715950679*^9}, {3.638598745965393*^9, 
   3.638599027862546*^9}, {3.63859911924256*^9, 3.638599218024869*^9}, {
   3.638599432346508*^9, 3.638599440784299*^9}, 3.638599480603827*^9, {
   3.638599724750149*^9, 3.638599956480467*^9}, {3.638600168701071*^9, 
   3.638600467803062*^9}, {3.6386125040362377`*^9, 3.638612507443781*^9}}],

Cell[BoxData["\<\"----------------------------------\\nSUSYHD v1.0 \
(2015)\\nJavier Pardo Vega and Giovanni \
Villadoro\\nhttp://www.ictp.it/~susyhd\\n----------------------------------\"\
\>"], "Print",
 CellChangeTimes->{
  3.6382510657365026`*^9, 3.638251300494707*^9, 3.638251356696637*^9, 
   3.638251433681459*^9, 3.63851421905548*^9, 3.63851426199856*^9, 
   3.638535920190337*^9, 3.6385360464654503`*^9, 3.638536200798996*^9, 
   3.638536591331167*^9, 3.638536845295185*^9, 3.6385369271440773`*^9, 
   3.638536970651293*^9, {3.638537027999279*^9, 3.6385370630372334`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<Private`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.634841976407382*^9, 3.634841982827784*^9}}],

Cell[BoxData["\<\"Private`\"\>"], "Output",
 CellChangeTimes->{3.638251065754312*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SM RGEs", "Title",
 CellChangeTimes->{{3.624968644602496*^9, 3.6249686595070753`*^9}, {
  3.634842015765648*^9, 3.634842017743676*^9}}],

Cell["\<\
This sub-package solves the renormalization group equations of the Standard \
Model up to the three loop order. \
\>", "Text",
 CellChangeTimes->{{3.6249686900974903`*^9, 3.6249687454336567`*^9}, {
   3.624968793176572*^9, 3.624968844407144*^9}, 3.635708376392536*^9, {
   3.63855919219453*^9, 3.6385591941945353`*^9}}],

Cell[CellGroupData[{

Cell["Preambula", "Section",
 CellChangeTimes->{{3.6249675277085743`*^9, 3.624967539284958*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
    RowBox[{"SM\[Beta]", "::", "usage"}], "=", 
    "\"\<SM\[Beta][loops,coupling] gives the SM \[Beta]-function of a \!\(\*
StyleBox[\"coupling\",
FontSlant->\"Italic\"]\) up to a given order specified by \!\(\*
StyleBox[\"loops\",
FontSlant->\"Italic\"]\)\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SMrun", "::", "usage"}], "=", 
    "\"\<SMrun[variables,initialconds,tmin,tmax,opts] solves the coupled RGEs \
of the \!\(\*
StyleBox[\"variables\",
FontSlant->\"Italic\"]\) with the initial coditions given by \!\(\*
StyleBox[\"initialconds\",
FontSlant->\"Italic\"]\) between \!\(\*
StyleBox[\"tmin\",
FontSlant->\"Italic\"]\) and \!\(\*
StyleBox[\"tmax\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",
FontSlant->\"Italic\"]\) \n It accepts the options of NDSolve. For time \
saving we recommend the \!\(\*
StyleBox[\"optsrun\",
FontSlant->\"Italic\"]\)\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"optsSMrun", "::", "usage"}], "=", 
    "\"\<Default options for the function SMrun. It selects the numerical \
method used by NDSolve and the precision goal\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["g", "1"], ",", "g1", ",", 
     SubscriptBox["g", "2"], ",", "g2", ",", 
     SubscriptBox["g", "3"], ",", "g3", ",", 
     SubscriptBox["g", "t"], ",", "gt", ",", 
     SubscriptBox["g", "\[Tau]"], ",", "g\[Tau]", ",", 
     SubscriptBox["g", "b"], ",", "gb", ",", "\[Lambda]"}], "}"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "The", " ", "names", " ", "of", " ", "the", " ", "couplings", " ", "are", 
    " ", "not", " ", 
    RowBox[{"encapsulated", "."}]}], "*)"}], "*)"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620020538209491*^9, 3.6200205562165127`*^9}, {
   3.62002058632047*^9, 3.620020611120508*^9}, {3.620020836953085*^9, 
   3.6200209055433197`*^9}, {3.620020940943014*^9, 3.620021024221815*^9}, {
   3.620021125372918*^9, 3.620021190347931*^9}, {3.620305269770131*^9, 
   3.62030526996218*^9}, {3.620305328824441*^9, 3.62030532962578*^9}, {
   3.620307217265112*^9, 3.620307217359693*^9}, {3.624967434065027*^9, 
   3.624967434288769*^9}, {3.634539537446233*^9, 3.6345396263429947`*^9}, {
   3.6345399275738277`*^9, 3.6345399282530622`*^9}, 3.634842033553157*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Manipuation : rationalization of the three loop beta functions\
\>", "Section",
 CellChangeTimes->{{3.624967544306217*^9, 3.624967591052432*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Here", " ", "we", " ", "rationalize", " ", "the", " ", "numbers", " ", 
    "in", " ", "the", " ", "three", " ", "loop", " ", "beta", " ", 
    "functions"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SM\[Beta]aux", "[", 
      RowBox[{"3", ",", "\[Lambda]"}], "]"}], ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Lambda]", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6011.35`", " ", "\[Lambda]"}], "+", 
          RowBox[{"873", " ", 
           SuperscriptBox[
            SubscriptBox["g", "t"], "2"]}], "-", 
          RowBox[{"387.452`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "-", 
          RowBox[{"77.49`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Lambda]", "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1768.26`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "t"], "2"]}], "+", 
          RowBox[{"160.77`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}], "-", 
          RowBox[{"359.539`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "-", 
          RowBox[{"63.869`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Lambda]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "790.28`"}], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "4"]}], "-", 
          RowBox[{"185.532`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "4"]}], "-", 
          RowBox[{"316.64`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "223.382`"}], " ", 
           SuperscriptBox[
            SubscriptBox["g", "t"], "2"]}], "-", 
          RowBox[{"662.866`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}], "-", 
          RowBox[{"5.47`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "-", 
          RowBox[{"21.015`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", "\[Lambda]", " ", 
       "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"356.968`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "4"]}], "-", 
          RowBox[{"319.664`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "4"]}], "-", 
          RowBox[{"74.8599`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "4"]}], "+", 
          RowBox[{"15.1443`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"17.454`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{"5.615`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "57.144`"}], " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}], "+", 
          RowBox[{"865.483`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"79.638`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8.381`"}], " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}], "+", 
          RowBox[{"61.753`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"28.168`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "243.149`"}], " ", 
           SuperscriptBox[
            SubscriptBox["g", "t"], "2"]}], "+", 
          RowBox[{"250.494`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}], "+", 
          RowBox[{"74.138`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"33.93`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "50.201`"}], " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "4"]}], "+", 
          RowBox[{"15.884`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "4"]}], "+", 
          RowBox[{"15.948`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "4"]}], "+", 
          RowBox[{"13.349`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"17.57`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "-", 
          RowBox[{"70.356`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"16.464`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "4"]}], "+", 
          RowBox[{"1.016`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "4"]}], "+", 
          RowBox[{"11.386`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"62.5`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"13.041`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"10.627`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"11.117`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "3"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7.536`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "6"]}], "+", 
          RowBox[{"0.663`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "6"]}], "+", 
          RowBox[{"1.507`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "4"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{"1.105`", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "4"]}]}], ")"}]}], "-", 
       RowBox[{"114.091`", " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "8"]}], "-", 
       RowBox[{"1.508`", " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "8"]}], "-", 
       RowBox[{"37.889`", " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "6"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{"6.5`", " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{"1.543`", " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "6"]}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SM\[Beta]aux", "[", 
      RowBox[{"3", ",", 
       SubscriptBox["g", "t"]}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["g", "t"], "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubscriptBox["g", "t"], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"58.6028`", " ", 
            SuperscriptBox[
             SubscriptBox["g", "t"], "2"]}], "+", 
           RowBox[{"198", " ", "\[Lambda]"}], "-", 
           RowBox[{"157", " ", 
            SuperscriptBox[
             SubscriptBox["g", "3"], "2"]}], "-", 
           RowBox[{
            FractionBox["1593", "16"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "2"]}], "-", 
           RowBox[{
            FractionBox["2437", "80"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
        RowBox[{"\[Lambda]", " ", 
         SuperscriptBox[
          SubscriptBox["g", "t"], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"15", " ", "\[Lambda]"}], "4"], "+", 
           RowBox[{"16", " ", 
            SuperscriptBox[
             SubscriptBox["g", "3"], "2"]}], "-", 
           RowBox[{
            FractionBox["135", "2"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "2"]}], "-", 
           RowBox[{
            FractionBox["127", "10"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["g", "t"], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"363.764`", " ", 
            SuperscriptBox[
             SubscriptBox["g", "3"], "4"]}], "+", 
           RowBox[{"16.99`", " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "4"]}], "-", 
           RowBox[{"24.422`", " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "4"]}], "+", 
           RowBox[{"48.37`", " ", 
            SuperscriptBox[
             SubscriptBox["g", "3"], "2"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "2"]}], "+", 
           RowBox[{"18.074`", " ", 
            SuperscriptBox[
             SubscriptBox["g", "3"], "2"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "2"]}], "+", 
           RowBox[{"34.829`", " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "2"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "36"}], " ", "\[Lambda]"}], "+", 
           RowBox[{"45", " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "2"]}], "+", 
           RowBox[{"9", " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "16"]}], " ", 
            RowBox[{"(", 
             RowBox[{"171", " ", 
              SuperscriptBox[
               SubscriptBox["g", "2"], "4"]}], ")"}]}], "-", 
           RowBox[{
            FractionBox["1089", "400"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "4"]}], "+", 
           RowBox[{
            FractionBox["117", "40"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "2"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "-", 
        RowBox[{"619.35`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "6"]}], "+", 
        RowBox[{"169.829`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "6"]}], "+", 
        RowBox[{"16.099`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "6"]}], "+", 
        RowBox[{"73.654`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "2"]}], "-", 
        RowBox[{"15.096`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}], "-", 
        RowBox[{"21.072`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "4"]}], "-", 
        RowBox[{"22.319`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "4"]}], "-", 
        RowBox[{
         FractionBox["321", "20"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}], "-", 
        RowBox[{"4.743`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}], "-", 
        RowBox[{"4.442`", " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "4"]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Rationalize", "[", " ", 
    RowBox[{"-", "2472.28"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Rationalize", "[", 
    RowBox[{"SM\[Beta]aux", "[", 
     RowBox[{"3", ",", "\[Lambda]"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Rationalize", "[", 
    RowBox[{"SM\[Beta]aux", "[", 
     RowBox[{"3", ",", 
      SubscriptBox["g", "t"]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.61994619304844*^9, 3.619946254302493*^9}, {
   3.619951354660358*^9, 3.619951395156617*^9}, {3.619951426547813*^9, 
   3.619951434482814*^9}, {3.6199514993795643`*^9, 3.619951562879836*^9}, {
   3.619951619780147*^9, 3.619951663965116*^9}, 3.6199771034907312`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["61807", "25"]}]], "Output",
 CellChangeTimes->{
  3.619946255131234*^9, {3.6199513744275208`*^9, 3.619951396287445*^9}, {
   3.619951428947085*^9, 3.619951435376791*^9}, {3.61995150932059*^9, 
   3.6199515638432617`*^9}, 3.6199516205930157`*^9, {3.61995166048377*^9, 
   3.619951664601355*^9}, 3.619976206771887*^9, 3.619978442286209*^9, 
   3.620020613435382*^9}],

Cell[BoxData[
 RowBox[{"\[Lambda]", "-", 
  FractionBox[
   RowBox[{"377", " ", 
    SubsuperscriptBox["g", "1", "8"]}], "250"], "-", 
  FractionBox[
   RowBox[{"1543", " ", 
    SubsuperscriptBox["g", "1", "6"], " ", 
    SubsuperscriptBox["g", "2", "2"]}], "1000"], "+", 
  RowBox[{
   FractionBox["13", "2"], " ", 
   SubsuperscriptBox["g", "1", "4"], " ", 
   SubsuperscriptBox["g", "2", "4"]}], "-", 
  FractionBox[
   RowBox[{"37889", " ", 
    SubsuperscriptBox["g", "1", "2"], " ", 
    SubsuperscriptBox["g", "2", "6"]}], "1000"], "-", 
  FractionBox[
   RowBox[{"114091", " ", 
    SubsuperscriptBox["g", "2", "8"]}], "1000"], "+", 
  RowBox[{
   SuperscriptBox["\[Lambda]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"46383", " ", 
        SubsuperscriptBox["g", "1", "4"]}], "250"]}], "-", 
     RowBox[{
      FractionBox["7916", "25"], " ", 
      SubsuperscriptBox["g", "1", "2"], " ", 
      SubsuperscriptBox["g", "2", "2"]}], "-", 
     FractionBox[
      RowBox[{"19757", " ", 
       SubsuperscriptBox["g", "2", "4"]}], "25"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"663", " ", 
       SubsuperscriptBox["g", "1", "6"]}], "1000"], "+", 
     RowBox[{
      FractionBox["221", "200"], " ", 
      SubsuperscriptBox["g", "1", "4"], " ", 
      SubsuperscriptBox["g", "2", "2"]}], "+", 
     FractionBox[
      RowBox[{"1507", " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       SubsuperscriptBox["g", "2", "4"]}], "1000"], "+", 
     FractionBox[
      RowBox[{"942", " ", 
       SubsuperscriptBox["g", "2", "6"]}], "125"]}], ")"}], " ", 
   SubsuperscriptBox["g", "3", "2"]}], "+", 
  RowBox[{"\[Lambda]", " ", 
   SubsuperscriptBox["g", "2", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"39819", " ", 
       SubsuperscriptBox["g", "1", "2"]}], "500"], "+", 
     FractionBox[
      RowBox[{"865483", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "1000"], "-", 
     FractionBox[
      RowBox[{"7143", " ", 
       SubsuperscriptBox["g", "3", "2"]}], "125"]}], ")"}]}], "+", 
  RowBox[{"\[Lambda]", " ", 
   SubsuperscriptBox["g", "1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3521", " ", 
       SubsuperscriptBox["g", "1", "2"]}], "125"], "+", 
     FractionBox[
      RowBox[{"61753", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "1000"], "-", 
     FractionBox[
      RowBox[{"8381", " ", 
       SubsuperscriptBox["g", "3", "2"]}], "1000"]}], ")"}]}], "+", 
  RowBox[{
   SubsuperscriptBox["g", "1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"11117", " ", 
       SubsuperscriptBox["g", "1", "2"]}], "1000"], "+", 
     FractionBox[
      RowBox[{"10627", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "1000"]}], ")"}], " ", 
   SubsuperscriptBox["g", "t", "2"]}], "+", 
  RowBox[{
   SubsuperscriptBox["g", "2", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"13041", " ", 
       SubsuperscriptBox["g", "1", "2"]}], "1000"], "+", 
     FractionBox[
      RowBox[{"125", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "2"]}], ")"}], " ", 
   SubsuperscriptBox["g", "t", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"127", " ", 
       SubsuperscriptBox["g", "1", "4"]}], "125"], "+", 
     RowBox[{
      FractionBox["5693", "500"], " ", 
      SubsuperscriptBox["g", "1", "2"], " ", 
      SubsuperscriptBox["g", "2", "2"]}], "+", 
     FractionBox[
      RowBox[{"2058", " ", 
       SubsuperscriptBox["g", "2", "4"]}], "125"]}], ")"}], " ", 
   SubsuperscriptBox["g", "3", "2"], " ", 
   SubsuperscriptBox["g", "t", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"748599", " ", 
        SubsuperscriptBox["g", "1", "4"]}], "10000"]}], "+", 
     RowBox[{
      FractionBox["1123", "200"], " ", 
      SubsuperscriptBox["g", "1", "2"], " ", 
      SubsuperscriptBox["g", "2", "2"]}], "-", 
     FractionBox[
      RowBox[{"39958", " ", 
       SubsuperscriptBox["g", "2", "4"]}], "125"], "+", 
     RowBox[{
      FractionBox["8727", "500"], " ", 
      SubsuperscriptBox["g", "1", "2"], " ", 
      SubsuperscriptBox["g", "3", "2"]}], "+", 
     FractionBox[
      RowBox[{"151443", " ", 
       SubsuperscriptBox["g", "2", "2"], " ", 
       SubsuperscriptBox["g", "3", "2"]}], "10000"], "+", 
     FractionBox[
      RowBox[{"44621", " ", 
       SubsuperscriptBox["g", "3", "4"]}], "125"]}], ")"}], " ", 
   SubsuperscriptBox["g", "t", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3987", " ", 
       SubsuperscriptBox["g", "1", "4"]}], "250"], "-", 
     RowBox[{
      FractionBox["17589", "250"], " ", 
      SubsuperscriptBox["g", "1", "2"], " ", 
      SubsuperscriptBox["g", "2", "2"]}], "+", 
     FractionBox[
      RowBox[{"3971", " ", 
       SubsuperscriptBox["g", "2", "4"]}], "250"], "+", 
     RowBox[{
      FractionBox["1757", "100"], " ", 
      SubsuperscriptBox["g", "1", "2"], " ", 
      SubsuperscriptBox["g", "3", "2"]}], "+", 
     FractionBox[
      RowBox[{"13349", " ", 
       SubsuperscriptBox["g", "2", "2"], " ", 
       SubsuperscriptBox["g", "3", "2"]}], "1000"], "-", 
     FractionBox[
      RowBox[{"50201", " ", 
       SubsuperscriptBox["g", "3", "4"]}], "1000"]}], ")"}], " ", 
   SubsuperscriptBox["g", "t", "4"]}], "+", 
  RowBox[{
   SubsuperscriptBox["g", "t", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3393", " ", 
       SubsuperscriptBox["g", "1", "2"]}], "100"], "+", 
     FractionBox[
      RowBox[{"37069", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "500"], "+", 
     FractionBox[
      RowBox[{"125247", " ", 
       SubsuperscriptBox["g", "3", "2"]}], "500"], "-", 
     FractionBox[
      RowBox[{"243149", " ", 
       SubsuperscriptBox["g", "t", "2"]}], "1000"]}], ")"}]}], "+", 
  RowBox[{"\[Lambda]", " ", 
   SubsuperscriptBox["g", "t", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4203", " ", 
        SubsuperscriptBox["g", "1", "2"]}], "200"]}], "-", 
     FractionBox[
      RowBox[{"547", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "100"], "-", 
     FractionBox[
      RowBox[{"331433", " ", 
       SubsuperscriptBox["g", "3", "2"]}], "500"], "-", 
     FractionBox[
      RowBox[{"111691", " ", 
       SubsuperscriptBox["g", "t", "2"]}], "500"]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[Lambda]", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"120227", " ", "\[Lambda]"}], "20"], "-", 
     FractionBox[
      RowBox[{"7749", " ", 
       SubsuperscriptBox["g", "1", "2"]}], "100"], "-", 
     FractionBox[
      RowBox[{"96863", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "250"], "+", 
     RowBox[{"873", " ", 
      SubsuperscriptBox["g", "t", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[Lambda]", "2"], " ", 
   SubsuperscriptBox["g", "t", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"63869", " ", 
        SubsuperscriptBox["g", "1", "2"]}], "1000"]}], "-", 
     FractionBox[
      RowBox[{"359539", " ", 
       SubsuperscriptBox["g", "2", "2"]}], "1000"], "+", 
     FractionBox[
      RowBox[{"16077", " ", 
       SubsuperscriptBox["g", "3", "2"]}], "100"], "+", 
     FractionBox[
      RowBox[{"88413", " ", 
       SubsuperscriptBox["g", "t", "2"]}], "50"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.619946255131234*^9, {3.6199513744275208`*^9, 3.619951396287445*^9}, {
   3.619951428947085*^9, 3.619951435376791*^9}, {3.61995150932059*^9, 
   3.6199515638432617`*^9}, 3.6199516205930157`*^9, {3.61995166048377*^9, 
   3.619951664601355*^9}, 3.619976206771887*^9, 3.619978442286209*^9, 
   3.620020613438509*^9}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["g", "t", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{"16099", " ", 
      SubsuperscriptBox["g", "1", "6"]}], "1000"], "-", 
    RowBox[{
     FractionBox["2221", "500"], " ", 
     SubsuperscriptBox["g", "1", "4"], " ", 
     SubsuperscriptBox["g", "2", "2"]}], "-", 
    FractionBox[
     RowBox[{"4743", " ", 
      SubsuperscriptBox["g", "1", "2"], " ", 
      SubsuperscriptBox["g", "2", "4"]}], "1000"], "+", 
    FractionBox[
     RowBox[{"169829", " ", 
      SubsuperscriptBox["g", "2", "6"]}], "1000"], "+", 
    RowBox[{
     SuperscriptBox["\[Lambda]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "36"}], " ", "\[Lambda]"}], "+", 
       RowBox[{"9", " ", 
        SubsuperscriptBox["g", "1", "2"]}], "+", 
       RowBox[{"45", " ", 
        SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"1089", " ", 
          SubsuperscriptBox["g", "1", "4"]}], "400"]}], "+", 
       RowBox[{
        FractionBox["117", "40"], " ", 
        SubsuperscriptBox["g", "1", "2"], " ", 
        SubsuperscriptBox["g", "2", "2"]}], "-", 
       FractionBox[
        RowBox[{"171", " ", 
         SubsuperscriptBox["g", "2", "4"]}], "16"]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"22319", " ", 
      SubsuperscriptBox["g", "1", "4"], " ", 
      SubsuperscriptBox["g", "3", "2"]}], "1000"], "-", 
    RowBox[{
     FractionBox["321", "20"], " ", 
     SubsuperscriptBox["g", "1", "2"], " ", 
     SubsuperscriptBox["g", "2", "2"], " ", 
     SubsuperscriptBox["g", "3", "2"]}], "-", 
    RowBox[{
     FractionBox["2634", "125"], " ", 
     SubsuperscriptBox["g", "2", "4"], " ", 
     SubsuperscriptBox["g", "3", "2"]}], "-", 
    RowBox[{
     FractionBox["1887", "125"], " ", 
     SubsuperscriptBox["g", "1", "2"], " ", 
     SubsuperscriptBox["g", "3", "4"]}], "+", 
    RowBox[{
     FractionBox["36827", "500"], " ", 
     SubsuperscriptBox["g", "2", "2"], " ", 
     SubsuperscriptBox["g", "3", "4"]}], "-", 
    FractionBox[
     RowBox[{"12387", " ", 
      SubsuperscriptBox["g", "3", "6"]}], "20"], "+", 
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"15", " ", "\[Lambda]"}], "4"], "-", 
       FractionBox[
        RowBox[{"127", " ", 
         SubsuperscriptBox["g", "1", "2"]}], "10"], "-", 
       FractionBox[
        RowBox[{"135", " ", 
         SubsuperscriptBox["g", "2", "2"]}], "2"], "+", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["g", "3", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["g", "t", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"12211", " ", 
          SubsuperscriptBox["g", "1", "4"]}], "500"]}], "+", 
       FractionBox[
        RowBox[{"34829", " ", 
         SubsuperscriptBox["g", "1", "2"], " ", 
         SubsuperscriptBox["g", "2", "2"]}], "1000"], "+", 
       FractionBox[
        RowBox[{"1699", " ", 
         SubsuperscriptBox["g", "2", "4"]}], "100"], "+", 
       RowBox[{
        FractionBox["9037", "500"], " ", 
        SubsuperscriptBox["g", "1", "2"], " ", 
        SubsuperscriptBox["g", "3", "2"]}], "+", 
       RowBox[{
        FractionBox["4837", "100"], " ", 
        SubsuperscriptBox["g", "2", "2"], " ", 
        SubsuperscriptBox["g", "3", "2"]}], "+", 
       FractionBox[
        RowBox[{"90941", " ", 
         SubsuperscriptBox["g", "3", "4"]}], "250"]}], ")"}], " ", 
     SubsuperscriptBox["g", "t", "2"]}], "+", 
    RowBox[{
     SubsuperscriptBox["g", "t", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"198", " ", "\[Lambda]"}], "-", 
       FractionBox[
        RowBox[{"2437", " ", 
         SubsuperscriptBox["g", "1", "2"]}], "80"], "-", 
       FractionBox[
        RowBox[{"1593", " ", 
         SubsuperscriptBox["g", "2", "2"]}], "16"], "-", 
       RowBox[{"157", " ", 
        SubsuperscriptBox["g", "3", "2"]}], "+", 
       FractionBox[
        RowBox[{"146507", " ", 
         SubsuperscriptBox["g", "t", "2"]}], "2500"]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.619946255131234*^9, {3.6199513744275208`*^9, 3.619951396287445*^9}, {
   3.619951428947085*^9, 3.619951435376791*^9}, {3.61995150932059*^9, 
   3.6199515638432617`*^9}, 3.6199516205930157`*^9, {3.61995166048377*^9, 
   3.619951664601355*^9}, 3.619976206771887*^9, 3.619978442286209*^9, 
   3.620020613441412*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Beta functions", "Section",
 CellChangeTimes->{{3.624967544306217*^9, 3.624967591052432*^9}, {
  3.624967651400056*^9, 3.624967651879682*^9}}],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Kappa]", "=", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"4", "\[Pi]"}], ")"}], "2"]]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"1", ",", 
       SubscriptBox["g", "1"]}], "]"}], ":=", 
     RowBox[{"\[Kappa]", " ", 
      SuperscriptBox[
       SubscriptBox["g", "1"], "4"], " ", 
      RowBox[{"(", 
       FractionBox["41", "10"], ")"}]}]}], ";", "\n", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "1"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"1", ",", 
        SubscriptBox["g", "1"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "1"], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["44", "5"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"]}], "+", 
         RowBox[{
          FractionBox["27", "10"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "+", 
         RowBox[{
          FractionBox["199", "50"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "-", 
         RowBox[{
          FractionBox["17", "10"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"]}], "-", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "2"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"3", ",", 
       SubscriptBox["g", "1"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"2", ",", 
        SubscriptBox["g", "1"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "3"], 
       SuperscriptBox[
        SubscriptBox["g", "1"], "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["189", "16"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "-", 
            RowBox[{
             FractionBox["29", "5"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "-", 
            RowBox[{
             FractionBox["471", "32"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "-", 
            RowBox[{
             FractionBox["2827", "800"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "5"]}], " ", 
             RowBox[{"(", 
              RowBox[{"36", " ", "\[Lambda]"}], ")"}]}], "+", 
            RowBox[{
             FractionBox["9", "5"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["27", "25"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["297", "5"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "4"]}], ")"}], "+", 
         RowBox[{
          FractionBox["789", "64"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "4"]}], "-", 
         FractionBox[
          RowBox[{"388613", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "4"]}], "24000"], "-", 
         RowBox[{
          FractionBox["3", "5"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "-", 
         RowBox[{
          FractionBox["137", "75"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "+", 
         RowBox[{
          FractionBox["123", "160"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"**", "**", "**", "**", "**", "**"}], "********)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"1", ",", 
       SubscriptBox["g", "2"]}], "]"}], ":=", 
     RowBox[{"\[Kappa]", " ", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "4"], " ", 
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox["19", "6"]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "2"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"1", ",", 
        SubscriptBox["g", "2"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"]}], "+", 
         RowBox[{
          FractionBox["35", "6"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "+", 
         RowBox[{
          FractionBox["9", "10"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "-", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"]}], "-", 
         RowBox[{
          FractionBox["3", "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "2"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"3", ",", 
       SubscriptBox["g", "2"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"2", ",", 
        SubscriptBox["g", "2"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "3"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["147", "16"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "-", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "-", 
            RowBox[{
             FractionBox["729", "32"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "-", 
            RowBox[{
             FractionBox["593", "160"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", "\[Lambda]"}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["3", "10"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"81", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "4"]}], "+", 
         FractionBox[
          RowBox[{"324953", " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "4"]}], "1728"], "-", 
         FractionBox[
          RowBox[{"5597", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "4"]}], "1600"], "+", 
         RowBox[{"39", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "-", 
         RowBox[{
          FractionBox["1", "5"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "+", 
         RowBox[{
          FractionBox["873", "160"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"**", "**", "**", "**", "**", "**", "**"}], "*******)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"1", ",", 
       SubscriptBox["g", "3"]}], "]"}], ":=", 
     RowBox[{"\[Kappa]", " ", 
      SuperscriptBox[
       SubscriptBox["g", "3"], "4"], " ", 
      RowBox[{"(", 
       RowBox[{"-", "7"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "3"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"1", ",", 
        SubscriptBox["g", "3"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "3"], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "26"}], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"]}], "+", 
         RowBox[{
          FractionBox["9", "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "+", 
         RowBox[{
          FractionBox["11", "10"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"3", ",", 
       SubscriptBox["g", "3"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"2", ",", 
        SubscriptBox["g", "3"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "3"], 
       SuperscriptBox[
        SubscriptBox["g", "3"], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"15", " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "-", 
            RowBox[{"40", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "-", 
            RowBox[{
             FractionBox["93", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "-", 
            RowBox[{
             FractionBox["101", "40"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["65", "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "4"]}], "+", 
         RowBox[{
          FractionBox["109", "8"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "4"]}], "-", 
         RowBox[{
          FractionBox["523", "120"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "4"]}], "+", 
         RowBox[{"21", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "+", 
         RowBox[{
          FractionBox["77", "15"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "-", 
         RowBox[{
          FractionBox["3", "40"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
      RowBox[{"0", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", " ", "\[Pi]"}], ")"}], "8"]], 
       SuperscriptBox[
        SubscriptBox["g", "3"], "10"], " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["61807", "25"]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
      "*", "We", " ", "multiplied", " ", "by", " ", "2", "\[Lambda]", " ", 
       "to", " ", "have", " ", "all", " ", "the", " ", "RGEs", " ", "in", " ",
        "the", " ", "form", " ", 
       FractionBox[
        SuperscriptBox["dg", "2"], 
        RowBox[{"d", " ", 
         RowBox[{"Log", "[", 
          SuperscriptBox["\[Mu]", "2"], "]"}]}]]}], "=", 
      SubscriptBox["\[Beta]", "g"]}], "**)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"1", ",", "\[Lambda]"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Kappa]", " ", "2", "\[Lambda]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", "\[Lambda]"}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             SubscriptBox["g", "t"], "2"]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             SubscriptBox["g", "b"], "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
           RowBox[{
            FractionBox["9", "2"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "2"]}], "-", 
           RowBox[{
            FractionBox["9", "10"], " ", 
            SuperscriptBox[
             SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox["g", "t"], "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox["g", "b"], "4"]}], "-", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"], "+", 
        RowBox[{
         FractionBox["9", "16"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "4"]}], "+", 
        RowBox[{
         FractionBox["27", "400"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "4"]}], "+", 
        RowBox[{
         FractionBox["9", "40"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", "\[Lambda]"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"1", ",", "\[Lambda]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Kappa]", "2"], "2", "\[Lambda]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Lambda]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "156"}], " ", "\[Lambda]"}], "-", 
            RowBox[{"72", " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "-", 
            RowBox[{"72", " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "-", 
            RowBox[{"24", " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
            RowBox[{"54", " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["54", "5"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], " ", 
             RowBox[{"(", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                SubscriptBox["g", "t"], "2"]}], ")"}]}], "-", 
            RowBox[{"21", " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "+", 
            RowBox[{"40", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["45", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["17", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], " ", 
             RowBox[{"(", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                SubscriptBox["g", "b"], "2"]}], ")"}]}], "+", 
            RowBox[{"40", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["45", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["5", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
            RowBox[{
             FractionBox["15", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["15", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "16"]}], " ", 
             RowBox[{"(", 
              RowBox[{"73", " ", 
               SuperscriptBox[
                SubscriptBox["g", "2"], "4"]}], ")"}]}], "+", 
            RowBox[{
             FractionBox["1887", "400"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "4"]}], "+", 
            RowBox[{
             FractionBox["117", "40"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"15", " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "-", 
            RowBox[{"16", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "-", 
            RowBox[{
             FractionBox["4", "5"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "8"]}], " ", 
             RowBox[{"(", 
              RowBox[{"9", " ", 
               SuperscriptBox[
                SubscriptBox["g", "2"], "4"]}], ")"}]}], "-", 
            RowBox[{
             FractionBox["171", "200"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "4"]}], "+", 
            RowBox[{
             FractionBox["63", "20"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "b"], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "+", 
            RowBox[{"15", " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "-", 
            RowBox[{"16", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["2", "5"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "8"]}], " ", 
             RowBox[{"(", 
              RowBox[{"9", " ", 
               SuperscriptBox[
                SubscriptBox["g", "2"], "4"]}], ")"}]}], "+", 
            RowBox[{
             FractionBox["9", "40"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "4"]}], "+", 
            RowBox[{
             FractionBox["27", "20"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
            RowBox[{
             FractionBox["6", "5"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "8"]}], " ", 
             RowBox[{"(", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                SubscriptBox["g", "2"], "4"]}], ")"}]}], "-", 
            RowBox[{
             FractionBox["9", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "4"]}], "+", 
            RowBox[{
             FractionBox["33", "20"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["305", "32"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "6"]}], "-", 
         FractionBox[
          RowBox[{"3411", " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "6"]}], "4000"], "-", 
         RowBox[{
          FractionBox["289", "160"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "4"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "-", 
         RowBox[{
          FractionBox["1677", "800"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "4"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"3", ",", "\[Lambda]"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"2", ",", "\[Lambda]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Kappa]", "3"], "2", "\[Lambda]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "-", 
         FractionBox[
          RowBox[{"377", " ", 
           SubsuperscriptBox["g", "1", "8"]}], "250"], "-", 
         FractionBox[
          RowBox[{"1543", " ", 
           SubsuperscriptBox["g", "1", "6"], " ", 
           SubsuperscriptBox["g", "2", "2"]}], "1000"], "+", 
         RowBox[{
          FractionBox["13", "2"], " ", 
          SubsuperscriptBox["g", "1", "4"], " ", 
          SubsuperscriptBox["g", "2", "4"]}], "-", 
         FractionBox[
          RowBox[{"37889", " ", 
           SubsuperscriptBox["g", "1", "2"], " ", 
           SubsuperscriptBox["g", "2", "6"]}], "1000"], "-", 
         FractionBox[
          RowBox[{"114091", " ", 
           SubsuperscriptBox["g", "2", "8"]}], "1000"], "+", 
         RowBox[{
          SuperscriptBox["\[Lambda]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"46383", " ", 
               SubsuperscriptBox["g", "1", "4"]}], "250"]}], "-", 
            RowBox[{
             FractionBox["7916", "25"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "-", 
            FractionBox[
             RowBox[{"19757", " ", 
              SubsuperscriptBox["g", "2", "4"]}], "25"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"663", " ", 
              SubsuperscriptBox["g", "1", "6"]}], "1000"], "+", 
            RowBox[{
             FractionBox["221", "200"], " ", 
             SubsuperscriptBox["g", "1", "4"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "+", 
            FractionBox[
             RowBox[{"1507", " ", 
              SubsuperscriptBox["g", "1", "2"], " ", 
              SubsuperscriptBox["g", "2", "4"]}], "1000"], "+", 
            FractionBox[
             RowBox[{"942", " ", 
              SubsuperscriptBox["g", "2", "6"]}], "125"]}], ")"}], " ", 
          SubsuperscriptBox["g", "3", "2"]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          SubsuperscriptBox["g", "2", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"39819", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "500"], "+", 
            FractionBox[
             RowBox[{"865483", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "1000"], "-", 
            FractionBox[
             RowBox[{"7143", " ", 
              SubsuperscriptBox["g", "3", "2"]}], "125"]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          SubsuperscriptBox["g", "1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3521", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "125"], "+", 
            FractionBox[
             RowBox[{"61753", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "1000"], "-", 
            FractionBox[
             RowBox[{"8381", " ", 
              SubsuperscriptBox["g", "3", "2"]}], "1000"]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["g", "1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"11117", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "1000"], "+", 
            FractionBox[
             RowBox[{"10627", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "1000"]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["g", "2", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"13041", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "1000"], "+", 
            FractionBox[
             RowBox[{"125", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "2"]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"127", " ", 
              SubsuperscriptBox["g", "1", "4"]}], "125"], "+", 
            RowBox[{
             FractionBox["5693", "500"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "+", 
            FractionBox[
             RowBox[{"2058", " ", 
              SubsuperscriptBox["g", "2", "4"]}], "125"]}], ")"}], " ", 
          SubsuperscriptBox["g", "3", "2"], " ", 
          SubsuperscriptBox["g", "t", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"748599", " ", 
               SubsuperscriptBox["g", "1", "4"]}], "10000"]}], "+", 
            RowBox[{
             FractionBox["1123", "200"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "-", 
            FractionBox[
             RowBox[{"39958", " ", 
              SubsuperscriptBox["g", "2", "4"]}], "125"], "+", 
            RowBox[{
             FractionBox["8727", "500"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "3", "2"]}], "+", 
            FractionBox[
             RowBox[{"151443", " ", 
              SubsuperscriptBox["g", "2", "2"], " ", 
              SubsuperscriptBox["g", "3", "2"]}], "10000"], "+", 
            FractionBox[
             RowBox[{"44621", " ", 
              SubsuperscriptBox["g", "3", "4"]}], "125"]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3987", " ", 
              SubsuperscriptBox["g", "1", "4"]}], "250"], "-", 
            RowBox[{
             FractionBox["17589", "250"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "+", 
            FractionBox[
             RowBox[{"3971", " ", 
              SubsuperscriptBox["g", "2", "4"]}], "250"], "+", 
            RowBox[{
             FractionBox["1757", "100"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "3", "2"]}], "+", 
            FractionBox[
             RowBox[{"13349", " ", 
              SubsuperscriptBox["g", "2", "2"], " ", 
              SubsuperscriptBox["g", "3", "2"]}], "1000"], "-", 
            FractionBox[
             RowBox[{"50201", " ", 
              SubsuperscriptBox["g", "3", "4"]}], "1000"]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "4"]}], "+", 
         RowBox[{
          SubsuperscriptBox["g", "t", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3393", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "100"], "+", 
            FractionBox[
             RowBox[{"37069", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "500"], "+", 
            FractionBox[
             RowBox[{"125247", " ", 
              SubsuperscriptBox["g", "3", "2"]}], "500"], "-", 
            FractionBox[
             RowBox[{"243149", " ", 
              SubsuperscriptBox["g", "t", "2"]}], "1000"]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          SubsuperscriptBox["g", "t", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"4203", " ", 
               SubsuperscriptBox["g", "1", "2"]}], "200"]}], "-", 
            FractionBox[
             RowBox[{"547", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "100"], "-", 
            FractionBox[
             RowBox[{"331433", " ", 
              SubsuperscriptBox["g", "3", "2"]}], "500"], "-", 
            FractionBox[
             RowBox[{"111691", " ", 
              SubsuperscriptBox["g", "t", "2"]}], "500"]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Lambda]", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"120227", " ", "\[Lambda]"}], "20"], "-", 
            FractionBox[
             RowBox[{"7749", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "100"], "-", 
            FractionBox[
             RowBox[{"96863", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "250"], "+", 
            RowBox[{"873", " ", 
             SubsuperscriptBox["g", "t", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Lambda]", "2"], " ", 
          SubsuperscriptBox["g", "t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"63869", " ", 
               SubsuperscriptBox["g", "1", "2"]}], "1000"]}], "-", 
            FractionBox[
             RowBox[{"359539", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "1000"], "+", 
            FractionBox[
             RowBox[{"16077", " ", 
              SubsuperscriptBox["g", "3", "2"]}], "100"], "+", 
            FractionBox[
             RowBox[{"88413", " ", 
              SubsuperscriptBox["g", "t", "2"]}], "50"]}], ")"}]}]}], 
        ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"1", ",", 
       SubscriptBox["g", "t"]}], "]"}], ":=", 
     RowBox[{"\[Kappa]", " ", 
      SuperscriptBox[
       SubscriptBox["g", "t"], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["9", "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "t"], "2"]}], "+", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "b"], "2"]}], "+", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "2"]}], "-", 
        RowBox[{
         FractionBox["9", "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "2"]}], "-", 
        RowBox[{
         FractionBox["17", "20"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "t"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"1", ",", 
        SubscriptBox["g", "t"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "t"], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "-", 
            RowBox[{
             FractionBox["11", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "-", 
            RowBox[{
             FractionBox["9", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
            RowBox[{"12", " ", "\[Lambda]"}], "+", 
            RowBox[{"36", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["225", "16"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["393", "80"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "4"]}], " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "+", 
            RowBox[{
             FractionBox["5", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["99", "16"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["7", "80"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "4"]}], " ", 
             RowBox[{"(", 
              RowBox[{"9", " ", 
               SuperscriptBox[
                SubscriptBox["g", "\[Tau]"], "2"]}], ")"}]}], "+", 
            RowBox[{
             FractionBox["15", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["15", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Lambda]", "2"]}], "-", 
         RowBox[{"108", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "4"]}], "-", 
         RowBox[{
          FractionBox["23", "4"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "4"]}], "+", 
         RowBox[{
          FractionBox["1187", "600"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "4"]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "+", 
         RowBox[{
          FractionBox["19", "15"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "-", 
         RowBox[{
          FractionBox["9", "20"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"3", ",", 
       SubscriptBox["g", "t"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"2", ",", 
        SubscriptBox["g", "t"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "3"], " ", 
       SubsuperscriptBox["g", "t", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"16099", " ", 
           SubsuperscriptBox["g", "1", "6"]}], "1000"], "-", 
         RowBox[{
          FractionBox["2221", "500"], " ", 
          SubsuperscriptBox["g", "1", "4"], " ", 
          SubsuperscriptBox["g", "2", "2"]}], "-", 
         FractionBox[
          RowBox[{"4743", " ", 
           SubsuperscriptBox["g", "1", "2"], " ", 
           SubsuperscriptBox["g", "2", "4"]}], "1000"], "+", 
         FractionBox[
          RowBox[{"169829", " ", 
           SubsuperscriptBox["g", "2", "6"]}], "1000"], "+", 
         RowBox[{
          SuperscriptBox["\[Lambda]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "36"}], " ", "\[Lambda]"}], "+", 
            RowBox[{"9", " ", 
             SubsuperscriptBox["g", "1", "2"]}], "+", 
            RowBox[{"45", " ", 
             SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"1089", " ", 
               SubsuperscriptBox["g", "1", "4"]}], "400"]}], "+", 
            RowBox[{
             FractionBox["117", "40"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "-", 
            FractionBox[
             RowBox[{"171", " ", 
              SubsuperscriptBox["g", "2", "4"]}], "16"]}], ")"}]}], "-", 
         FractionBox[
          RowBox[{"22319", " ", 
           SubsuperscriptBox["g", "1", "4"], " ", 
           SubsuperscriptBox["g", "3", "2"]}], "1000"], "-", 
         RowBox[{
          FractionBox["321", "20"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          SubsuperscriptBox["g", "2", "2"], " ", 
          SubsuperscriptBox["g", "3", "2"]}], "-", 
         RowBox[{
          FractionBox["2634", "125"], " ", 
          SubsuperscriptBox["g", "2", "4"], " ", 
          SubsuperscriptBox["g", "3", "2"]}], "-", 
         RowBox[{
          FractionBox["1887", "125"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          SubsuperscriptBox["g", "3", "4"]}], "+", 
         RowBox[{
          FractionBox["36827", "500"], " ", 
          SubsuperscriptBox["g", "2", "2"], " ", 
          SubsuperscriptBox["g", "3", "4"]}], "-", 
         FractionBox[
          RowBox[{"12387", " ", 
           SubsuperscriptBox["g", "3", "6"]}], "20"], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"15", " ", "\[Lambda]"}], "4"], "-", 
            FractionBox[
             RowBox[{"127", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "10"], "-", 
            FractionBox[
             RowBox[{"135", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "2"], "+", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["g", "3", "2"]}]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"12211", " ", 
               SubsuperscriptBox["g", "1", "4"]}], "500"]}], "+", 
            FractionBox[
             RowBox[{"34829", " ", 
              SubsuperscriptBox["g", "1", "2"], " ", 
              SubsuperscriptBox["g", "2", "2"]}], "1000"], "+", 
            FractionBox[
             RowBox[{"1699", " ", 
              SubsuperscriptBox["g", "2", "4"]}], "100"], "+", 
            RowBox[{
             FractionBox["9037", "500"], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "3", "2"]}], "+", 
            RowBox[{
             FractionBox["4837", "100"], " ", 
             SubsuperscriptBox["g", "2", "2"], " ", 
             SubsuperscriptBox["g", "3", "2"]}], "+", 
            FractionBox[
             RowBox[{"90941", " ", 
              SubsuperscriptBox["g", "3", "4"]}], "250"]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["g", "t", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"198", " ", "\[Lambda]"}], "-", 
            FractionBox[
             RowBox[{"2437", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "80"], "-", 
            FractionBox[
             RowBox[{"1593", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "16"], "-", 
            RowBox[{"157", " ", 
             SubsuperscriptBox["g", "3", "2"]}], "+", 
            FractionBox[
             RowBox[{"146507", " ", 
              SubsuperscriptBox["g", "t", "2"]}], "2500"]}], ")"}]}]}], 
        ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
     "******)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"1", ",", 
       SubscriptBox["g", "b"]}], "]"}], ":=", 
     RowBox[{"\[Kappa]", " ", 
      SuperscriptBox[
       SubscriptBox["g", "b"], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["3", "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "t"], "2"]}], "+", 
        RowBox[{
         FractionBox["9", "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "b"], "2"]}], "+", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          SubscriptBox["g", "3"], "2"]}], "-", 
        RowBox[{
         FractionBox["9", "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "2"]}], "-", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "b"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"1", ",", 
        SubscriptBox["g", "b"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "b"], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "4"]}], " ", 
             SuperscriptBox[
              SubscriptBox["g", "t"], "2"]}], "-", 
            RowBox[{
             FractionBox["11", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "+", 
            RowBox[{
             FractionBox["5", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["99", "16"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["91", "80"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "-", 
            RowBox[{
             FractionBox["9", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
            RowBox[{"12", " ", "\[Lambda]"}], "+", 
            RowBox[{"36", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["225", "16"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["237", "80"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "4"]}], " ", 
             RowBox[{"(", 
              RowBox[{"9", " ", 
               SuperscriptBox[
                SubscriptBox["g", "\[Tau]"], "2"]}], ")"}]}], "+", 
            RowBox[{
             FractionBox["15", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["15", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Lambda]", "2"]}], "-", 
         RowBox[{"108", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "4"]}], "-", 
         RowBox[{
          FractionBox["23", "4"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "4"]}], "-", 
         RowBox[{
          FractionBox["127", "600"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "4"]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"]}], "+", 
         RowBox[{
          FractionBox["31", "15"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "3"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "-", 
         RowBox[{
          FractionBox["27", "20"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"3", ",", 
       SubscriptBox["g", "b"]}], "]"}], ":=", 
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "b"]}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"defined", " ", "for", " ", "convenience"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"**", "**", "**", "**", "**"}], "*******)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"1", ",", 
       SubscriptBox["g", "\[Tau]"]}], "]"}], ":=", 
     RowBox[{"\[Kappa]", " ", 
      SuperscriptBox[
       SubscriptBox["g", "\[Tau]"], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox["g", "t"], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox["g", "b"], "2"]}], "+", 
        RowBox[{
         FractionBox["5", "2"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
        RowBox[{
         FractionBox["9", "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "2"], "2"]}], "-", 
        RowBox[{
         FractionBox["9", "4"], " ", 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "\[Tau]"]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"SM\[Beta]", "[", 
       RowBox[{"1", ",", 
        SubscriptBox["g", "\[Tau]"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SuperscriptBox["\[Lambda]", "2"]}], "-", 
         RowBox[{
          FractionBox["23", "4"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "4"]}], "+", 
         RowBox[{
          FractionBox["1371", "200"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "4"]}], "+", 
         RowBox[{
          FractionBox["27", "20"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "2"], " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "4"]}], " ", 
             RowBox[{"(", 
              RowBox[{"27", " ", 
               SuperscriptBox[
                SubscriptBox["g", "t"], "2"]}], ")"}]}], "+", 
            RowBox[{
             FractionBox["3", "2"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "b"], "2"]}], "-", 
            RowBox[{
             FractionBox["27", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
            RowBox[{"20", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["45", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["17", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "4"]}], " ", 
             RowBox[{"(", 
              RowBox[{"27", " ", 
               SuperscriptBox[
                SubscriptBox["g", "b"], "2"]}], ")"}]}], "-", 
            RowBox[{
             FractionBox["27", "4"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
            RowBox[{"20", " ", 
             SuperscriptBox[
              SubscriptBox["g", "3"], "2"]}], "+", 
            RowBox[{
             FractionBox["45", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["5", "8"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["g", "\[Tau]"], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox[
              SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
            RowBox[{"12", " ", "\[Lambda]"}], "+", 
            RowBox[{
             FractionBox["165", "16"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "2"], "2"]}], "+", 
            RowBox[{
             FractionBox["537", "80"], " ", 
             SuperscriptBox[
              SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"3", ",", 
       SubscriptBox["g", "\[Tau]"]}], "]"}], ":=", 
     RowBox[{"SM\[Beta]", "[", 
      RowBox[{"2", ",", 
       SubscriptBox["g", "\[Tau]"]}], "]"}]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"defined", " ", "for", " ", "convenience"}], "*)"}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.619509535916149*^9, 3.619509638575777*^9}, {
   3.619510571627549*^9, 3.619510572993925*^9}, {3.619510867335615*^9, 
   3.6195108844955063`*^9}, {3.619511098783066*^9, 3.619511113692492*^9}, {
   3.619511149357335*^9, 3.6195111696118393`*^9}, {3.61952307666183*^9, 
   3.619523096507805*^9}, {3.619523249816845*^9, 3.61952327483714*^9}, {
   3.619523348784717*^9, 3.619523353727911*^9}, {3.619523409050211*^9, 
   3.619523436446224*^9}, {3.619523466694311*^9, 3.619523799471447*^9}, {
   3.619523832187036*^9, 3.619523834025763*^9}, {3.619523930212381*^9, 
   3.619523932857347*^9}, {3.619523973676613*^9, 3.6195239976678534`*^9}, {
   3.619524036003541*^9, 3.619524052147172*^9}, {3.619524205185267*^9, 
   3.61952428133179*^9}, {3.6195243179629087`*^9, 3.6195243226456623`*^9}, {
   3.619524474889927*^9, 3.619524547014398*^9}, {3.619524579732706*^9, 
   3.6195246430411253`*^9}, {3.619524679609295*^9, 3.619524683603201*^9}, {
   3.619524838392129*^9, 3.619524839269026*^9}, {3.619525340571638*^9, 
   3.6195253450384912`*^9}, {3.619525741274544*^9, 3.6195257484167347`*^9}, 
   3.619526747684413*^9, {3.6195267871464033`*^9, 3.619526826127368*^9}, {
   3.6195268800086517`*^9, 3.6195270072089577`*^9}, {3.6195270446613197`*^9, 
   3.619527116047083*^9}, {3.6195272242078867`*^9, 3.6195272637234983`*^9}, 
   3.6195301331401052`*^9, {3.6196854017369204`*^9, 3.6196854151381817`*^9}, {
   3.619685847286806*^9, 3.619685925108738*^9}, {3.619685976999894*^9, 
   3.6196860240140457`*^9}, {3.6196907497442417`*^9, 
   3.6196907762171497`*^9}, {3.619691004186102*^9, 3.619691006824308*^9}, {
   3.619691041476961*^9, 3.6196910440367193`*^9}, {3.619691095361607*^9, 
   3.6196910999139633`*^9}, {3.619691144649295*^9, 3.619691147316451*^9}, {
   3.6196938311773148`*^9, 3.619693832195434*^9}, {3.619694212453656*^9, 
   3.61969424497073*^9}, {3.619694459693757*^9, 3.619694628028319*^9}, {
   3.619694658500515*^9, 3.619694710712655*^9}, {3.619705220720221*^9, 
   3.619705314357561*^9}, {3.619705434250917*^9, 3.619705437991515*^9}, {
   3.619705515869739*^9, 3.61970551779552*^9}, {3.619707437756361*^9, 
   3.619707438157881*^9}, {3.619708062767351*^9, 3.6197080908050203`*^9}, {
   3.6197081405659*^9, 3.6197081803517523`*^9}, {3.619708331429428*^9, 
   3.619708347096169*^9}, {3.6197159625642776`*^9, 3.619715979953403*^9}, {
   3.619717901804819*^9, 3.6197181815216913`*^9}, {3.619718722157539*^9, 
   3.619718770405674*^9}, 3.6198499046257963`*^9, 3.619869083554284*^9, 
   3.619869212233857*^9, {3.619869929360292*^9, 3.61986993133668*^9}, {
   3.619870046254284*^9, 3.6198700469231567`*^9}, {3.619946043265233*^9, 
   3.619946070603774*^9}, {3.619946116015215*^9, 3.619946116601186*^9}, {
   3.619946275611806*^9, 3.6199462888857117`*^9}, {3.619951121753448*^9, 
   3.6199511734836683`*^9}, 3.619951255863991*^9, 3.619951470325738*^9, 
   3.61995158714047*^9, {3.619952374312475*^9, 3.619952383143793*^9}, {
   3.6199595464704103`*^9, 3.619959549032943*^9}, {3.619959648588567*^9, 
   3.619959649692128*^9}, {3.6199607002743883`*^9, 3.619960722758992*^9}, {
   3.6199608646112432`*^9, 3.619960866385002*^9}, 3.619977000205039*^9, 
   3.619977060631343*^9, {3.619977130160081*^9, 3.619977134266326*^9}, 
   3.619977207601475*^9, 3.619977248791363*^9, {3.619977319712809*^9, 
   3.6199773235825243`*^9}, {3.619977356534425*^9, 3.619977372199758*^9}, {
   3.619977420944738*^9, 3.619977421158847*^9}, {3.619977478333284*^9, 
   3.619977486634*^9}, {3.619978455012858*^9, 3.619978466130805*^9}, {
   3.620022093864769*^9, 3.620022140426762*^9}, {3.624967945599697*^9, 
   3.6249679483336697`*^9}, {3.624968070186414*^9, 3.624968075386507*^9}, 
   3.624968426407371*^9, {3.627061057375298*^9, 3.6270610591831017`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Running", "Section",
 CellChangeTimes->{{3.6249684710261097`*^9, 3.624968524046983*^9}, {
  3.6249689004697313`*^9, 3.6249689071733017`*^9}, {3.6249701195722723`*^9, 
  3.624970121348089*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SMrun", "[", 
   RowBox[{"variables_", ",", "init_", ",", "tmin_", ",", "tmax_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"equations", ",", "vars", ",", "reps"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"reps", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "1"], "->", "g1"}], ",", 
        RowBox[{
         SubscriptBox["g", "2"], "->", "g2"}], ",", 
        RowBox[{
         SubscriptBox["g", "3"], "->", "g3"}], ",", 
        RowBox[{
         SubscriptBox["g", "t"], "->", "gt"}], ",", 
        RowBox[{
         SubscriptBox["g", "\[Tau]"], "->", "g\[Tau]"}], ",", 
        RowBox[{
         SubscriptBox["g", "b"], "->", "gb"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"equations", "=", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", "t", "]"}], 
             RowBox[{
              RowBox[{"#", "'"}], "[", "t", "]"}]}], "\[Equal]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"SM\[Beta]", "[", 
               RowBox[{"3", ",", "#"}], "]"}], " ", "/.", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"#", "\[Rule]", 
                  RowBox[{"#", "[", "t", "]"}]}], "&"}], "/@", "variables"}], 
               ")"}]}], ")"}]}], "&"}], "/@", "variables"}], ",", "init"}], 
        "]"}], "/.", "reps"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vars", "=", 
      RowBox[{"variables", "/.", "reps"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"First", "[", 
      RowBox[{"NDSolve", "[", 
       RowBox[{"equations", ",", "vars", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
        RowBox[{"FilterRules", "[", 
         RowBox[{
          RowBox[{"{", "opts", "}"}], ",", 
          RowBox[{"Options", "[", "NDSolve", "]"}]}], "]"}]}], "]"}], 
      "]"}]}]}], " ", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"optsSMrun", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AccuracyGoal", "\[Rule]", "5"}], ",", 
     RowBox[{"PrecisionGoal", "\[Rule]", "5"}], ",", 
     RowBox[{"MaxSteps", "\[Rule]", "350"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$VersionNumber", "\[GreaterEqual]", "10"}], ",", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Shooting\>\"", ",", 
          RowBox[{"\"\<StartingInitialConditions\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[Lambda]", "[", "35", "]"}], "\[Equal]", "0.15"}], 
            "}"}]}]}], "}"}]}], ",", 
       RowBox[{"Method", "\[Rule]", "Automatic"}]}], "]"}]}], "}"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.619718406992728*^9, 3.619718407676568*^9}, {
   3.619718900530966*^9, 3.619718946689465*^9}, {3.619867563898479*^9, 
   3.619867620951013*^9}, {3.6198676540056877`*^9, 3.619867654292354*^9}, {
   3.6198677490897017`*^9, 3.619867778514296*^9}, {3.619868051659614*^9, 
   3.619868088362026*^9}, {3.619868129546776*^9, 3.619868150391461*^9}, {
   3.619868588156517*^9, 3.6198685883157253`*^9}, {3.619868871268096*^9, 
   3.619868871425868*^9}, {3.619868985410309*^9, 3.619868985553142*^9}, {
   3.619869038560424*^9, 3.619869038753227*^9}, {3.619871837318523*^9, 
   3.619871841846922*^9}, 3.6198719586770287`*^9, {3.6199524539651413`*^9, 
   3.6199524882679243`*^9}, {3.619953054378057*^9, 3.619953064122868*^9}, {
   3.619959812558391*^9, 3.619959838144959*^9}, {3.619960337138743*^9, 
   3.61996035862569*^9}, {3.6199768079863453`*^9, 3.6199768084580393`*^9}, {
   3.619976923696089*^9, 3.619976924258278*^9}, {3.620020275776877*^9, 
   3.620020282861834*^9}, {3.620020327005473*^9, 3.620020377054303*^9}, {
   3.620020458958733*^9, 3.6200204977729483`*^9}, {3.620020679298925*^9, 
   3.620020689922379*^9}, {3.620020951733536*^9, 3.620020955114091*^9}, {
   3.6200215671469307`*^9, 3.620021568994966*^9}, {3.620066142772053*^9, 
   3.620066142923394*^9}, {3.6200668120921593`*^9, 3.6200668457665243`*^9}, {
   3.620066909478797*^9, 3.620066909808599*^9}, {3.620066958851636*^9, 
   3.62006695903932*^9}, {3.620067141120864*^9, 3.6200671412571363`*^9}, {
   3.62030529016017*^9, 3.620305293309023*^9}, {3.6203070758664503`*^9, 
   3.620307076831778*^9}, {3.6205010027457438`*^9, 3.6205010426944*^9}, {
   3.620501147767933*^9, 3.620501149373744*^9}, {3.6228899994977694`*^9, 
   3.622890001193869*^9}, {3.622890116737813*^9, 3.622890134667392*^9}, {
   3.6249697576565447`*^9, 3.624969758485606*^9}, {3.634539504623122*^9, 
   3.63453951706104*^9}, {3.634842048666441*^9, 3.634842051137398*^9}, {
   3.6357083924681168`*^9, 3.635708415432173*^9}, {3.6386131271850967`*^9, 
   3.638613151904415*^9}, 3.638613184244478*^9, {3.638613291178438*^9, 
   3.6386132955011253`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Split RGEs", "Title",
 CellChangeTimes->{{3.6249699406583652`*^9, 3.6249699503965597`*^9}, {
  3.6347451998708363`*^9, 3.634745206214531*^9}}],

Cell["\<\
This sub-package solves the renormalization group equations of Split \
Supersymmetry. \
\>", "Text",
 CellChangeTimes->{{3.6249686900974903`*^9, 3.6249687454336567`*^9}, {
  3.624968793176572*^9, 3.624968844407144*^9}, {3.624970184930913*^9, 
  3.624970188770245*^9}, {3.6249702973195143`*^9, 3.624970311262919*^9}, {
  3.628061270970759*^9, 3.628061271122448*^9}, {3.635708447255609*^9, 
  3.635708455415186*^9}, {3.638559202458652*^9, 3.638559204841775*^9}}],

Cell[CellGroupData[{

Cell["Preambula", "Section",
 CellChangeTimes->{{3.624969952654285*^9, 3.62496995857996*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
    RowBox[{"Split\[Beta]", "::", "usage"}], "=", 
    "\"\<Split\[Beta][loops,coupling] gives the Split \[Beta]-function of a \
\!\(\*
StyleBox[\"coupling\",
FontSlant->\"Italic\"]\) up to a given order specified by \!\(\*
StyleBox[\"loops\",
FontSlant->\"Italic\"]\)\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Splitrun", "::", "usage"}], "=", 
    "\"\<run[variables,initialconds,tmin,tmax,opts] solves the coupled RGEs \
of the \!\(\*
StyleBox[\"variables\",
FontSlant->\"Italic\"]\) with the initial coditions given by \!\(\*
StyleBox[\"initialconds\",
FontSlant->\"Italic\"]\) between \!\(\*
StyleBox[\"tmin\",
FontSlant->\"Italic\"]\) and \!\(\*
StyleBox[\"tmax\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\".\",
FontSlant->\"Italic\"]\) \n It accepts the options of NDSolve. For time \
saving we recommend the \!\(\*
StyleBox[\"optsrun\",
FontSlant->\"Italic\"]\)\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"optsSplitrun", "::", "usage"}], "=", 
    "\"\<Default options for the function run. It selects the numerical \
method used by NDSolve and the precision goal\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"(*", 
     RowBox[{"\[Lambda]", ",", 
      SubscriptBox["g", "3"], ",", 
      SubscriptBox["g", "2"], ",", 
      SubscriptBox["g", "1"], ",", 
      SubscriptBox["g", "t"], ",", 
      SubscriptBox["g", "\[Tau]"], ",", 
      SubscriptBox["g", "b"], ",", "g3", ",", "g2", ",", "g1", ",", "gt", ",",
       "g\[Tau]", ",", "gb", ","}], "*)"}], 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], ",", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]], ",", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], ",", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], ",", "gtildeu", ",", "gtilde2u", ",", 
     "gtilded", ",", "gtilde2d"}], "}"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "The", " ", "names", " ", "of", " ", "the", " ", "couplings", " ", "are", 
    " ", "not", " ", 
    RowBox[{"encapsulated", "."}]}], "*)"}], "*)"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620020538209491*^9, 3.6200205562165127`*^9}, {
   3.62002058632047*^9, 3.620020611120508*^9}, {3.620020836953085*^9, 
   3.6200209055433197`*^9}, {3.620020940943014*^9, 3.620021024221815*^9}, {
   3.620021125372918*^9, 3.620021190347931*^9}, {3.6202897904185123`*^9, 
   3.620289840365484*^9}, {3.624972301228712*^9, 3.62497230241118*^9}, {
   3.634539988019163*^9, 3.634539997384295*^9}, {3.634541107134062*^9, 
   3.634541143909443*^9}, 3.6345411814223957`*^9, {3.634588018684475*^9, 
   3.634588019317367*^9}, 3.636021641110652*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Beta Functions", "Section",
 CellChangeTimes->{{3.620370105994863*^9, 3.620370113711244*^9}, {
  3.620371152139513*^9, 3.620371157210164*^9}, {3.624970016199293*^9, 
  3.624970018582839*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Split\[Beta]", "[", 
   RowBox[{"1", ",", "coupling_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"4", "\[Pi]"}], ")"}], "2"]], " ", 
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", "coupling", 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Split\[Beta]", "[", 
   RowBox[{"2", ",", "coupling_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]"}], ")"}], "2"]], " ", 
    RowBox[{
     SubscriptBox["\[Beta]", "1"], "[", "coupling", "]"}]}], "+", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]"}], ")"}], "4"]], 
    RowBox[{
     SubscriptBox["\[Beta]", "2"], "[", "coupling", "]"}]}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620371361179719*^9, 3.620371388936883*^9}, {
  3.6203714229999847`*^9, 3.62037144746386*^9}, {3.620375810023345*^9, 
  3.620375828311288*^9}, {3.620386536023602*^9, 3.6203865634458933`*^9}, {
  3.624971094974804*^9, 3.624971110703885*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "eqs. (26) : ",
 Cell[BoxData[
  FormBox["\[Beta]", TraditionalForm]]],
 " tilde"
}], "Subsubsection",
 CellChangeTimes->{{3.6186686297299557`*^9, 3.6186686434680977`*^9}, {
  3.618813409736869*^9, 3.6188134383050823`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[Beta]", "~"], "t"], ":=", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "~"], 
        RowBox[{"1", " ", "d"}]], "2"], "+", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "~"], 
        RowBox[{"1", " ", "u"}]], "2"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ";", " ", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[Beta]", "~"], "\[Lambda]"], ":=", 
   RowBox[{
    RowBox[{"2", " ", "\[Lambda]", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "d"}]], "2"], "+", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], "2"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "-", 
    SuperscriptBox[
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], "4"], "-", 
    SuperscriptBox[
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], "4"], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], "4"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]], "4"]}], "-", 
    RowBox[{"4", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "d"}]], "2"], "+", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], "2"], "+", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], "2"]}], ")"}]}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6186684291017637`*^9, 3.6186685227337713`*^9}, {
  3.618668574576021*^9, 3.6186686059792557`*^9}, {3.620454586417449*^9, 
  3.620454586532134*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq.  (35)-(36) : ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "1"], TraditionalForm]]],
 " "
}], "Subsubsection",
 CellChangeTimes->{{3.618662338588649*^9, 3.618662351142838*^9}, {
  3.6188133095387*^9, 3.618813324881247*^9}, {3.6189140614271803`*^9, 
  3.6189140668903522`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox["g", "1"], "]"}], ":=", 
   RowBox[{
    FractionBox["9", "2"], " ", 
    SuperscriptBox[
     SubscriptBox["g", "1"], "3"]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox["g", "2"], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7", "6"]}], " ", 
    SuperscriptBox[
     SubscriptBox["g", "2"], "3"]}]}], " ", ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox["g", "3"], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", "5"}], " ", 
    SuperscriptBox[
     SubscriptBox["g", "3"], "3"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox["g", "t"], "]"}], ":=", 
   RowBox[{
    SubscriptBox["g", "t"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Beta]", "~"], "t"], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "b"], "2"]}], "+", 
      SuperscriptBox[
       SubscriptBox["g", "\[Tau]"], "2"], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "t"], "2"]}], "-", 
      RowBox[{
       FractionBox["17", "20"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "1"], "2"]}], "-", 
      RowBox[{
       FractionBox["9", "4"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox[
        SubscriptBox["g", "3"], "2"]}]}], ")"}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox["g", "b"], "]"}], ":=", 
   RowBox[{
    SubscriptBox["g", "b"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Beta]", "~"], "t"], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "t"], "2"]}], "+", 
      SuperscriptBox[
       SubscriptBox["g", "\[Tau]"], "2"], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "b"], "2"]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "1"], "2"]}], "-", 
      RowBox[{
       FractionBox["9", "4"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox[
        SubscriptBox["g", "3"], "2"]}]}], ")"}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox["g", "\[Tau]"], "]"}], ":=", 
   RowBox[{
    SubscriptBox["g", "\[Tau]"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[Beta]", "~"], "t"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        SubscriptBox["g", "b"], "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        SubscriptBox["g", "t"], "2"]}], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
      RowBox[{
       FractionBox["9", "4"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "1"], "2"]}], "-", 
      RowBox[{
       FractionBox["9", "4"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"]}]}], ")"}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"2", " ", "u"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "+", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["3", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["11", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], "2"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"], "-", 
       RowBox[{
        FractionBox["9", "20"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "-", 
       RowBox[{
        FractionBox["33", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}]}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"2", " ", "d"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["3", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["11", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]], "2"], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"], "-", 
       RowBox[{
        FractionBox["9", "20"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "-", 
       RowBox[{
        FractionBox["33", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}]}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"1", " ", "u"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{"3", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["5", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"], "-", 
       RowBox[{
        FractionBox["9", "20"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}]}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"1", " ", "d"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{"3", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["5", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "+", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"], "-", 
       RowBox[{
        FractionBox["9", "20"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}]}], ")"}]}]}]}], ";", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "[", "\[Lambda]", "]"}], ":=", 
   RowBox[{
    RowBox[{"4", " ", "\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"]}], ")"}]}], "-", 
    RowBox[{"9", " ", "\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "5"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "4"]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["27", "100"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "4"]}], "+", 
    RowBox[{
     FractionBox["9", "10"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "2"], "2"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "2"]}], "+", 
    RowBox[{
     FractionBox["9", "4"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "2"], "4"]}], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["\[Lambda]", "2"]}], "+", 
    SubscriptBox[
     OverscriptBox["\[Beta]", "~"], "\[Lambda]"]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.618657462709778*^9, 3.618657517432454*^9}, {
   3.61865759449853*^9, 3.6186576176317663`*^9}, 3.618657804356395*^9, {
   3.618657844224222*^9, 3.618657849561694*^9}, {3.618659682362097*^9, 
   3.618659687119773*^9}, {3.618660670514948*^9, 3.618660691371705*^9}, {
   3.618660805325832*^9, 3.618660812570649*^9}, {3.6186609301591663`*^9, 
   3.618660931954863*^9}, {3.618661048274632*^9, 3.61866105221418*^9}, {
   3.618661213672481*^9, 3.6186612145150623`*^9}, {3.61866385392264*^9, 
   3.618663868408347*^9}, {3.6189140737437277`*^9, 3.618914075483987*^9}, {
   3.6204545754759274`*^9, 3.620454579406288*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq. (37) - (39) : ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "2"], TraditionalForm]]],
 " of the gauge couplings"
}], "Subsubsection",
 CellChangeTimes->{{3.618662358080781*^9, 3.6186623723458853`*^9}, {
  3.618813333977373*^9, 3.6188133426253433`*^9}, {3.6280611711636353`*^9, 
  3.628061188458211*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox["g", "1"], "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["g", "1"], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "20"], " ", 
       RowBox[{"(", 
        RowBox[{"-", "3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"1", " ", "d"}]], "2"], "+", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["9", "20"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "d"}]], "2"], "+", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "u"}]], "2"]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "b"], "2"]}], "-", 
      RowBox[{
       FractionBox["17", "10"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "t"], "2"]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
      RowBox[{
       FractionBox["104", "25"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "1"], "2"]}], "+", 
      RowBox[{
       FractionBox["18", "5"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"]}], "+", 
      RowBox[{
       FractionBox["44", "5"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "3"], "2"]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox["g", "2"], "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["g", "2"], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"1", " ", "d"}]], "2"], "+", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["11", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "d"}]], "2"], "+", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "u"}]], "2"]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox[
           SubscriptBox["g", "b"], "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           SubscriptBox["g", "t"], "2"]}], "+", 
         SuperscriptBox[
          SubscriptBox["g", "\[Tau]"], "2"]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["6", "5"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "1"], "2"]}], "+", 
      RowBox[{
       FractionBox["106", "3"], " ", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        SubscriptBox["g", "3"], "2"]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Beta]", "2"], "[", 
   SubscriptBox["g", "3"], "]"}], ":=", 
  RowBox[{
   SuperscriptBox[
    SubscriptBox["g", "3"], "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"], "+", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["11", "10"], " ", 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}], "+", 
     RowBox[{
      FractionBox["9", "2"], " ", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "2"]}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox[
       SubscriptBox["g", "3"], "2"]}]}], ")"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6186620945723763`*^9, 3.6186621518113413`*^9}, {
  3.6186622554600763`*^9, 3.618662293519642*^9}, {3.618664542546657*^9, 
  3.618664551610643*^9}, {3.6204545794407253`*^9, 3.620454579572956*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eqs. (40) - (47): ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "2"], TraditionalForm]]],
 " of the rest of the couplings"
}], "Subsubsection",
 CellChangeTimes->{{3.618664486815435*^9, 3.618664497511174*^9}, {
  3.618813348257106*^9, 3.618813354937455*^9}, {3.6280611905937033`*^9, 
  3.628061196056924*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox["g", "t"], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", 
     SuperscriptBox[
      SubscriptBox["g", "t"], "5"]}], "+", 
    RowBox[{
     SubscriptBox["g", "t"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "4"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
          RowBox[{
           FractionBox["7", "80"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["99", "16"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "-", 
          RowBox[{
           FractionBox["9", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{
           FractionBox["19", "15"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["5", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["3", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
       RowBox[{
        FractionBox["1303", "600"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{
        FractionBox["17", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "-", 
       RowBox[{
        FractionBox["284", "3"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "4"]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "2"]}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "t"], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "8"]}], " ", 
        RowBox[{"(", 
         RowBox[{"9", " ", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["11", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
       RowBox[{
        FractionBox["393", "80"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["225", "16"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "+", 
       RowBox[{"36", " ", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "2"]}], "-", 
       RowBox[{"6", " ", "\[Lambda]"}]}], ")"}]}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox["g", "b"], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", 
     SuperscriptBox[
      SubscriptBox["g", "b"], "5"]}], "+", 
    RowBox[{
     SubscriptBox["g", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "4"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
          RowBox[{
           FractionBox["91", "80"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["99", "16"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "-", 
          RowBox[{
           FractionBox["27", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{
           FractionBox["31", "15"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["5", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["3", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
       RowBox[{
        FractionBox["131", "600"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{
        FractionBox["17", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "-", 
       RowBox[{
        FractionBox["284", "3"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "4"]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "2"]}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "b"], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "8"]}], " ", 
        RowBox[{"(", 
         RowBox[{"9", " ", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["11", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
       RowBox[{
        FractionBox["237", "80"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["225", "16"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "+", 
       RowBox[{"36", " ", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "2"]}], "-", 
       RowBox[{"6", " ", "\[Lambda]"}]}], ")"}]}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox["g", "\[Tau]"], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox[
      SubscriptBox["g", "\[Tau]"], "5"]}], "+", 
    RowBox[{
     SubscriptBox["g", "\[Tau]"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["27", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["5", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["3", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["3", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "+", 
       RowBox[{
        FractionBox["1503", "200"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{
        FractionBox["17", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "2"]}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "\[Tau]"], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "8"]}], " ", 
        RowBox[{"(", 
         RowBox[{"9", " ", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "+", 
       RowBox[{
        FractionBox["537", "80"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["165", "16"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "-", 
       RowBox[{"6", " ", "\[Lambda]"}]}], ")"}]}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"2", " ", "u"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["63", "160"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "20"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["111", "32"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["13", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "4"]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "8"]}], " ", 
           RowBox[{"(", 
            RowBox[{"9", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["3", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "8"]}], " ", 
           RowBox[{"(", 
            RowBox[{"9", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["3", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}]], "2"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "8"]}], " ", 
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["31", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["5", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["11", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"]}], "+", 
       RowBox[{
        FractionBox["117", "200"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{
        FractionBox["409", "12"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "2"]}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "16"]}], " ", 
        RowBox[{"(", 
         RowBox[{"15", " ", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["59", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["15", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
       RowBox[{
        FractionBox["87", "32"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["875", "32"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "-", 
       RowBox[{"5", " ", "\[Lambda]"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]], "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox[
      SubscriptBox["g", "b"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "-", 
    RowBox[{"\[Lambda]", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox[
      SubscriptBox["g", "t"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "-", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "\[Tau]"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "-", 
    RowBox[{
     FractionBox["9", "4"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], "3"]}], "-", 
    RowBox[{
     FractionBox["3", "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "-", 
    RowBox[{
     FractionBox["5", "4"], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "+", 
    RowBox[{
     FractionBox["3", "20"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "+", 
    RowBox[{
     FractionBox["9", "4"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "2"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"7", " ", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]], "5"]}], ")"}]}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"2", " ", "d"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["63", "160"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "20"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["111", "32"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "8"]}], " ", 
           RowBox[{"(", 
            RowBox[{"9", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["3", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "8"]}], " ", 
           RowBox[{"(", 
            RowBox[{"9", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["3", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}]], "2"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "8"]}], " ", 
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "+", 
          RowBox[{
           FractionBox["1", "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["31", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["5", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["13", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["11", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"]}], "+", 
       RowBox[{
        FractionBox["117", "200"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{
        FractionBox["409", "12"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "2"]}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "16"]}], " ", 
        RowBox[{"(", 
         RowBox[{"59", " ", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["15", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["15", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
       RowBox[{
        FractionBox["87", "32"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["875", "32"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "-", 
       RowBox[{"5", " ", "\[Lambda]"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox[
      SubscriptBox["g", "b"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"\[Lambda]", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox[
      SubscriptBox["g", "t"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "\[Tau]"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["9", "4"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]], "3"]}], "-", 
    RowBox[{
     FractionBox["5", "4"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["3", "2"], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     FractionBox["3", "20"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     FractionBox["9", "4"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "2"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"7", " ", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], "5"]}], ")"}]}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"1", " ", "u"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["3", "40"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["189", "160"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "-", 
          RowBox[{
           FractionBox["27", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["39", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["549", "32"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["75", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "4"]}], " ", 
           RowBox[{"(", 
            RowBox[{"21", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
          RowBox[{
           FractionBox["27", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "4"]}], " ", 
           RowBox[{"(", 
            RowBox[{"21", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
          RowBox[{
           FractionBox["27", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", "\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}]], "2"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "4"]}], " ", 
           RowBox[{"(", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
          RowBox[{
           FractionBox["9", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["75", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["21", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["99", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"]}], "+", 
       RowBox[{
        FractionBox["117", "200"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{
        FractionBox["17", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "2"]}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"15", " ", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["27", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
       RowBox[{
        FractionBox["309", "160"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["165", "32"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "-", 
       RowBox[{"3", " ", "\[Lambda]"}]}], ")"}]}], "-", 
    RowBox[{"6", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"9", " ", 
     SuperscriptBox[
      SubscriptBox["g", "b"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"3", " ", "\[Lambda]", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"9", " ", 
     SuperscriptBox[
      SubscriptBox["g", "t"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox[
      SubscriptBox["g", "\[Tau]"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["9", "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]], "3"]}], "-", 
    RowBox[{
     FractionBox["33", "4"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["9", "4"], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     FractionBox["9", "20"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     FractionBox["51", "4"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "2"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], "5"]}], ")"}]}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", 
    SubscriptBox[
     OverscriptBox["g", "~"], 
     RowBox[{"1", " ", "d"}]], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "d"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["3", "40"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["189", "160"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["9", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "-", 
          RowBox[{
           FractionBox["27", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["39", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["549", "32"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["165", "16"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "4"]}], " ", 
           RowBox[{"(", 
            RowBox[{"21", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "-", 
          RowBox[{
           FractionBox["27", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "4"]}], " ", 
           RowBox[{"(", 
            RowBox[{"21", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "-", 
          RowBox[{
           FractionBox["27", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}], "+", 
          RowBox[{"20", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", "\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}]], "2"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "4"]}], " ", 
           RowBox[{"(", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "-", 
          RowBox[{
           FractionBox["9", "8"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "8"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["75", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["75", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["21", "8"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["99", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["45", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "-", 
       RowBox[{
        FractionBox["27", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "-", 
       RowBox[{
        FractionBox["9", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"]}], "+", 
       RowBox[{
        FractionBox["117", "200"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "-", 
       RowBox[{
        FractionBox["17", "4"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "2"]}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", 
        RowBox[{"(", 
         RowBox[{"15", " ", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["9", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "16"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["27", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
       RowBox[{
        FractionBox["309", "160"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["165", "32"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "-", 
       RowBox[{"3", " ", "\[Lambda]"}]}], ")"}]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "5"]}], "-", 
    RowBox[{"9", " ", 
     SuperscriptBox[
      SubscriptBox["g", "b"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"3", " ", "\[Lambda]", " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"9", " ", 
     SuperscriptBox[
      SubscriptBox["g", "t"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox[
      SubscriptBox["g", "\[Tau]"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["33", "4"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]], "3"]}], "-", 
    RowBox[{
     FractionBox["9", "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "-", 
    RowBox[{
     FractionBox["9", "4"], " ", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "3"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     FractionBox["9", "20"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}], "+", 
    RowBox[{
     FractionBox["51", "4"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "2"], "2"], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"1", " ", "u"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "d"}]], " ", 
     SubscriptBox[
      OverscriptBox["g", "~"], 
      RowBox[{"2", " ", "u"}]]}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "[", "\[Lambda]", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "78"}], " ", 
     SuperscriptBox["\[Lambda]", "3"]}], "-", 
    FractionBox[
     RowBox[{"3699", " ", 
      SuperscriptBox[
       SubscriptBox["g", "1"], "6"]}], "1000"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["9", "10"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["171", "50"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "100"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "2"], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "4"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["8", "5"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "-", 
       RowBox[{
        FractionBox["16", "5"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "-", 
       RowBox[{
        FractionBox["24", "5"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "4"]}]}], ")"}], " ", 
     SuperscriptBox[
      SubscriptBox["g", "1"], "2"]}], "+", 
    RowBox[{
     FractionBox["209", "8"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "2"], "6"]}], "+", 
    RowBox[{"20", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "6"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "6"]}], "+", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "6"]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox[
      SubscriptBox["g", "3"], "2"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "b"], "4"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "2"]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}]}], ")"}], " ", 
     SuperscriptBox[
      SubscriptBox["g", "t"], "4"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox[
      SubscriptBox["g", "b"], "4"], " ", 
     SuperscriptBox[
      SubscriptBox["g", "t"], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["\[Lambda]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["54", "5"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{"54", " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], "-", 
       RowBox[{"72", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{"72", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{"24", " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "2"], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "2"], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "8"]}], " ", 
        RowBox[{"(", 
         RowBox[{"77", " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "2"]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["9", "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "-", 
       RowBox[{
        FractionBox["9", "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "-", 
       RowBox[{
        FractionBox["3", "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
       RowBox[{
        FractionBox["3", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "2"], "+", 
          RowBox[{"51", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{"51", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "2"], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "200"]}], " ", 
        RowBox[{"(", 
         RowBox[{"1773", " ", 
          SuperscriptBox[
           SubscriptBox["g", "1"], "4"]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["27", "5"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["63", "5"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "t"], "2"]}], "+", 
          RowBox[{
           FractionBox["33", "5"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "\[Tau]"], "2"]}], "-", 
          RowBox[{
           FractionBox["3", "10"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"], "+", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"], "-", 
             RowBox[{"21", " ", 
              SuperscriptBox[
               SubscriptBox[
                OverscriptBox["g", "~"], 
                RowBox[{"2", " ", "d"}]], "2"]}], "-", 
             RowBox[{"21", " ", 
              SuperscriptBox[
               SubscriptBox[
                OverscriptBox["g", "~"], 
                RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "-", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "4"]}], "+", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}]], " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}]]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "4"]}], "+", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["2007", "200"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["5", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["17", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "t"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
          RowBox[{
           FractionBox["3", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"], "+", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               SubscriptBox[
                OverscriptBox["g", "~"], 
                RowBox[{"2", " ", "d"}]], "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               SubscriptBox[
                OverscriptBox["g", "~"], 
                RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         SubscriptBox["g", "1"], "2"]}], "+", 
       RowBox[{
        FractionBox["47", "8"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "4"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "4"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "4"]}], "-", 
       SuperscriptBox[
        SubscriptBox["g", "\[Tau]"], "4"], "+", 
       RowBox[{"80", " ", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "2"], " ", 
        SuperscriptBox[
         SubscriptBox["g", "b"], "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"80", " ", 
           SuperscriptBox[
            SubscriptBox["g", "3"], "2"]}], "-", 
          RowBox[{"42", " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}], "+", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "4"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"2", " ", "d"}]], "2"], "-", 
             RowBox[{"6", " ", 
              SuperscriptBox[
               SubscriptBox[
                OverscriptBox["g", "~"], 
                RowBox[{"1", " ", "u"}]], "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{"80", " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}]], " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}]], " ", 
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]]}], "-", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "4"], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "4"]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "4"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "-", 
          RowBox[{"44", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["117", "20"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "b"], "2"]}], "+", 
          RowBox[{
           FractionBox["45", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "t"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "2"], " ", 
           SuperscriptBox[
            SubscriptBox["g", "\[Tau]"], "2"]}], "+", 
          RowBox[{
           FractionBox["15", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}]], "2"], "+", 
             SuperscriptBox[
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}]], "2"], "+", 
             RowBox[{"11", " ", 
              SuperscriptBox[
               SubscriptBox[
                OverscriptBox["g", "~"], 
                RowBox[{"2", " ", "d"}]], "2"]}], "+", 
             RowBox[{"11", " ", 
              SuperscriptBox[
               SubscriptBox[
                OverscriptBox["g", "~"], 
                RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"47", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}]], "6"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}]], "6"]}], ")"}]}], "+", 
       RowBox[{"5", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "6"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "6"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"42", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"]}], "+", 
          RowBox[{"42", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{"38", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{"38", " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}]}], ")"}]}], "+", 
       RowBox[{"19", " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}]], "2"]}], ")"}]}], "+", 
       RowBox[{"21", " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"], " ", 
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}]], "2"]}], ")"}]}], "+", 
       RowBox[{"17", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "4"]}], "+", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "4"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "2"]}]}], ")"}]}], "+", 
       RowBox[{"11", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], "4"]}], "+", 
          RowBox[{
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], "2"], " ", 
           SuperscriptBox[
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], "4"]}]}], ")"}]}], "+", 
       RowBox[{"7", " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"], " ", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}]], "2"], "+", 
          SuperscriptBox[
           SubscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}]], "2"]}], ")"}]}]}], ")"}]}]}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.618663621735489*^9, 3.618663812438902*^9}, {
   3.618663995542984*^9, 3.618664066756797*^9}, {3.618664139051688*^9, 
   3.6186642025484056`*^9}, {3.618664278901271*^9, 3.618664280776688*^9}, {
   3.6186643188071337`*^9, 3.618664330357872*^9}, {3.61866440642457*^9, 
   3.6186644407808733`*^9}, 3.618664522092512*^9, {3.6187362018710413`*^9, 
   3.6187362034407187`*^9}, {3.6187368062702208`*^9, 
   3.6187368210488358`*^9}, {3.6204545796280317`*^9, 3.620454586398569*^9}, {
   3.620455055676458*^9, 3.620455062034885*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"**", "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
                    "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
              "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], "**"}], 
      "**"}], "**"}], "**"}], "**"}], "*******)"}]], "Input",
 CellChangeTimes->{{3.62029012407299*^9, 3.6202901328901367`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Running", "Section",
 CellChangeTimes->{{3.620455846054335*^9, 3.620455854812232*^9}, {
  3.6249701012366*^9, 3.62497011307627*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Splitrun", "[", 
   RowBox[{"variables_", ",", "init_", ",", "tmin_", ",", "tmax_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"equations", ",", "vars", ",", "reps"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"reps", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "1"], "->", "g1"}], ",", 
        RowBox[{
         SubscriptBox["g", "2"], "->", "g2"}], ",", 
        RowBox[{
         SubscriptBox["g", "3"], "->", "g3"}], ",", 
        RowBox[{
         SubscriptBox["g", "t"], "->", "gt"}], ",", 
        RowBox[{
         SubscriptBox["g", "\[Tau]"], "->", "g\[Tau]"}], ",", 
        RowBox[{
         SubscriptBox["g", "b"], "->", "gb"}], ",", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "->", "gtildeu"}], ",", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "->", "gtilde2u"}], ",", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "->", "gtilded"}], ",", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "->", "gtilde2d"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"equations", "=", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "'"}], "[", "t", "]"}], "\[Equal]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Split\[Beta]", "[", 
               RowBox[{"2", ",", "#"}], "]"}], " ", "/.", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"#", "\[Rule]", 
                  RowBox[{"#", "[", "t", "]"}]}], "&"}], "/@", "variables"}], 
               ")"}]}], ")"}]}], "&"}], "/@", "variables"}], ",", "init"}], 
        "]"}], "/.", "reps"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vars", "=", 
      RowBox[{"variables", "/.", "reps"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"First", "[", 
      RowBox[{"NDSolve", "[", 
       RowBox[{"equations", ",", "vars", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
        RowBox[{"FilterRules", "[", 
         RowBox[{
          RowBox[{"{", "opts", "}"}], ",", 
          RowBox[{"Options", "[", "NDSolve", "]"}]}], "]"}]}], "]"}], 
      "]"}]}]}], " ", "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"optsSplitrun", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AccuracyGoal", "\[Rule]", "5"}], ",", 
     RowBox[{"PrecisionGoal", "\[Rule]", "5"}], ",", 
     RowBox[{"MaxSteps", "\[Rule]", "200"}]}], "}"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.619718406992728*^9, 3.619718407676568*^9}, {
   3.619718900530966*^9, 3.619718946689465*^9}, {3.619867563898479*^9, 
   3.619867620951013*^9}, {3.6198676540056877`*^9, 3.619867654292354*^9}, {
   3.6198677490897017`*^9, 3.619867778514296*^9}, {3.619868051659614*^9, 
   3.619868088362026*^9}, {3.619868129546776*^9, 3.619868150391461*^9}, {
   3.619868588156517*^9, 3.6198685883157253`*^9}, {3.619868871268096*^9, 
   3.619868871425868*^9}, {3.619868985410309*^9, 3.619868985553142*^9}, {
   3.619869038560424*^9, 3.619869038753227*^9}, {3.619871837318523*^9, 
   3.619871841846922*^9}, 3.6198719586770287`*^9, {3.6199524539651413`*^9, 
   3.6199524882679243`*^9}, {3.619953054378057*^9, 3.619953064122868*^9}, {
   3.619959812558391*^9, 3.619959838144959*^9}, {3.619960337138743*^9, 
   3.61996035862569*^9}, {3.6199768079863453`*^9, 3.6199768084580393`*^9}, {
   3.619976923696089*^9, 3.619976924258278*^9}, {3.620020275776877*^9, 
   3.620020282861834*^9}, {3.620020327005473*^9, 3.620020377054303*^9}, {
   3.620020458958733*^9, 3.6200204977729483`*^9}, {3.620020679298925*^9, 
   3.620020689922379*^9}, {3.620020951733536*^9, 3.620020955114091*^9}, {
   3.6200215671469307`*^9, 3.620021568994966*^9}, {3.620066142772053*^9, 
   3.620066142923394*^9}, {3.6200668120921593`*^9, 3.6200668457665243`*^9}, {
   3.620066909478797*^9, 3.620066909808599*^9}, {3.620066958851636*^9, 
   3.62006695903932*^9}, {3.620067141120864*^9, 3.6200671412571363`*^9}, {
   3.620290034575245*^9, 3.6202900485791273`*^9}, {3.6203015431993856`*^9, 
   3.620301544388996*^9}, {3.6203015777278852`*^9, 3.620301588370308*^9}, {
   3.620301643644878*^9, 3.620301649196721*^9}, {3.620301975475741*^9, 
   3.6203019764961987`*^9}, {3.620302088834682*^9, 3.620302173933475*^9}, {
   3.620302392823045*^9, 3.620302442807501*^9}, {3.620305725117692*^9, 
   3.620305738635519*^9}, {3.6203204471196957`*^9, 3.62032048135445*^9}, {
   3.620463619840773*^9, 3.620463620863633*^9}, 3.624970149436331*^9, {
   3.634540170471382*^9, 3.6345402223032513`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUSY Thresholds", "Title",
 CellChangeTimes->{{3.620242366836763*^9, 3.6202424117136993`*^9}, {
  3.620243214642*^9, 3.620243214993498*^9}, {3.638610632551381*^9, 
  3.6386106333634157`*^9}}],

Cell["\<\
This sub-package contains the threshold corrections to the quartic coupling \
of the Higgs in High Scale Supersymmetry and Split Supersymmetry. \
\>", "Text",
 CellChangeTimes->{{3.620024332925829*^9, 3.620024399986741*^9}, {
   3.620242427199189*^9, 3.620242519517866*^9}, {3.620243220736781*^9, 
   3.620243225297827*^9}, 3.62806132277988*^9, {3.628061389576995*^9, 
   3.628061421665002*^9}, {3.6280620317486553`*^9, 3.6280620628366823`*^9}, {
   3.62806210558204*^9, 3.628062116818376*^9}, {3.628062165476777*^9, 
   3.62806218779582*^9}, 3.63570849224691*^9, {3.638559313801805*^9, 
   3.638559325594356*^9}}],

Cell[CellGroupData[{

Cell["Preambula", "Section",
 CellChangeTimes->{{3.620548286922056*^9, 3.6205482965080748`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]HSS", "::", "usage"}], "=", 
    "\"\<\[Lambda]HSS[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the thresholds \
to the quartic coupling at scale of the scalar masses in High Scale \
Supersymmetry.\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hiOrd", "::", "usage"}], "=", 
    "\"\<controls the inclusion of higher-order corrections\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"scheme", "::", "usage"}], "=", 
    "\"\<chooses the renormalization scheme\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"suppressedCorrections", "::", "usage"}], "=", 
    "\"\<\!\(\*SuperscriptBox[\(v\), \
\(2\)]\)/\!\(\*SuperscriptBox[OverscriptBox[\(m\), \(~\)], \
\(2\)]\)-suppressed corrections\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]Splitscalars", "::", "usage"}], "=", 
    "\"\<\[Lambda]Splitscalars[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the thresholds \
to the quartic coupling at the mass of the scalars in Split \
Supersymmetry.\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]SMsplit", "::", "usage"}], "=", 
    "\"\<\[Lambda]SMsplit[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the quartic \
coupling of the Standard Model at the scale of the fermions obtained after \
integrating out all the supersymmetric particles.\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gtSplitsplit", "::", "usage"}], "=", 
    "\"\<gtSplitsplit[\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\)] computes the top Yukawa coupling just above the scale of the \
fermion masses in Split Supersymmetry.\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1umtilde", "::", "usage"}], "=", 
    "\"\<g1umtilde[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(1\)]]\),\!\
\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the \
Higgs-higgsino-gaugino coupling at the mass of the scalar masses including \
the one-loop thresholds corrections.\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2umtilde", "::", "usage"}], "=", 
    "\"\<g2umtilde[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(1\)]]\),\!\
\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the \
Higgs-higgsino-gaugino coupling at the mass of the scalar masses including \
the one-loop thresholds corrections.\>\""}], ";", 
   RowBox[{
    RowBox[{"g1dmtilde", "::", "usage"}], "=", 
    "\"\<g1dmtilde[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(1\)]]\),\!\
\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the \
Higgs-higgsino-gaugino coupling at the mass of the scalar masses including \
the one-loop thresholds corrections.\>\""}], ";", 
   RowBox[{
    RowBox[{"g2dmtilde", "::", "usage"}], "=", 
    "\"\<g2dmtilde[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \(1\)]]\),\!\
\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(1\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(2\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), \(A\)]\),\[Mu],\!\(\*SubscriptBox[\(M\), \
\(1\)]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the \
Higgs-higgsino-gaugino coupling at the mass of the scalar masses including \
the one-loop thresholds corrections.\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gbDR", "::", "usage"}], "=", 
    "\"\<gbDR[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(Q\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(U\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(D\), \
\(3\)]]\),\!\(\*SubscriptBox[\(M\), \
\(3\)]\),\[Mu],tan\[Beta],\!\(\*SubscriptBox[\(X\), \(t\)]\)] computes the \!\
\(\*OverscriptBox[\(DR\), \(_\)]\) bottom Yukawa.\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gtauDR", "::", "usage"}], "=", 
    "\"\<gtauDR[\!\(\*SubscriptBox[\(m\), SubscriptBox[\(L\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(E\), \
\(3\)]]\),\!\(\*SubscriptBox[\(m\), SubscriptBox[\(N\), \
\(3\)]]\),\!\(\*SubscriptBox[\(M\), \(2\)]\),\!\(\*SubscriptBox[\(M\), \(1\)]\
\),\[Mu],tan\[Beta]] computes the \!\(\*OverscriptBox[\(DR\), \(_\)]\) bottom \
Yukawa.\>\""}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]HSS1lsuppressed", "::", "usage"}], "=", 
    "\"\<It is used to estimate the \!\(\*SuperscriptBox[\(v\), \(2\)]\)/\!\(\
\*SuperscriptBox[SubscriptBox[\(m\), \(SUSY\)], \(2\)]\)-suppressed \
corrections.\>\""}]}], "*)"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620040712967806*^9, 3.620040853721449*^9}, {
   3.620041147328121*^9, 3.620041161742852*^9}, {3.6202432323332*^9, 
   3.620243309317051*^9}, {3.620310674595845*^9, 3.620310678233266*^9}, {
   3.620311519556712*^9, 3.6203115498756638`*^9}, {3.62032271488181*^9, 
   3.6203227193127623`*^9}, {3.6205406179366217`*^9, 
   3.6205406614645844`*^9}, {3.620540780504744*^9, 3.6205407810954237`*^9}, {
   3.6205408472401237`*^9, 3.6205408540715113`*^9}, {3.620540988655677*^9, 
   3.6205410203824797`*^9}, {3.6205410545194483`*^9, 3.620541141814281*^9}, {
   3.6205412198143578`*^9, 3.620541220146373*^9}, {3.620541250691324*^9, 
   3.620541333930626*^9}, {3.620541448452393*^9, 3.620541527125373*^9}, {
   3.6252578608273907`*^9, 3.625257908798497*^9}, 3.6280638967240477`*^9, {
   3.634647066231276*^9, 3.634647111643568*^9}, {3.6346739293003073`*^9, 
   3.6346739305251503`*^9}, 3.63467445381236*^9, {3.6358465484068747`*^9, 
   3.6358465497227087`*^9}, {3.636021150700169*^9, 3.636021218070415*^9}, {
   3.636196944988612*^9, 3.636197022264021*^9}, {3.636364219440333*^9, 
   3.636364226020605*^9}, {3.63636683102892*^9, 3.636366832489065*^9}, 
   3.6363668768650217`*^9, {3.6363669268903522`*^9, 3.6363669599774837`*^9}, {
   3.6363670098019876`*^9, 3.636367025068926*^9}, {3.63636708581352*^9, 
   3.636367094851802*^9}, {3.636367126079854*^9, 3.636367193294479*^9}, {
   3.636705815876677*^9, 3.636705881679737*^9}, 3.636706317620638*^9, 
   3.6381184269067583`*^9, {3.6385593811844997`*^9, 3.638559449942017*^9}, {
   3.6385601065822353`*^9, 3.638560117969658*^9}, {3.638560227516461*^9, 
   3.638560254084999*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Thresholds MSSM", "Section",
 CellChangeTimes->{{3.620548261883444*^9, 3.62054827104527*^9}, {
  3.6205483125035152`*^9, 3.6205483139513407`*^9}}],

Cell[CellGroupData[{

Cell["One Loop", "Subsection",
 CellChangeTimes->{{3.622265901801799*^9, 3.6222659113806067`*^9}}],

Cell[CellGroupData[{

Cell["Expressions one-loop", "Subsubsection",
 CellChangeTimes->{{3.622265846412086*^9, 3.62226585801775*^9}, {
  3.622312336515005*^9, 3.622312379362548*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{"\[Lambda]HSS1laux", ":=", 
  RowBox[{
  "\[Lambda]tree", "+", "\[CapitalDelta]\[Lambda]1lreg", "+", 
   "\[CapitalDelta]\[Lambda]1l\[Phi]", "+", 
   "\[CapitalDelta]\[Lambda]1l\[Chi]1HSS", "+", 
   "\[CapitalDelta]\[Lambda]1l\[Chi]2"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Lambda]HSS1lsuppressedaux", ":=", 
  RowBox[{
   RowBox[{"factorscalars", " ", "\[CapitalDelta]\[Lambda]1l\[Phi]"}], "+", 
   RowBox[{"factorfermions", " ", 
    RowBox[{"(", 
     RowBox[{
     "\[CapitalDelta]\[Lambda]1l\[Chi]1HSS", "+", 
      "\[CapitalDelta]\[Lambda]1l\[Chi]2"}], 
     ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Lambda]Splitscalarsaux", ":=", 
  RowBox[{
  "\[Lambda]tree", "+", "\[CapitalDelta]\[Lambda]1lreg", "+", 
   "\[CapitalDelta]\[Lambda]1l\[Phi]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Lambda]SMsplitaux", ":=", 
  RowBox[{
  "\[Lambda]", "+", 
   "\[CapitalDelta]\[Lambda]1l\[Chi]1Split"}]}], "\[IndentingNewLine]", 
 RowBox[{"gtSplitsplitaux", ":=", 
  RowBox[{
   SubscriptBox["g", "t"], 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[CapitalDelta]gt\[Chi]"}], ")"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6197750208181477`*^9, 3.619775086915099*^9}, {
   3.6197767208065853`*^9, 3.619776738021739*^9}, 3.619776768421875*^9, {
   3.619777033476289*^9, 3.619777038897537*^9}, {3.619778903960243*^9, 
   3.61977891200975*^9}, {3.619778954746719*^9, 3.619778956352997*^9}, {
   3.619778998152606*^9, 3.619779016439775*^9}, {3.61977934347015*^9, 
   3.619779349613338*^9}, {3.620024171417177*^9, 3.6200241728251963`*^9}, {
   3.6200308430782747`*^9, 3.620030843917705*^9}, 3.620030875318843*^9, 
   3.620239543255022*^9, 3.620239619416938*^9, {3.620242145049872*^9, 
   3.620242149245323*^9}, {3.620243314054263*^9, 3.6202433504871798`*^9}, {
   3.620243681044486*^9, 3.620243681453712*^9}, {3.620246933553314*^9, 
   3.62024698041555*^9}, {3.62024705598453*^9, 3.620247145194631*^9}, {
   3.620287584159409*^9, 3.6202875844771633`*^9}, {3.62028847577503*^9, 
   3.620288476037458*^9}, {3.620308411524251*^9, 3.620308415594118*^9}, 
   3.620308499623837*^9, {3.620311074745768*^9, 3.6203110748395157`*^9}, {
   3.620541665153584*^9, 3.62054166781706*^9}, {3.621144514081089*^9, 
   3.621144516345064*^9}, 3.62115674227826*^9, {3.6222650986044693`*^9, 
   3.622265099132058*^9}, {3.635845533680233*^9, 3.635845584377576*^9}, {
   3.635845647717087*^9, 3.635845664252755*^9}}],

Cell[BoxData[{
 RowBox[{"\[Lambda]tree", ":=", 
  RowBox[{
   FractionBox["1", "4"], 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["g", "2"], "2"], "+", 
     RowBox[{
      FractionBox["3", "5"], 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}]}], ")"}], 
   SuperscriptBox[
    RowBox[{"Cos", "[", 
     RowBox[{"2", "\[Beta]"}], "]"}], "2"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Lambda]1lreg", ":=", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"4", "\[Pi]"}], ")"}], "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["9", "100"]}], "  ", 
        SubsuperscriptBox["g", "1", "4"]}], "-", 
       RowBox[{
        FractionBox["3", "10"], " ", 
        SubsuperscriptBox["g", "1", "2"], " ", 
        SubsuperscriptBox["g", "2", "2"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3", "4"], "-", 
          RowBox[{
           FractionBox["1", "6"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "\[Beta]"}], "]"}], "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "9"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]1l\[Phi]", ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"], " "}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SubsuperscriptBox["g", "t", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["g", "t", "2"], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["g", "2", "2"], "-", 
            FractionBox[
             SubsuperscriptBox["g", "1", "2"], "5"]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "\[Beta]"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SuperscriptBox[
          OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["g", "t", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["g", "t", "2"], "+", 
         RowBox[{
          FractionBox["2", "5"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "\[Beta]"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SuperscriptBox[
          OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "300"], " ", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Beta]"}], "]"}], "2"], ")"}], " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "1"}], "3"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["g", "1", "4"], "+", 
             RowBox[{"25", " ", 
              SubsuperscriptBox["g", "2", "4"]}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["Q", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
          RowBox[{"24", " ", 
           SubsuperscriptBox["g", "1", "4"], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["U", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["g", "1", "4"], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["D", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"9", " ", 
              SubsuperscriptBox["g", "1", "4"]}], "+", 
             RowBox[{"25", " ", 
              SubsuperscriptBox["g", "2", "4"]}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["L", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
          RowBox[{"18", " ", 
           SubsuperscriptBox["g", "1", "4"], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["E", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", "4800"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"261", " ", 
          SubsuperscriptBox["g", "1", "4"]}], "+", 
         RowBox[{"630", " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          SubsuperscriptBox["g", "2", "2"]}], "+", 
         RowBox[{"1325", " ", 
          SubsuperscriptBox["g", "2", "4"]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SubsuperscriptBox["g", "1", "4"]}], "+", 
            RowBox[{"90", " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "+", 
            RowBox[{"175", " ", 
             SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], "-", 
         RowBox[{"9", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"8", " ", "\[Beta]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "+", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["g", "2", "2"]}]}], ")"}], "2"]}]}], ")"}], 
       " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox[
          SubscriptBox["m", "A"], "2"], 
         SuperscriptBox[
          OverscriptBox["m", "~"], "2"]], "]"}]}], "-", 
      RowBox[{
       FractionBox["3", "16"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
          SubsuperscriptBox["g", "2", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], "2"]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["g", "t", "4"], " ", 
       SubscriptBox[
        OverscriptBox["X", "~"], "t"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox[
           OverscriptBox["F", "~"], "1"], "[", 
          SubscriptBox["x", "QU"], "]"}], "-", 
         RowBox[{
          FractionBox["1", "12"], " ", 
          SubscriptBox[
           OverscriptBox["X", "~"], "t"], " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["F", "~"], "2"], "[", 
           SubscriptBox["x", "QU"], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["g", "t", "2"], " ", 
       SubscriptBox[
        OverscriptBox["X", "~"], "t"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "\[Beta]"}], " ", "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["3", "5"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["F", "~"], "3"], "[", 
           SubscriptBox["x", "QU"], "]"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["g", "2", "2"], " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["F", "~"], "4"], "[", 
           SubscriptBox["x", "QU"], "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["g", "t", "2"], " ", 
       SubscriptBox[
        OverscriptBox["X", "~"], "t"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "\[Beta]"}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", 
           SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
         SubsuperscriptBox["g", "2", "2"]}], ")"}], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["F", "~"], "5"], "[", 
        SubscriptBox["x", "QU"], "]"}]}]}], ")"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "10"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["X", "~"], "t"], ":=", 
   FractionBox[
    SuperscriptBox[
     SubscriptBox["X", "t"], "2"], 
    RowBox[{
     SubscriptBox["m", 
      SubscriptBox["Q", "3"]], 
     SubscriptBox["m", 
      SubscriptBox["U", "3"]]}]]}], ";", 
  RowBox[{
   SubscriptBox["x", "QU"], ":=", 
   RowBox[{
    SubscriptBox["m", 
     SubscriptBox["Q", "3"]], "/", 
    SubscriptBox["m", 
     SubscriptBox["U", "3"]]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.619777044153404*^9, 3.619777047929717*^9}, {
  3.6200239423720207`*^9, 3.6200239648717203`*^9}, {3.620043426092043*^9, 
  3.6200434266426477`*^9}, {3.620239914409624*^9, 3.620239915699563*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Lambda]1l\[Chi]1Split", ":=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Beta]", "~"], "\[Lambda]"], " "}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"], " "}]], 
      FractionBox["1", "2"], 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["\[Mu]", "2"], 
        SuperscriptBox["msplit", "2"]], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "12"], " ", 
         RowBox[{"(", 
          RowBox[{"-", "7"}], ")"}], " ", 
         RowBox[{
          SubscriptBox["f", "1"], "[", 
          SubscriptBox["r", "1"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}], "4"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}], "4"]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["9", "4"], " ", 
         RowBox[{
          SubscriptBox["f", "2"], "[", 
          SubscriptBox["r", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}], "4"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}], "4"]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{
          SubscriptBox["f", "3"], "[", 
          SubscriptBox["r", "1"], "]"}], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}], "2"], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}], "2"]}], "-", 
        RowBox[{
         FractionBox["7", "2"], " ", 
         RowBox[{
          SubscriptBox["f", "4"], "[", 
          SubscriptBox["r", "2"], "]"}], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}], "2"], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}], "2"]}], "-", 
        RowBox[{
         FractionBox["8", "3"], " ", 
         RowBox[{
          SubscriptBox["f", "5"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]]}], "-", 
        RowBox[{
         FractionBox["7", "6"], " ", 
         RowBox[{
          SubscriptBox["f", "6"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}], "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "6"], " ", 
         RowBox[{
          SubscriptBox["f", "7"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}], "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["4", "3"], " ", 
         RowBox[{
          SubscriptBox["f", "8"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]]}], "+", 
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]]}], "+", 
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["2", "3"], " ", 
         RowBox[{"f", "[", 
          SubscriptBox["r", "1"], "]"}], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}], "2"], "+", 
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}], "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"f", "[", 
          SubscriptBox["r", "2"], "]"}], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"2", " ", "d"}], "2"], "+", 
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"2", " ", "u"}], "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"gg", "[", 
          SubscriptBox["r", "1"], "]"}], " ", "\[Lambda]", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}], "2"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}], "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"gg", "[", 
          SubscriptBox["r", "2"], "]"}], " ", "\[Lambda]", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}], "2"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}], "2"]}], ")"}]}]}], ")"}]}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "11"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Beta]", "~"], "\[Lambda]"], ":=", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], "+", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "d"}]], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "-", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "4"], "-", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "4"], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "~"], 
        RowBox[{"2", " ", "d"}]], "4"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "~"], 
        RowBox[{"2", " ", "u"}]], "4"]}], "-", 
     RowBox[{"4", " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], "+", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], "+", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], ")"}]}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "12"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["r", "1"], ":=", 
   RowBox[{
    SubscriptBox["M", "1"], "/", "\[Mu]"}]}], ";", 
  RowBox[{
   SubscriptBox["r", "2"], ":=", 
   RowBox[{
    SubscriptBox["M", "2"], "/", "\[Mu]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.618726330074712*^9, 3.6187264030076027`*^9}, {
   3.618726442325347*^9, 3.6187264503417377`*^9}, {3.618726516152412*^9, 
   3.618726525944816*^9}, {3.6187265651156063`*^9, 3.618726591673334*^9}, {
   3.6188123100734673`*^9, 3.618812318466593*^9}, {3.6188123830700197`*^9, 
   3.618812391433647*^9}, 3.618837047347385*^9, {3.618838282716663*^9, 
   3.618838293982607*^9}, {3.619776227443231*^9, 3.6197762422148743`*^9}, {
   3.619776358995343*^9, 3.6197763788861113`*^9}, {3.619776437817748*^9, 
   3.619776455534588*^9}, {3.619777616680846*^9, 3.619777630717984*^9}, {
   3.619778144356958*^9, 3.6197781446163397`*^9}, {3.619787569203102*^9, 
   3.6197875987652884`*^9}, {3.6200240591332273`*^9, 3.620024065201736*^9}, {
   3.620024153155864*^9, 3.620024162340822*^9}, {3.620243570154501*^9, 
   3.6202435987099543`*^9}, {3.62024395043226*^9, 3.62024396430105*^9}, {
   3.620244013801319*^9, 3.620244017625918*^9}, {3.620244050989429*^9, 
   3.620244054878484*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]1l\[Chi]1Split", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"msplit", "\[Rule]", 
      OverscriptBox["m", "~"]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["g", "2"], " ", 
        RowBox[{"Sin", "[", "\[Beta]", "]"}]}], ")"}]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["g", "2"], " ", 
        RowBox[{"Cos", "[", "\[Beta]", "]"}]}], ")"}]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"3", "/", "5"}]], " ", 
        SubscriptBox["g", "1"], " ", 
        RowBox[{"Sin", "[", "\[Beta]", "]"}]}], ")"}]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"3", "/", "5"}]], " ", 
        SubscriptBox["g", "1"], " ", 
        RowBox[{"Cos", "[", "\[Beta]", "]"}]}], ")"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "\[Lambda]tree"}]}], "}"}]}], "//", 
  "Simplify"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"6400", " ", 
    SuperscriptBox["\[Pi]", "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "\[Beta]"}], "]"}], "2"], " ", 
     RowBox[{"gg", "[", 
      FractionBox[
       SubscriptBox["M", "1"], "\[Mu]"], "]"}], " ", 
     SubsuperscriptBox["g", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SubsuperscriptBox["g", "1", "2"]}], "+", 
       RowBox[{"5", " ", 
        SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["g", "1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "18"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["\[Mu]", "2"], 
          SuperscriptBox[
           OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["\[Mu]", "2"], 
          SuperscriptBox[
           OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         FractionBox[
          SubscriptBox["M", "1"], "\[Mu]"], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "31"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "\[Beta]"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"6", " ", "\[Beta]"}], "]"}]}], ")"}]}], "-", 
       RowBox[{"7", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["f", "1"], "[", 
         FractionBox[
          SubscriptBox["M", "1"], "\[Mu]"], "]"}]}], "-", 
       RowBox[{"9", " ", 
        RowBox[{
         SubscriptBox["f", "3"], "[", 
         FractionBox[
          SubscriptBox["M", "1"], "\[Mu]"], "]"}]}], "+", 
       RowBox[{"9", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["f", "3"], "[", 
         FractionBox[
          SubscriptBox["M", "1"], "\[Mu]"], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"25", " ", 
     SubsuperscriptBox["g", "2", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Beta]"}], "]"}], "2"], " ", 
        RowBox[{"gg", "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
       RowBox[{"26", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["\[Mu]", "2"], 
          SuperscriptBox[
           OverscriptBox["m", "~"], "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["\[Mu]", "2"], 
          SuperscriptBox[
           OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "31"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "\[Beta]"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"6", " ", "\[Beta]"}], "]"}]}], ")"}]}], "-", 
       RowBox[{"27", " ", 
        RowBox[{
         SubscriptBox["f", "2"], "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
       RowBox[{"9", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["f", "2"], "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
       RowBox[{"7", " ", 
        RowBox[{
         SubscriptBox["f", "4"], "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "+", 
       RowBox[{"7", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["f", "4"], "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"5", " ", 
     SubsuperscriptBox["g", "1", "2"], " ", 
     SubsuperscriptBox["g", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}]}], ")"}], " ", 
        RowBox[{"gg", "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
       RowBox[{"24", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["\[Mu]", "2"], 
          SuperscriptBox[
           OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
       RowBox[{"24", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["\[Mu]", "2"], 
          SuperscriptBox[
           OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"f", "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "\[Beta]"}], "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"f", "[", 
         FractionBox[
          SubscriptBox["M", "2"], "\[Mu]"], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"6", " ", "\[Beta]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         FractionBox[
          SubscriptBox["M", "1"], "\[Mu]"], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "\[Beta]"}], "]"}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"6", " ", "\[Beta]"}], "]"}]}], ")"}]}], "-", 
       RowBox[{"16", " ", 
        RowBox[{
         SubscriptBox["f", "5"], "[", 
         RowBox[{
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], ",", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "+", 
       RowBox[{"16", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["f", "5"], "[", 
         RowBox[{
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], ",", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
       RowBox[{"42", " ", 
        RowBox[{
         SubscriptBox["f", "6"], "[", 
         RowBox[{
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], ",", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
       RowBox[{"14", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["f", "6"], "[", 
         RowBox[{
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], ",", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["f", "7"], "[", 
         RowBox[{
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], ",", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["f", "7"], "[", 
         RowBox[{
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], ",", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
       RowBox[{"64", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "\[Beta]"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["f", "8"], "[", 
         RowBox[{
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], ",", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.625160375539588*^9}]
}, Closed]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]1l\[Chi]1HSS", ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"6400", " ", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "\[Beta]"}], "]"}], "2"], " ", 
       RowBox[{"gg", "[", 
        FractionBox[
         SubscriptBox["M", "1"], "\[Mu]"], "]"}], " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SubsuperscriptBox["g", "1", "2"]}], "+", 
         RowBox[{"5", " ", 
          SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["g", "1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "18"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{"6", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{
          RowBox[{"f", "[", 
           FractionBox[
            SubscriptBox["M", "1"], "\[Mu]"], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "31"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "\[Beta]"}], "]"}]}], "+", 
            RowBox[{"Sin", "[", 
             RowBox[{"6", " ", "\[Beta]"}], "]"}]}], ")"}]}], "-", 
         RowBox[{"7", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", "\[Beta]"}], "]"}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["f", "1"], "[", 
           FractionBox[
            SubscriptBox["M", "1"], "\[Mu]"], "]"}]}], "-", 
         RowBox[{"9", " ", 
          RowBox[{
           SubscriptBox["f", "3"], "[", 
           FractionBox[
            SubscriptBox["M", "1"], "\[Mu]"], "]"}]}], "+", 
         RowBox[{"9", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["f", "3"], "[", 
           FractionBox[
            SubscriptBox["M", "1"], "\[Mu]"], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"25", " ", 
       SubsuperscriptBox["g", "2", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[Beta]"}], "]"}], "2"], " ", 
          RowBox[{"gg", "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
         RowBox[{"26", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{
          RowBox[{"f", "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "31"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", "\[Beta]"}], "]"}]}], "+", 
            RowBox[{"Sin", "[", 
             RowBox[{"6", " ", "\[Beta]"}], "]"}]}], ")"}]}], "-", 
         RowBox[{"27", " ", 
          RowBox[{
           SubscriptBox["f", "2"], "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
         RowBox[{"9", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["f", "2"], "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
         RowBox[{"7", " ", 
          RowBox[{
           SubscriptBox["f", "4"], "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "+", 
         RowBox[{"7", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["f", "4"], "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"5", " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       SubsuperscriptBox["g", "2", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", "\[Beta]"}], "]"}]}], ")"}], " ", 
          RowBox[{"gg", "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
         RowBox[{"24", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{"24", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"f", "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "\[Beta]"}], "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"f", "[", 
           FractionBox[
            SubscriptBox["M", "2"], "\[Mu]"], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"6", " ", "\[Beta]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"f", "[", 
           FractionBox[
            SubscriptBox["M", "1"], "\[Mu]"], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "\[Beta]"}], "]"}], "+", 
            RowBox[{"Sin", "[", 
             RowBox[{"6", " ", "\[Beta]"}], "]"}]}], ")"}]}], "-", 
         RowBox[{"16", " ", 
          RowBox[{
           SubscriptBox["f", "5"], "[", 
           RowBox[{
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], ",", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "+", 
         RowBox[{"16", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["f", "5"], "[", 
           RowBox[{
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], ",", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
         RowBox[{"42", " ", 
          RowBox[{
           SubscriptBox["f", "6"], "[", 
           RowBox[{
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], ",", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
         RowBox[{"14", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["f", "6"], "[", 
           RowBox[{
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], ",", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SubscriptBox["f", "7"], "[", 
           RowBox[{
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], ",", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["f", "7"], "[", 
           RowBox[{
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], ",", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}], "-", 
         RowBox[{"64", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "\[Beta]"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["f", "8"], "[", 
           RowBox[{
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], ",", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"]}], "]"}]}]}], ")"}]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Lambda]1l\[Chi]2", ":=", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"4", "\[Pi]"}], ")"}], "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "6"]}], 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"2", "\[Beta]"}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          SuperscriptBox[
           SubscriptBox["g", "2"], "4"], 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox[
             SubscriptBox["M", "2"], "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["9", "25"], 
             SuperscriptBox[
              SubscriptBox["g", "1"], "4"]}], "+", 
            SuperscriptBox[
             SubscriptBox["g", "2"], "4"]}], ")"}], 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}], ")"}]}]}], 
   ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "13"}], "*)"}]}], "\[IndentingNewLine]"}], "Input",\

 CellChangeTimes->{{3.620024227775024*^9, 3.620024233240749*^9}, {
  3.620024298638546*^9, 3.620024304836375*^9}, {3.620222408351479*^9, 
  3.6202224104700117`*^9}, {3.620243672343609*^9, 3.6202436729560633`*^9}, {
  3.620243752236747*^9, 3.620243755959189*^9}, {3.62237483753792*^9, 
  3.62237484669036*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Lambda]1l\[Chi]1Split", ":=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Beta]", "~"], "\[Lambda]"], " "}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"], " "}]], 
      FractionBox["1", "2"], 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["\[Mu]", "2"], 
        SuperscriptBox["msplit", "2"]], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "12"], " ", 
         RowBox[{"(", 
          RowBox[{"-", "7"}], ")"}], " ", 
         RowBox[{
          SubscriptBox["f", "1"], "[", 
          SubscriptBox["r", "1"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}], "4"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}], "4"]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["9", "4"], " ", 
         RowBox[{
          SubscriptBox["f", "2"], "[", 
          SubscriptBox["r", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}], "4"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}], "4"]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{
          SubscriptBox["f", "3"], "[", 
          SubscriptBox["r", "1"], "]"}], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}], "2"], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}], "2"]}], "-", 
        RowBox[{
         FractionBox["7", "2"], " ", 
         RowBox[{
          SubscriptBox["f", "4"], "[", 
          SubscriptBox["r", "2"], "]"}], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}], "2"], " ", 
         SubsuperscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}], "2"]}], "-", 
        RowBox[{
         FractionBox["8", "3"], " ", 
         RowBox[{
          SubscriptBox["f", "5"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]]}], "-", 
        RowBox[{
         FractionBox["7", "6"], " ", 
         RowBox[{
          SubscriptBox["f", "6"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}], "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "6"], " ", 
         RowBox[{
          SubscriptBox["f", "7"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}], "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}], "2"], " ", 
            SubsuperscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["4", "3"], " ", 
         RowBox[{
          SubscriptBox["f", "8"], "[", 
          RowBox[{
           SubscriptBox["r", "1"], ",", 
           SubscriptBox["r", "2"]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]]}], "+", 
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]]}], "+", 
           RowBox[{
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], " ", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["2", "3"], " ", 
         RowBox[{"f", "[", 
          SubscriptBox["r", "1"], "]"}], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "d"}], "2"], "+", 
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", " ", "u"}], "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"f", "[", 
          SubscriptBox["r", "2"], "]"}], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"2", " ", "d"}], "2"], "+", 
              SubsuperscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"2", " ", "u"}], "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         RowBox[{"gg", "[", 
          SubscriptBox["r", "1"], "]"}], " ", "\[Lambda]", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}], "2"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}], "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"gg", "[", 
          SubscriptBox["r", "2"], "]"}], " ", "\[Lambda]", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}], "2"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}], "2"]}], ")"}]}]}], ")"}]}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "11"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[Beta]", "~"], "\[Lambda]"], ":=", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], "+", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "d"}]], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          SubscriptBox[
           OverscriptBox["g", "~"], 
           RowBox[{"2", " ", "u"}]], "2"]}]}], ")"}]}], "-", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], "4"], "-", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], "4"], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "~"], 
        RowBox[{"2", " ", "d"}]], "4"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "~"], 
        RowBox[{"2", " ", "u"}]], "4"]}], "-", 
     RowBox[{"4", " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "d"}]], " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"1", " ", "u"}]], " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "d"}]], " ", 
      SubscriptBox[
       OverscriptBox["g", "~"], 
       RowBox[{"2", " ", "u"}]]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], "2"], "+", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], "2"], "+", 
        SuperscriptBox[
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], "2"]}], ")"}]}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"eq", ".", " ", "12"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["r", "1"], ":=", 
   RowBox[{
    SubscriptBox["M", "1"], "/", "\[Mu]"}]}], ";", 
  RowBox[{
   SubscriptBox["r", "2"], ":=", 
   RowBox[{
    SubscriptBox["M", "2"], "/", "\[Mu]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.618726330074712*^9, 3.6187264030076027`*^9}, {
   3.618726442325347*^9, 3.6187264503417377`*^9}, {3.618726516152412*^9, 
   3.618726525944816*^9}, {3.6187265651156063`*^9, 3.618726591673334*^9}, {
   3.6188123100734673`*^9, 3.618812318466593*^9}, {3.6188123830700197`*^9, 
   3.618812391433647*^9}, 3.618837047347385*^9, {3.618838282716663*^9, 
   3.618838293982607*^9}, {3.619776227443231*^9, 3.6197762422148743`*^9}, {
   3.619776358995343*^9, 3.6197763788861113`*^9}, {3.619776437817748*^9, 
   3.619776455534588*^9}, {3.619777616680846*^9, 3.619777630717984*^9}, {
   3.619778144356958*^9, 3.6197781446163397`*^9}, {3.619787569203102*^9, 
   3.6197875987652884`*^9}, {3.6200240591332273`*^9, 3.620024065201736*^9}, {
   3.620024153155864*^9, 3.620024162340822*^9}, {3.620243570154501*^9, 
   3.6202435987099543`*^9}, {3.62024395043226*^9, 3.62024396430105*^9}, {
   3.620244013801319*^9, 3.620244017625918*^9}, {3.620244050989429*^9, 
   3.620244054878484*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g2umtildeaux", ":=", 
   RowBox[{
    SubscriptBox["g", "2"], " ", 
    RowBox[{"Sin", "[", "\[Beta]", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["g", "2", "2"]}], 
          RowBox[{"(", 
           RowBox[{
            FractionBox["2", "3"], "+", 
            FractionBox[
             RowBox[{"11", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "16"]}], ")"}]}],
          "+", 
         RowBox[{
          FractionBox["1", "80"], " ", 
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"9", " ", 
           SubsuperscriptBox["g", "t", "2"]}], 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]], "+", 
         RowBox[{
          FractionBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"20", " ", 
              SubsuperscriptBox["g", "2", "2"]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "9"}], " ", 
                 SubsuperscriptBox["g", "1", "2"]}], "+", 
                RowBox[{"35", " ", 
                 SubsuperscriptBox["g", "2", "2"]}]}], ")"}], 
              SuperscriptBox[
               RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}]}], ")"}], "120"], 
          
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox[
             SubscriptBox["m", "A"], "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          SubsuperscriptBox["g", "2", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["L", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["g", "2", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["Q", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}]}], "-", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "t", "2"], " "}], 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"], ")"}]}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], 
               SuperscriptBox[
                OverscriptBox["m", "~"], "2"]], "]"}]}], "-", 
            RowBox[{"Log", "[", 
             FractionBox[
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"], 
              SuperscriptBox[
               OverscriptBox["m", "~"], "2"]], "]"}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2dmtildeaux", ":=", 
   RowBox[{
    SubscriptBox["g", "2"], 
    RowBox[{"Cos", "[", "\[Beta]", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["g", "2", "2"]}], 
          RowBox[{"(", 
           RowBox[{
            FractionBox["2", "3"], "+", 
            FractionBox[
             RowBox[{"11", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}], "16"]}], ")"}]}],
          "+", 
         RowBox[{
          FractionBox["1", "80"], " ", 
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["g", "2", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["Q", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}]}], "+", 
         RowBox[{
          FractionBox["1", "120"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"20", " ", 
             SubsuperscriptBox["g", "2", "2"]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SubsuperscriptBox["g", "1", "2"]}], "+", 
               RowBox[{"35", " ", 
                SubsuperscriptBox["g", "2", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", "A", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          SubsuperscriptBox["g", "2", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"Log", "[", 
            FractionBox[
             SubsuperscriptBox["m", 
              SubscriptBox["L", "i"], "2"], 
             SuperscriptBox[
              OverscriptBox["m", "~"], "2"]], "]"}]}]}]}], ")"}]}]}], " ", 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g1umtildeaux", ":=", 
   RowBox[{
    SqrtBox[
     FractionBox["3", "5"]], " ", 
    SubscriptBox["g", "1"], " ", 
    RowBox[{"Sin", "[", "\[Beta]", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "16"], " ", 
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "2", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "80"], " ", 
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "44"}], "+", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"9", " ", 
           SubsuperscriptBox["g", "t", "2"]}], 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]], "+", 
         RowBox[{
          FractionBox["1", "40"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SubsuperscriptBox["g", "1", "2"]}], "-", 
            RowBox[{"9", " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["g", "1", "2"], "+", 
               RowBox[{"5", " ", 
                SubsuperscriptBox["g", "2", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", "A", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "10"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["L", "i"], "2"], 
               SuperscriptBox[
                OverscriptBox["m", "~"], "2"]], "]"}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SubsuperscriptBox["m", 
                 SubscriptBox["\[ExponentialE]", "i"], "2"], 
                SuperscriptBox[
                 OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}]}], "+", 
         RowBox[{
          FractionBox["1", "30"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "i"], "2"], 
               SuperscriptBox[
                OverscriptBox["m", "~"], "2"]], "]"}], "+", 
             RowBox[{"8", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SubsuperscriptBox["m", 
                 SubscriptBox["U", "i"], "2"], 
                SuperscriptBox[
                 OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SubsuperscriptBox["m", 
                 SubscriptBox["D", "i"], "2"], 
                SuperscriptBox[
                 OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}]}], "+", 
         RowBox[{
          FractionBox[
           RowBox[{
            SubsuperscriptBox["g", "t", "2"], " "}], 
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"7", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], 
               SuperscriptBox[
                OverscriptBox["m", "~"], "2"]], "]"}]}], "-", 
            RowBox[{"13", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"], 
               SuperscriptBox[
                OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g1dmtildeaux", ":=", 
   RowBox[{
    SqrtBox[
     FractionBox["3", "5"]], " ", 
    SubscriptBox["g", "1"], " ", 
    RowBox[{"Cos", "[", "\[Beta]", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "16"], " ", 
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "2", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "80"], " ", 
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "44"}], "+", 
            RowBox[{"7", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "40"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SubsuperscriptBox["g", "1", "2"]}], "-", 
            RowBox[{"9", " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["g", "1", "2"], "+", 
               RowBox[{"5", " ", 
                SubsuperscriptBox["g", "2", "2"]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", "A", "2"], 
            SuperscriptBox[
             OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "10"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["L", "i"], "2"], 
               SuperscriptBox[
                OverscriptBox["m", "~"], "2"]], "]"}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SubsuperscriptBox["m", 
                 SubscriptBox["\[ExponentialE]", "i"], "2"], 
                SuperscriptBox[
                 OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}]}], "+", 
         RowBox[{
          FractionBox["1", "30"], " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "i"], "2"], 
               SuperscriptBox[
                OverscriptBox["m", "~"], "2"]], "]"}], "+", 
             RowBox[{"8", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SubsuperscriptBox["m", 
                 SubscriptBox["U", "i"], "2"], 
                SuperscriptBox[
                 OverscriptBox["m", "~"], "2"]], "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SubsuperscriptBox["m", 
                 SubscriptBox["D", "i"], "2"], 
                SuperscriptBox[
                 OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}]}]}], 
        ")"}]}]}], ")"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"\[CapitalDelta]gt\[Chi]", ":=", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"4", " ", "\[Pi]"}], ")"}], "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "6"]}], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "u"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", " ", "d"}]], " ", 
         RowBox[{"f", "[", 
          FractionBox[
           SubscriptBox["M", "1"], "\[Mu]"], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "12"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "u"}], "2"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"1", " ", "d"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"gg", "[", 
            FractionBox[
             SubscriptBox["M", "1"], "\[Mu]"], "]"}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["\[Mu]", "2"], 
              SuperscriptBox[
               OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "u"}]], " ", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", " ", "d"}]], " ", 
         RowBox[{"f", "[", 
          FractionBox[
           SubscriptBox["M", "2"], "\[Mu]"], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "u"}], "2"], "+", 
           SubsuperscriptBox[
            OverscriptBox["g", "~"], 
            RowBox[{"2", " ", "d"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"gg", "[", 
            FractionBox[
             SubscriptBox["M", "2"], "\[Mu]"], "]"}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["\[Mu]", "2"], 
              SuperscriptBox[
               OverscriptBox["m", "~"], "2"]], "]"}]}]}], ")"}]}]}], ")"}]}], 
     "/.", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox["m", "~"], "\[Rule]", "msplit"}], "}"}]}]}], 
   ";"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6202458617687683`*^9, 3.620245936010948*^9}, {
  3.62024596980335*^9, 3.620246099411791*^9}, {3.620246201632934*^9, 
  3.6202466994496613`*^9}, {3.6202470282046957`*^9, 3.620247034084188*^9}, {
  3.62028865012614*^9, 3.620288659333879*^9}, {3.6203114381260433`*^9, 
  3.620311460410418*^9}, {3.620311492863936*^9, 3.620311509213173*^9}, {
  3.620311697338964*^9, 3.620311708103725*^9}, {3.620312290957584*^9, 
  3.6203122947292*^9}, {3.620312330274809*^9, 3.6203123339227877`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Loop Functions", "Subsubsection",
 CellChangeTimes->{{3.620244302260407*^9, 3.620244325244125*^9}, {
   3.620306167489921*^9, 3.6203061727604218`*^9}, {3.622265737342599*^9, 
   3.6222657445768948`*^9}, 3.6223123275263968`*^9},
 Background->GrayLevel[0.85]],

Cell["\<\
When evaluating the loop functions, the limit values need to be treated \
carefully to avoid indeterminate expressions.\
\>", "Text",
 CellChangeTimes->{{3.628062684790942*^9, 3.6280627143675117`*^9}, {
  3.628062749661428*^9, 3.628062808951696*^9}, {3.628062860368815*^9, 
  3.628062890241288*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", "Commented", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.628062599909416*^9, 3.628062616740046*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Delta]", "=", 
      SuperscriptBox["10", 
       RowBox[{"-", "7"}]]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "1"], "[", "x_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"x", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        FractionBox[
         RowBox[{"x", " ", 
          RowBox[{"Log", "[", 
           SuperscriptBox["x", "2"], "]"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], "-", "1"}]]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "2"], "[", "x_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"x", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        FractionBox[
         RowBox[{"6", " ", 
          SuperscriptBox["x", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["x", "2"]}], ")"}], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["x", "2"], "]"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", "1"}], ")"}], "3"]]}], "]"}]}], 
     ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "3"], "[", "x_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"x", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        FractionBox[
         RowBox[{"2", " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SuperscriptBox["x", "2"]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["x", "2"]}]}], ")"}], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["x", "2"], "]"}]}]}], ")"}]}], 
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "-", "1"}], ")"}], "2"]}]]}], "]"}]}], 
     ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "4"], "[", "x_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"x", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        FractionBox[
         RowBox[{"2", " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", "1", "-", 
            RowBox[{"Log", "[", 
             SuperscriptBox["x", "2"], "]"}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", "1"}], ")"}], "2"]]}], "]"}]}], 
     ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "5"], "[", "x_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"x", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        FractionBox[
         RowBox[{"3", " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["x", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["x", "2"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["x", "2"], "]"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["x", "2"]}], ")"}], "3"]]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "6"], "[", "x_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"x", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], "-", "3"}], 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["x", "2"]}], ")"}]}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "-", "2"}], ")"}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            SuperscriptBox["x", "2"], "]"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SuperscriptBox["x", "2"]}], ")"}], "2"]}]]}]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "7"], "[", "x_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"x", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "4"], "-", 
              RowBox[{"6", " ", 
               SuperscriptBox["x", "2"]}], "+", "1"}], ")"}]}], 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "-", "1"}], ")"}], "2"]}]]}], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", 
             SuperscriptBox["x", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "-", "3"}], ")"}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            SuperscriptBox["x", "2"], "]"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "-", "1"}], ")"}], "3"]]}]}], "]"}]}], 
     ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "8"], "[", 
       RowBox[{"x1_", ",", "x2_"}], "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"x1", "-", "1"}], "]"}], "+", 
              RowBox[{"Abs", "[", 
               RowBox[{"x2", "-", "1"}], "]"}]}], ")"}], "<", "\[Delta]"}]}], 
          "}"}], "}"}], ",", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " "}], 
           RowBox[{
            SuperscriptBox["x1", "2"], "-", 
            SuperscriptBox["x2", "2"]}]], 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["x1", "4"], " ", 
              RowBox[{"Log", "[", 
               SuperscriptBox["x1", "2"], "]"}]}], 
             RowBox[{
              SuperscriptBox["x1", "2"], "-", "1"}]], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["x2", "4"], " ", 
              RowBox[{"Log", "[", 
               SuperscriptBox["x2", "2"], "]"}]}], 
             RowBox[{
              SuperscriptBox["x2", "2"], "-", "1"}]]}], ")"}]}]}]}], "]"}]}], 
     ";", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "9"], "[", 
       RowBox[{"x1_", ",", "x2_"}], "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"x1", "-", "1"}], "]"}], "+", 
              RowBox[{"Abs", "[", 
               RowBox[{"x2", "-", "1"}], "]"}]}], ")"}], "<", "\[Delta]"}]}], 
          "}"}], "}"}], ",", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["x1", "2"], " ", 
              RowBox[{"Log", "[", 
               SuperscriptBox["x1", "2"], "]"}]}], 
             RowBox[{
              SuperscriptBox["x1", "2"], "-", "1"}]], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["x2", "2"], " ", 
              RowBox[{"Log", "[", 
               SuperscriptBox["x2", "2"], "]"}]}], 
             RowBox[{
              SuperscriptBox["x2", "2"], "-", "1"}]]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["x1", "2"], "-", 
          SuperscriptBox["x2", "2"]}]]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "[", "r_", "]"}], ":=", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "5"], "[", "r", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gg", "[", "r_", "]"}], ":=", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "7"], "[", "r", "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"define", " ", "gg", " ", "to", " ", "avoid", " ", "conflict"}],
       "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "1"], "[", "r_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"r", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "+", "3"}], ")"}], " ", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{"7", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
         FractionBox[
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "5"}], ")"}], " ", 
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"Log", "[", 
            SuperscriptBox["r", "2"], "]"}]}], 
          RowBox[{"7", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "2"], "[", "r_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"r", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "+", "11"}], ")"}], " ", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{"9", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox["r", "2"]}], "-", "17"}], ")"}], " ", 
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"Log", "[", 
            SuperscriptBox["r", "2"], "]"}]}], 
          RowBox[{"9", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
       "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "3"], "[", "r_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"r", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "4"], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["r", "2"]}], "+", "2"}], ")"}]}], 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "4"], "-", 
             RowBox[{"7", " ", 
              SuperscriptBox["r", "2"]}], "-", "6"}], ")"}], " ", 
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"Log", "[", 
            SuperscriptBox["r", "2"], "]"}]}], 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
       "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "4"], "[", "r_", "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"r", "-", "1"}], "]"}], "<", "\[Delta]"}]}], "}"}], 
         "}"}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox["r", "4"]}], "+", 
             RowBox[{"25", " ", 
              SuperscriptBox["r", "2"]}], "+", "6"}], ")"}]}], 
          RowBox[{"7", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "4"], "-", 
             RowBox[{"19", " ", 
              SuperscriptBox["r", "2"]}], "-", "18"}], ")"}], " ", 
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"Log", "[", 
            SuperscriptBox["r", "2"], "]"}]}], 
          RowBox[{"7", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
       "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "5"], "[", 
       RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"r1", "-", "1"}], "]"}], "+", 
              RowBox[{"Abs", "[", 
               RowBox[{"r2", "-", "1"}], "]"}]}], ")"}], "<", "\[Delta]"}]}], 
          "}"}], "}"}], ",", 
        RowBox[{
         FractionBox["3", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"r1", "+", "r2"}], ")"}], "2"], "-", 
             RowBox[{
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"]}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "+", "1"}], ")"}], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r1", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r2", "3"], 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "+", "1"}], ")"}], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r2", "2"], "]"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
          ")"}]}]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "6"], "[", 
       RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"r1", "-", "1"}], "]"}], "+", 
              RowBox[{"Abs", "[", 
               RowBox[{"r2", "-", "1"}], "]"}]}], ")"}], "<", "\[Delta]"}]}], 
          "}"}], "}"}], ",", 
        RowBox[{
         FractionBox["6", "7"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["r1", "2"], "+", 
             SuperscriptBox["r2", "2"], "+", 
             RowBox[{"r1", " ", "r2"}], "-", 
             RowBox[{
              SuperscriptBox["r1", "2"], " ", 
              SuperscriptBox["r2", "2"]}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r1", "5"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r1", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r2", "5"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r2", "2"], "]"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
          ")"}]}]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "7"], "[", 
       RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"r1", "-", "1"}], "]"}], "+", 
              RowBox[{"Abs", "[", 
               RowBox[{"r2", "-", "1"}], "]"}]}], ")"}], "<", "\[Delta]"}]}], 
          "}"}], "}"}], ",", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"1", "+", 
             RowBox[{"r1", " ", "r2"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r1", "3"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r1", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r2", "3"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r2", "2"], "]"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
          ")"}]}]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "8"], "[", 
       RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"r1", "-", "1"}], "]"}], "+", 
              RowBox[{"Abs", "[", 
               RowBox[{"r2", "-", "1"}], "]"}]}], ")"}], "<", "\[Delta]"}]}], 
          "}"}], "}"}], ",", 
        RowBox[{
         FractionBox["3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"r1", "+", "r2"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r1", "4"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r1", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r2", "4"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["r2", "2"], "]"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"r1", "-", "r2"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
          ")"}]}]}], "]"}]}], ";"}]}], "]"}], "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.6197838282184563`*^9, 3.619783943081627*^9}, {
   3.619786741339839*^9, 3.619786749634777*^9}, {3.6197877043147583`*^9, 
   3.619787717098135*^9}, {3.619787749690153*^9, 3.6197877745781183`*^9}, {
   3.619848199712783*^9, 3.619848303165107*^9}, {3.6198483983040657`*^9, 
   3.6198484309162607`*^9}, {3.619848905007491*^9, 3.619848911989327*^9}, {
   3.619849751046484*^9, 3.619849782214807*^9}, {3.620023163927197*^9, 
   3.62002319818281*^9}, {3.620023284046846*^9, 3.620023291375175*^9}, {
   3.6200234398128242`*^9, 3.62002344992474*^9}, {3.6200234950598707`*^9, 
   3.620023524058948*^9}, {3.620023570004026*^9, 3.6200235817634993`*^9}, {
   3.620023638828959*^9, 3.620023659115425*^9}, {3.620024656382123*^9, 
   3.620024663357435*^9}, {3.620024878365899*^9, 3.6200248861048183`*^9}, {
   3.6200291580482273`*^9, 3.620029189693668*^9}, {3.6200293586006327`*^9, 
   3.62002940757454*^9}, {3.6200294492620087`*^9, 3.62002945484573*^9}, {
   3.6200295063153152`*^9, 3.620029657199974*^9}, {3.620029735205472*^9, 
   3.620029761436604*^9}, {3.6200297947583103`*^9, 3.620029939293313*^9}, {
   3.620030752058197*^9, 3.620030765864955*^9}, {3.620039182557536*^9, 
   3.6200391910767403`*^9}, {3.620240430752709*^9, 3.6202404363548403`*^9}, {
   3.620241063501821*^9, 3.620241088253599*^9}, {3.620241934327037*^9, 
   3.62024193453123*^9}, {3.62054766122749*^9, 3.620547666119228*^9}, {
   3.6205477080227757`*^9, 3.6205477109388533`*^9}, 3.622265744577026*^9, 
   3.622312327526532*^9, {3.625166654372189*^9, 3.625166659105311*^9}, 
   3.628062616740115*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Delta]", "=", 
      RowBox[{"1.3564", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}], ",", 
     RowBox[{"\[Delta]2", "=", 
      RowBox[{"2.36547", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}]}], "}"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "1"], "[", "Qx_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx"}]}], "}"}], ",", 
       FractionBox[
        RowBox[{"x", " ", 
         RowBox[{"Log", "[", 
          SuperscriptBox["x", "2"], "]"}]}], 
        RowBox[{
         SuperscriptBox["x", "2"], "-", "1"}]]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "2"], "[", "Qx_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx"}]}], "}"}], ",", 
       FractionBox[
        RowBox[{"6", " ", 
         SuperscriptBox["x", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["x", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["x", "2"]}], ")"}], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["x", "2"], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "-", "1"}], ")"}], "3"]]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "3"], "[", "Qx_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx"}]}], "}"}], ",", 
       FractionBox[
        RowBox[{"2", " ", "x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SuperscriptBox["x", "2"]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["x", "2"]}]}], ")"}], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["x", "2"], "]"}]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", "1"}], ")"}], "2"]}]]}], "]"}]}], 
    ";", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "4"], "[", "Qx_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx"}]}], "}"}], ",", 
       FractionBox[
        RowBox[{"2", " ", "x", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "-", "1", "-", 
           RowBox[{"Log", "[", 
            SuperscriptBox["x", "2"], "]"}]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "-", "1"}], ")"}], "2"]]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "5"], "[", "Qx_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx"}]}], "}"}], ",", 
       FractionBox[
        RowBox[{"3", " ", "x", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["x", "4"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["x", "2"], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["x", "2"], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["x", "2"]}], ")"}], "3"]]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "6"], "[", "Qx_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx"}]}], "}"}], ",", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "-", "3"}], 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["x", "2"]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "-", "2"}], ")"}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SuperscriptBox["x", "2"], "]"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["x", "2"]}], ")"}], "2"]}]]}]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "7"], "[", "Qx_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "4"], "-", 
             RowBox[{"6", " ", 
              SuperscriptBox["x", "2"]}], "+", "1"}], ")"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "-", "1"}], ")"}], "2"]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", " ", 
            SuperscriptBox["x", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "-", "3"}], ")"}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SuperscriptBox["x", "2"], "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "-", "1"}], ")"}], "3"]]}]}], "]"}]}], 
    ";", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "8"], "[", 
      RowBox[{"Qx1_", ",", "Qx2_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x1", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx1"}]}], ",", 
         RowBox[{"x2", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]2"}], ")"}], "Qx2"}]}]}], "}"}], ",", 
       
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " "}], 
          RowBox[{
           SuperscriptBox["x1", "2"], "-", 
           SuperscriptBox["x2", "2"]}]], 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "4"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["x1", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox["x1", "2"], "-", "1"}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x2", "4"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["x2", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox["x2", "2"], "-", "1"}]]}], ")"}]}]}]}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "9"], "[", 
      RowBox[{"Qx1_", ",", "Qx2_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x1", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qx1"}]}], ",", 
         RowBox[{"x2", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]2"}], ")"}], "Qx2"}]}]}], "}"}], ",", 
       
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["x1", "2"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["x1", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox["x1", "2"], "-", "1"}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x2", "2"], " ", 
             RowBox[{"Log", "[", 
              SuperscriptBox["x2", "2"], "]"}]}], 
            RowBox[{
             SuperscriptBox["x2", "2"], "-", "1"}]]}], ")"}]}], 
        RowBox[{
         SuperscriptBox["x1", "2"], "-", 
         SuperscriptBox["x2", "2"]}]]}], "]"}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"f", "[", "r_", "]"}], ":=", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "5"], "[", "r", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gg", "[", "r_", "]"}], ":=", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "7"], "[", "r", "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"define", " ", "gg", " ", "to", " ", "avoid", " ", "conflict"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "1"], "[", "Qr_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr"}]}], "}"}], ",", 
       RowBox[{
        FractionBox[
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", "3"}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], 
         RowBox[{"7", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
        FractionBox[
         RowBox[{"6", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "-", "5"}], ")"}], " ", 
          SuperscriptBox["r", "4"], " ", 
          RowBox[{"Log", "[", 
           SuperscriptBox["r", "2"], "]"}]}], 
         RowBox[{"7", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "2"], "[", "Qr_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr"}]}], "}"}], ",", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", "11"}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], 
         RowBox[{"9", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["r", "2"]}], "-", "17"}], ")"}], " ", 
          SuperscriptBox["r", "4"], " ", 
          RowBox[{"Log", "[", 
           SuperscriptBox["r", "2"], "]"}]}], 
         RowBox[{"9", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
      "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "3"], "[", "Qr_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr"}]}], "}"}], ",", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "4"], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["r", "2"]}], "+", "2"}], ")"}]}], 
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "4"], "-", 
            RowBox[{"7", " ", 
             SuperscriptBox["r", "2"]}], "-", "6"}], ")"}], " ", 
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"Log", "[", 
           SuperscriptBox["r", "2"], "]"}]}], 
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
      "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "4"], "[", "Qr_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr"}]}], "}"}], ",", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["r", "4"]}], "+", 
            RowBox[{"25", " ", 
             SuperscriptBox["r", "2"]}], "+", "6"}], ")"}]}], 
         RowBox[{"7", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "2"]}]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "4"], "-", 
            RowBox[{"19", " ", 
             SuperscriptBox["r", "2"]}], "-", "18"}], ")"}], " ", 
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"Log", "[", 
           SuperscriptBox["r", "2"], "]"}]}], 
         RowBox[{"7", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "-", "1"}], ")"}], "3"]}]]}]}], 
      "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "5"], "[", 
      RowBox[{"Qr1_", ",", "Qr2_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r1", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr1"}]}], ",", 
         RowBox[{"r2", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]2"}], ")"}], "Qr2"}]}]}], "}"}], ",", 
       
       RowBox[{
        FractionBox["3", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r1", "+", "r2"}], ")"}], "2"], "-", 
            RowBox[{
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r1", "2"], "+", "1"}], ")"}], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r1", "2"], "]"}]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r2", "3"], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r2", "2"], "+", "1"}], ")"}], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r2", "2"], "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
         ")"}]}]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "6"], "[", 
      RowBox[{"Qr1_", ",", "Qr2_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r1", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr1"}]}], ",", 
         RowBox[{"r2", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]2"}], ")"}], "Qr2"}]}]}], "}"}], ",", 
       
       RowBox[{
        FractionBox["6", "7"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["r1", "2"], "+", 
            SuperscriptBox["r2", "2"], "+", 
            RowBox[{"r1", " ", "r2"}], "-", 
            RowBox[{
             SuperscriptBox["r1", "2"], " ", 
             SuperscriptBox["r2", "2"]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r1", "5"], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r1", "2"], "]"}]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r2", "5"], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r2", "2"], "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
         ")"}]}]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "7"], "[", 
      RowBox[{"Qr1_", ",", "Qr2_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r1", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr1"}]}], ",", 
         RowBox[{"r2", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]2"}], ")"}], "Qr2"}]}]}], "}"}], ",", 
       
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"1", "+", 
            RowBox[{"r1", " ", "r2"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r1", "3"], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r1", "2"], "]"}]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r2", "3"], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r2", "2"], "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
         ")"}]}]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "8"], "[", 
      RowBox[{"Qr1_", ",", "Qr2_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"r1", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]"}], ")"}], "Qr1"}]}], ",", 
         RowBox[{"r2", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.", "+", "\[Delta]2"}], ")"}], "Qr2"}]}]}], "}"}], ",", 
       
       RowBox[{
        FractionBox["3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"r1", "+", "r2"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r1", "2"], "-", "1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r2", "2"], "-", "1"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r1", "4"], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r1", "2"], "]"}]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r1", "2"], "-", "1"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["r2", "4"], " ", 
            RowBox[{"Log", "[", 
             SuperscriptBox["r2", "2"], "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r1", "-", "r2"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r2", "2"], "-", "1"}], ")"}], "2"]}]]}], 
         ")"}]}]}], "]"}]}]}]}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.625159881385028*^9, 3.6251599043694057`*^9}, {
   3.6251600014363003`*^9, 3.625160042916421*^9}, {3.625160176467626*^9, 
   3.6251601819209423`*^9}, {3.625160332327895*^9, 3.6251603439641247`*^9}, {
   3.628062453764082*^9, 3.628062455323412*^9}, 3.628062530683573*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["One loop function HSS", "Subsubsection",
 CellChangeTimes->{{3.622265122173018*^9, 3.622265138059533*^9}, 
   3.6222652361225157`*^9, {3.622265969995983*^9, 3.622265971042828*^9}, 
   3.6223123275266447`*^9, {3.622312428002152*^9, 3.6223124301312103`*^9}, {
   3.6386117648103323`*^9, 3.6386117663477497`*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]HSS1laux", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
     RowBox[{
      SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
     RowBox[{
      SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
     RowBox[{
      SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
     RowBox[{
      SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
     RowBox[{
      SubscriptBox["X", "t"], "\[Rule]", "Xt"}], ",", 
     RowBox[{
      OverscriptBox["m", "~"], "\[Rule]", "mtilde"}]}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.622264726001223*^9, 3.6222647473938627`*^9}, {
   3.6222647796010733`*^9, 3.622264782358738*^9}, {3.622265111245438*^9, 
   3.622265111620495*^9}, 3.6222652361227703`*^9, {3.622265373957211*^9, 
   3.6222653800993547`*^9}, {3.62226545526199*^9, 3.622265456923568*^9}, 
   3.6223123275279512`*^9, 3.62237527306756*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "19200"], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"960", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SubsuperscriptBox["g", "1", "2"]}], "+", 
       RowBox[{"5", " ", 
        SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "27"}], " ", 
         SubsuperscriptBox["g", "1", "4"]}], "-", 
        RowBox[{"90", " ", 
         SubsuperscriptBox["g", "1", "2"], " ", 
         SubsuperscriptBox["g", "2", "2"]}], "+", 
        RowBox[{"25", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "8"}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
         " ", 
         SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], 
     SuperscriptBox["\[Pi]", "2"]], "-", 
    FractionBox[
     RowBox[{"200", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", 
         RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["M2", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         SubsuperscriptBox["g", "2", "4"]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q\[Mu]", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"9", " ", 
             SubsuperscriptBox["g", "1", "4"]}], "25"], "+", 
           SubsuperscriptBox["g", "2", "4"]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox["\[Pi]", "2"]], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["\[Pi]", "2"]], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
         RowBox[{"gg", "[", 
          FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
         SubsuperscriptBox["g", "1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"]}], "+", 
           RowBox[{"5", " ", 
            SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         SubsuperscriptBox["g", "1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "18"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{
            RowBox[{"f", "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "31"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"Sin", "[", 
               RowBox[{"6", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             ")"}]}], "-", 
           RowBox[{"7", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
            " ", 
            RowBox[{
             SubscriptBox["f", "1"], "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"9", " ", 
            RowBox[{
             SubscriptBox["f", "3"], "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}]}], "+", 
           RowBox[{"9", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "3"], "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"25", " ", 
         SubsuperscriptBox["g", "2", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
            RowBox[{"gg", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"26", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{
            RowBox[{"f", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "31"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"Sin", "[", 
               RowBox[{"6", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             ")"}]}], "-", 
           RowBox[{"27", " ", 
            RowBox[{
             SubscriptBox["f", "2"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"9", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "2"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"7", " ", 
            RowBox[{
             SubscriptBox["f", "4"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "+", 
           RowBox[{"7", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "4"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"5", " ", 
         SubsuperscriptBox["g", "1", "2"], " ", 
         SubsuperscriptBox["g", "2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
            " ", 
            RowBox[{"gg", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"24", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{"24", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"f", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"f", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"6", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"f", "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "+", 
              RowBox[{"Sin", "[", 
               RowBox[{"6", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             ")"}]}], "-", 
           RowBox[{"16", " ", 
            RowBox[{
             SubscriptBox["f", "5"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
           RowBox[{"16", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "5"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"42", " ", 
            RowBox[{
             SubscriptBox["f", "6"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"14", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "6"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SubscriptBox["f", "7"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "7"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"64", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "8"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
    "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["\[Pi]", "2"]], 
     RowBox[{"1200", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["3", "16"]}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"4", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
            SubsuperscriptBox["g", "2", "2"]}], ")"}], "2"]}], "-", 
        RowBox[{
         FractionBox["1", "4800"], 
         RowBox[{
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mA", "2"], 
            SuperscriptBox["mtilde", "2"]], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "29"}], "+", 
               RowBox[{"4", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
               
               RowBox[{"9", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"8", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
              ")"}], " ", 
             SubsuperscriptBox["g", "1", "4"]}], "-", 
            RowBox[{"360", " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"3", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
              ")"}], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], 
             " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"]}], "+", 
            RowBox[{"25", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "53"}], "+", 
               RowBox[{"28", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
               
               RowBox[{"9", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"8", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
              ")"}], " ", 
             SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}]}], "+", 
        RowBox[{
         FractionBox["1", "300"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mD1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mD2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mD3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mE1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mE2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mE3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mL1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mL2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mL3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"8", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mU1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"8", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mU2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"8", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mU3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
            SubsuperscriptBox["g", "1", "4"]}], "+", 
           RowBox[{"25", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mQ1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mQ2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mQ3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
            SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         SubsuperscriptBox["g", "t", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["2", "5"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            SubsuperscriptBox["g", "1", "2"]}], "+", 
           SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         SubsuperscriptBox["g", "t", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "10"]}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["g", "1", "2"], "-", 
              RowBox[{"5", " ", 
               SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
           SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Xt", "2"], " ", 
          SubsuperscriptBox["g", "t", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", "mQ3", " ", "mU3", " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "1"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["Xt", "2"], " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "2"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["mQ3", "2"], " ", 
          SuperscriptBox["mU3", "2"]}]], "+", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["Xt", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
          SubsuperscriptBox["g", "t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "3"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}], "+", 
            RowBox[{"5", " ", 
             SubsuperscriptBox["g", "2", "2"], " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "4"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
         RowBox[{"20", " ", "mQ3", " ", "mU3"}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Xt", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
            SubsuperscriptBox["g", "2", "2"]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "2"], " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["F", "~"], "5"], "[", 
           FractionBox["mQ3", "mU3"], "]"}]}], 
         RowBox[{"4", " ", "mQ3", " ", "mU3"}]]}], ")"}]}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.622375098169937*^9, 3.622375138376442*^9, 
  3.622375170264632*^9, 3.6251603775191803`*^9, 3.6358455007710667`*^9, 
  3.63584563802973*^9, 3.635845719049006*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]HSS1lsuppressedaux", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
     RowBox[{
      SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
     RowBox[{
      SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
     RowBox[{
      SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
     RowBox[{
      SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
     RowBox[{
      SubscriptBox["X", "t"], "\[Rule]", "Xt"}], ",", 
     RowBox[{
      OverscriptBox["m", "~"], "\[Rule]", "mtilde"}]}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.622264726001223*^9, 3.6222647473938627`*^9}, {
   3.6222647796010733`*^9, 3.622264782358738*^9}, {3.622265111245438*^9, 
   3.622265111620495*^9}, 3.6222652361227703`*^9, {3.622265373957211*^9, 
   3.6222653800993547`*^9}, {3.62226545526199*^9, 3.622265456923568*^9}, 
   3.6223123275279512`*^9, 3.62237527306756*^9, {3.635845702217544*^9, 
   3.635845722734096*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"19200", " ", 
    SuperscriptBox["\[Pi]", "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"factorfermions", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", 
           RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
        RowBox[{"gg", "[", 
         FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
        SubsuperscriptBox["g", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SubsuperscriptBox["g", "1", "2"]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
       RowBox[{"9", " ", 
        SubsuperscriptBox["g", "1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "22"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["Q\[Mu]", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["Q\[Mu]", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
          RowBox[{
           RowBox[{"f", "[", 
            FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "31"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
             RowBox[{"Sin", "[", 
              RowBox[{"6", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}]}],
           "-", 
          RowBox[{"7", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"4", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
           " ", 
           RowBox[{
            SubscriptBox["f", "1"], "[", 
            FractionBox["M1", "Q\[Mu]"], "]"}]}], "-", 
          RowBox[{"9", " ", 
           RowBox[{
            SubscriptBox["f", "3"], "[", 
            FractionBox["M1", "Q\[Mu]"], "]"}]}], "+", 
          RowBox[{"9", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{
            SubscriptBox["f", "3"], "[", 
            FractionBox["M1", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"25", " ", 
        SubsuperscriptBox["g", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"4", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
           " ", 
           RowBox[{"gg", "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
          RowBox[{"8", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["M2", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
          RowBox[{"8", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["M2", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
          RowBox[{"82", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["Q\[Mu]", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
          RowBox[{"10", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["Q\[Mu]", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"f", "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "31"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
             RowBox[{"Sin", "[", 
              RowBox[{"6", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}]}],
           "-", 
          RowBox[{"81", " ", 
           RowBox[{
            SubscriptBox["f", "2"], "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
          RowBox[{"27", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{
            SubscriptBox["f", "2"], "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
          RowBox[{"21", " ", 
           RowBox[{
            SubscriptBox["f", "4"], "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}]}], "+", 
          RowBox[{"21", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{
            SubscriptBox["f", "4"], "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"15", " ", 
        SubsuperscriptBox["g", "1", "2"], " ", 
        SubsuperscriptBox["g", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"4", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
           " ", 
           RowBox[{"gg", "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
          RowBox[{"24", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["Q\[Mu]", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
          RowBox[{"24", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["Q\[Mu]", "2"], 
             SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"f", "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"f", "[", 
            FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"6", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"f", "[", 
            FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "+", 
             RowBox[{"Sin", "[", 
              RowBox[{"6", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}]}],
           "-", 
          RowBox[{"16", " ", 
           RowBox[{
            SubscriptBox["f", "5"], "[", 
            RowBox[{
             FractionBox["M1", "Q\[Mu]"], ",", 
             FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
          RowBox[{"16", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{
            SubscriptBox["f", "5"], "[", 
            RowBox[{
             FractionBox["M1", "Q\[Mu]"], ",", 
             FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
          RowBox[{"42", " ", 
           RowBox[{
            SubscriptBox["f", "6"], "[", 
            RowBox[{
             FractionBox["M1", "Q\[Mu]"], ",", 
             FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
          RowBox[{"14", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{
            SubscriptBox["f", "6"], "[", 
            RowBox[{
             FractionBox["M1", "Q\[Mu]"], ",", 
             FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{
            SubscriptBox["f", "7"], "[", 
            RowBox[{
             FractionBox["M1", "Q\[Mu]"], ",", 
             FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{
            SubscriptBox["f", "7"], "[", 
            RowBox[{
             FractionBox["M1", "Q\[Mu]"], ",", 
             FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
          RowBox[{"64", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{
            SubscriptBox["f", "8"], "[", 
            RowBox[{
             FractionBox["M1", "Q\[Mu]"], ",", 
             FractionBox["M2", "Q\[Mu]"]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"1200", " ", "factorscalars", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["3", "16"]}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"4", " ", 
           RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"3", " ", 
             SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
           SubsuperscriptBox["g", "2", "2"]}], ")"}], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "4800"], 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mA", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "29"}], "+", 
              RowBox[{"4", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"9", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"8", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
             ")"}], " ", 
            SubsuperscriptBox["g", "1", "4"]}], "-", 
           RowBox[{"360", " ", 
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"3", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
             ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
            SubsuperscriptBox["g", "1", "2"], " ", 
            SubsuperscriptBox["g", "2", "2"]}], "+", 
           RowBox[{"25", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "53"}], "+", 
              RowBox[{"28", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"9", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"8", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
             ")"}], " ", 
            SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}]}], "+", 
       RowBox[{
        FractionBox["1", "300"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", 
           RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mD1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mD2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mD3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"6", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mE1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"6", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mE2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"6", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mE3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mQ1", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], "+", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mQ2", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], "+", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mQ3", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], "+", 
             RowBox[{"8", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mU1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"8", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mU2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"8", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mU3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
           SubsuperscriptBox["g", "1", "4"]}], "+", 
          RowBox[{"25", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mL1", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], "+", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mL2", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], "+", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mL3", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
           SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["mtilde", "2"]], "]"}], " ", 
        SubsuperscriptBox["g", "t", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["2", "5"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           SubsuperscriptBox["g", "1", "2"]}], "+", 
          SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["mtilde", "2"]], "]"}], " ", 
        SubsuperscriptBox["g", "t", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "10"]}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["g", "1", "2"], "-", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
          SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["Xt", "2"], " ", 
         SubsuperscriptBox["g", "t", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", "mQ3", " ", "mU3", " ", 
            RowBox[{
             SubscriptBox[
              OverscriptBox["F", "~"], "1"], "[", 
             FractionBox["mQ3", "mU3"], "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["Xt", "2"], " ", 
            RowBox[{
             SubscriptBox[
              OverscriptBox["F", "~"], "2"], "[", 
             FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"]}]], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["Xt", "2"], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", 
           RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
         SubsuperscriptBox["g", "t", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"], " ", 
            RowBox[{
             SubscriptBox[
              OverscriptBox["F", "~"], "3"], "[", 
             FractionBox["mQ3", "mU3"], "]"}]}], "+", 
           RowBox[{"5", " ", 
            SubsuperscriptBox["g", "2", "2"], " ", 
            RowBox[{
             SubscriptBox[
              OverscriptBox["F", "~"], "4"], "[", 
             FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
        RowBox[{"20", " ", "mQ3", " ", "mU3"}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["Xt", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"3", " ", 
             SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
           SubsuperscriptBox["g", "2", "2"]}], ")"}], " ", 
         SubsuperscriptBox["g", "t", "2"], " ", 
         RowBox[{
          SubscriptBox[
           OverscriptBox["F", "~"], "5"], "[", 
          FractionBox["mQ3", "mU3"], "]"}]}], 
        RowBox[{"4", " ", "mQ3", " ", "mU3"}]]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.622375098169937*^9, 3.622375138376442*^9, 
  3.622375170264632*^9, 3.6251603775191803`*^9, 3.6358455007710667`*^9, 
  3.63584563802973*^9, 3.6358457648475122`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]HSS1l", "[", 
   RowBox[{
   "mtilde_", ",", "mQ1_", ",", "mQ2_", ",", "mQ3_", ",", "mU1_", ",", "mU2_",
     ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", "mE1_", ",", 
    "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", ",", "mA_", 
    ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", "tan\[Beta]_", 
    ",", "Xt_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["1.", "19200"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"960", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", 
         RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SubsuperscriptBox["g", "1", "2"]}], "+", 
        RowBox[{"5", " ", 
         SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "27"}], " ", 
          SubsuperscriptBox["g", "1", "4"]}], "-", 
         RowBox[{"90", " ", 
          SubsuperscriptBox["g", "1", "2"], " ", 
          SubsuperscriptBox["g", "2", "2"]}], "+", 
         RowBox[{"25", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "8"}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
          " ", 
          SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], 
      SuperscriptBox["\[Pi]", "2"]], "-", 
     FractionBox[
      RowBox[{"200", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", 
          RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["M2", "2"], 
            SuperscriptBox["mtilde", "2"]], "]"}], " ", 
          SubsuperscriptBox["g", "2", "4"]}], "+", 
         RowBox[{
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["Q\[Mu]", "2"], 
            SuperscriptBox["mtilde", "2"]], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"9", " ", 
              SubsuperscriptBox["g", "1", "4"]}], "25"], "+", 
            SubsuperscriptBox["g", "2", "4"]}], ")"}]}]}], ")"}]}], 
      SuperscriptBox["\[Pi]", "2"]], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["\[Pi]", "2"]], "3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
         RowBox[{"gg", "[", 
          FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
         SubsuperscriptBox["g", "1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SubsuperscriptBox["g", "1", "2"]}], "+", 
           RowBox[{"5", " ", 
            SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         SubsuperscriptBox["g", "1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "18"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{
            RowBox[{"f", "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "31"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"Sin", "[", 
               RowBox[{"6", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             ")"}]}], "-", 
           RowBox[{"7", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
            " ", 
            RowBox[{
             SubscriptBox["f", "1"], "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"9", " ", 
            RowBox[{
             SubscriptBox["f", "3"], "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}]}], "+", 
           RowBox[{"9", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "3"], "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"25", " ", 
         SubsuperscriptBox["g", "2", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
            RowBox[{"gg", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"26", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{
            RowBox[{"f", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "31"}], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"Sin", "[", 
               RowBox[{"6", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             ")"}]}], "-", 
           RowBox[{"27", " ", 
            RowBox[{
             SubscriptBox["f", "2"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"9", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "2"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"7", " ", 
            RowBox[{
             SubscriptBox["f", "4"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "+", 
           RowBox[{"7", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "4"], "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"5", " ", 
         SubsuperscriptBox["g", "1", "2"], " ", 
         SubsuperscriptBox["g", "2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], ")"}], 
            " ", 
            RowBox[{"gg", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
           RowBox[{"24", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{"24", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["Q\[Mu]", "2"], 
              SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"f", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"f", "[", 
             FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"6", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"f", "[", 
             FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "+", 
              RowBox[{"Sin", "[", 
               RowBox[{"6", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             ")"}]}], "-", 
           RowBox[{"16", " ", 
            RowBox[{
             SubscriptBox["f", "5"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
           RowBox[{"16", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "5"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"42", " ", 
            RowBox[{
             SubscriptBox["f", "6"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"14", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "6"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SubscriptBox["f", "7"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "7"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
           RowBox[{"64", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{
             SubscriptBox["f", "8"], "[", 
             RowBox[{
              FractionBox["M1", "Q\[Mu]"], ",", 
              FractionBox["M2", "Q\[Mu]"]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["\[Pi]", "2"]], "1200", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["3", "16"]}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"4", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
            SubsuperscriptBox["g", "2", "2"]}], ")"}], "2"]}], "-", 
        RowBox[{
         FractionBox["1", "4800"], 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mA", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "29"}], "+", 
              RowBox[{"4", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"9", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"8", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
             ")"}], " ", 
            SubsuperscriptBox["g", "1", "4"]}], "-", 
           RowBox[{"360", " ", 
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"3", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
             ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", 
               RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
            SubsuperscriptBox["g", "1", "2"], " ", 
            SubsuperscriptBox["g", "2", "2"]}], "+", 
           RowBox[{"25", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "53"}], "+", 
              RowBox[{"28", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
              RowBox[{"9", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"8", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
             ")"}], " ", 
            SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "300"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mD1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mD2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mD3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mE1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mE2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mE3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mL1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mL2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mL3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mQ3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"8", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mU1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"8", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mU2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"8", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mU3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
            SubsuperscriptBox["g", "1", "4"]}], "+", 
           RowBox[{"25", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL1", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL2", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mL3", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mQ1", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mQ2", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mQ3", "2"], 
                 SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
            SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         SubsuperscriptBox["g", "t", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["2", "5"], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            SubsuperscriptBox["g", "1", "2"]}], "+", 
           SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["mtilde", "2"]], "]"}], " ", 
         SubsuperscriptBox["g", "t", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "10"]}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["g", "1", "2"], "-", 
              RowBox[{"5", " ", 
               SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
           SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Xt", "2"], " ", 
          SubsuperscriptBox["g", "t", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", "mQ3", " ", "mU3", " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "1"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["Xt", "2"], " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "2"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["mQ3", "2"], " ", 
          SuperscriptBox["mU3", "2"]}]], "+", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["Xt", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
          SubsuperscriptBox["g", "t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "3"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}], "+", 
            RowBox[{"5", " ", 
             SubsuperscriptBox["g", "2", "2"], " ", 
             RowBox[{
              SubscriptBox[
               OverscriptBox["F", "~"], "4"], "[", 
              FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
         RowBox[{"20", " ", "mQ3", " ", "mU3"}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Xt", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"3", " ", 
              SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
            SubsuperscriptBox["g", "2", "2"]}], ")"}], " ", 
          SubsuperscriptBox["g", "t", "2"], " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["F", "~"], "5"], "[", 
           FractionBox["mQ3", "mU3"], "]"}]}], 
         RowBox[{"4", " ", "mQ3", " ", "mU3"}]]}], ")"}]}]}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.622265187623082*^9, 3.622265190431396*^9}, 
   3.622265236124042*^9, {3.6222654049655743`*^9, 3.622265439898197*^9}, 
   3.622265503462841*^9, {3.622270255171176*^9, 3.6222702553337173`*^9}, 
   3.622312327534421*^9, {3.622353557472314*^9, 3.622353568014635*^9}, {
   3.6223750475674562`*^9, 3.6223750537020073`*^9}, {3.622375254440874*^9, 
   3.622375273068664*^9}, {3.625157517158475*^9, 3.625157523538151*^9}, {
   3.6251576371029*^9, 3.625157850579646*^9}, {3.6251578859545*^9, 
   3.6251578861599417`*^9}, {3.625158127556802*^9, 3.625158149777234*^9}, {
   3.625158218684161*^9, 3.625158279146139*^9}, {3.625160479262105*^9, 
   3.625160483622019*^9}, {3.625160647821281*^9, 3.625160649929702*^9}, 
   3.638560045650915*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]HSS1lsuppressed", "[", 
   RowBox[{
   "mtilde_", ",", "mQ1_", ",", "mQ2_", ",", "mQ3_", ",", "mU1_", ",", "mU2_",
     ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", "mE1_", ",", 
    "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", ",", "mA_", 
    ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", "tan\[Beta]_", 
    ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"factorfermions", "=", 
       FractionBox[
        SuperscriptBox["91", "2"], 
        SuperscriptBox[
         RowBox[{"Min", "[", 
          RowBox[{
           RowBox[{"Abs", "@", "Q\[Mu]"}], ",", 
           RowBox[{"Abs", "@", "M2"}]}], "]"}], "2"]]}], ",", 
      RowBox[{"factorscalars", "=", 
       FractionBox[
        SuperscriptBox["246", "2"], 
        RowBox[{"mQ3", " ", "mU3"}]]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], 
      FractionBox[
       SuperscriptBox["91", "2"], 
       SuperscriptBox["mA", "2"]], 
      FractionBox["1", "4"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["3", "5"], 
         SuperscriptBox[
          SubscriptBox["g", "1"], "2"]}], "+", 
        SuperscriptBox[
         SubscriptBox["g", "2"], "2"]}], ")"}], 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"4", 
         RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"]}], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"19200", " ", 
        SuperscriptBox["\[Pi]", "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"factorfermions", " ", 
         RowBox[{"Abs", "@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], 
             " ", 
             RowBox[{"gg", "[", 
              FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SubsuperscriptBox["g", "1", "2"]}], "+", 
               RowBox[{"5", " ", 
                SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
            RowBox[{"9", " ", 
             SubsuperscriptBox["g", "1", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "22"}], " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["Q\[Mu]", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["Q\[Mu]", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
               RowBox[{
                RowBox[{"f", "[", 
                 FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "31"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"6", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                 ")"}]}], "-", 
               RowBox[{"7", " ", 
                RowBox[{"(", 
                 RowBox[{"3", "+", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"4", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                 ")"}], " ", 
                RowBox[{
                 SubscriptBox["f", "1"], "[", 
                 FractionBox["M1", "Q\[Mu]"], "]"}]}], "-", 
               RowBox[{"9", " ", 
                RowBox[{
                 SubscriptBox["f", "3"], "[", 
                 FractionBox["M1", "Q\[Mu]"], "]"}]}], "+", 
               RowBox[{"9", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{
                 SubscriptBox["f", "3"], "[", 
                 FractionBox["M1", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"25", " ", 
             SubsuperscriptBox["g", "2", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"4", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                 ")"}], " ", 
                RowBox[{"gg", "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
               RowBox[{"8", " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["M2", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
               RowBox[{"8", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["M2", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
               RowBox[{"82", " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["Q\[Mu]", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "-", 
               RowBox[{"10", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["Q\[Mu]", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"f", "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "31"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                  "+", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"6", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                 ")"}]}], "-", 
               RowBox[{"81", " ", 
                RowBox[{
                 SubscriptBox["f", "2"], "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
               RowBox[{"27", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{
                 SubscriptBox["f", "2"], "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
               RowBox[{"21", " ", 
                RowBox[{
                 SubscriptBox["f", "4"], "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}]}], "+", 
               RowBox[{"21", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{
                 SubscriptBox["f", "4"], "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"15", " ", 
             SubsuperscriptBox["g", "1", "2"], " ", 
             SubsuperscriptBox["g", "2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"4", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                 ")"}], " ", 
                RowBox[{"gg", "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}]}], "-", 
               RowBox[{"24", " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["Q\[Mu]", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
               RowBox[{"24", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["Q\[Mu]", "2"], 
                  SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"f", "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
               
               RowBox[{"3", " ", 
                RowBox[{"f", "[", 
                 FractionBox["M2", "Q\[Mu]"], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"6", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "+", 
               
               RowBox[{
                RowBox[{"f", "[", 
                 FractionBox["M1", "Q\[Mu]"], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "+", 
                  
                  RowBox[{"Sin", "[", 
                   RowBox[{"6", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                 ")"}]}], "-", 
               RowBox[{"16", " ", 
                RowBox[{
                 SubscriptBox["f", "5"], "[", 
                 RowBox[{
                  FractionBox["M1", "Q\[Mu]"], ",", 
                  FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
               RowBox[{"16", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{
                 SubscriptBox["f", "5"], "[", 
                 RowBox[{
                  FractionBox["M1", "Q\[Mu]"], ",", 
                  FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
               RowBox[{"42", " ", 
                RowBox[{
                 SubscriptBox["f", "6"], "[", 
                 RowBox[{
                  FractionBox["M1", "Q\[Mu]"], ",", 
                  FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
               RowBox[{"14", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{
                 SubscriptBox["f", "6"], "[", 
                 RowBox[{
                  FractionBox["M1", "Q\[Mu]"], ",", 
                  FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{
                 SubscriptBox["f", "7"], "[", 
                 RowBox[{
                  FractionBox["M1", "Q\[Mu]"], ",", 
                  FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{
                 SubscriptBox["f", "7"], "[", 
                 RowBox[{
                  FractionBox["M1", "Q\[Mu]"], ",", 
                  FractionBox["M2", "Q\[Mu]"]}], "]"}]}], "-", 
               RowBox[{"64", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{
                 SubscriptBox["f", "8"], "[", 
                 RowBox[{
                  FractionBox["M1", "Q\[Mu]"], ",", 
                  FractionBox["M2", "Q\[Mu]"]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], "+", 
        RowBox[{"1200", " ", "factorscalars", " ", 
         RowBox[{"Abs", "@", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["3", "16"]}], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], 
             " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
                SubsuperscriptBox["g", "2", "2"]}], ")"}], "2"]}], "-", 
            RowBox[{
             FractionBox["1", "4800"], 
             RowBox[{
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mA", "2"], 
                SuperscriptBox["mtilde", "2"]], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"9", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "29"}], "+", 
                   RowBox[{"4", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"4", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                   "+", 
                   RowBox[{"9", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"8", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
                  ")"}], " ", 
                 SubsuperscriptBox["g", "1", "4"]}], "-", 
                RowBox[{"360", " ", 
                 RowBox[{"(", 
                  RowBox[{"5", "+", 
                   RowBox[{"3", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"4", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
                  ")"}], " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"2", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"],
                  " ", 
                 SubsuperscriptBox["g", "1", "2"], " ", 
                 SubsuperscriptBox["g", "2", "2"]}], "+", 
                RowBox[{"25", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "53"}], "+", 
                   RowBox[{"28", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"4", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                   "+", 
                   RowBox[{"9", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"8", " ", 
                    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]}], 
                  ")"}], " ", 
                 SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}]}], "+", 
            RowBox[{
             FractionBox["1", "300"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mD1", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mD2", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mD3", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"6", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mE1", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"6", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mE2", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"6", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mE3", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mL1", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mL2", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mL3", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"Log", "[", 
                   FractionBox[
                    SuperscriptBox["mQ1", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}], "+", 
                  RowBox[{"Log", "[", 
                   FractionBox[
                    SuperscriptBox["mQ2", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}], "+", 
                  RowBox[{"Log", "[", 
                   FractionBox[
                    SuperscriptBox["mQ3", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}], "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mU1", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mU2", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mU3", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
                SubsuperscriptBox["g", "1", "4"]}], "+", 
               RowBox[{"25", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Log", "[", 
                   FractionBox[
                    SuperscriptBox["mL1", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}], "+", 
                  RowBox[{"Log", "[", 
                   FractionBox[
                    SuperscriptBox["mL2", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}], "+", 
                  RowBox[{"Log", "[", 
                   FractionBox[
                    SuperscriptBox["mL3", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mQ1", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mQ2", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox[
                    SuperscriptBox["mQ3", "2"], 
                    SuperscriptBox["mtilde", "2"]], "]"}]}]}], ")"}], " ", 
                SubsuperscriptBox["g", "2", "4"]}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mU3", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], " ", 
             SubsuperscriptBox["g", "t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["2", "5"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                SubsuperscriptBox["g", "1", "2"]}], "+", 
               SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mQ3", "2"], 
               SuperscriptBox["mtilde", "2"]], "]"}], " ", 
             SubsuperscriptBox["g", "t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "10"]}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", 
                  RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["g", "1", "2"], "-", 
                  RowBox[{"5", " ", 
                   SubsuperscriptBox["g", "2", "2"]}]}], ")"}]}], "+", 
               SubsuperscriptBox["g", "t", "2"]}], ")"}]}], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["Xt", "2"], " ", 
              SubsuperscriptBox["g", "t", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"12", " ", "mQ3", " ", "mU3", " ", 
                 RowBox[{
                  SubscriptBox[
                   OverscriptBox["F", "~"], "1"], "[", 
                  FractionBox["mQ3", "mU3"], "]"}]}], "-", 
                RowBox[{
                 SuperscriptBox["Xt", "2"], " ", 
                 RowBox[{
                  SubscriptBox[
                   OverscriptBox["F", "~"], "2"], "[", 
                  FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
             RowBox[{"2", " ", 
              SuperscriptBox["mQ3", "2"], " ", 
              SuperscriptBox["mU3", "2"]}]], "+", 
            FractionBox[
             RowBox[{"3", " ", 
              SuperscriptBox["Xt", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], " ", 
              SubsuperscriptBox["g", "t", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SubsuperscriptBox["g", "1", "2"], " ", 
                 RowBox[{
                  SubscriptBox[
                   OverscriptBox["F", "~"], "3"], "[", 
                  FractionBox["mQ3", "mU3"], "]"}]}], "+", 
                RowBox[{"5", " ", 
                 SubsuperscriptBox["g", "2", "2"], " ", 
                 RowBox[{
                  SubscriptBox[
                   OverscriptBox["F", "~"], "4"], "[", 
                  FractionBox["mQ3", "mU3"], "]"}]}]}], ")"}]}], 
             RowBox[{"20", " ", "mQ3", " ", "mU3"}]], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["Xt", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}], "2"], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["g", "1", "2"]}], "5"], "+", 
                SubsuperscriptBox["g", "2", "2"]}], ")"}], " ", 
              SubsuperscriptBox["g", "t", "2"], " ", 
              RowBox[{
               SubscriptBox[
                OverscriptBox["F", "~"], "5"], "[", 
               FractionBox["mQ3", "mU3"], "]"}]}], 
             RowBox[{"4", " ", "mQ3", " ", "mU3"}]]}], ")"}]}]}]}], 
       ")"}]}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6358458211166773`*^9, 3.635845861577673*^9}, {
  3.635845907921398*^9, 3.635845933459248*^9}, {3.6358459806213217`*^9, 
  3.635846034756769*^9}, {3.6358463340033417`*^9, 3.6358463941804867`*^9}, {
  3.638044909817926*^9, 3.638044917643461*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "One loop ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SubscriptBox["\[Alpha]", "b"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") including tan\[Beta]-enhanced corrections"
}], "Subsubsection",
 CellChangeTimes->{{3.62119111331535*^9, 3.621191114051093*^9}, {
   3.6211911549748583`*^9, 3.621191174542444*^9}, 3.6211931357478*^9, 
   3.622266002963265*^9, 3.622266657733597*^9, {3.628063482251444*^9, 
   3.628063514210046*^9}, {3.6386106528043547`*^9, 3.638610685977252*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The one-loop tan\[Beta]-enhanced SUSY threshold contribution to \[Lambda] \
from the sbottom is in ",
 StyleBox["\[Lambda]2lbottom[ ].",
  FontSlant->"Italic"],
 " The factor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "b"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " used in the Appendix of the paper is defined as ",
 StyleBox["gbDR[ ] cos\[Beta] ",
  FontSlant->"Italic"],
 StyleBox["/",
  FontSize->16,
  FontSlant->"Italic"],
 StyleBox[" ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["g", "b"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.638611066392373*^9, 3.638611094374542*^9}, {
  3.6386111935440283`*^9, 3.638611394390648*^9}, {3.638611536581664*^9, 
  3.6386115698235292`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Auxiliar",
 FontVariations->{"Underline"->True}]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.6270641354274178`*^9, 3.627064151116722*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Lambda]2lbottomaux", ":=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]"}], ")"}], "2"]], 
    RowBox[{"(", 
     RowBox[{"6", 
      SuperscriptBox[
       SubscriptBox["g", "b"], "4"]}], ")"}], 
    FractionBox[
     SuperscriptBox[
      SubscriptBox["X", "b"], "2"], 
     RowBox[{"mQ3", " ", "mD3"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "1"], "[", 
       FractionBox["mQ3", "mD3"], "]"}], "-", 
      RowBox[{
       FractionBox["1", "12"], 
       FractionBox[
        SuperscriptBox[
         SubscriptBox["X", "b"], "2"], 
        RowBox[{"mQ3", " ", "mD3"}]], 
       RowBox[{
        SubscriptBox[
         OverscriptBox["F", "~"], "2"], "[", 
        FractionBox["mQ3", "mD3"], "]"}]}]}], ")"}], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", 
       RowBox[{"1", "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "\[Pi]"}], ")"}], 
          RowBox[{"-", "2"}]], 
         SubscriptBox["\[CapitalDelta]h", "b"]}]}]], ")"}], "4"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[CapitalDelta]h", "b"], ":=", 
   RowBox[{
    RowBox[{
     FractionBox["8", "3"], " ", 
     SubsuperscriptBox["g", "3", "2"], "M3", " ", 
     SubscriptBox["X", "b"], " ", 
     RowBox[{"II", "[", 
      RowBox[{"mQ3", ",", "mD3", ",", "M3"}], "]"}]}], "-", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       SubscriptBox["g", "t"], "2"], 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}], "]"}], "2"]], " ", 
     "\[Mu]", " ", "tan\[Beta]", " ", 
     SubscriptBox["X", "t"], " ", 
     RowBox[{"II", "[", 
      RowBox[{"mQ3", ",", "mU3", ",", "\[Mu]"}], "]"}]}]}]}], ";"}]}], "Input",\

 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.627062278307995*^9, 3.627062315922945*^9}, {
   3.627062347305262*^9, 3.627062602578443*^9}, {3.627062645184227*^9, 
   3.627062654490965*^9}, {3.627062724005007*^9, 3.627062730850717*^9}, {
   3.627062861517906*^9, 3.6270628690122347`*^9}, {3.627062927130417*^9, 
   3.627062940037138*^9}, {3.6270630144097443`*^9, 3.627063087503401*^9}, {
   3.6270631639159107`*^9, 3.6270632244330606`*^9}, 3.62706325957803*^9, {
   3.6270636069382267`*^9, 3.6270637191989822`*^9}, {3.627063765551765*^9, 
   3.627063794728344*^9}, {3.6270638428125153`*^9, 3.6270638661306477`*^9}, {
   3.627063941285627*^9, 3.627063957451069*^9}, {3.627064033171528*^9, 
   3.6270640347105427`*^9}, {3.627064070384933*^9, 3.627064071383066*^9}, 
   3.627064151116922*^9}],

Cell[BoxData[
 RowBox[{"\[Lambda]2lbottomaux", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["X", "b"], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", "tan\[Beta]"}]}], ",", 
    RowBox[{
     SubscriptBox["X", "t"], "\[Rule]", "Xt"}]}], "}"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.627062833347836*^9, 3.627062849627123*^9}, {
   3.627064053028019*^9, 3.627064057051713*^9}, 3.627064151117013*^9, 
   3.627067095336252*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   SuperscriptBox["tan\[Beta]", "2"], " ", 
   SuperscriptBox["\[Mu]", "2"], " ", 
   SubsuperscriptBox["g", "b", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["F", "~"], "1"], "[", 
      FractionBox["mQ3", "mD3"], "]"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["tan\[Beta]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["F", "~"], "2"], "[", 
        FractionBox["mQ3", "mD3"], "]"}]}], 
      RowBox[{"12", " ", "mD3", " ", "mQ3"}]]}], ")"}]}], 
  RowBox[{"8", " ", "mD3", " ", "mQ3", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["8", "3"]}], " ", "M3", " ", "tan\[Beta]", " ", "\[Mu]",
          " ", 
         RowBox[{"II", "[", 
          RowBox[{"mQ3", ",", "mD3", ",", "M3"}], "]"}], " ", 
         SubsuperscriptBox["g", "3", "2"]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["tan\[Beta]", "2"]}], ")"}], " ", "Xt", " ", 
          "\[Mu]", " ", 
          RowBox[{"II", "[", 
           RowBox[{"mQ3", ",", "mU3", ",", "\[Mu]"}], "]"}], " ", 
          SubsuperscriptBox["g", "t", "2"]}], "tan\[Beta]"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], "4"]}]]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.627062655908223*^9, {3.627062826083096*^9, 3.627062870786869*^9}, 
   3.627063972498301*^9, {3.627064037364133*^9, 3.6270640739414043`*^9}, 
   3.6270641511171083`*^9, {3.627067099221983*^9, 3.627067102874899*^9}}]
}, Closed]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]2lbottom", "[", 
    RowBox[{
    "mQ3_", ",", "mU3_", ",", "mD3_", ",", "M3_", ",", "\[Mu]_", ",", 
     "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["6", 
     RowBox[{"16", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gbDR", "[", 
        RowBox[{
        "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", "\[Mu]", ",", 
         "tan\[Beta]", ",", "Xt"}], "]"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}], "]"}]}], ")"}], "4"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["tan\[Beta]", "2"], " ", 
      SuperscriptBox["\[Mu]", "2"]}], 
     RowBox[{" ", 
      RowBox[{"mD3", " ", "mQ3", " "}]}]], "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "1"], "[", 
       FractionBox["mQ3", "mD3"], "]"}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["tan\[Beta]", "2"], " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["F", "~"], "2"], "[", 
         FractionBox["mQ3", "mD3"], "]"}]}], 
       RowBox[{"12", " ", "mD3", " ", "mQ3"}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gbDR", "[", 
    RowBox[{
    "mQ3_", ",", "mU3_", ",", "mD3_", ",", "M3_", ",", "\[Mu]_", ",", 
     "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     SubscriptBox["g", "b"], 
     RowBox[{"Cos", "[", 
      RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}], "]"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["8", "3"]}], " ", "M3", " ", "tan\[Beta]", " ", 
          "\[Mu]", " ", 
          RowBox[{"II", "[", 
           RowBox[{"mQ3", ",", "mD3", ",", "M3"}], "]"}], " ", 
          SubsuperscriptBox["g", "3", "2"]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}], ")"}], " ", "Xt", " ", 
           "\[Mu]", " ", 
           RowBox[{"II", "[", 
            RowBox[{"mQ3", ",", "mU3", ",", "\[Mu]"}], "]"}], " ", 
           SubsuperscriptBox["g", "t", "2"]}], "tan\[Beta]"]}], 
        RowBox[{"16", " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], 
     RowBox[{"-", "1"}]]}]}], ";", 
  RowBox[{
   RowBox[{"II", "[", 
    RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"2", 
           SuperscriptBox["a", "2"]}]], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"a", "-", "b"}], "]"}], "<", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}], "&&", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"a", "-", 
             RowBox[{"Abs", "[", "c", "]"}]}], "]"}], "<", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["a", "2"]], 
          FractionBox["1", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"c", "/", "a"}], ")"}], "2"]}]], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"c", "/", "a"}], ")"}], "2"], 
              RowBox[{"Log", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"c", "/", "a"}], ")"}], "2"], "]"}]}], 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"c", "/", "a"}], ")"}], "2"]}]]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"a", "-", "b"}], "]"}], "<", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SuperscriptBox["a", "2"]]}], 
          FractionBox["1", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"c", "/", "a"}], ")"}], "2"]}]], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"Log", "[", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"c", "/", "a"}], ")"}], "2"], "]"}], 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"c", "/", "a"}], ")"}], "2"]}]]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"b", "-", 
            RowBox[{"Abs", "[", "c", "]"}]}], "]"}], "<", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SuperscriptBox["b", "2"]]}], 
          FractionBox["1", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"c", "/", "b"}], ")"}], "2"]}]], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"Log", "[", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"c", "/", "b"}], ")"}], "2"], "]"}], 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"c", "/", "b"}], ")"}], "2"]}]]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"a", "-", 
            RowBox[{"Abs", "[", "c", "]"}]}], "]"}], "<", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}]}], "}"}]}], "}"}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["a", "2"], 
          SuperscriptBox["b", "2"]], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["b", "2"], 
          SuperscriptBox["c", "2"]], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["c", "2"], 
          SuperscriptBox["a", "2"]], "]"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}]}]]}], "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627064003512279*^9, 3.627064120615611*^9}, 
   3.627067124227556*^9, 3.627067285570196*^9, 3.627067569224793*^9, {
   3.627068439863797*^9, 3.627068447548938*^9}, {3.627068510269907*^9, 
   3.6270685106595497`*^9}, {3.628063556889017*^9, 3.6280635816797123`*^9}, 
   3.636363747566255*^9, 3.636363799130219*^9, {3.636363900081558*^9, 
   3.636364008257818*^9}, {3.6363640470807943`*^9, 3.636364054897677*^9}, {
   3.6363643515882673`*^9, 3.6363643525945168`*^9}, {3.636364475915667*^9, 
   3.636364485920465*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "One loop ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SubscriptBox["\[Alpha]", "\[Tau]"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") including tan\[Beta]-enhanced corrections"
}], "Subsubsection",
 CellChangeTimes->{{3.62119111331535*^9, 3.621191114051093*^9}, {
   3.6211911549748583`*^9, 3.621191174542444*^9}, 3.6211931357478*^9, 
   3.622266002963265*^9, 3.622266657733597*^9, {3.628063482251444*^9, 
   3.628063514210046*^9}, {3.636704964277294*^9, 3.636704972944518*^9}, {
   3.6386106907849817`*^9, 3.6386106961395617`*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The one-loop tan\[Beta]-enhanced SUSY threshold contribution to \[Lambda] \
from the sbottom is in \[Lambda]2ltau",
 StyleBox["[ ].",
  FontSlant->"Italic"],
 " The factor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "\[Tau]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " used in the Appendix of the paper is defined as ",
 StyleBox["gtauDR[ ] cos\[Beta] ",
  FontSlant->"Italic"],
 StyleBox["/",
  FontSize->16,
  FontSlant->"Italic"],
 StyleBox[" ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["g", "\[Tau]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.638611066392373*^9, 3.638611094374542*^9}, {
  3.6386111935440283`*^9, 3.638611394390648*^9}, {3.638611536581664*^9, 
  3.6386115698235292`*^9}, {3.638611629939006*^9, 3.638611657289145*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]2ltau", "[", 
    RowBox[{
    "mL3_", ",", "mE3_", ",", "M2_", ",", "M1_", ",", "\[Mu]_", ",", 
     "tan\[Beta]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["2", 
      RowBox[{"16", 
       SuperscriptBox["\[Pi]", "2"]}]], ")"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gtauDR", "[", 
        RowBox[{
        "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", "\[Mu]", ",", 
         "tan\[Beta]"}], "]"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}], "]"}]}], ")"}], "4"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["tan\[Beta]", "2"], " ", 
      SuperscriptBox["\[Mu]", "2"]}], 
     RowBox[{" ", 
      RowBox[{"mL3", " ", "mE3", " "}]}]], "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        OverscriptBox["F", "~"], "1"], "[", 
       FractionBox["mL3", "mE3"], "]"}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["tan\[Beta]", "2"], " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["F", "~"], "2"], "[", 
         FractionBox["mL3", "mE3"], "]"}]}], 
       RowBox[{"12", " ", "mL3", " ", "mE3"}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gtauDR", "[", 
    RowBox[{
    "mL3_", ",", "mE3_", ",", "M2_", ",", "M1_", ",", "\[Mu]_", ",", 
     "tan\[Beta]_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     SubscriptBox["g", "\[Tau]"], 
     RowBox[{"Cos", "[", 
      RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}], "]"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "\[Pi]"}], ")"}], "2"]], "tan\[Beta]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            SubscriptBox["g", "2"], "2"], "M2", " ", "\[Mu]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"II", "[", 
              RowBox[{"mL3", ",", "M2", ",", "\[Mu]"}], "]"}], "+", 
             RowBox[{
              FractionBox["1", "2"], 
              RowBox[{"II", "[", 
               RowBox[{"mL3", ",", "M2", ",", "\[Mu]"}], "]"}]}]}], ")"}]}], 
          "-", 
          RowBox[{
           FractionBox["3", "5"], 
           SuperscriptBox[
            SubscriptBox["g", "1"], "2"], "M1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "\[Mu]"}], " ", 
              RowBox[{"II", "[", 
               RowBox[{"mL3", ",", "mE3", ",", "M1"}], "]"}]}], "+", 
             RowBox[{
              FractionBox["1", "2"], "\[Mu]", " ", 
              RowBox[{"II", "[", 
               RowBox[{"mL3", ",", "M1", ",", "\[Mu]"}], "]"}]}], "-", 
             RowBox[{"\[Mu]", " ", 
              RowBox[{"II", "[", 
               RowBox[{"mE3", ",", "M1", ",", "\[Mu]"}], "]"}]}]}], ")"}]}]}],
          ")"}]}]}], ")"}], 
     RowBox[{"-", "1"}]]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627064003512279*^9, 3.627064120615611*^9}, 
   3.627067124227556*^9, 3.627067285570196*^9, 3.627067569224793*^9, {
   3.627068439863797*^9, 3.627068447548938*^9}, {3.627068510269907*^9, 
   3.6270685106595497`*^9}, {3.628063556889017*^9, 3.6280635816797123`*^9}, 
   3.636363747566255*^9, 3.636363799130219*^9, {3.636363900081558*^9, 
   3.636364008257818*^9}, {3.6363640470807943`*^9, 3.636364054897677*^9}, {
   3.6363643515882673`*^9, 3.6363643525945168`*^9}, {3.636364475915667*^9, 
   3.636364485920465*^9}, {3.6367049827203712`*^9, 3.636704983709671*^9}, {
   3.6367051508883753`*^9, 3.636705175969356*^9}, {3.6367052311618443`*^9, 
   3.636705299087359*^9}, {3.636705329852376*^9, 3.636705397842352*^9}, {
   3.636705454661707*^9, 3.636705708804082*^9}, {3.636705837729538*^9, 
   3.6367058406812*^9}, 3.636706001933937*^9, 3.6367064144846697`*^9, {
   3.638042166460384*^9, 3.638042191152563*^9}, {3.638045277263734*^9, 
   3.6380453113913717`*^9}, {3.6380453701211853`*^9, 3.6380455023118267`*^9}, 
   3.638188840316965*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two - Loops", "Subsection",
 CellChangeTimes->{{3.6222659824095716`*^9, 3.622265993801209*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Two - Loop",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"O", "(", 
     RowBox[{
      SubscriptBox["\[Alpha]", "t"], 
      SubscriptBox["\[Alpha]", "S"]}]}]}], TraditionalForm]],
  FontWeight->"Plain"],
 ") auxiliar manipulation"
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.621144589037407*^9, 3.621144616512233*^9}, 
   3.621144791574795*^9, {3.621145079873595*^9, 3.6211451048610973`*^9}, {
   3.622266001115625*^9, 3.622266005733881*^9}, {3.622266239434598*^9, 
   3.6222662423626966`*^9}, {3.628063272989092*^9, 3.6280632834363728`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"\[CapitalDelta]\[Lambda]2lstrongdegenerateaux", ":=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"96", " ", 
     SuperscriptBox["\[Pi]", "4"]}]], 
   SuperscriptBox["g3", "2"], " ", 
   SuperscriptBox["gt", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["Xth", "5"]}], "+", 
     RowBox[{"Xth", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "12"}], "-", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["Xth", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "2"], "-", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], ")"}]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["Xth", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["Xth", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "6"}], "+", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.621155867125914*^9, 3.621155987233982*^9}, 
   3.6211560202557173`*^9, {3.622266234874892*^9, 3.622266235790102*^9}, 
   3.62701813681124*^9}],

Cell[BoxData[
 RowBox[{"\[CapitalDelta]\[Lambda]2lstrongaux", ":=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"96", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", 
      SubsuperscriptBox["m", 
       SubscriptBox["Q", "3"], "2"], " ", 
      SubsuperscriptBox["m", 
       SubscriptBox["U", "3"], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"]}], "+", 
         SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"]}], "+", 
         SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"]}]], 
    SubsuperscriptBox["g", "3", "2"], " ", 
    SubsuperscriptBox["g", "t", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"]}], "+", 
      RowBox[{"27", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"30", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"27", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"30", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"24", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         RowBox[{
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], "-", 
          SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"72", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"72", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"72", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"72", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"72", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"24", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         RowBox[{
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], "-", 
          SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "4"]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"57", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"54", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"21", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"39", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         RowBox[{
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], "-", 
          SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"57", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"54", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"39", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"21", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         RowBox[{
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], "-", 
          SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "6"], " ", 
       SubsuperscriptBox["M", "3", "6"]}], "-", 
      RowBox[{"12", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"39", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"36", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "+", 
      RowBox[{"21", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "+", 
      RowBox[{"21", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "+", 
      RowBox[{"18", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], 
          SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], 
         RowBox[{
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"], "-", 
          SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], 
         RowBox[{
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"], "-", 
          SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"12", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "4"], " ", 
       SubsuperscriptBox["M", "3", "8"]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "10"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "10"]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "10"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "10"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         FractionBox[
          SubsuperscriptBox["M", "3", "2"], 
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"]]}], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"]}], "+", 
          SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         FractionBox[
          SubsuperscriptBox["M", "3", "2"], 
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"]]}], "]"}], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], " ", 
       SubsuperscriptBox["m", 
        SubscriptBox["U", "3"], "2"], " ", 
       SubsuperscriptBox["M", "3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"]}], "+", 
          SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["g", "3", "2"], " ", 
      SubsuperscriptBox["g", "t", "4"], " ", 
      SubscriptBox["M", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "6"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SubsuperscriptBox["M", "3", "2"], 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"]]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["m", 
              SubscriptBox["Q", "3"], "2"]}], " ", 
            SubsuperscriptBox["M", "3", "2"]}], "+", 
           SubsuperscriptBox["M", "3", "4"]}], ")"}]}], "-", 
        RowBox[{"12", " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SubsuperscriptBox["M", "3", "2"], 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["m", 
              SubscriptBox["U", "3"], "2"]}], " ", 
            SubsuperscriptBox["M", "3", "2"]}], "+", 
           SubsuperscriptBox["M", "3", "4"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["X", "t"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"24", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["m", 
         SubscriptBox["Q", "3"], "2"], "-", 
        SubsuperscriptBox["m", 
         SubscriptBox["U", "3"], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"]}], "+", 
        SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        SubsuperscriptBox["M", "3", "2"]}], ")"}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["g", "3", "2"], " ", 
      SubsuperscriptBox["g", "t", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["m", 
              SubscriptBox["U", "3"], "2"]}], "+", 
            SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "6"]}], "-", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "4"], " ", 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "4"]}], "+", 
              RowBox[{"4", " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"]}]}], ")"}], " ", 
            SubsuperscriptBox["M", "3", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"]}], "-", 
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"]}], ")"}], " ", 
            SubsuperscriptBox["M", "3", "4"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]}], "+", 
           SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["Q", "2"], 
                SubsuperscriptBox["M", "3", "2"]], "]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], "-", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"]}], ")"}], "2"], " ", 
            SubsuperscriptBox["M", "3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"]}], "+", 
              SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SubsuperscriptBox["m", 
                 SubscriptBox["U", "3"], "2"]}], "+", 
               SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Log", "[", 
              FractionBox[
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"], 
               SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], " ", 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["m", 
                  SubscriptBox["Q", "3"], "2"], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "4"], " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}], "+", 
                 RowBox[{"6", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"], " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "4"]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "6"]}]}], ")"}], " ", 
               SubsuperscriptBox["M", "3", "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["m", 
                  SubscriptBox["Q", "3"], "4"], "+", 
                 RowBox[{
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"], " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}], "-", 
                 RowBox[{"8", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "4"]}]}], ")"}], " ", 
               SubsuperscriptBox["M", "3", "4"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["m", 
                  SubscriptBox["Q", "3"], "2"], "-", 
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}]}], ")"}], " ", 
               SubsuperscriptBox["M", "3", "6"]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox[
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"], 
              SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], " ", 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["m", 
               SubscriptBox["Q", "3"], "2"], "-", 
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"], "-", 
              SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}]}], ")"}], " ", 
               SubsuperscriptBox["M", "3", "2"]}], "+", 
              RowBox[{"7", " ", 
               SubsuperscriptBox["M", "3", "4"]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["Q", "2"], 
                 SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"]}], "+", 
                 SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}], "+", 
                 SubsuperscriptBox["M", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox[
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"], 
              SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "4"], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["m", 
                  SubscriptBox["Q", "3"], "2"], "+", 
                 SubsuperscriptBox["m", 
                  SubscriptBox["U", "3"], "2"]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"], "+", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}], ")"}], "2"], " ", 
               SubsuperscriptBox["M", "3", "2"]}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"], "+", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}], ")"}], "3"], " ", 
               SubsuperscriptBox["M", "3", "4"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "4"]}], "+", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"], " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "4"]}]}], ")"}], " ", 
               SubsuperscriptBox["M", "3", "6"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["m", 
                  SubscriptBox["Q", "3"], "2"], "+", 
                 SubsuperscriptBox["m", 
                  SubscriptBox["U", "3"], "2"]}], ")"}], " ", 
               SubsuperscriptBox["M", "3", "8"]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["m", 
               SubscriptBox["Q", "3"], "2"], "-", 
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"]}], "+", 
              SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"]}], "+", 
              SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["Q", "3"], "2"], " ", 
               SubsuperscriptBox["m", 
                SubscriptBox["U", "3"], "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}]}], ")"}], " ", 
               SubsuperscriptBox["M", "3", "2"]}], "+", 
              RowBox[{"7", " ", 
               SubsuperscriptBox["M", "3", "4"]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["Q", "2"], 
                 SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["Q", "3"], "2"]}], "+", 
                 SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SubsuperscriptBox["m", 
                   SubscriptBox["U", "3"], "2"]}], "+", 
                 SubsuperscriptBox["M", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], " ", 
      SubsuperscriptBox["X", "t", "2"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"16", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", 
      SubsuperscriptBox["m", 
       SubscriptBox["Q", "3"], "2"], " ", 
      SubsuperscriptBox["m", 
       SubscriptBox["U", "3"], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], "-", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"]}], "+", 
         SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"]}], "+", 
         SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["g", "3", "2"], " ", 
      SubsuperscriptBox["g", "t", "4"], " ", 
      SubscriptBox["M", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{"8", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"]}], "+", 
        RowBox[{"8", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"8", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SubsuperscriptBox["M", "3", "2"], 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]}], "+", 
           SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"]}], "+", 
           SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]}], "-", 
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], "+", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["M", "3", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SubsuperscriptBox["M", "3", "2"], 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"]]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]}], "+", 
           SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"]}], "+", 
           SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]}], "-", 
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], "+", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["M", "3", "2"]}]}], ")"}]}]}], ")"}], " ", 
      SubsuperscriptBox["X", "t", "3"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], "-", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"]}], "+", 
        SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        SubsuperscriptBox["M", "3", "2"]}], ")"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["g", "3", "2"], " ", 
      SubsuperscriptBox["g", "t", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"10", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "-", 
        RowBox[{"15", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"]}], "-", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"]}], "-", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"]}], "+", 
        RowBox[{"10", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "-", 
        RowBox[{"15", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"]}], "-", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"22", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"31", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"7", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"22", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"27", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"22", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"27", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"22", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"7", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"31", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "2"]}], "+", 
        RowBox[{"8", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"5", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"24", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"44", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"64", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"64", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"38", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"19", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"38", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"38", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"19", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"24", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"44", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"24", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"8", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"5", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "4"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"18", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"29", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"9", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"10", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"18", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"7", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"13", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"22", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"18", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"13", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"7", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"22", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"18", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"9", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"29", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"10", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "10"], " ", 
         SubsuperscriptBox["M", "3", "6"]}], "-", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"14", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"7", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"10", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"10", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"20", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"16", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"8", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"14", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"7", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"10", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"10", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "8"], " ", 
         SubsuperscriptBox["M", "3", "8"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "4"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], 
            SubsuperscriptBox["M", "3", "2"]], "]"}], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           RowBox[{
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"], "-", 
            SubsuperscriptBox["M", "3", "2"]}]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "4"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "6"], " ", 
         SubsuperscriptBox["M", "3", "10"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SubsuperscriptBox["M", "3", "2"], 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "2"]]}], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["m", 
              SubscriptBox["Q", "3"], "2"]}], "+", 
            SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["m", 
              SubscriptBox["U", "3"], "2"]}], "+", 
            SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "4"]}], "+", 
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "4"], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["m", 
               SubscriptBox["Q", "3"], "2"], "-", 
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"]}], ")"}], " ", 
            SubsuperscriptBox["M", "3", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SubsuperscriptBox["M", "3", "2"], 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"]]}], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["m", 
              SubscriptBox["Q", "3"], "2"]}], "+", 
            SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["m", 
              SubscriptBox["U", "3"], "2"]}], "+", 
            SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["Q", "3"], "4"]}], "+", 
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "4"], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["m", 
               SubscriptBox["Q", "3"], "2"], "-", 
              SubsuperscriptBox["m", 
               SubscriptBox["U", "3"], "2"]}], ")"}], " ", 
            SubsuperscriptBox["M", "3", "2"]}]}], ")"}]}]}], ")"}], " ", 
      SubsuperscriptBox["X", "t", "4"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"32", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", 
      SubsuperscriptBox["m", 
       SubscriptBox["Q", "3"], "2"], " ", 
      SubsuperscriptBox["m", 
       SubscriptBox["U", "3"], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], "-", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], ")"}], "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["m", 
           SubscriptBox["Q", "3"], "2"]}], "+", 
         SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["m", 
           SubscriptBox["U", "3"], "2"]}], "+", 
         SubsuperscriptBox["M", "3", "2"]}], ")"}], "2"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["g", "3", "2"], " ", 
      SubsuperscriptBox["g", "t", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], "+", 
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], "+", 
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["M", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["U", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], "-", 
           SubsuperscriptBox["M", "3", "2"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           SubsuperscriptBox["m", 
            SubscriptBox["Q", "3"], "2"], 
           SubsuperscriptBox["M", "3", "2"]], "]"}], " ", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["m", 
             SubscriptBox["U", "3"], "2"]}], "+", 
           SubsuperscriptBox["M", "3", "2"]}], ")"}]}]}], ")"}], " ", 
      SubsuperscriptBox["X", "t", "5"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"], "-", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], ")"}], "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["m", 
          SubscriptBox["Q", "3"], "2"]}], "+", 
        SubsuperscriptBox["M", "3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["m", 
          SubscriptBox["U", "3"], "2"]}], "+", 
        SubsuperscriptBox["M", "3", "2"]}], ")"}]}], ")"}]}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.6211450665700817`*^9, 3.621145072408861*^9}, 
   3.6211451193831577`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Two - Loop",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"O", "(", 
     RowBox[{
      SubscriptBox["\[Alpha]", "t"], 
      SubscriptBox["\[Alpha]", "S"]}]}]}], TraditionalForm]],
  FontWeight->"Plain"],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.6280633268605127`*^9, 3.628063367192389*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The complete analytical expression for the two-loop ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{
     SubscriptBox["\[Alpha]", "t"], 
     SubscriptBox["\[Alpha]", "s"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") correction in the ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["DR", "_"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " scheme can be found in the definition of the function ",
 "\[CapitalDelta]\[Lambda]2lstronggeneral",
 StyleBox["[ ].",
  FontSlant->"Italic"],
 " In the on-shell scheme one needs to add the shift contribution given in \
the function ",
 StyleBox["shiftDROS\[Alpha]t\[Alpha]Sgeneral[ ].",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.6386107363072653`*^9, 3.638610853247431*^9}, 
   3.638610903302285*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]2lstrong", "[", 
   RowBox[{"mtilde_", ",", "mQ3_", ",", "mU3_", ",", "Xt_", ",", "M3_"}], 
   "]"}], ":=", 
  RowBox[{
   SuperscriptBox[
    SubscriptBox["g", "3"], "2"], 
   SuperscriptBox[
    SubscriptBox["g", "t"], "4"], 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Delta]", "=", 
        RowBox[{"8", " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "2"}]]}]}], ",", 
       RowBox[{"\[Delta]2", "=", 
        RowBox[{"1", " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "2"}]]}]}]}], "}"}], ",", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[Lambda]2lstrongdegenerate", "[", 
            RowBox[{"mtilde", ",", "mQ3", ",", "Xt"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{
               FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<", 
             "\[Delta]2"}], "&&", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{
               FractionBox["M3", "mU3"], "-", "1"}], "]"}], "<", 
             "\[Delta]2"}], "&&", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{
               FractionBox["M3", "mQ3"], "-", "1"}], "]"}], "<", 
             "\[Delta]2"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
               RowBox[{
                RowBox[{"1.", "mtilde"}], ",", 
                RowBox[{"mU3", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Delta]"}], ")"}]}], ",", "mU3", ",", 
                "Xt", " ", ",", "M3"}], "]"}], "]"}], 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"mQ3", "-", 
                RowBox[{"mU3", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}], 
              RowBox[{"2", "mU3", " ", "\[Delta]"}]]}], "+", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
               RowBox[{
                RowBox[{"1.", "mtilde"}], ",", 
                RowBox[{"mU3", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Delta]"}], ")"}]}], ",", "mU3", ",", 
                "Xt", " ", ",", "M3"}], "]"}], "]"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"mQ3", "-", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], 
                RowBox[{"2", " ", "mU3", " ", "\[Delta]"}]]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<=", " ", 
            "\[Delta]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
               RowBox[{
                RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                " ", ",", 
                RowBox[{"mQ3", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"M3", "-", 
                RowBox[{"mQ3", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}], 
              RowBox[{"2", "mQ3", " ", "\[Delta]"}]]}], "+", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
               RowBox[{
                RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                " ", ",", 
                RowBox[{"mQ3", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"M3", "-", 
                 RowBox[{"mQ3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], 
                RowBox[{"2", "mQ3", " ", "\[Delta]"}]]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              FractionBox["mQ3", "M3"], "-", "1"}], "]"}], "<=", 
            "\[Delta]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
               RowBox[{
                RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                " ", ",", 
                RowBox[{"mU3", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"M3", "-", 
                RowBox[{"mU3", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}], 
              RowBox[{"2", "mU3", " ", "\[Delta]"}]]}], "+", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
               RowBox[{
                RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                " ", ",", 
                RowBox[{"mU3", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"M3", "-", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], 
                RowBox[{"2", "mU3", " ", "\[Delta]"}]]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              FractionBox["mU3", "M3"], "-", "1"}], "]"}], "<=", " ", 
            "\[Delta]"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"Re", "[", 
        RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
         RowBox[{"mtilde", ",", 
          RowBox[{"1.", "mQ3"}], ",", "mU3", ",", "Xt", " ", ",", "M3"}], 
         "]"}], "]"}]}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "The", " ", "two", " ", "loop", " ", "corrections", " ", "has", " ", 
      "singularities", " ", "for", " ", "mQ3"}], "\[Rule]", "mU3"}], ",", " ", 
    RowBox[{"mU3", "\[Rule]", 
     RowBox[{
      RowBox[{"M3", " ", "and", " ", "mQ3"}], "\[Rule]", 
      RowBox[{
       RowBox[{"mU3", ".", " ", "We"}], " ", "avoid", " ", "evaluating", " ", 
       "the", " ", "function", " ", "at", " ", "the", " ", "singular", " ", 
       "points", " ", "by", " ", "using", " ", "a", " ", "linear", " ", 
       "interpolation", " ", "near", " ", "the", " ", "singular", " ", 
       "point"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"i", ".", "e", ".", " ", "for"}], " ", "|", 
     RowBox[{"x", "-", 
      SubscriptBox["x", "0"]}], "|", 
     RowBox[{"<", 
      RowBox[{"\[Delta]", "."}]}]}]}], "*)"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627019911174324*^9, 3.627019974234519*^9}, {
   3.627020419646247*^9, 3.627020456125626*^9}, {3.6270205353034163`*^9, 
   3.627020690894658*^9}, {3.627020818446722*^9, 3.627020834121888*^9}, {
   3.6270209500465183`*^9, 3.627020959293396*^9}, 3.627021028536152*^9, {
   3.627021258540223*^9, 3.627021277739552*^9}, {3.627021472970434*^9, 
   3.627021508698105*^9}, {3.6270216028102922`*^9, 3.627021604206541*^9}, {
   3.628063186002244*^9, 3.628063187546753*^9}, {3.633773539009853*^9, 
   3.63377359595914*^9}, {3.6337737072725573`*^9, 3.63377371512012*^9}, {
   3.633774022406859*^9, 3.633774252144473*^9}, {3.633774325768745*^9, 
   3.633774331119628*^9}, {3.63377438468038*^9, 3.633774399028811*^9}, {
   3.633775301059082*^9, 3.633775352665783*^9}, {3.633775437754253*^9, 
   3.6337754447692747`*^9}, {3.633775561517144*^9, 3.6337755741756077`*^9}, {
   3.633776108490451*^9, 3.633776155215466*^9}, {3.633776400206437*^9, 
   3.6337764157710342`*^9}, {3.6337765677063704`*^9, 3.633776569945066*^9}, {
   3.633776696333263*^9, 3.6337767115802393`*^9}, {3.633779270316586*^9, 
   3.6337792758588657`*^9}, {3.633779372116445*^9, 3.633779460761766*^9}, {
   3.633779944605957*^9, 3.633779944748765*^9}, {3.6337800470436277`*^9, 
   3.6337800473311977`*^9}, 3.633780242216721*^9, {3.633780280816383*^9, 
   3.6337802826000557`*^9}, {3.633780318671916*^9, 3.633780319448442*^9}, {
   3.633780420726551*^9, 3.633780462430272*^9}, {3.633780506271009*^9, 
   3.633780506893813*^9}, {3.633780578255287*^9, 3.6337805851983147`*^9}, {
   3.633780700118104*^9, 3.633780700923643*^9}, {3.633780852550787*^9, 
   3.633780854387738*^9}, {3.633780982049855*^9, 3.633780997139186*^9}, {
   3.6337810629472437`*^9, 3.633781063554397*^9}, {3.633781174711917*^9, 
   3.633781193349206*^9}, {3.633781282731577*^9, 3.633781293222135*^9}, {
   3.633781958502585*^9, 3.63378196786963*^9}, {3.6337822624754*^9, 
   3.633782267147847*^9}, 3.633785980672068*^9, {3.63378609400599*^9, 
   3.633786096972684*^9}, 3.6337863673225307`*^9, 3.633786613602344*^9, 
   3.6337866824735518`*^9, {3.6363526752815647`*^9, 3.6363526860265293`*^9}, {
   3.636352758795632*^9, 3.6363527648723917`*^9}, {3.63635309053437*^9, 
   3.636353092275432*^9}, {3.636353266211926*^9, 3.636353274467122*^9}, {
   3.636353340426055*^9, 3.636353341225141*^9}, {3.636353427436315*^9, 
   3.63635344572933*^9}, {3.636353548240789*^9, 3.636353558978875*^9}, 
   3.636353607720994*^9, {3.63635379173496*^9, 3.636353799375742*^9}, {
   3.6363538306865063`*^9, 3.6363538329898443`*^9}, {3.636353901678031*^9, 
   3.636353901941333*^9}, {3.6363541204128637`*^9, 3.636354127782055*^9}, {
   3.6363541888631697`*^9, 3.636354202980447*^9}, {3.636354243308239*^9, 
   3.63635427741934*^9}, 3.6363543146193247`*^9, {3.636354355307527*^9, 
   3.636354355434383*^9}, {3.636355080149438*^9, 3.63635510820724*^9}, {
   3.636355180357085*^9, 3.636355181107572*^9}, {3.636355241428359*^9, 
   3.636355241955715*^9}, {3.6363553661708937`*^9, 3.636355366331778*^9}, {
   3.636355460200736*^9, 3.636355485096369*^9}, {3.636355536429562*^9, 
   3.636355541762117*^9}, {3.636355623833921*^9, 3.636355624609395*^9}, {
   3.636355658241687*^9, 3.636355661068564*^9}, {3.6363559367919893`*^9, 
   3.636355937838779*^9}, {3.636356022407339*^9, 3.636356023878109*^9}, {
   3.636356102326702*^9, 3.6363561046734962`*^9}, {3.636356136269096*^9, 
   3.63635619890821*^9}, {3.636356238752409*^9, 3.636356245293261*^9}, 
   3.6363566481498528`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"commented", ":", 
   RowBox[{"old", " ", "definition"}]}], "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.628063192219872*^9, 3.628063249459339*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Lambda]2lstrong", "[", 
    RowBox[{"mtilde_", ",", "mQ3_", ",", "mU3_", ",", "Xt_", ",", "M3_"}], 
    "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["g", "3"], "2"], 
    SuperscriptBox[
     SubscriptBox["g", "t"], "4"], 
    RowBox[{"Piecewise", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[CapitalDelta]\[Lambda]2lstrongdegenerate", "[", 
           RowBox[{"mtilde", ",", "M3", ",", "Xt"}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<", 
            RowBox[{"3.", " ", 
             SuperscriptBox["10", 
              RowBox[{"-", "2"}]]}]}], "&&", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              FractionBox["M3", "mU3"], "-", "1"}], "]"}], "<", 
            RowBox[{"3.", " ", 
             SuperscriptBox["10", 
              RowBox[{"-", "2"}]]}]}], "&&", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              FractionBox["M3", "mQ3"], "-", "1"}], "]"}], "<", 
            RowBox[{"3.", " ", 
             SuperscriptBox["10", 
              RowBox[{"-", "2"}]]}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
            RowBox[{"mtilde", ",", 
             RowBox[{"1.01", "mQ3"}], ",", "mU3", ",", "Xt", " ", ",", "M3"}],
             "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{
             FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
            RowBox[{"mtilde", ",", 
             RowBox[{"1.01", "mQ3"}], ",", "mU3", ",", "Xt", " ", ",", "M3"}],
             "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{
             FractionBox["mQ3", "M3"], "-", "1"}], "]"}], "<", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
            RowBox[{"mtilde", ",", "mQ3", ",", 
             RowBox[{"1.01", "mU3"}], ",", "Xt", " ", ",", "M3"}], "]"}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{
             FractionBox["mU3", "M3"], "-", "1"}], "]"}], "<", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}]}], "}"}]}], "}"}], ",", 
      RowBox[{"Re", "[", 
       RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
        RowBox[{"mtilde", ",", 
         RowBox[{"1.", "mQ3"}], ",", "mU3", ",", "Xt", " ", ",", "M3"}], 
        "]"}], "]"}]}], "]"}]}]}], "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.627019911174324*^9, 3.627019974234519*^9}, {
   3.627020419646247*^9, 3.627020456125626*^9}, {3.6270205353034163`*^9, 
   3.627020690894658*^9}, {3.627020818446722*^9, 3.627020834121888*^9}, {
   3.6270209500465183`*^9, 3.627020959293396*^9}, 3.627021028536152*^9, {
   3.627021258540223*^9, 3.627021277739552*^9}, {3.627021472970434*^9, 
   3.627021508698105*^9}, {3.6270216028102922`*^9, 3.627021604206541*^9}, {
   3.628063186002244*^9, 3.628063187546753*^9}, {3.633779333183148*^9, 
   3.633779364297853*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Lambda]2lstrong", "[", 
    RowBox[{"mtilde_", ",", "mQ3_", ",", "mU3_", ",", "Xt_", ",", "M3_"}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["g", "3"], "2"], 
    SuperscriptBox[
     SubscriptBox["g", "t"], "4"], 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<", 
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]]}], "&&", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          FractionBox["M3", "mU3"], "-", "1"}], "]"}], "<", 
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]]}], "&&", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          FractionBox["M3", "mQ3"], "-", "1"}], "]"}], "<", 
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\[CapitalDelta]\[Lambda]2lstrongdegenerate", "[", 
       RowBox[{"mtilde", ",", "M3", ",", "Xt"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{
            FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}], "||", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{
            FractionBox["M3", "mU3"], "-", "1"}], "]"}], "<", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}], "||", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{
            FractionBox["M3", "mQ3"], "-", "1"}], "]"}], "<", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}]}], ",", "\[IndentingNewLine]", "\t", 
        RowBox[{"Re", "[", 
         RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
          RowBox[{
           RowBox[{"1.013", "mtilde"}], ",", "mQ3", ",", 
           RowBox[{"1.011", "mU3"}], ",", "Xt", " ", ",", 
           RowBox[{"1.012", "M3"}]}], "]"}], "]"}], ",", 
        "\[IndentingNewLine]", "\t", 
        RowBox[{"Re", "[", 
         RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
          RowBox[{"mtilde", ",", 
           RowBox[{"1.", "mQ3"}], ",", "mU3", ",", "Xt", " ", ",", "M3"}], 
          "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.628063238663929*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]\[Lambda]2lstrongdegenerateaux", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Xth", "\[Rule]", 
     FractionBox["Xt", "M3"]}], ",", 
    RowBox[{"g3", "\[Rule]", "1"}], ",", 
    RowBox[{"gt", "\[Rule]", "1"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.627018162984043*^9, 3.6270182166238956`*^9}, {
  3.627018290751479*^9, 3.6270182944543657`*^9}, {3.627059826976698*^9, 
  3.627059827141014*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["Xt", "5"], 
     SuperscriptBox["M3", "5"]]}], "+", 
   FractionBox[
    RowBox[{"Xt", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "12"}], "-", 
       RowBox[{"24", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], "M3"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Xt", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], ")"}]}], 
    SuperscriptBox["M3", "4"]], "-", 
   RowBox[{"18", " ", 
    SuperscriptBox[
     RowBox[{"Log", "[", 
      FractionBox[
       SuperscriptBox["Q", "2"], 
       SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Xt", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"14", "+", 
       RowBox[{"4", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], 
    SuperscriptBox["M3", "3"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Xt", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "6"}], "+", 
       RowBox[{"24", " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], 
    SuperscriptBox["M3", "2"]]}], 
  RowBox[{"96", " ", 
   SuperscriptBox["\[Pi]", "4"]}]]], "Output",
 CellChangeTimes->{
  3.627018158292747*^9, {3.627018194373396*^9, 3.627018216939636*^9}, 
   3.62701825845818*^9, 3.627018295761368*^9, 3.6270598374118233`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]2lstrongdegenerate", "[", 
   RowBox[{"Q_", ",", "M3_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"96", " ", 
     SuperscriptBox["\[Pi]", "4"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["Xt", "5"], 
       SuperscriptBox["M3", "5"]]}], "+", 
     FractionBox[
      RowBox[{"Xt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "12"}], "-", 
         RowBox[{"24", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["Q", "2"], 
            SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], "M3"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Xt", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], ")"}]}], 
      SuperscriptBox["M3", "4"]], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Xt", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"14", "+", 
         RowBox[{"4", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["Q", "2"], 
            SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], 
      SuperscriptBox["M3", "3"]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Xt", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "6"}], "+", 
         RowBox[{"24", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["Q", "2"], 
            SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], 
      SuperscriptBox["M3", "2"]]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.622266450480658*^9, 3.622266488009837*^9}, {
  3.6222677327450113`*^9, 3.6222677443801117`*^9}, {3.626447035931406*^9, 
  3.62644706272786*^9}, {3.626447246556076*^9, 3.626447254188444*^9}, {
  3.627018273982121*^9, 3.627018307812675*^9}, {3.627059845486967*^9, 
  3.627059850334983*^9}, {3.633780990483881*^9, 3.633780993099148*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]2lstrongaux", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
     RowBox[{
      SubscriptBox["m", 
       SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
     RowBox[{
      SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
     RowBox[{
      SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
     RowBox[{
      SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
     RowBox[{
      SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
     RowBox[{
      SubscriptBox["X", "t"], "\[Rule]", "Xt"}], ",", 
     RowBox[{
      OverscriptBox["m", "~"], "\[Rule]", "mtilde"}]}], "}"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["g", "3"], "\[Rule]", "1"}], ",", 
    RowBox[{
     SubscriptBox["g", "t"], "\[Rule]", "1"}]}], "}"}]}]], "Input",
 CellChangeTimes->{
  3.622266517248995*^9, 3.622266555300188*^9, {3.622267219399576*^9, 
   3.622267239574512*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"M3", " ", 
     SuperscriptBox["Xt", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mU3", "2"]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["M3", "2"]}], "+", 
          SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["mQ3", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mU3", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["mQ3", "2"], "+", 
          SuperscriptBox["mU3", "2"]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["mQ3", "2"], "+", 
          SuperscriptBox["mU3", "2"]}], ")"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M3", "2"], "-", 
       SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M3", "2"], "-", 
       SuperscriptBox["mU3", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["mQ3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], "4"], " ", 
     SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Xt", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["mQ3", "6"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["mQ3", "4"], " ", 
           SuperscriptBox["mU3", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["M3", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["mQ3", "2"]}], "-", 
             SuperscriptBox["mU3", "2"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["M3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["mQ3", "4"]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["mQ3", "2"], " ", 
              SuperscriptBox["mU3", "2"]}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["mQ3", "2"], " ", 
           SuperscriptBox["mU3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["M3", "6"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["mQ3", "2"], "-", 
                RowBox[{"3", " ", 
                 SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["mQ3", "2"], " ", 
              SuperscriptBox["mU3", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["mQ3", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["M3", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["mQ3", "4"], "+", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], " ", 
                 SuperscriptBox["mU3", "2"]}], "-", 
                RowBox[{"8", " ", 
                 SuperscriptBox["mU3", "4"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["M3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 SuperscriptBox["mQ3", "4"], " ", 
                 SuperscriptBox["mU3", "2"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox["mQ3", "2"], " ", 
                 SuperscriptBox["mU3", "4"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["mU3", "6"]}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["mU3", "2"], 
              SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["M3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["M3", "2"], "-", 
             SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["M3", "2"], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["Q", "2"], 
               SuperscriptBox["M3", "2"]], "]"}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["mQ3", "2"], " ", 
           SuperscriptBox["mU3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mQ3", "2"], "-", 
             SuperscriptBox["mU3", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["M3", "2"]}], "+", 
             SuperscriptBox["mU3", "2"]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mU3", "2"], 
             SuperscriptBox["M3", "2"]], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", " ", 
              SuperscriptBox["M3", "4"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["mQ3", "2"], " ", 
              SuperscriptBox["mU3", "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["M3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["mQ3", "2"]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
             RowBox[{"6", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["M3", "2"], "-", 
                SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["M3", "2"], "-", 
                SuperscriptBox["mU3", "2"]}], ")"}], " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["Q", "2"], 
                SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}]}], ")"}]}], 
       "+", 
       RowBox[{
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["M3", "8"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["mQ3", "2"], "+", 
                SuperscriptBox["mU3", "2"]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["mQ3", "4"], " ", 
              SuperscriptBox["mU3", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["mQ3", "2"], "+", 
                SuperscriptBox["mU3", "2"]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["M3", "2"], " ", 
              SuperscriptBox["mQ3", "2"], " ", 
              SuperscriptBox["mU3", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], "+", 
                 SuperscriptBox["mU3", "2"]}], ")"}], "2"]}], "-", 
             RowBox[{"3", " ", 
              SuperscriptBox["M3", "4"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], "+", 
                 SuperscriptBox["mU3", "2"]}], ")"}], "3"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["M3", "6"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["mQ3", "4"]}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["mQ3", "2"], " ", 
                 SuperscriptBox["mU3", "2"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["mU3", "4"]}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mU3", "2"], 
             SuperscriptBox["M3", "2"]], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["M3", "2"], "-", 
             SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["M3", "2"], "-", 
             SuperscriptBox["mU3", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mQ3", "2"], "-", 
             SuperscriptBox["mU3", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", " ", 
              SuperscriptBox["M3", "4"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["mQ3", "2"], " ", 
              SuperscriptBox["mU3", "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["M3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["mQ3", "2"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
             RowBox[{"6", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["M3", "2"], "-", 
                SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["M3", "2"], "-", 
                SuperscriptBox["mU3", "2"]}], ")"}], " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["Q", "2"], 
                SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"16", " ", 
     SuperscriptBox["mQ3", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox["mU3", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["mQ3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"M3", " ", "Xt", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["\[Pi]", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox["\[Pi]", "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "4"], "-", 
          RowBox[{
           SuperscriptBox["M3", "2"], " ", 
           SuperscriptBox["mU3", "2"]}]}], ")"}], " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          FractionBox[
           SuperscriptBox["M3", "2"], 
           SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "4"], "-", 
          RowBox[{
           SuperscriptBox["M3", "2"], " ", 
           SuperscriptBox["mQ3", "2"]}]}], ")"}], " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          FractionBox[
           SuperscriptBox["M3", "2"], 
           SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"24", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M3", "2"], "-", 
       SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M3", "2"], "-", 
       SuperscriptBox["mU3", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["mQ3", "2"], "-", 
       SuperscriptBox["mU3", "2"]}], ")"}], " ", 
     SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "10"], " ", 
      SuperscriptBox["mQ3", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "4"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "6"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "10"], " ", 
      SuperscriptBox["mU3", "2"]}], "-", 
     RowBox[{"39", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"]}], "+", 
     RowBox[{"57", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mU3", "4"]}], "+", 
     RowBox[{"57", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"]}], "-", 
     RowBox[{"72", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"]}], "+", 
     RowBox[{"27", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mU3", "6"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"]}], "+", 
     RowBox[{"27", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox["\[Pi]", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox["\[Pi]", "2"]}], "+", 
     RowBox[{"21", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"21", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"39", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"15", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"15", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["M3", "2"]}], "+", 
         SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["M3", "2"]}], "+", 
         SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["M3", "2"]}], "+", 
         SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
     RowBox[{"21", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"39", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"21", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"15", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"15", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["M3", "2"]}], "+", 
         SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["M3", "2"]}], "+", 
         SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["M3", "2"]}], "+", 
         SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "10"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "10"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"54", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"54", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"72", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"30", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"30", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"72", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mQ3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"72", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mU3", "2"], 
        SuperscriptBox["M3", "2"]], "]"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["Q", "2"], 
        SuperscriptBox["M3", "2"]], "]"}]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "8"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "6"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"72", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["M3", "2"], " ", 
      SuperscriptBox["mQ3", "4"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["mQ3", "6"], " ", 
      SuperscriptBox["mU3", "6"], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        FractionBox[
         SuperscriptBox["M3", "2"], 
         SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["M3", "4"], " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        FractionBox[
         SuperscriptBox["M3", "2"], 
         SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"96", " ", 
     SuperscriptBox["mQ3", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox["mU3", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"M3", " ", 
     SuperscriptBox["Xt", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mU3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["M3", "2"]}], "-", 
          SuperscriptBox["mQ3", "2"], "-", 
          SuperscriptBox["mU3", "2"]}], ")"}], " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          FractionBox[
           SuperscriptBox["M3", "2"], 
           SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mU3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["M3", "2"]}], "-", 
          SuperscriptBox["mQ3", "2"], "-", 
          SuperscriptBox["mU3", "2"]}], ")"}], " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          FractionBox[
           SuperscriptBox["M3", "2"], 
           SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M3", "2"], "-", 
       SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M3", "2"], "-", 
       SuperscriptBox["mU3", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["mQ3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], "3"], " ", 
     SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["Xt", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "6"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "8"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "10"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"]}], "+", 
       RowBox[{"14", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"]}], "-", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"]}], "-", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "4"]}], "+", 
       RowBox[{"18", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"]}], "-", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mU3", "6"]}], "+", 
       RowBox[{"14", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"]}], "+", 
       RowBox[{"18", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"]}], "-", 
       RowBox[{"64", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "6"]}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mU3", "8"]}], "-", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"]}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"]}], "-", 
       RowBox[{"20", " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "8"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mU3", "10"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"]}], "-", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"44", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"31", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"13", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"38", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"15", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"27", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"19", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"13", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"38", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"27", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"44", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"31", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"15", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"22", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"22", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"38", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"19", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        SuperscriptBox[
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"18", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"22", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"64", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"22", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"18", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"22", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"24", " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"22", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M3", "10"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "4"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["M3", "8"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "8"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "10"], " ", 
        SuperscriptBox["mU3", "6"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "6"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "8"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M3", "4"], " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["M3", "2"], " ", 
        SuperscriptBox["mQ3", "4"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["mQ3", "6"], " ", 
        SuperscriptBox["mU3", "10"], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["mQ3", "4"]}], "+", 
          SuperscriptBox["mU3", "4"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["M3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mQ3", "2"], "-", 
             SuperscriptBox["mU3", "2"]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          FractionBox[
           SuperscriptBox["M3", "2"], 
           SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["mQ3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
        SuperscriptBox["mU3", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["mQ3", "4"]}], "+", 
          SuperscriptBox["mU3", "4"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["M3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mQ3", "2"], "-", 
             SuperscriptBox["mU3", "2"]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          FractionBox[
           SuperscriptBox["M3", "2"], 
           SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", 
     SuperscriptBox["mQ3", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox["mU3", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["mQ3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], "4"], " ", 
     SuperscriptBox["\[Pi]", "4"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.622268480743525*^9, 3.6222685060409517`*^9}}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]2lstronggeneral", "[", 
   RowBox[{"Q_", ",", "mQ3_", ",", "mU3_", ",", "Xt_", ",", "M3_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"M3", " ", 
      SuperscriptBox["Xt", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["M3", "2"]}], "+", 
           SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["mQ3", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mU3", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mQ3", "2"], "+", 
           SuperscriptBox["mU3", "2"]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mQ3", "2"], "+", 
           SuperscriptBox["mU3", "2"]}], ")"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mQ3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "4"], " ", 
      SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Xt", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["M3", "2"], "-", 
            SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["mQ3", "6"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mQ3", "4"], " ", 
            SuperscriptBox["mU3", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["M3", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["mQ3", "2"]}], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["M3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SuperscriptBox["mQ3", "4"]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["mQ3", "2"], " ", 
               SuperscriptBox["mU3", "2"]}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["mQ3", "2"], " ", 
            SuperscriptBox["mU3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["M3", "6"]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], "-", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["mQ3", "2"], " ", 
               SuperscriptBox["mU3", "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["M3", "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "4"], "+", 
                 RowBox[{
                  SuperscriptBox["mQ3", "2"], " ", 
                  SuperscriptBox["mU3", "2"]}], "-", 
                 RowBox[{"8", " ", 
                  SuperscriptBox["mU3", "4"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["M3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox["mQ3", "4"], " ", 
                  SuperscriptBox["mU3", "2"]}], "+", 
                 RowBox[{"6", " ", 
                  SuperscriptBox["mQ3", "2"], " ", 
                  SuperscriptBox["mU3", "4"]}], "+", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["mU3", "6"]}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mU3", "2"], 
               SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["M3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["M3", "2"], "-", 
              SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["M3", "2"], "-", 
               SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["mQ3", "2"], "-", 
               SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["Q", "2"], 
                SuperscriptBox["M3", "2"]], "]"}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox["mQ3", "2"], " ", 
            SuperscriptBox["mU3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["M3", "2"]}], "+", 
              SuperscriptBox["mU3", "2"]}], ")"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["mU3", "2"], 
              SuperscriptBox["M3", "2"]], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"7", " ", 
               SuperscriptBox["M3", "4"]}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["mQ3", "2"], " ", 
               SuperscriptBox["mU3", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["M3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["mQ3", "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["M3", "2"], "-", 
                 SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["M3", "2"], "-", 
                 SuperscriptBox["mU3", "2"]}], ")"}], " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["Q", "2"], 
                 SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["M3", "8"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], "+", 
                 SuperscriptBox["mU3", "2"]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mQ3", "4"], " ", 
               SuperscriptBox["mU3", "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], "+", 
                 SuperscriptBox["mU3", "2"]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["M3", "2"], " ", 
               SuperscriptBox["mQ3", "2"], " ", 
               SuperscriptBox["mU3", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["mQ3", "2"], "+", 
                  SuperscriptBox["mU3", "2"]}], ")"}], "2"]}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox["M3", "4"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["mQ3", "2"], "+", 
                  SuperscriptBox["mU3", "2"]}], ")"}], "3"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["M3", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["mQ3", "4"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["mQ3", "2"], " ", 
                  SuperscriptBox["mU3", "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["mU3", "4"]}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["mU3", "2"], 
              SuperscriptBox["M3", "2"]], "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["M3", "2"], "-", 
              SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["M3", "2"], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"7", " ", 
               SuperscriptBox["M3", "4"]}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["mQ3", "2"], " ", 
               SuperscriptBox["mU3", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["M3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["mQ3", "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["mU3", "2"]}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["M3", "2"], "-", 
                 SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["M3", "2"], "-", 
                 SuperscriptBox["mU3", "2"]}], ")"}], " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["Q", "2"], 
                 SuperscriptBox["M3", "2"]], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"16", " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mQ3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"M3", " ", "Xt", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "4"], "-", 
           RowBox[{
            SuperscriptBox["M3", "2"], " ", 
            SuperscriptBox["mU3", "2"]}]}], ")"}], " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SuperscriptBox["M3", "2"], 
            SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "4"], "-", 
           RowBox[{
            SuperscriptBox["M3", "2"], " ", 
            SuperscriptBox["mQ3", "2"]}]}], ")"}], " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SuperscriptBox["M3", "2"], 
            SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"24", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["mQ3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "10"], " ", 
       SuperscriptBox["mQ3", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "4"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "6"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "10"], " ", 
       SuperscriptBox["mU3", "2"]}], "-", 
      RowBox[{"39", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"]}], "+", 
      RowBox[{"57", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mU3", "4"]}], "+", 
      RowBox[{"57", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"]}], "-", 
      RowBox[{"72", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mU3", "6"]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox["\[Pi]", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox["\[Pi]", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox["\[Pi]", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox["\[Pi]", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox["\[Pi]", "2"]}], "+", 
      RowBox[{"21", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"21", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"39", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"15", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"15", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mQ3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["M3", "2"]}], "+", 
          SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["M3", "2"]}], "+", 
          SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["M3", "2"]}], "+", 
          SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
      RowBox[{"21", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"39", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"21", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"15", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"15", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mU3", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["M3", "2"]}], "+", 
          SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["M3", "2"]}], "+", 
          SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["M3", "2"]}], "+", 
          SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "10"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "10"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"54", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"54", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"72", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"30", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"30", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"72", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mQ3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"72", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mU3", "2"], 
         SuperscriptBox["M3", "2"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["Q", "2"], 
         SuperscriptBox["M3", "2"]], "]"}]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "8"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "6"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"72", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "4"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       SuperscriptBox["M3", "2"], " ", 
       SuperscriptBox["mQ3", "4"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"18", " ", 
       SuperscriptBox["mQ3", "6"], " ", 
       SuperscriptBox["mU3", "6"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["Q", "2"], 
          SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         FractionBox[
          SuperscriptBox["M3", "2"], 
          SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M3", "4"], " ", 
       SuperscriptBox["mQ3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M3", "2"], "-", 
          SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox["mU3", "2"], " ", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         FractionBox[
          SuperscriptBox["M3", "2"], 
          SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"96", " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"M3", " ", 
      SuperscriptBox["Xt", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["M3", "2"]}], "-", 
           SuperscriptBox["mQ3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SuperscriptBox["M3", "2"], 
            SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["M3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["M3", "2"]}], "-", 
           SuperscriptBox["mQ3", "2"], "-", 
           SuperscriptBox["mU3", "2"]}], ")"}], " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SuperscriptBox["M3", "2"], 
            SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mQ3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M3", "2"], "-", 
        SuperscriptBox["mU3", "2"]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mQ3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "3"], " ", 
      SuperscriptBox["\[Pi]", "4"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["Xt", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "6"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "10"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"]}], "+", 
        RowBox[{"14", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"]}], "-", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"]}], "-", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "4"]}], "+", 
        RowBox[{"18", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"]}], "-", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mU3", "6"]}], "+", 
        RowBox[{"14", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"]}], "+", 
        RowBox[{"18", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"]}], "-", 
        RowBox[{"64", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "6"]}], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mU3", "8"]}], "-", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"]}], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"]}], "-", 
        RowBox[{"20", " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mU3", "10"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"]}], "-", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"29", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"44", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"31", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"38", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"15", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"9", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"27", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"19", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mQ3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mQ3", "2"]}]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"9", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"38", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"27", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"29", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"44", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"31", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"15", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"5", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"22", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"22", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"38", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"5", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"19", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mU3", "2"], 
            SuperscriptBox["M3", "2"]], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["M3", "2"]}], "+", 
            SuperscriptBox["mU3", "2"]}]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"18", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"64", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"22", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"18", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"22", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"24", " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mQ3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["M3", "10"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "4"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["M3", "8"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "8"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "10"], " ", 
         SuperscriptBox["mU3", "6"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "6"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "8"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M3", "4"], " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox["mQ3", "4"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["mQ3", "6"], " ", 
         SuperscriptBox["mU3", "10"], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mU3", "2"], 
           SuperscriptBox["M3", "2"]], "]"}], " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["Q", "2"], 
           SuperscriptBox["M3", "2"]], "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["M3", "2"], "-", 
            SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["M3", "2"], "-", 
            SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["mQ3", "4"]}], "+", 
           SuperscriptBox["mU3", "4"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["M3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SuperscriptBox["M3", "2"], 
            SuperscriptBox["mQ3", "2"]]}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["mQ3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["M3", "2"], "-", 
            SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
         SuperscriptBox["mU3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["M3", "2"], "-", 
            SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["mQ3", "4"]}], "+", 
           SuperscriptBox["mU3", "4"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["M3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "-", 
              SuperscriptBox["mU3", "2"]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            SuperscriptBox["M3", "2"], 
            SuperscriptBox["mU3", "2"]]}], "]"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"32", " ", 
      SuperscriptBox["mQ3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mQ3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox["mU3", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["M3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mQ3", "2"], "-", 
         SuperscriptBox["mU3", "2"]}], ")"}], "4"], " ", 
      SuperscriptBox["\[Pi]", "4"]}], ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.622268517234727*^9, {3.6223535923397284`*^9, 3.622353600335541*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Shift", " ", "DR", " ", "to", " ", "OS"}], "*)"}]], "Input",
 CellChangeTimes->{{3.636351806242632*^9, 3.636351815735495*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"sing", "[", 
     RowBox[{"f_", ",", "x_", ",", "x0_", ",", "\[Delta]_"}], "]"}], ":=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"x0", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[Delta]"}], ")"}]}], "]"}], 
        FractionBox[
         RowBox[{"(", 
          RowBox[{"x", "-", 
           RowBox[{"x0", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}], 
         RowBox[{"2", "x0", " ", "\[Delta]"}]]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"x0", 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Delta]"}], ")"}]}], "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"2", "x0", " ", "\[Delta]"}]], 
           RowBox[{"(", 
            RowBox[{"x", "-", 
             RowBox[{"x0", 
              RowBox[{"(", 
               RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         FractionBox["x", "x0"], "-", "1"}], "]"}], "<", "\[Delta]"}]}], 
     "}"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"shiftDROS\[Alpha]t\[Alpha]S", "[", 
    RowBox[{"mtilde_", ",", "mQ3_", ",", "mU3_", ",", "Xt_", ",", "M3_"}], 
    "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["g", "3"], "2"], 
    SuperscriptBox[
     SubscriptBox["g", "t"], "4"], 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Delta]", "=", 
         RowBox[{"8.5", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}]}], ",", 
        RowBox[{"\[Delta]2", "=", 
         RowBox[{"1", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "2"}]]}]}]}], "}"}], ",", 
      RowBox[{"Piecewise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sdegenerate", "[", 
             RowBox[{"mtilde", ",", "mQ3", ",", "Xt"}], "]"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{
                FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<", 
              "\[Delta]2"}], "&&", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{
                FractionBox["M3", "mU3"], "-", "1"}], "]"}], "<", 
              "\[Delta]2"}], "&&", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{
                FractionBox["M3", "mQ3"], "-", "1"}], "]"}], "<", 
              "\[Delta]2"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
                RowBox[{
                 RowBox[{"1.", "mtilde"}], ",", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "\[Delta]"}], ")"}]}], ",", "mU3", ",", 
                 "Xt", " ", ",", "M3"}], "]"}], "]"}], 
              FractionBox[
               RowBox[{"(", 
                RowBox[{"mQ3", "-", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}], 
               RowBox[{"2", "mU3", " ", "\[Delta]"}]]}], "+", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
                RowBox[{
                 RowBox[{"1.", "mtilde"}], ",", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}], ",", "mU3", ",", 
                 "Xt", " ", ",", "M3"}], "]"}], "]"}], 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                FractionBox[
                 RowBox[{"mQ3", "-", 
                  RowBox[{"mU3", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], 
                 RowBox[{"2", " ", "mU3", " ", "\[Delta]"}]]}], ")"}]}]}], 
            ",", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{
               FractionBox["mQ3", "mU3"], "-", "1"}], "]"}], "<", " ", 
             "\[Delta]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
                RowBox[{
                 RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                 " ", ",", 
                 RowBox[{"mQ3", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
              FractionBox[
               RowBox[{"(", 
                RowBox[{"M3", "-", 
                 RowBox[{"mQ3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}], 
               RowBox[{"2", "mQ3", " ", "\[Delta]"}]]}], "+", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
                RowBox[{
                 RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                 " ", ",", 
                 RowBox[{"mQ3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                FractionBox[
                 RowBox[{"M3", "-", 
                  RowBox[{"mQ3", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], 
                 RowBox[{"2", "mQ3", " ", "\[Delta]"}]]}], ")"}]}]}], ",", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{
               FractionBox["mQ3", "M3"], "-", "1"}], "]"}], "<", 
             "\[Delta]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
                RowBox[{
                 RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                 " ", ",", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
              FractionBox[
               RowBox[{"(", 
                RowBox[{"M3", "-", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], ")"}], 
               RowBox[{"2", "mU3", " ", "\[Delta]"}]]}], "+", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
                RowBox[{
                 RowBox[{"1.", "mtilde"}], ",", "mQ3", ",", "mU3", ",", "Xt", 
                 " ", ",", 
                 RowBox[{"mU3", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], "]"}], "]"}], 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                FractionBox[
                 RowBox[{"M3", "-", 
                  RowBox[{"mU3", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "\[Delta]"}], ")"}]}]}], 
                 RowBox[{"2", "mU3", " ", "\[Delta]"}]]}], ")"}]}]}], ",", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{
               FractionBox["mU3", "M3"], "-", "1"}], "]"}], "<", " ", 
             "\[Delta]"}]}], "}"}]}], "}"}], ",", 
        RowBox[{"Re", "[", 
         RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
          RowBox[{"mtilde", ",", 
           RowBox[{"1.", "mQ3"}], ",", "mU3", ",", "Xt", " ", ",", "M3"}], 
          "]"}], "]"}]}], "]"}]}], "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627019911174324*^9, 3.627019974234519*^9}, {
   3.627020419646247*^9, 3.627020456125626*^9}, {3.6270205353034163`*^9, 
   3.627020690894658*^9}, {3.627020818446722*^9, 3.627020834121888*^9}, {
   3.6270209500465183`*^9, 3.627020959293396*^9}, 3.627021028536152*^9, {
   3.627021258540223*^9, 3.627021277739552*^9}, {3.627021472970434*^9, 
   3.627021508698105*^9}, {3.6270216028102922`*^9, 3.627021604206541*^9}, {
   3.628063186002244*^9, 3.628063187546753*^9}, {3.633773539009853*^9, 
   3.63377359595914*^9}, {3.6337737072725573`*^9, 3.63377371512012*^9}, {
   3.633774022406859*^9, 3.633774252144473*^9}, {3.633774325768745*^9, 
   3.633774331119628*^9}, {3.63377438468038*^9, 3.633774399028811*^9}, {
   3.633775301059082*^9, 3.633775352665783*^9}, {3.633775437754253*^9, 
   3.6337754447692747`*^9}, {3.633775561517144*^9, 3.6337755741756077`*^9}, {
   3.633776108490451*^9, 3.633776155215466*^9}, {3.633776400206437*^9, 
   3.6337764157710342`*^9}, {3.6337765677063704`*^9, 3.633776569945066*^9}, {
   3.633776696333263*^9, 3.6337767115802393`*^9}, {3.633779270316586*^9, 
   3.6337792758588657`*^9}, {3.633779372116445*^9, 3.633779460761766*^9}, {
   3.633779944605957*^9, 3.633779944748765*^9}, {3.6337800470436277`*^9, 
   3.6337800473311977`*^9}, 3.633780242216721*^9, {3.633780280816383*^9, 
   3.6337802826000557`*^9}, {3.633780318671916*^9, 3.633780319448442*^9}, {
   3.633780420726551*^9, 3.633780462430272*^9}, {3.633780506271009*^9, 
   3.633780506893813*^9}, {3.633780578255287*^9, 3.6337805851983147`*^9}, {
   3.633780700118104*^9, 3.633780700923643*^9}, {3.633780852550787*^9, 
   3.633780854387738*^9}, {3.633780982049855*^9, 3.633780997139186*^9}, {
   3.6337810629472437`*^9, 3.633781063554397*^9}, {3.633781174711917*^9, 
   3.633781193349206*^9}, {3.633781282731577*^9, 3.633781293222135*^9}, {
   3.633781958502585*^9, 3.63378196786963*^9}, {3.6337822624754*^9, 
   3.633782267147847*^9}, 3.633785980672068*^9, {3.63378609400599*^9, 
   3.633786096972684*^9}, 3.6337863673225307`*^9, 3.633786613602344*^9, 
   3.6337866824735518`*^9, {3.636312397192642*^9, 3.636312405794183*^9}, {
   3.636312478834928*^9, 3.6363127034384623`*^9}, {3.6363127770251102`*^9, 
   3.636312815843918*^9}, {3.636313216321279*^9, 3.63631322497048*^9}, 
   3.6363132731662416`*^9, {3.6363134853594637`*^9, 3.636313490252091*^9}, {
   3.636313565437278*^9, 3.636313568119835*^9}, {3.636351800808422*^9, 
   3.636351803758848*^9}, {3.636351973888101*^9, 3.636351976815823*^9}, 
   3.63635244681248*^9, 3.636354414358409*^9, {3.636354643915269*^9, 
   3.636354709912649*^9}, {3.6363547442257233`*^9, 3.636354750247018*^9}, 
   3.636354797794155*^9, 3.636354897224842*^9, {3.6363549461131973`*^9, 
   3.636354963634426*^9}, 3.636355068759802*^9, {3.636355172397581*^9, 
   3.636355174084478*^9}, {3.636355257838214*^9, 3.6363552613109627`*^9}, {
   3.636355357946278*^9, 3.6363553584328823`*^9}, {3.636355476627956*^9, 
   3.636355480575144*^9}, {3.636355552499352*^9, 3.636355560333665*^9}, {
   3.636355949825141*^9, 3.636355949943379*^9}, {3.636356295158588*^9, 
   3.636356320132228*^9}, 3.6363563611459103`*^9, {3.6363564018467827`*^9, 
   3.636356402151709*^9}, {3.636356441151763*^9, 3.636356454574893*^9}, {
   3.636356580519246*^9, 3.63635658441963*^9}, 3.636356642694624*^9, {
   3.636356691170219*^9, 3.636356691425864*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sgeneral", "[", 
    RowBox[{"mtilde_", ",", "mQ3_", ",", "mU3_", ",", "QXt_", ",", "M3_"}], 
    "]"}], ":=", 
   RowBox[{"Re", "@", " ", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x1", "=", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", "mQ3", ")"}], "2"], 
          SuperscriptBox["M3", "2"]]}], ",", 
        RowBox[{"x2", "=", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", "mU3", ")"}], "2"], 
          SuperscriptBox["M3", "2"]]}], ",", 
        RowBox[{"xt", "=", 
         FractionBox["QXt", "M3"]}], ",", 
        RowBox[{"xs", "=", 
         FractionBox[
          SuperscriptBox["mtilde", "2"], 
          SuperscriptBox["M3", "2"]]}]}], "}"}], ",", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"64", " ", 
         SuperscriptBox["\[Pi]", "4"]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
               RowBox[{"Log", "[", 
                RowBox[{"1", "-", "x1"}], "]"}]}], "+", 
              RowBox[{"x1", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x1", "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x1"}], ")"}], " ", 
                  RowBox[{"Log", "[", "x1", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Log", "[", 
                   FractionBox["xs", "x1"], "]"}]}]}], ")"}]}]}], ")"}]}], 
           SuperscriptBox["x1", "2"]]}], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"], " ", 
              RowBox[{"Log", "[", 
               RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
             RowBox[{"x2", " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", "x2", "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x2"}], ")"}], " ", 
                 RowBox[{"Log", "[", "x2", "]"}]}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{"Log", "[", 
                  FractionBox["xs", "x2"], "]"}]}]}], ")"}]}]}], ")"}]}], 
          SuperscriptBox["x2", "2"]], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            SuperscriptBox["x1", "2"], " ", 
            SuperscriptBox["x2", "2"]}]], "xt", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x1", "-", "x2"}], ")"}], "3"]], 
             SuperscriptBox["x1", "2"], " ", 
             SuperscriptBox["x2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"x1", "-", "x2"}], ")"}], " ", 
                SuperscriptBox["xt", "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["x1", "2"]}], "+", 
                  RowBox[{"x2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "x2"}], "-", 
                    SuperscriptBox["xt", "2"]}], ")"}]}], "-", 
                  RowBox[{"x1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", "x2"}], "+", 
                    SuperscriptBox["xt", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", 
                 FractionBox["x1", "x2"], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"4", " ", 
                  SuperscriptBox["xt", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], " ", "x2", " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}]}], ")"}]}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"x1", "-", "x2"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}]}]]}], "+", 
               RowBox[{
                FractionBox["1", 
                 RowBox[{"x1", "-", "x2"}]], "xt", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "7"}], " ", "x1"}], "+", 
                  FractionBox["x1", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}]], "+", 
                  FractionBox["x1", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}]], "+", 
                  RowBox[{"7", " ", "x2"}], "+", 
                  FractionBox["x2", 
                   RowBox[{"1", "-", "x1"}]], "+", 
                  FractionBox["x2", 
                   RowBox[{"1", "-", "x2"}]], "-", 
                  FractionBox[
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "x1"], "+", 
                  FractionBox[
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "x1"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"]], "-", 
                  RowBox[{"8", " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
                  FractionBox[
                   RowBox[{"4", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "x2"], "+", 
                  RowBox[{"4", " ", "x2", " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "-", 
                  FractionBox[
                   RowBox[{"x1", " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"]], "+", 
                  FractionBox[
                   RowBox[{"x2", " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"]], "+", 
                  RowBox[{"9", " ", "x1", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox["x1", "xs"], "]"}]}], "-", 
                  RowBox[{"x2", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox["x1", "xs"], "]"}]}], "+", 
                  RowBox[{"x1", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox["x2", "xs"], "]"}]}], "-", 
                  RowBox[{"9", " ", "x2", " ", 
                   RowBox[{"Log", "[", 
                    FractionBox["x2", "xs"], "]"}]}], "+", 
                  RowBox[{"4", " ", "x1", " ", 
                   RowBox[{"Log", "[", "xs", "]"}]}], "-", 
                  RowBox[{"4", " ", "x2", " ", 
                   RowBox[{"Log", "[", "xs", "]"}]}]}], ")"}]}], "-", 
               FractionBox[
                RowBox[{"4", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], " ", "x2", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "+", 
                   RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "-", 
                    RowBox[{"2", " ", "x2", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Log", "[", "xs", "]"}]}], ")"}]}]}], ")"}]}]}], 
                  ")"}]}], 
                RowBox[{"x1", " ", "x2"}]], "+", 
               FractionBox[
                RowBox[{"xt", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "+", 
                   RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", "x1", "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x1"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x1"], "]"}]}]}], ")"}]}]}], ")"}]}], 
                SuperscriptBox["x1", "2"]], "+", 
               FractionBox[
                RowBox[{"xt", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
                   RowBox[{"x2", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", "x2", "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x2"], "]"}]}]}], ")"}]}]}], ")"}]}], 
                SuperscriptBox["x2", "2"]]}], ")"}]}], "+", 
            RowBox[{"xt", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"x1", "-", "x2"}], ")"}], "2"]], "2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "x1"}], "+", 
                  RowBox[{"2", " ", "x2"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"x1", "+", "x2"}], ")"}], " ", 
                   RowBox[{"Log", "[", 
                    FractionBox["x1", "x2"], "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
                   SuperscriptBox["x2", "2"], " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "-", 
                  RowBox[{"x1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x1"}], ")"}], " ", 
                    SuperscriptBox["x2", "2"], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], "+", 
                    RowBox[{"x1", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
                    RowBox[{"x2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "x1"}], "-", 
                    RowBox[{"3", " ", "x2"}], "-", 
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], "-", 
                    RowBox[{"2", " ", "x2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x1"], "]"}]}], "+", 
                    RowBox[{"2", " ", "x1", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x2"], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
                 ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["x1", "2"], " ", "xt", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FractionBox["1", 
                    RowBox[{
                    SuperscriptBox["x1", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x1", "-", "x2"}], ")"}], "3"]}]], "2", " ", "xt",
                    " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "x1"}], "+", "x2", "+", 
                    RowBox[{"x1", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["x1", "x2"], "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
                    SuperscriptBox["x2", "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "-", 
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x1"}], ")"}], " ", 
                    SuperscriptBox["x2", "2"], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], "+", 
                    RowBox[{"x1", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
                    RowBox[{"x2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "x1"}], "-", 
                    RowBox[{"3", " ", "x2"}], "-", 
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], "-", 
                    RowBox[{"2", " ", "x2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x1"], "]"}]}], "+", 
                    RowBox[{"2", " ", "x1", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x2"], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}], "-", 
                  RowBox[{
                   FractionBox["1", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    FractionBox["x1", "x2"]}], ")"}], "4"], " ", "x2"}]], 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "x1"}], "+", 
                    RowBox[{"2", " ", "x2"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"x1", "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["x1", "x2"], "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    FractionBox["x1", "x2"]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"4", " ", 
                    SuperscriptBox["xt", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], " ", "x2", " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"x1", "-", "x2"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}]}]]}], "+", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"x1", "-", "x2"}]], "xt", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "7"}], " ", "x1"}], "+", 
                    FractionBox["x1", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}]], "+", 
                    FractionBox["x1", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}]], "+", 
                    RowBox[{"7", " ", "x2"}], "+", 
                    FractionBox["x2", 
                    RowBox[{"1", "-", "x1"}]], "+", 
                    FractionBox["x2", 
                    RowBox[{"1", "-", "x2"}]], "-", 
                    FractionBox[
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "x1"], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "x1"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"]], "-", 
                    RowBox[{"8", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
                    FractionBox[
                    RowBox[{"4", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "x2"], "+", 
                    RowBox[{"4", " ", "x2", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "-", 
                    FractionBox[
                    RowBox[{"x1", " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"]], "+", 
                    FractionBox[
                    RowBox[{"x2", " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"]], "+", 
                    RowBox[{"9", " ", "x1", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["x1", "xs"], "]"}]}], "-", 
                    RowBox[{"x2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["x1", "xs"], "]"}]}], "+", 
                    RowBox[{"x1", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["x2", "xs"], "]"}]}], "-", 
                    RowBox[{"9", " ", "x2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["x2", "xs"], "]"}]}], "+", 
                    RowBox[{"4", " ", "x1", " ", 
                    RowBox[{"Log", "[", "xs", "]"}]}], "-", 
                    RowBox[{"4", " ", "x2", " ", 
                    RowBox[{"Log", "[", "xs", "]"}]}]}], ")"}]}], "-", 
                    FractionBox[
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], " ", "x2", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "+", 
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "-", 
                    RowBox[{"2", " ", "x2", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Log", "[", "xs", "]"}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}], 
                    RowBox[{"x1", " ", "x2"}]], "-", 
                    FractionBox[
                    RowBox[{"xt", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "+", 
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", "x1", "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x1"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x1"], "]"}]}]}], ")"}]}]}], ")"}]}], 
                    SuperscriptBox["x1", "2"]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", "xt", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
                    RowBox[{"x2", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", "x2", "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x2"], "]"}]}]}], ")"}]}]}], ")"}]}], 
                    SuperscriptBox["x2", "2"]]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"x1", " ", 
                    SuperscriptBox["x2", "3"]}]], "6", " ", "xt", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x1"}], ")"}], "2"], " ", 
                    SuperscriptBox["x2", "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x1"}], "]"}]}], "-", 
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x1"}], ")"}], " ", 
                    SuperscriptBox["x2", "2"], " ", 
                    RowBox[{"Log", "[", "x1", "]"}]}], "+", 
                    RowBox[{"x1", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x2"}], ")"}], "2"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "-", "x2"}], "]"}]}], "+", 
                    RowBox[{"x2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "x1"}], "-", 
                    RowBox[{"3", " ", "x2"}], "-", 
                    RowBox[{"x1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x2"}], ")"}], " ", 
                    RowBox[{"Log", "[", "x2", "]"}]}], "-", 
                    RowBox[{"2", " ", "x2", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x1"], "]"}]}], "+", 
                    RowBox[{"2", " ", "x1", " ", 
                    RowBox[{"Log", "[", 
                    FractionBox["xs", "x2"], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"shiftDROS\[Alpha]t\[Alpha]Sdegenerate", "[", 
    RowBox[{"mtilde_", ",", "M3_", ",", "Xt_"}], "]"}], ":=", 
   RowBox[{"Re", "@", " ", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xt", "=", 
         FractionBox["Xt", "M3"]}], ",", 
        RowBox[{"xs", "=", 
         FractionBox[
          SuperscriptBox["mtilde", "2"], 
          SuperscriptBox["M3", "2"]]}]}], "}"}], ",", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "+", "xt"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6"}], "+", 
           RowBox[{"18", " ", "xt"}], "-", 
           RowBox[{"9", " ", 
            SuperscriptBox["xt", "2"]}], "+", 
           SuperscriptBox["xt", "3"]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "12"}], "+", 
           RowBox[{"24", " ", "xt"}], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["xt", "2"]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["xt", "3"]}], "+", 
           SuperscriptBox["xt", "4"]}], ")"}], " ", 
         RowBox[{"Log", "[", "xs", "]"}]}]}], 
       RowBox[{"96", " ", 
        SuperscriptBox["\[Pi]", "4"]}]]}], "]"}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.636179957114511*^9, 3.636179985705956*^9}, {
   3.636180022387319*^9, 3.6361801270061693`*^9}, {3.6361802041661053`*^9, 
   3.6361802057937117`*^9}, {3.636180259627437*^9, 3.6361802633144827`*^9}, {
   3.636180483575148*^9, 3.636180494564165*^9}, {3.636180691444521*^9, 
   3.636180730874946*^9}, {3.6361807789409933`*^9, 3.6361808461015463`*^9}, {
   3.636192887849647*^9, 3.6361928901304407`*^9}, {3.6361965708786488`*^9, 
   3.636196574604759*^9}, {3.636207023063039*^9, 3.636207028253996*^9}, {
   3.636207452490645*^9, 3.636207459029673*^9}, {3.636225796380316*^9, 
   3.63622580437403*^9}, {3.636270168827455*^9, 3.636270174633404*^9}, {
   3.63631204522229*^9, 3.636312079222455*^9}, {3.636312846803111*^9, 
   3.6363129173983507`*^9}, {3.636313251122179*^9, 3.6363132592816353`*^9}, {
   3.636354600077468*^9, 3.636354603106783*^9}, 3.636354939804594*^9, {
   3.636354974729138*^9, 3.636354996720055*^9}, {3.638101007691552*^9, 
   3.6381010321197357`*^9}, {3.638101095412784*^9, 3.638101097451098*^9}, {
   3.638101339054706*^9, 3.638101359438427*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Two - Loop ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox[
     SubscriptBox["\[Alpha]", "t"], "2"]}], TraditionalForm]],
  FontWeight->"Plain"],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.62119111331535*^9, 3.621191114051093*^9}, {
   3.6211911549748583`*^9, 3.621191174542444*^9}, 3.6211931357478*^9, 
   3.622266002963265*^9, 3.622266657733597*^9},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "The analytical expression for the two-loop ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{
     SubscriptBox["\[Alpha]", "t"], 
     SubscriptBox["\[Alpha]", "s"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") correction for degenerate scalars in the ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["DR", "_"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " scheme can be found in the definition of the function \[CapitalDelta]\
\[Lambda]2lalphat2",
 StyleBox["[].",
  FontSlant->"Italic"],
 " In the on-shell scheme one needs to add the shift contribution given in \
the function ",
 "shiftDROS\[Alpha]t2",
 StyleBox["[ ].",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.6386107363072653`*^9, 3.638610853247431*^9}, {
  3.638610891258759*^9, 3.638610956823398*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Auxiliar",
 FontVariations->{"Underline"->True}]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.622288745185974*^9, 3.622288768887352*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Lambda]2lalphat2aux", ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["ht", "6"], 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Beta]", "]"}], "4"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]"}], ")"}], "4"]], 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "2"], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Mu]h", "2"]}], "-", 
      FractionBox[
       RowBox[{"13", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "2"], "+", 
      RowBox[{"60", " ", "K", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["\[Pi]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"f1", "[", "\[Mu]h", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Mu]h", "2"], " ", 
       RowBox[{"f1", "[", "\[Mu]h", "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]h", "2"], " ", 
       RowBox[{"f2", "[", "\[Mu]h", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"f3", "[", "\[Mu]h", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["Xth", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "2"], "-", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mst", "2"], 
         SuperscriptBox["Q", "2"]], "]"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Mu]h", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mst", "2"], 
         SuperscriptBox["Q", "2"]], "]"}]}], "+", 
      RowBox[{"13", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mst", "2"], 
         SuperscriptBox["Q", "2"]], "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mst", "2"], 
          SuperscriptBox["Q", "2"]], "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mst", "2"], 
          SuperscriptBox["Q", "2"]], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["Xth", "3"], " ", "Yth", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "+", 
         RowBox[{"16", " ", "K", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["Yth", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
         RowBox[{"16", " ", "K", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"Xth", " ", "Yth", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
         RowBox[{"64", " ", "K", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["Xth", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "7"}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Mu]h", "2"]}], "+", 
         RowBox[{"15", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
         RowBox[{"24", " ", "K", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"f1", "[", "\[Mu]h", "]"}]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Mu]h", "2"], " ", 
          RowBox[{"f1", "[", "\[Mu]h", "]"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"f2", "[", "\[Mu]h", "]"}]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Mu]h", "2"], " ", 
          RowBox[{"f2", "[", "\[Mu]h", "]"}]}], "+", 
         RowBox[{"27", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Mu]h", "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["Yth", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"14", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "3"], "+", 
            RowBox[{"24", " ", "K", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      
      RowBox[{
       SuperscriptBox["Xth", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["11", "2"], "+", 
         SuperscriptBox["\[Mu]h", "2"], "-", 
         FractionBox[
          RowBox[{"25", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "4"], "-", 
         FractionBox[
          RowBox[{"f1", "[", "\[Mu]h", "]"}], "2"], "+", 
         RowBox[{
          SuperscriptBox["\[Mu]h", "2"], " ", 
          RowBox[{"f1", "[", "\[Mu]h", "]"}]}], "+", 
         FractionBox[
          RowBox[{"f2", "[", "\[Mu]h", "]"}], "2"], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox["\[Mu]h", "2"], " ", 
          RowBox[{"f2", "[", "\[Mu]h", "]"}]}], "-", 
         RowBox[{
          FractionBox["13", "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[Mu]h", "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["Yth", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["19", "12"]}], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
            RowBox[{"8", " ", "K", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Lambda]2lalphat2aux", "/.", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", 
       SuperscriptBox["\[Mu]h", "2"]}], "]"}], "\[Rule]", 
     RowBox[{"log", "[", 
      RowBox[{"1", "-", 
       SuperscriptBox["\[Mu]h", "2"]}], "]"}]}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Mu]h", "\[Rule]", 
      FractionBox["\[Mu]", "mst"]}], ",", 
     RowBox[{"Xth", "\[Rule]", 
      FractionBox["Xt", "mst"]}], ",", 
     RowBox[{"Yth", "\[Rule]", 
      RowBox[{
       FractionBox["Xt", "mst"], "+", 
       FractionBox[
        RowBox[{"2", "\[Mu]"}], 
        RowBox[{"mst", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "\[Beta]"}], "]"}]}]]}]}], ",", 
     RowBox[{"ht", "\[Rule]", 
      FractionBox[
       SubscriptBox["g", "t"], 
       RowBox[{"Sin", "[", "\[Beta]", "]"}]]}]}], "}"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{"\[Beta]", "\[Rule]", 
    RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "}"}]}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.622269199521061*^9, 3.622269226250399*^9}, {
   3.622269749011737*^9, 3.62226975387039*^9}, {3.622269941812601*^9, 
   3.622269962275576*^9}, {3.62227000671172*^9, 3.622270028224441*^9}, {
   3.622270123354759*^9, 3.62227012668552*^9}, {3.622270171674491*^9, 
   3.622270176314089*^9}, 3.6222887688874817`*^9, 3.622353159873786*^9, {
   3.627060125787305*^9, 3.627060152659225*^9}, {3.627060349267424*^9, 
   3.6270603855839777`*^9}, {3.6270606016268177`*^9, 3.627060602547014*^9}, {
   3.627372083730031*^9, 3.627372119621089*^9}, {3.627372184313961*^9, 
   3.62737223674788*^9}, {3.627372294166833*^9, 3.627372302672861*^9}, 
   3.627372581285882*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"256", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["tan\[Beta]", "2"]}]], 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["tan\[Beta]", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     FractionBox["13", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"60", " ", "K"}], 
      RowBox[{"1", "+", 
       SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
     FractionBox[
      SuperscriptBox["\[Pi]", "2"], 
      RowBox[{"1", "+", 
       SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox["\[Mu]", "2"]}], 
      SuperscriptBox["mst", "2"]], "-", 
     RowBox[{"8", " ", 
      RowBox[{"f1", "[", 
       FractionBox["\[Mu]", "mst"], "]"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"f1", "[", 
        FractionBox["\[Mu]", "mst"], "]"}]}], 
      SuperscriptBox["mst", "2"]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"f2", "[", 
        FractionBox["\[Mu]", "mst"], "]"}]}], 
      SuperscriptBox["mst", "2"]], "+", 
     RowBox[{"4", " ", 
      RowBox[{"f3", "[", 
       FractionBox["\[Mu]", "mst"], "]"}]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Xt", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], "+", 
         FractionBox[
          RowBox[{
           FractionBox["1", "2"], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["mst", "2"], 
              SuperscriptBox["Q", "2"]], "]"}]}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}], 
      SuperscriptBox["mst", "6"]], "-", 
     RowBox[{"4", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        SuperscriptBox["mst", "2"], 
        SuperscriptBox["Q", "2"]], "]"}]}], "+", 
     FractionBox[
      RowBox[{"13", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mst", "2"], 
         SuperscriptBox["Q", "2"]], "]"}]}], 
      RowBox[{"1", "+", 
       SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mst", "2"], 
         SuperscriptBox["Q", "2"]], "]"}]}], 
      SuperscriptBox["mst", "2"]], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox["mst", "2"], 
         SuperscriptBox["Q", "2"]], "]"}], "2"]}], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox["mst", "2"], 
          SuperscriptBox["Q", "2"]], "]"}], "2"]}], 
      RowBox[{"1", "+", 
       SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Xt", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["Xt", "mst"], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[Mu]", " ", 
           RowBox[{"Csc", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "mst"]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["4", 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
         FractionBox[
          RowBox[{"16", " ", "K"}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mst", "2"], 
             SuperscriptBox["Q", "2"]], "]"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}], 
      SuperscriptBox["mst", "3"]], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox["Xt", "mst"], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[Mu]", " ", 
           RowBox[{"Csc", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "mst"]}], 
        ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3", 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]]}], "-", 
        FractionBox[
         RowBox[{"16", " ", "K"}], 
         RowBox[{"1", "+", 
          SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
        FractionBox[
         RowBox[{"3", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{"Xt", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["Xt", "mst"], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[Mu]", " ", 
           RowBox[{"Csc", "[", 
            RowBox[{"2", " ", 
             RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], "mst"]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["12", 
           RowBox[{"1", "+", 
            SuperscriptBox["tan\[Beta]", "2"]}]]}], "-", 
         FractionBox[
          RowBox[{"64", " ", "K"}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
         FractionBox[
          RowBox[{"12", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mst", "2"], 
             SuperscriptBox["Q", "2"]], "]"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}], "mst"], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["mst", "2"]], 
      RowBox[{
       SuperscriptBox["Xt", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "7"}], "+", 
         FractionBox["15", 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
         FractionBox[
          RowBox[{"24", " ", "K"}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
         FractionBox[
          RowBox[{"6", " ", 
           SuperscriptBox["\[Mu]", "2"]}], 
          SuperscriptBox["mst", "2"]], "+", 
         RowBox[{"4", " ", 
          RowBox[{"f1", "[", 
           FractionBox["\[Mu]", "mst"], "]"}]}], "-", 
         FractionBox[
          RowBox[{"6", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"f1", "[", 
            FractionBox["\[Mu]", "mst"], "]"}]}], 
          SuperscriptBox["mst", "2"]], "-", 
         RowBox[{"4", " ", 
          RowBox[{"f2", "[", 
           FractionBox["\[Mu]", "mst"], "]"}]}], "-", 
         FractionBox[
          RowBox[{"6", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"f2", "[", 
            FractionBox["\[Mu]", "mst"], "]"}]}], 
          SuperscriptBox["mst", "2"]], "+", 
         RowBox[{"27", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "-", 
         FractionBox[
          RowBox[{"24", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mst", "2"], 
             SuperscriptBox["Q", "2"]], "]"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
         FractionBox[
          RowBox[{"6", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mst", "2"], 
             SuperscriptBox["Q", "2"]], "]"}]}], 
          SuperscriptBox["mst", "2"]], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["Xt", "mst"], "+", 
             FractionBox[
              RowBox[{"2", " ", "\[Mu]", " ", 
               RowBox[{"Csc", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
              "mst"]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["14", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]], "+", 
            FractionBox[
             RowBox[{"24", " ", "K"}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
            FractionBox[
             RowBox[{"3", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mst", "2"], 
                SuperscriptBox["Q", "2"]], "]"}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}]}], ")"}]}]}], 
     "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["mst", "4"]], 
      RowBox[{
       SuperscriptBox["Xt", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["11", "2"], "-", 
         FractionBox["25", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]], "+", 
         FractionBox[
          SuperscriptBox["\[Mu]", "2"], 
          SuperscriptBox["mst", "2"]], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"f1", "[", 
           FractionBox["\[Mu]", "mst"], "]"}]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"f1", "[", 
            FractionBox["\[Mu]", "mst"], "]"}]}], 
          SuperscriptBox["mst", "2"]], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"f2", "[", 
           FractionBox["\[Mu]", "mst"], "]"}]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"f2", "[", 
            FractionBox["\[Mu]", "mst"], "]"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["mst", "2"]}]], "-", 
         RowBox[{
          FractionBox["13", "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], "+", 
         FractionBox[
          RowBox[{"6", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mst", "2"], 
             SuperscriptBox["Q", "2"]], "]"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mst", "2"], 
             SuperscriptBox["Q", "2"]], "]"}]}], 
          SuperscriptBox["mst", "2"]], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FractionBox["Xt", "mst"], "+", 
             FractionBox[
              RowBox[{"2", " ", "\[Mu]", " ", 
               RowBox[{"Csc", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
              "mst"]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["19", 
              RowBox[{"12", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]]}], "-", 
            FractionBox[
             RowBox[{"8", " ", "K"}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
            FractionBox[
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}], 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]]}], ")"}]}]}], 
        ")"}]}]}]}], ")"}], " ", 
   SubsuperscriptBox["g", "t", "6"]}]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.622269904527323*^9, 3.622269963295278*^9, 3.622270029539562*^9, 
   3.6222701274198723`*^9, 3.622270177133815*^9, {3.6222887688876123`*^9, 
   3.622288781998258*^9}, {3.6223523824183693`*^9, 3.622352393075747*^9}, {
   3.622353175271892*^9, 3.62235319398837*^9}, 3.622353228741041*^9, 
   3.6270601687551537`*^9, {3.627060359511239*^9, 3.62706038725905*^9}, 
   3.6270606030631647`*^9, 3.627372149340725*^9, {3.627372219418077*^9, 
   3.627372237439419*^9}, 3.627372303038589*^9, 3.627372581889468*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", "f2", ",", "f3", ",", 
     RowBox[{"\[Kappa]", "=", 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"4", "\[Pi]"}], ")"}], "2"]]}], ",", 
     RowBox[{"K", "=", 
      RowBox[{"-", "0.1953256"}]}], ",", 
     RowBox[{"\[Delta]", "=", 
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "\[Mu]_", "]"}], ":=", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], "-", "1"}], "]"}], "<", 
           "\[Delta]"}]}], "}"}], "}"}], ",", 
       RowBox[{
        FractionBox[
         SuperscriptBox["\[Mu]", "2"], 
         RowBox[{"1", "-", 
          SuperscriptBox["\[Mu]", "2"]}]], 
        RowBox[{"Log", "[", 
         SuperscriptBox["\[Mu]", "2"], "]"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f2", "[", "\[Mu]_", "]"}], ":=", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], "-", "1"}], "]"}], "<", 
           "\[Delta]"}]}], "}"}], "}"}], ",", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "-", 
          SuperscriptBox["\[Mu]", "2"]}]], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            RowBox[{"1", "-", 
             SuperscriptBox["\[Mu]", "2"]}]], 
           RowBox[{"Log", "[", 
            SuperscriptBox["\[Mu]", "2"], "]"}]}]}], ")"}]}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f3", "[", "\[Mu]_", "]"}], ":=", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "9"}], "4"], ",", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], "-", "1"}], "]"}], "<", 
           "\[Delta]"}]}], "}"}], "}"}], ",", 
       RowBox[{"Re", "[", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", 
            SuperscriptBox["\[Mu]", "2"]}], "+", 
           RowBox[{"2", 
            SuperscriptBox["\[Mu]", "4"]}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["\[Mu]", "2"]}], ")"}], "2"]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Log", "[", 
             SuperscriptBox["\[Mu]", "2"], "]"}], 
            RowBox[{"Log", "[", 
             RowBox[{"1", "-", 
              SuperscriptBox["\[Mu]", "2"]}], "]"}]}], "+", 
           RowBox[{"PolyLog", "[", 
            RowBox[{"2", ",", 
             SuperscriptBox["\[Mu]", "2"]}], "]"}], "-", 
           FractionBox[
            SuperscriptBox["\[Pi]", "2"], "6"], "-", 
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], 
            RowBox[{"Log", "[", 
             SuperscriptBox["\[Mu]", "2"], "]"}]}]}], ")"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalDelta]\[Lambda]2lalphat2", "[", 
      RowBox[{
      "Q_", ",", "mst_", ",", "\[Mu]_", ",", "tan\[Beta]_", ",", "Xt_"}], 
      "]"}], ":=", " ", 
     RowBox[{
      SubsuperscriptBox["g", "t", "6"], 
      FractionBox["1", 
       RowBox[{"256", " ", 
        SuperscriptBox["\[Pi]", "4"], " ", 
        SuperscriptBox["tan\[Beta]", "2"]}]], "3", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["tan\[Beta]", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "2"], "-", 
        FractionBox["13", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"60", " ", "K"}], 
         RowBox[{"1", "+", 
          SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
        FractionBox[
         SuperscriptBox["\[Pi]", "2"], 
         RowBox[{"1", "+", 
          SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
        FractionBox[
         RowBox[{"6", " ", 
          SuperscriptBox["\[Mu]", "2"]}], 
         SuperscriptBox["mst", "2"]], "-", 
        RowBox[{"8", " ", 
         RowBox[{"f1", "[", 
          FractionBox["\[Mu]", "mst"], "]"}]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          RowBox[{"f1", "[", 
           FractionBox["\[Mu]", "mst"], "]"}]}], 
         SuperscriptBox["mst", "2"]], "+", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          RowBox[{"f2", "[", 
           FractionBox["\[Mu]", "mst"], "]"}]}], 
         SuperscriptBox["mst", "2"]], "+", 
        RowBox[{"4", " ", 
         RowBox[{"f3", "[", 
          FractionBox["\[Mu]", "mst"], "]"}]}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["Xt", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "2"]}], "+", 
            FractionBox[
             RowBox[{
              FractionBox["1", "2"], "-", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mst", "2"], 
                 SuperscriptBox["Q", "2"]], "]"}]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}]}], ")"}]}], 
         SuperscriptBox["mst", "6"]], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Log", "[", 
          FractionBox[
           SuperscriptBox["mst", "2"], 
           SuperscriptBox["Q", "2"]], "]"}]}], "+", 
        FractionBox[
         RowBox[{"13", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
        FractionBox[
         RowBox[{"6", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}]}], 
         SuperscriptBox["mst", "2"]], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox[
            SuperscriptBox["mst", "2"], 
            SuperscriptBox["Q", "2"]], "]"}], "2"]}], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"Log", "[", 
            FractionBox[
             SuperscriptBox["mst", "2"], 
             SuperscriptBox["Q", "2"]], "]"}], "2"]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["mst", "3"]], 
         RowBox[{
          SuperscriptBox["Xt", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["Xt", "mst"], "+", 
            FractionBox[
             RowBox[{"2", " ", "\[Mu]", " ", 
              RowBox[{"Csc", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             "mst"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["4", 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
            FractionBox[
             RowBox[{"16", " ", "K"}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
            FractionBox[
             RowBox[{"2", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mst", "2"], 
                SuperscriptBox["Q", "2"]], "]"}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["Xt", "mst"], "+", 
            FractionBox[
             RowBox[{"2", " ", "\[Mu]", " ", 
              RowBox[{"Csc", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             "mst"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["3", 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]]}], "-", 
           FractionBox[
            RowBox[{"16", " ", "K"}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
           FractionBox[
            RowBox[{"3", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "mst"], 
         RowBox[{"Xt", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["Xt", "mst"], "+", 
            FractionBox[
             RowBox[{"2", " ", "\[Mu]", " ", 
              RowBox[{"Csc", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
             "mst"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["12", 
              RowBox[{"1", "+", 
               SuperscriptBox["tan\[Beta]", "2"]}]]}], "-", 
            FractionBox[
             RowBox[{"64", " ", "K"}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
            FractionBox[
             RowBox[{"12", " ", 
              RowBox[{"Log", "[", 
               FractionBox[
                SuperscriptBox["mst", "2"], 
                SuperscriptBox["Q", "2"]], "]"}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}]}], "+", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["mst", "2"]], 
         SuperscriptBox["Xt", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "7"}], "+", 
           FractionBox["15", 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           FractionBox[
            RowBox[{"24", " ", "K"}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           FractionBox[
            RowBox[{"6", " ", 
             SuperscriptBox["\[Mu]", "2"]}], 
            SuperscriptBox["mst", "2"]], "+", 
           RowBox[{"4", " ", 
            RowBox[{"f1", "[", 
             FractionBox["\[Mu]", "mst"], "]"}]}], "-", 
           FractionBox[
            RowBox[{"6", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"f1", "[", 
              FractionBox["\[Mu]", "mst"], "]"}]}], 
            SuperscriptBox["mst", "2"]], "-", 
           RowBox[{"4", " ", 
            RowBox[{"f2", "[", 
             FractionBox["\[Mu]", "mst"], "]"}]}], "-", 
           FractionBox[
            RowBox[{"6", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"f2", "[", 
              FractionBox["\[Mu]", "mst"], "]"}]}], 
            SuperscriptBox["mst", "2"]], "+", 
           RowBox[{"27", " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["mst", "2"], 
              SuperscriptBox["Q", "2"]], "]"}]}], "-", 
           FractionBox[
            RowBox[{"24", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
           FractionBox[
            RowBox[{"6", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}], 
            SuperscriptBox["mst", "2"]], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               FractionBox["Xt", "mst"], "+", 
               FractionBox[
                RowBox[{"2", " ", "\[Mu]", " ", 
                 RowBox[{"Csc", "[", 
                  RowBox[{"2", " ", 
                   RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                "mst"]}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox["14", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]], "+", 
              FractionBox[
               RowBox[{"24", " ", "K"}], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
              FractionBox[
               RowBox[{"3", " ", 
                RowBox[{"Log", "[", 
                 FractionBox[
                  SuperscriptBox["mst", "2"], 
                  SuperscriptBox["Q", "2"]], "]"}]}], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["mst", "4"]], 
         SuperscriptBox["Xt", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["11", "2"], "-", 
           FractionBox["25", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]], "+", 
           FractionBox[
            SuperscriptBox["\[Mu]", "2"], 
            SuperscriptBox["mst", "2"]], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"f1", "[", 
             FractionBox["\[Mu]", "mst"], "]"}]}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"f1", "[", 
              FractionBox["\[Mu]", "mst"], "]"}]}], 
            SuperscriptBox["mst", "2"]], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"f2", "[", 
             FractionBox["\[Mu]", "mst"], "]"}]}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"f2", "[", 
              FractionBox["\[Mu]", "mst"], "]"}]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["mst", "2"]}]], "-", 
           RowBox[{
            FractionBox["13", "2"], " ", 
            RowBox[{"Log", "[", 
             FractionBox[
              SuperscriptBox["mst", "2"], 
              SuperscriptBox["Q", "2"]], "]"}]}], "+", 
           FractionBox[
            RowBox[{"6", " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"Log", "[", 
              FractionBox[
               SuperscriptBox["mst", "2"], 
               SuperscriptBox["Q", "2"]], "]"}]}], 
            SuperscriptBox["mst", "2"]], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               FractionBox["Xt", "mst"], "+", 
               FractionBox[
                RowBox[{"2", " ", "\[Mu]", " ", 
                 RowBox[{"Csc", "[", 
                  RowBox[{"2", " ", 
                   RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}], 
                "mst"]}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["19", 
                RowBox[{"12", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]]}], "-", 
              FractionBox[
               RowBox[{"8", " ", "K"}], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "+", 
              FractionBox[
               RowBox[{"Log", "[", 
                FractionBox[
                 SuperscriptBox["mst", "2"], 
                 SuperscriptBox["Q", "2"]], "]"}], 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  SuperscriptBox["tan\[Beta]", "2"]}], ")"}]}]]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"shift", " ", "DRbar", " ", "to", " ", "OS"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"log", "[", "y_", "]"}], ":=", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{
           RowBox[{"Abs", "[", "y", "]"}], "<", 
           RowBox[{"0.5", " ", 
            SuperscriptBox["10", 
             RowBox[{"-", "2"}]]}]}]}], "}"}], "}"}], ",", 
       RowBox[{"Log", "[", 
        RowBox[{"Abs", "[", "y", "]"}], "]"}]}], "]"}]}], " ", ";", 
    RowBox[{"(*", 
     RowBox[{
     "defined", " ", "to", " ", "avoid", " ", "numerical", " ", "problems"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"shiftDROS\[Alpha]t2", "[", 
      RowBox[{
      "Q_", ",", "mst_", ",", "\[Mu]_", ",", "tan\[Beta]_", ",", "Xt_"}], 
      "]"}], ":=", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["g", "t"], "6"], 
      RowBox[{"Re", "@", 
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Beta]", "=", 
            RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
           RowBox[{"xt", "=", 
            FractionBox["Xt", "mst"]}], ",", 
           RowBox[{"yt", "=", 
            RowBox[{
             FractionBox["Xt", "mst"], "+", 
             FractionBox[
              RowBox[{"2", " ", "\[Mu]"}], 
              RowBox[{"mst", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", 
                 RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], "]"}]}]]}]}], 
           ",", 
           RowBox[{"x\[Mu]", "=", 
            FractionBox[
             SuperscriptBox[
              RowBox[{"(", "\[Mu]", ")"}], "2"], 
             SuperscriptBox["mst", "2"]]}], ",", 
           RowBox[{"xq", "=", 
            FractionBox[
             SuperscriptBox["Q", "2"], 
             SuperscriptBox["mst", "2"]]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Beta]", "]"}], 
           RowBox[{"-", "2"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{"1024", " ", 
               SuperscriptBox["\[Pi]", "4"]}]], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "36"}], "-", 
               RowBox[{"36", " ", 
                SuperscriptBox["xt", "2"]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["xt", "4"]}], "+", 
               RowBox[{"72", " ", "x\[Mu]"}], "-", 
               RowBox[{"72", " ", 
                SuperscriptBox["xt", "2"], " ", "x\[Mu]"}], "+", 
               RowBox[{"12", " ", 
                SuperscriptBox["xt", "4"], " ", "x\[Mu]"}], "-", 
               RowBox[{"36", " ", 
                SuperscriptBox["x\[Mu]", "2"]}], "+", 
               RowBox[{"108", " ", 
                SuperscriptBox["xt", "2"], " ", 
                SuperscriptBox["x\[Mu]", "2"]}], "-", 
               RowBox[{"18", " ", 
                SuperscriptBox["xt", "4"], " ", 
                SuperscriptBox["x\[Mu]", "2"]}]}], ")"}], " ", 
             RowBox[{"log", "[", 
              RowBox[{"1", "-", "x\[Mu]"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", 
              RowBox[{"1024", " ", 
               SuperscriptBox["\[Pi]", "4"]}]], 
             RowBox[{"(", 
              RowBox[{"108", "-", 
               RowBox[{"54", " ", 
                SuperscriptBox["xt", "2"]}], "+", 
               RowBox[{"9", " ", 
                SuperscriptBox["xt", "4"]}], "-", 
               RowBox[{"108", " ", "x\[Mu]"}], "+", 
               RowBox[{"180", " ", 
                SuperscriptBox["xt", "2"], " ", "x\[Mu]"}], "-", 
               RowBox[{"30", " ", 
                SuperscriptBox["xt", "4"], " ", "x\[Mu]"}], "-", 
               RowBox[{"6", " ", 
                SuperscriptBox["xt", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "6"}], "+", 
                  SuperscriptBox["xt", "2"]}], ")"}], " ", "x\[Mu]", " ", 
                RowBox[{"f2", "[", 
                 SqrtBox["x\[Mu]"], "]"}]}], "+", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "24"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x\[Mu]"}], ")"}]}], "+", 
                  RowBox[{"12", " ", 
                   SuperscriptBox["xt", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", "x\[Mu]"}]}], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["xt", "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", "x\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "xq", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"36", "-", 
                  RowBox[{"48", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", "\[Pi]"}]}], ")"}], " ", "xt", " ", 
                   "yt"}], "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", "\[Pi]"}]}], ")"}], " ", 
                   SuperscriptBox["xt", "3"], " ", "yt"}], "+", 
                  RowBox[{"72", " ", 
                   SuperscriptBox["yt", "2"]}], "-", 
                  RowBox[{"12", " ", 
                   SqrtBox["3"], " ", "\[Pi]", " ", 
                   SuperscriptBox["yt", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["xt", "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{"9", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", "\[Pi]"}]}], ")"}], " ", 
                    SuperscriptBox["yt", "2"]}]}], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                   SuperscriptBox["xt", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", "\[Pi]"}]}], ")"}], " ", 
                    SuperscriptBox["yt", "2"]}]}], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"24", " ", "xt", " ", "yt"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["xt", "3"], " ", "yt"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["yt", "2"]}], ")"}]}], "-", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["xt", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox["yt", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["xt", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox["yt", "2"]}], ")"}]}]}], ")"}], " ", 
                   RowBox[{"Log", "[", "xq", "]"}]}]}], ")"}]}], "+", 
               RowBox[{"36", " ", 
                SuperscriptBox["x\[Mu]", "2"], " ", 
                RowBox[{"Log", "[", "x\[Mu]", "]"}]}], "-", 
               RowBox[{"108", " ", 
                SuperscriptBox["xt", "2"], " ", 
                SuperscriptBox["x\[Mu]", "2"], " ", 
                RowBox[{"Log", "[", "x\[Mu]", "]"}]}], "+", 
               RowBox[{"18", " ", 
                SuperscriptBox["xt", "4"], " ", 
                SuperscriptBox["x\[Mu]", "2"], " ", 
                RowBox[{"Log", "[", "x\[Mu]", "]"}]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["xt", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"30", "-", 
                  RowBox[{"10", " ", 
                   SuperscriptBox["xt", "2"]}], "+", 
                  SuperscriptBox["xt", "4"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"Log", "[", "xq", "]"}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}]}], ")"}]}]}], 
           ")"}]}]}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", "]"}]], "Input",\

 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True,
 CellChangeTimes->{{3.61097400781422*^9, 3.610974056354995*^9}, {
   3.6109742159625196`*^9, 3.610974364280335*^9}, {3.610978554525606*^9, 
   3.610978555940909*^9}, 3.610978620217683*^9, {3.616419595193276*^9, 
   3.61641960201994*^9}, {3.6211914192395363`*^9, 3.621191480743058*^9}, {
   3.6211915203886747`*^9, 3.621191533549366*^9}, {3.621191581552478*^9, 
   3.621191657281622*^9}, 3.621191770750195*^9, {3.6211919578333187`*^9, 
   3.621191960886855*^9}, {3.6211920538109293`*^9, 3.621192105421732*^9}, {
   3.621192148542095*^9, 3.621192158670568*^9}, {3.621192417330573*^9, 
   3.621192517793619*^9}, {3.621192582483019*^9, 3.621192666687827*^9}, 
   3.62119313574894*^9, 3.62226665773594*^9, {3.62226916585561*^9, 
   3.62226917101891*^9}, 3.622269878206419*^9, 3.622269996315775*^9, {
   3.62227006235544*^9, 3.622270069935305*^9}, {3.622270102669757*^9, 
   3.622270191703512*^9}, 3.6223132463007507`*^9, {3.6223133280068293`*^9, 
   3.6223133352345543`*^9}, {3.6223133664757223`*^9, 3.622313389360394*^9}, {
   3.622313423895207*^9, 3.6223135198270607`*^9}, {3.6223532509106894`*^9, 
   3.622353275296639*^9}, 3.6223536297290363`*^9, {3.6223537693692713`*^9, 
   3.622353770137672*^9}, {3.622353900464561*^9, 3.622353930897266*^9}, {
   3.622354011442316*^9, 3.622354012485331*^9}, {3.625166788218774*^9, 
   3.625166793216085*^9}, {3.6270603101820517`*^9, 3.627060326805645*^9}, {
   3.62706041254979*^9, 3.627060423650236*^9}, 3.627060613747032*^9, {
   3.6273724249467783`*^9, 3.627372425387384*^9}, {3.627372660638953*^9, 
   3.627372700082762*^9}, {3.627372730187339*^9, 3.6273727323386717`*^9}, {
   3.628063445333248*^9, 3.628063446124625*^9}, {3.636270511861393*^9, 
   3.6362705162022133`*^9}, {3.6381046312031507`*^9, 3.638104655398449*^9}, {
   3.638189335175624*^9, 3.638189348784708*^9}, {3.638189569276895*^9, 
   3.638189570449802*^9}, {3.638561012469442*^9, 3.63856106952108*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global Functions", "Subsection",
 CellChangeTimes->{{3.622266701660203*^9, 3.6222667111586637`*^9}, {
  3.6223128688945*^9, 3.622312875928206*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "\[Lambda]HSS", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"suppressedCorrections", "\[Rule]", "False"}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]HSS", "[", 
   RowBox[{
    RowBox[{"mtilde_", "?", "NumericQ"}], ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", 
    RowBox[{"mQ2_", "?", "NumericQ"}], ",", 
    RowBox[{"mQ3_", "?", "NumericQ"}], ",", 
    RowBox[{"mU1_", "?", "NumericQ"}], ",", 
    RowBox[{"mU2_", "?", "NumericQ"}], ",", 
    RowBox[{"mU3_", "?", "NumericQ"}], ",", 
    RowBox[{"mD1_", "?", "NumericQ"}], ",", 
    RowBox[{"mD2_", "?", "NumericQ"}], ",", 
    RowBox[{"mD3_", "?", "NumericQ"}], ",", 
    RowBox[{"mE1_", "?", "NumericQ"}], ",", 
    RowBox[{"mE2_", "?", "NumericQ"}], ",", 
    RowBox[{"mE3_", "?", "NumericQ"}], ",", 
    RowBox[{"mL1_", "?", "NumericQ"}], ",", 
    RowBox[{"mL2_", "?", "NumericQ"}], ",", 
    RowBox[{"mL3_", "?", "NumericQ"}], ",", 
    RowBox[{"mA_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"M1_", "?", "NumericQ"}], ",", 
    RowBox[{"M2_", "?", "NumericQ"}], ",", 
    RowBox[{"M3_", "?", "NumericQ"}], ",", 
    RowBox[{"tan\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"Xt_", "?", "NumericQ"}], ",", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Lambda]HSS1l", "[", 
     RowBox[{
     "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
      ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2", 
      ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", "\[Mu]",
       ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[CapitalDelta]\[Lambda]2lstrong", "[", 
         RowBox[{"mtilde", ",", "mQ3", ",", "mU3", ",", "Xt", ",", "M3"}], 
         "]"}], "+", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"OptionValue", "[", "scheme", "]"}], "\[Equal]", 
           "\"\<OS\>\""}], ",", 
          RowBox[{"shiftDROS\[Alpha]t\[Alpha]S", "[", 
           RowBox[{"mtilde", ",", "mQ3", ",", "mU3", ",", "Xt", ",", "M3"}], 
           "]"}], ",", "0"}], "]"}]}], ")"}], ",", "0"}], "]"}], "+", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[CapitalDelta]\[Lambda]2lalphat2", "[", 
         RowBox[{"mtilde", ",", 
          SqrtBox[
           RowBox[{"mQ3", " ", "mU3"}]], ",", "\[Mu]", ",", "tan\[Beta]", ",",
           "Xt"}], "]"}], "+", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"OptionValue", "[", "scheme", "]"}], "\[Equal]", 
           "\"\<OS\>\""}], ",", 
          RowBox[{"shiftDROS\[Alpha]t2", "[", 
           RowBox[{"mtilde", ",", 
            SqrtBox[
             RowBox[{"mQ3", " ", "mU3"}]], ",", "\[Mu]", ",", "tan\[Beta]", 
            ",", "Xt"}], "]"}], ",", "0"}], "]"}]}], ")"}], ",", "0"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Lambda]2lbottom", "[", 
         RowBox[{
         "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", "\[Mu]", ",", 
          "tan\[Beta]", ",", "Xt"}], "]"}], "+", 
        RowBox[{"\[Lambda]2ltau", "[", 
         RowBox[{
         "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", "\[Mu]", ",", 
          "tan\[Beta]"}], "]"}]}], ")"}], ",", "0"}], "]"}], "+", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"OptionValue", "[", "suppressedCorrections", "]"}], ",", 
      RowBox[{"\[Lambda]HSS1lsuppressed", "[", 
       RowBox[{
       "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
        ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
        "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",",
         "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
        "Xt"}], "]"}], ",", "0"}], "]"}]}], ")"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.622270295180133*^9, 3.6222703610147676`*^9}, {
   3.6222704920144243`*^9, 3.622270590015731*^9}, {3.6222709855264874`*^9, 
   3.622270989998231*^9}, {3.622288525608575*^9, 3.6222885257535048`*^9}, 
   3.622288556103911*^9, {3.622288587863613*^9, 3.622288674774447*^9}, {
   3.622313829586733*^9, 3.6223138353730297`*^9}, {3.622370897460047*^9, 
   3.622370920601055*^9}, {3.625157922084803*^9, 3.625157924203829*^9}, {
   3.6251669684144793`*^9, 3.6251670405319347`*^9}, {3.6251671673881187`*^9, 
   3.625167221339675*^9}, {3.6270608106833773`*^9, 3.6270608133592863`*^9}, {
   3.6270642399878273`*^9, 3.627064262652156*^9}, {3.627064327731667*^9, 
   3.627064330219983*^9}, {3.627064939713812*^9, 3.6270649524955597`*^9}, {
   3.627065247966724*^9, 3.62706524974399*^9}, {3.6270671759619904`*^9, 
   3.62706718745651*^9}, {3.6270685234056168`*^9, 3.6270685267317133`*^9}, {
   3.62737277660644*^9, 3.627372808085793*^9}, {3.6346739186363583`*^9, 
   3.634673920612853*^9}, {3.63467395672521*^9, 3.634673966050726*^9}, {
   3.6346744540463743`*^9, 3.634674454049693*^9}, {3.635846431252576*^9, 
   3.635846516925538*^9}, {3.636196453460466*^9, 3.636196463029379*^9}, {
   3.636196513268385*^9, 3.636196554803583*^9}, {3.636196653002282*^9, 
   3.6361967728281927`*^9}, {3.6361968512608643`*^9, 3.6361968838915987`*^9}, 
   3.63619725181586*^9, 3.636197296191113*^9, 3.636198499431629*^9, {
   3.638045543861555*^9, 3.638045576070413*^9}, {3.638189412739871*^9, 
   3.638189451635891*^9}, {3.6385614652815638`*^9, 3.638561483929379*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Lambda]Splitscalars", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"\[Lambda]Splitscalarsaux", "/.", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox["m", "~"], "\[Rule]", "mtilde"}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
      RowBox[{
       SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
      RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
      RowBox[{
       SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
      RowBox[{
       SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
      RowBox[{
       SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", 
       RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
      RowBox[{
       SubscriptBox["X", "t"], "\[Rule]", "Xt"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]SMsplit", "[", 
   RowBox[{"Qmsplit_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"\[Lambda]SMsplitaux", "/.", 
     RowBox[{"{", 
      RowBox[{"msplit", "\[Rule]", "Qmsplit"}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
      RowBox[{
       SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
      RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
      RowBox[{
       SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
      RowBox[{
       SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
      RowBox[{
       SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", 
       RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
      RowBox[{
       SubscriptBox["X", "t"], "\[Rule]", "Xt"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gtSplitsplit", "[", 
   RowBox[{"Qmsplit_", ",", 
    RowBox[{"Q\[Mu]_", "?", "NumericQ"}], ",", "M1_", ",", "M2_", ",", 
    "M3_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"gtSplitsplitaux", "/.", 
     RowBox[{"{", 
      RowBox[{"msplit", "\[Rule]", "Qmsplit"}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
      RowBox[{
       SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
      RowBox[{
       SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
      RowBox[{
       SubscriptBox["M", "3"], "\[Rule]", "M3"}]}], "}"}]}], 
   "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620036604495273*^9, 3.620036700334557*^9}, {
   3.620038798627668*^9, 3.620038907214643*^9}, {3.620038960582526*^9, 
   3.620038967548971*^9}, {3.620039364411083*^9, 3.6200394288099747`*^9}, {
   3.620039526515194*^9, 3.6200395737849283`*^9}, {3.620039924845911*^9, 
   3.620039925231509*^9}, {3.620040081404818*^9, 3.620040082772276*^9}, {
   3.6200401137486343`*^9, 3.620040114691864*^9}, {3.6201259767504272`*^9, 
   3.620125987901672*^9}, {3.620132239799943*^9, 3.620132249623291*^9}, {
   3.6202441100491323`*^9, 3.620244117400297*^9}, {3.620287425790214*^9, 
   3.620287466357997*^9}, {3.620287735470365*^9, 3.620287804958466*^9}, {
   3.620288188512301*^9, 3.620288275794505*^9}, {3.6202887151179323`*^9, 
   3.620288833329062*^9}, {3.620308435448557*^9, 3.620308473110737*^9}, 
   3.620310695895473*^9, {3.620310795674629*^9, 3.620310801231983*^9}, {
   3.6205420097056103`*^9, 3.62054203595256*^9}, {3.6205422720339947`*^9, 
   3.620542299082074*^9}, {3.620542671772378*^9, 3.620542675256361*^9}, {
   3.6205427311164923`*^9, 3.620542736937961*^9}, 3.620547210379869*^9, {
   3.6205473484534397`*^9, 3.620547383577714*^9}, {3.6211444857979717`*^9, 
   3.6211444894098873`*^9}, {3.621156373499342*^9, 3.62115640931588*^9}, {
   3.621156441348481*^9, 3.6211564521126003`*^9}, 3.6211565326917543`*^9, {
   3.621156842843094*^9, 3.621156844626552*^9}, {3.621192723672309*^9, 
   3.6211927947960176`*^9}, {3.621192831759997*^9, 3.621192861764277*^9}, {
   3.621192913219323*^9, 3.621192980865156*^9}, 3.6211930469558077`*^9, {
   3.621193125210225*^9, 3.621193126219425*^9}, {3.621193288557585*^9, 
   3.6211933140362577`*^9}, {3.621663063111435*^9, 3.621663084572886*^9}, {
   3.621663172160185*^9, 3.621663178270907*^9}, {3.621663260044903*^9, 
   3.621663273458749*^9}, {3.621663348081176*^9, 3.621663352662414*^9}, {
   3.621663408821828*^9, 3.621663417070239*^9}, 3.6222710039654922`*^9, 
   3.622288908356443*^9, {3.622454493420985*^9, 3.6224545661149063`*^9}, {
   3.625166610461061*^9, 3.625166622278474*^9}, {3.628063661557345*^9, 
   3.628063683669442*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"g1umtilde", "[", 
    RowBox[{"mtilde_", ",", 
     RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_",
      ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
     "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
     ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
     "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"g1umtildeaux", "/.", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox["m", "~"], "\[Rule]", "mtilde"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
       RowBox[{
        SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
       RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
       RowBox[{
        SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
       RowBox[{
        SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
       RowBox[{
        SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", 
        RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
       RowBox[{
        SubscriptBox["X", "t"], "\[Rule]", "Xt"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g2umtilde", "[", 
    RowBox[{"mtilde_", ",", 
     RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_",
      ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
     "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
     ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
     "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"g2umtildeaux", "/.", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox["m", "~"], "\[Rule]", "mtilde"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
       RowBox[{
        SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
       RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
       RowBox[{
        SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
       RowBox[{
        SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
       RowBox[{
        SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", 
        RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
       RowBox[{
        SubscriptBox["X", "t"], "\[Rule]", "Xt"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1dmtilde", "[", 
    RowBox[{"mtilde_", ",", 
     RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_",
      ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
     "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
     ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
     "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"g1dmtildeaux", "/.", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox["m", "~"], "\[Rule]", "mtilde"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
       RowBox[{
        SubscriptBox["m", 
         SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
       RowBox[{
        SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
       RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
       RowBox[{
        SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
       RowBox[{
        SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
       RowBox[{
        SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", 
        RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
       RowBox[{
        SubscriptBox["X", "t"], "\[Rule]", "Xt"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2dmtilde", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"g2dmtildeaux", "/.", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox["m", "~"], "\[Rule]", "mtilde"}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "1"]], "\[Rule]", "mQ1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "2"]], "\[Rule]", "mQ2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["Q", "3"]], "\[Rule]", "mQ3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "1"]], "\[Rule]", "mU1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "2"]], "\[Rule]", "mU2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["U", "3"]], "\[Rule]", "mU3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "1"]], "\[Rule]", "mD1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "2"]], "\[Rule]", "mD2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["D", "3"]], "\[Rule]", "mD3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "1"]], "\[Rule]", "mE1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "2"]], "\[Rule]", "mE2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["E", "3"]], "\[Rule]", "mE3"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "1"]], "\[Rule]", "mL1"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "2"]], "\[Rule]", "mL2"}], ",", 
      RowBox[{
       SubscriptBox["m", 
        SubscriptBox["L", "3"]], "\[Rule]", "mL3"}], ",", 
      RowBox[{
       SubscriptBox["m", "A"], "\[Rule]", "mA"}], ",", 
      RowBox[{"\[Mu]", "\[Rule]", "Q\[Mu]"}], ",", 
      RowBox[{
       SubscriptBox["M", "1"], "\[Rule]", "M1"}], ",", 
      RowBox[{
       SubscriptBox["M", "2"], "\[Rule]", "M2"}], ",", 
      RowBox[{
       SubscriptBox["M", "3"], "\[Rule]", "M3"}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", 
       RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
      RowBox[{
       SubscriptBox["X", "t"], "\[Rule]", "Xt"}]}], "}"}]}], 
   "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.62031172778831*^9, 3.620311771677903*^9}, {
  3.620311866330326*^9, 3.620311945355227*^9}, {3.6205420378697844`*^9, 
  3.6205420465892963`*^9}, {3.622454572862062*^9, 3.62245460300828*^9}, {
  3.622454952457052*^9, 3.622454953526701*^9}, {3.628063690795945*^9, 
  3.628063710728037*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Higgs Mass", "Title",
 CellChangeTimes->{{3.634542178490542*^9, 3.63454218802376*^9}}],

Cell["\<\
This is the actual package for the calcualtion of the Higgs mass in the MSSM. \
It depends on the other previously defined sub-packages: SM RGEs, Split RGEs \
and Thresholds.\
\>", "Text",
 CellChangeTimes->{{3.638561757184341*^9, 3.638561935840353*^9}}],

Cell[CellGroupData[{

Cell["Matching at the electroweak scale (at the top mass)", "Section",
 CellChangeTimes->{{3.620123468801609*^9, 3.620123476099874*^9}, 
   3.62012352037787*^9, {3.6205507479381*^9, 3.6205507538257227`*^9}, {
   3.6385621384020452`*^9, 3.6385622050303383`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Mhpole", "::", "usage"}], "=", 
   "\"\<Mhpole[\[Lambda]atMT] computes the pole mass of the Higgs from the \
value of the quartic coupling \!\(\*
StyleBox[\"\[Lambda]atMT\",
FontSlant->\"Italic\"]\) at the pole mass of the top in the \
\!\(\*OverscriptBox[\(MS\), \(_\)]\) scheme.\>\""}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MW", "=", "80.384"}], ";", " ", 
  RowBox[{"MZ", "=", "91.1876"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mh", "=", "125.09"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]3MZ", "=", "0.1185"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MT", "=", "173.34"}], ";", 
  RowBox[{"vev", "=", "246.21971"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g3MT", "=", "  ", 
   RowBox[{"1.1666", "+", " ", 
    RowBox[{"0", " ", "1.15"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2MT", "=", " ", 
   RowBox[{"0.64779", "+", 
    RowBox[{"0", " ", "0.64822"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gyMT", "=", " ", 
   RowBox[{"0.35830", "+", 
    RowBox[{"0", " ", "0.35760"}]}]}], ";", 
  RowBox[{"g1MT", "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"5", "/", "3"}]], "gyMT"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gtMT2l", "=", "0.94018"}], ";"}], 
  RowBox[{"(*", "NNLO", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gtMT3l", "=", "0.93690"}], ";"}], 
  RowBox[{"(*", "NNNLO", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gbMT", "=", "0.0156"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g\[Tau]MT", "=", "0.0100"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]MT", "=", 
   RowBox[{"2", " ", "0.12604"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620116249171604*^9, 3.620116254274785*^9}, {
   3.620116687687405*^9, 3.6201166914151907`*^9}, {3.620116760646943*^9, 
   3.620116819927722*^9}, {3.620116863463142*^9, 3.62011692225489*^9}, {
   3.620117076845192*^9, 3.620117087980698*^9}, {3.620117275995344*^9, 
   3.620117278139203*^9}, {3.620117714498378*^9, 3.620117720520362*^9}, {
   3.62011857036742*^9, 3.620118571007656*^9}, {3.62011948105402*^9, 
   3.620119488360675*^9}, {3.620124046697544*^9, 3.620124046816873*^9}, {
   3.620125187048601*^9, 3.620125350119273*^9}, {3.62013252568274*^9, 
   3.62013256916212*^9}, {3.6201326943582907`*^9, 3.620132696909422*^9}, {
   3.620225336352893*^9, 3.620225339991156*^9}, 3.620225388046857*^9, 
   3.620225436111902*^9, {3.620225611979363*^9, 3.6202256321667547`*^9}, {
   3.620225759338983*^9, 3.6202257626753263`*^9}, {3.620226205283183*^9, 
   3.6202262829944353`*^9}, {3.620226368208169*^9, 3.620226411568182*^9}, {
   3.6203076048979673`*^9, 3.620307613231332*^9}, {3.6205503477953053`*^9, 
   3.620550349343876*^9}, {3.6223686246908503`*^9, 3.622368627787314*^9}, {
   3.6223689023231916`*^9, 3.622368903954578*^9}, {3.622369366369253*^9, 
   3.6223693691696253`*^9}, {3.622370371806448*^9, 3.622370373813258*^9}, {
   3.622539787854618*^9, 3.622539790926063*^9}, {3.622539977753117*^9, 
   3.622539984297304*^9}, {3.622781455136882*^9, 3.622781457605886*^9}, {
   3.625167909424982*^9, 3.6251679138955727`*^9}, {3.62516799334872*^9, 
   3.625167996178904*^9}, {3.627070302652143*^9, 3.627070353280113*^9}, {
   3.638514104059224*^9, 3.638514114828968*^9}, {3.638514145737526*^9, 
   3.638514148081197*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "SetSMparameters", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"useMStopYukawa", "\[Rule]", "False"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetSMparameters", "[", 
   RowBox[{"QMTorgt_", ",", "Q\[Alpha]3MZ_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"!", 
       RowBox[{"OptionValue", "[", "useMStopYukawa", "]"}]}], ",", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"g3MT", "=", 
        RowBox[{"1.1666", "+", 
         RowBox[{"0.00314", " ", 
          FractionBox[
           RowBox[{"Q\[Alpha]3MZ", "-", "0.1184"}], "0.0007"]}], "-", 
         RowBox[{"0.00046", 
          RowBox[{"(", 
           RowBox[{"QMTorgt", "-", "173.34"}], ")"}]}]}]}], ";", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"gtMT3l", "=", 
        RowBox[{"0.93690", "+", 
         RowBox[{"0.00556", 
          RowBox[{"(", 
           RowBox[{"QMTorgt", "-", "173.34"}], ")"}]}], "-", 
         RowBox[{"0.00042", " ", 
          FractionBox[
           RowBox[{"Q\[Alpha]3MZ", "-", "0.1184"}], "0.0007"]}]}]}], ";", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"gtMT2l", "=", 
        RowBox[{"gtMT3l", "-", "0.93690", "+", "0.94018"}]}]}], ",", 
      "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"gtMT3l", "=", "QMTorgt"}], ";", "\[IndentingNewLine]", "\t", 
       RowBox[{"gtMT2l", "=", 
        RowBox[{"gtMT3l", "-", "0.93690", "+", "0.94018"}]}], ";", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"MT", "=", 
        RowBox[{"173.34", "+", 
         RowBox[{
          FractionBox["1", "0.00556"], 
          RowBox[{"(", 
           RowBox[{"gtMT3l", "-", "0.93690", "+", 
            RowBox[{"0.00042", " ", 
             FractionBox[
              RowBox[{"Q\[Alpha]3MZ", "-", "0.1184"}], "0.0007"]}]}], 
           ")"}]}]}]}], ";", "\[IndentingNewLine]", "\t", 
       RowBox[{"g3MT", "=", 
        RowBox[{"1.1666", "+", 
         RowBox[{"0.00314", " ", 
          FractionBox[
           RowBox[{"Q\[Alpha]3MZ", "-", "0.1184"}], "0.0007"]}], "-", 
         RowBox[{"0.00046", 
          RowBox[{"(", 
           RowBox[{"MT", "-", "173.34"}], ")"}]}]}]}], ";"}]}], "]"}], ";", 
    RowBox[{"solSM3l", "=", 
     RowBox[{"SMrun", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["g", "1"], ",", 
         SubscriptBox["g", "2"], ",", 
         SubscriptBox["g", "3"], ",", 
         SubscriptBox["g", "t"], ",", "\[Lambda]", ",", 
         SubscriptBox["g", "\[Tau]"], ",", 
         SubscriptBox["g", "b"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["g", "1"], "[", "0", "]"}], "\[Equal]", "g1MT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "2"], "[", "0", "]"}], "\[Equal]", "g2MT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "3"], "[", "0", "]"}], "\[Equal]", "g3MT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "t"], "[", "0", "]"}], "\[Equal]", "gtMT3l"}], 
         ",", 
         RowBox[{
          RowBox[{"\[Lambda]", "[", "0", "]"}], "\[Equal]", 
          RowBox[{
           FractionBox["1", "2"], "\[Lambda]MT"}]}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "b"], "[", "0", "]"}], "\[Equal]", "gbMT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "\[Tau]"], "[", "0", "]"}], "\[Equal]", 
          "g\[Tau]MT"}]}], "}"}], ",", "0", ",", "40", ",", "optsSMrun"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"solSM2l", "=", 
     RowBox[{"SMrun", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["g", "1"], ",", 
         SubscriptBox["g", "2"], ",", 
         SubscriptBox["g", "3"], ",", 
         SubscriptBox["g", "t"], ",", "\[Lambda]", ",", 
         SubscriptBox["g", "\[Tau]"], ",", 
         SubscriptBox["g", "b"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["g", "1"], "[", "0", "]"}], "\[Equal]", "g1MT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "2"], "[", "0", "]"}], "\[Equal]", "g2MT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "3"], "[", "0", "]"}], "\[Equal]", "g3MT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "t"], "[", "0", "]"}], "\[Equal]", "gtMT2l"}], 
         ",", 
         RowBox[{
          RowBox[{"\[Lambda]", "[", "0", "]"}], "\[Equal]", 
          RowBox[{
           FractionBox["1", "2"], "\[Lambda]MT"}]}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "b"], "[", "0", "]"}], "\[Equal]", "gbMT"}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["g", "\[Tau]"], "[", "0", "]"}], "\[Equal]", 
          "g\[Tau]MT"}]}], "}"}], ",", "0", ",", "40", ",", "optsSMrun"}], 
      "]"}]}], ";"}], ")"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6225400214102592`*^9, 3.6225401341797047`*^9}, {
   3.622549315341651*^9, 3.6225493996923857`*^9}, {3.6225494347316732`*^9, 
   3.622549689589443*^9}, {3.622549726693288*^9, 3.622549732964595*^9}, {
   3.622553788701869*^9, 3.622553870117991*^9}, {3.622780343016189*^9, 
   3.6227804441321297`*^9}, {3.622780545548216*^9, 3.622780546139455*^9}, {
   3.622780763851409*^9, 3.622780766020606*^9}, {3.622780918913465*^9, 
   3.622780938697919*^9}, {3.6227812509066143`*^9, 3.6227813632175627`*^9}, {
   3.622783042245406*^9, 3.6227830463092003`*^9}, 3.622783368379648*^9, {
   3.622784738566921*^9, 3.622784744551078*^9}, {3.622886554806882*^9, 
   3.622886559943087*^9}, 3.622886612119039*^9, {3.6228868644456797`*^9, 
   3.622886865111226*^9}, {3.622886926462823*^9, 3.6228869290820427`*^9}, {
   3.6228874546694183`*^9, 3.622887470172216*^9}, 3.62288803600294*^9, {
   3.6228881802098103`*^9, 3.62288819804144*^9}, {3.622888615376495*^9, 
   3.622888647149909*^9}, {3.6228887141509657`*^9, 3.622888715227726*^9}, {
   3.622888789452816*^9, 3.622888790786569*^9}, 3.622888879364355*^9, {
   3.622889792548037*^9, 3.6228898335980997`*^9}, {3.622890472072761*^9, 
   3.6228904801920347`*^9}, {3.627105879516325*^9, 3.62710593038708*^9}, {
   3.6271059715906773`*^9, 3.6271059733627663`*^9}, {3.627106072394836*^9, 
   3.627106112471545*^9}, {3.627106298377187*^9, 3.6271062993536377`*^9}, {
   3.627106357888956*^9, 3.627106385528544*^9}, {3.6271065239119577`*^9, 
   3.627106530919355*^9}, {3.627110067146377*^9, 3.627110093252777*^9}, {
   3.634674299698394*^9, 3.634674302077264*^9}, {3.634674426833817*^9, 
   3.6346744268359823`*^9}, {3.636367362703002*^9, 3.636367455342205*^9}, {
   3.63636750294156*^9, 3.636367503749382*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Delta]\[Lambda]2lMT", "=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Delta]\[Lambda]2QCD", ",", "\[Delta]\[Lambda]2EW"}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Delta]\[Lambda]2QCD", "=", 
       RowBox[{
        FractionBox[
         SuperscriptBox["g3MT", "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "\[Pi]"}], ")"}], "4"]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "23.88"}], "+", 
          RowBox[{"0.12", 
           RowBox[{"(", 
            RowBox[{"Mh", "-", "125"}], ")"}]}], "-", 
          RowBox[{"0.64", " ", 
           RowBox[{"(", 
            RowBox[{"MT", "-", "173"}], ")"}]}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Delta]\[Lambda]2EW", "=", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "\[Pi]"}], ")"}], "4"]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9.45"}], "-", 
          RowBox[{"0.12", " ", 
           RowBox[{"(", 
            RowBox[{"Mh", "-", "125"}], ")"}]}], "-", 
          RowBox[{"0.21", 
           RowBox[{"(", 
            RowBox[{"MT", "-", "173"}], ")"}]}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "\[Delta]\[Lambda]2QCD"}], "-", 
       RowBox[{"2", " ", "\[Delta]\[Lambda]2EW"}]}]}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620117685192101*^9, 3.620117703609473*^9}, {
   3.6201177352018213`*^9, 3.620117929529344*^9}, {3.620118607307674*^9, 
   3.620118613594861*^9}, {3.62011864921916*^9, 3.620118649595216*^9}, {
   3.620118922344592*^9, 3.620118927400625*^9}, {3.6201195063655987`*^9, 
   3.620119514968144*^9}, {3.6205503578668747`*^9, 3.620550367995207*^9}, {
   3.622539928209016*^9, 3.62253996925994*^9}, {3.62254001698676*^9, 
   3.6225400181543417`*^9}, {3.622782962484186*^9, 3.622783027475342*^9}, {
   3.622783966839828*^9, 3.622783970041335*^9}, {3.625168066890109*^9, 
   3.625168110737364*^9}, 3.625171036508284*^9, {3.638562058284905*^9, 
   3.638562062488336*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mhpole", "[", "\[Lambda]mt_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox["vev", "2"], 
    RowBox[{"(", 
     RowBox[{"\[Lambda]mt", "+", 
      RowBox[{"0.0075", "\[Lambda]mt"}], "+", "\[Delta]\[Lambda]2lMT"}], 
     ")"}]}]]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620117582937495*^9, 3.620117674975418*^9}, {
   3.620117943502308*^9, 3.620117947741804*^9}, 3.6201180005176973`*^9, 
   3.620119004384193*^9, 3.621520773148288*^9, {3.622539993928707*^9, 
   3.622540004216116*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Pole mass of the Higgs in the MSSM", "Section",
 CellChangeTimes->{{3.620548692235442*^9, 3.620548709233898*^9}, {
  3.620550194636816*^9, 3.620550197228058*^9}}],

Cell[CellGroupData[{

Cell["Interpolated Solution of the RGEs", "Subsection",
 CellChangeTimes->{{3.634625330208816*^9, 3.6346253430786877`*^9}, {
  3.638562789979206*^9, 3.6385627903038063`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"ToExpression", "[", 
    RowBox[{"ToString", "[", 
     RowBox[{"Flatten", "@", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Directory", "[", "]"}], "<>", "\"\</RGsolution.txt\>\""}], 
        ",", "\"\<Data\>\""}], "]"}]}], "]"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.634625366572887*^9, 3.6346253744277163`*^9}, {
   3.634625517997375*^9, 3.634625519207468*^9}, 3.63856266652354*^9}],

Cell[CellGroupData[{

Cell["Table for interpolation (tableint)", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.634625435838449*^9, 3.634625451288397*^9}, 
   3.6346254888010073`*^9, 3.634629533392931*^9, 3.63463004972509*^9, {
   3.638562369558167*^9, 3.6385623713816557`*^9}, {3.6385625139474993`*^9, 
   3.6385625829071293`*^9}, {3.638562684371441*^9, 3.638562686115543*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tableint", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", 
       RowBox[{"-", "0.008068195410301826`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", 
       RowBox[{"-", "0.008068195410301826`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", 
       RowBox[{"-", "0.008068195410301826`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", 
       RowBox[{"-", "0.007723856547999131`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", 
       RowBox[{"-", "0.007723856547999131`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", 
       RowBox[{"-", "0.007723856547999131`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", 
       RowBox[{"-", "0.008408817954970574`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", 
       RowBox[{"-", "0.008408817954970574`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", 
       RowBox[{"-", "0.008408817954970574`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.0020352851002791864`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.0020352851002791864`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.0020352851002791864`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.0025396953252873025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.0025396953252873025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.0025396953252873025`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.0015363315640612172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.0015363315640612172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.0015363315640612172`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.011617521654989279`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.011617521654989279`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.011617521654989279`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.012274599315169435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.012274599315169435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.012274599315169435`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.010967566590489957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.010967566590489957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "0.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.010967566590489957`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.020714379793588485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.020714379793588485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.020714379793588485`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.021517172221571786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.021517172221571786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.021517172221571786`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.01992030444258303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.01992030444258303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.01992030444258303`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.029358637368335234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.029358637368335234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.029358637368335234`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.030300610665449507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.030300610665449507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.030300610665449507`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.028426907201590114`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.028426907201590114`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.028426907201590114`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.03758030136374664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.03758030136374664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.03758030136374664`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.038655310474637966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.038655310474637966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.038655310474637966`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.036516995944489386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.036516995944489386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.036516995944489386`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.045406887246077596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.045406887246077596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.045406887246077596`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.04660914840025003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.04660914840025003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.04660914840025003`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.044217727711245325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.044217727711245325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.044217727711245325`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.05286366582630709`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.05286366582630709`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.05286366582630709`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.054187731158079906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.054187731158079906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.054187731158079906`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.05155404017851422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.05155404017851422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "1.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.05155404017851422`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.05997388188898019`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.05997388188898019`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.05997388188898019`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.06141461605912326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.06141461605912326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.06141461605912326`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.058548868279443965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.058548868279443965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.058548868279443965`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.06675894822445971`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.06675894822445971`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.06675894822445971`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.06831150687895543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.06831150687895543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.06831150687895543`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.06522333639418082`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.06522333639418082`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.06522333639418082`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.07942927364807735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.07942927364807735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.07942927364807735`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.08119201928957345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.08119201928957345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.08119201928957345`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.07768577403562371`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.07768577403562371`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "2.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.07768577403562371`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.09101661499306041`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.09101661499306041`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.09101661499306041`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.09297320899134034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.09297320899134034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.09297320899134034`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.08908137634045968`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.08908137634045968`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.08908137634045968`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.10164215182210926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.10164215182210926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.10164215182210926`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.10377795563067146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.10377795563067146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.10377795563067146`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.09952963965610256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.09952963965610256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.09952963965610256`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.11140993810418444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.11140993810418444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.11140993810418444`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.11371180683942174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.11371180683942174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.11371180683942174`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.10913313967208373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.10913313967208373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "3.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.10913313967208373`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.12041013930864689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.12041013930864689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.12041013930864689`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.12286623894226334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.12286623894226334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.12286623894226334`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.11798074493811958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.11798074493811958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.11798074493811958`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.12872170948853226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.12872170948853226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.12872170948853226`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.13132135834777664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.13132135834777664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.13132135834777664`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.12615026954834704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.12615026954834704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "4.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.12615026954834704`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.13641303749197392`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.13641303749197392`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.13641303749197392`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.13914656374604728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.13914656374604728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.13914656374604728`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.13370910407993009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.13370910407993009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.13370910407993009`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.14354368961368963`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.14354368961368963`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.14354368961368963`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.14640232829486563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.14640232829486563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.14640232829486563`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.14071591827047497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.14071591827047497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.14071591827047497`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.15016651371358625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.15016651371358625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.15016651371358625`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.15314229847028782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.15314229847028782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.15314229847028782`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.1472227706576161`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.1472227706576161`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "5.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.1472227706576161`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.15632816491784976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.15632816491784976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.15632816491784976`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.15941383993917219`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.15941383993917219`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.15941383993917219`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.1532756142234446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.1532756142234446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.1532756142234446`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.16479471265162768`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.16479471265162768`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.16479471265162768`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.16803298545684306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.16803298545684306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.16803298545684306`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.16159103254065402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.16159103254065402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "6.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.16159103254065402`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.1724357458975667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.1724357458975667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.1724357458975667`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.17581356801496342`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.17581356801496342`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.17581356801496342`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.16909381804477594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.16909381804477594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "7.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.16909381804477594`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.17935280579098176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.17935280579098176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.17935280579098176`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.18285871190075867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.18285871190075867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.18285871190075867`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.1758839482278346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.1758839482278346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.1758839482278346`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.18563254733203358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.18563254733203358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.18563254733203358`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.18925642529646072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.18925642529646072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.18925642529646072`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.18204674175593316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.18204674175593316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "8.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.18204674175593316`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.19134831892933887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.19134831892933887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.19134831892933887`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.19508121903284703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.19508121903284703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.19508121903284703`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.18765439922564658`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.18765439922564658`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.18765439922564658`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.19656335021756566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.19656335021756566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.19656335021756566`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.20039732250805303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.20039732250805303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20039732250805303`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.19276916318569842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.19276916318569842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "9.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.19276916318569842`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.20133142032999338`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.20133142032999338`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20133142032999338`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.20525938155300924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.20525938155300924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20525938155300924`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.197443957199082`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.197443957199082`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "10.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.197443957199082`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.20570003714507215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.20570003714507215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20570003714507215`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.20971565910077988`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.20971565910077988`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20971565910077988`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.20172554361550735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.20172554361550735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20172554361550735`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.20970999034830623`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.20970999034830623`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20970999034830623`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2138076005953994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2138076005953994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2138076005953994`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.20565406485272272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.20565406485272272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "11.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.20565406485272272`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.213396113508952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.213396113508952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.213396113508952`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.21757062121829904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.21757062121829904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.21757062121829904`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2092637803127908`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2092637803127908`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2092637803127908`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.21679054550108645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.21679054550108645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.21679054550108645`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.22103736427226064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.22103736427226064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22103736427226064`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2125863307512784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2125863307512784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "12.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2125863307512784`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.21992022202405306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.21992022202405306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.21992022202405306`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2242352115538363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2242352115538363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2242352115538363`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.21564821169389928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.21564821169389928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "13.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.21564821169389928`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2228098212987354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2228098212987354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2228098212987354`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2271892374008025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2271892374008025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2271892374008025`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.21847371010074101`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.21847371010074101`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.21847371010074101`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.22548085414293081`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.22548085414293081`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22548085414293081`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.22992130107985867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.22992130107985867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22992130107985867`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2210839928495895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2210839928495895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "14.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2210839928495895`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.22795155002590584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.22795155002590584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22795155002590584`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.23244994915851755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.23244994915851755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23244994915851755`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.22349697649537956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.22349697649537956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22349697649537956`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.23023964134259467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.23023964134259467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23023964134259467`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.23479319151241343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.23479319151241343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23479319151241343`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.22573011912966293`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.22573011912966293`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "15.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22573011912966293`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.23236015790156064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.23236015790156064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23236015790156064`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.23696630614511605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.23696630614511605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23696630614511605`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.22779820559350866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.22779820559350866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "16.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22779820559350866`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2343262458308546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2343262458308546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2343262458308546`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2389826654424973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2389826654424973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2389826654424973`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.22971415873278145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.22971415873278145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.22971415873278145`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.23615022616554202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.23615022616554202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23615022616554202`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.24085479594603942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.24085479594603942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24085479594603942`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.23149009626503497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.23149009626503497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "17.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23149009626503497`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2378434226012271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2378434226012271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2378434226012271`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.24259419040579652`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.24259419040579652`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24259419040579652`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.23313717469648587`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.23313717469648587`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23313717469648587`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.23941500636051313`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.23941500636051313`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23941500636051313`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.24421020443272476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.24421020443272476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24421020443272476`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.23466438359245903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.23466438359245903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "18.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23466438359245903`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.24087363212898916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.24087363212898916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24087363212898916`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2457116404858613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2457116404858613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2457116404858613`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.23608023154585872`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.23608023154585872`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "19.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23608023154585872`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2422280190426217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2422280190426217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2422280190426217`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.24710734775003831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.24710734775003831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24710734775003831`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.23739330881131043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.23739330881131043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23739330881131043`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2434853416939051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2434853416939051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2434853416939051`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2484046249022876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2484046249022876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2484046249022876`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.23861066744828893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.23861066744828893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "20.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23861066744828893`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.24465161650849332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.24465161650849332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24465161650849332`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.24960961005057739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.24960961005057739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24960961005057739`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.23973820371045784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.23973820371045784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.23973820371045784`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.24573354136019485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.24573354136019485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24573354136019485`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25072909702442236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25072909702442236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25072909702442236`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24078252025125754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24078252025125754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "21.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24078252025125754`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.24673642684215202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.24673642684215202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24673642684215202`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25176849292483683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25176849292483683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25176849292483683`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24174883230504712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24174883230504712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "22.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24174883230504712`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2476653110910348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2476653110910348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2476653110910348`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25273292260943503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25273292260943503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25273292260943503`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24264209218060506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24264209218060506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24264209218060506`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.248524809215811`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.248524809215811`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.248524809215811`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2536270806636988`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2536270806636988`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2536270806636988`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2434668363098368`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2434668363098368`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "23.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2434668363098368`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.24931768494105258`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.24931768494105258`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24931768494105258`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2544538336420677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2544538336420677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2544538336420677`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2442257268390955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2442257268390955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2442257268390955`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25004953231849825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25004953231849825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25004953231849825`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25521881265440594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25521881265440594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25521881265440594`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24492432047850757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24492432047850757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "24.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24492432047850757`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2507232776862925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2507232776862925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2507232776862925`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2559250179886538`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2559250179886538`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2559250179886538`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24556547055163327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24556547055163327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "25.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24556547055163327`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25134214858858356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25134214858858356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25134214858858356`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25657573631075137`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25657573631075137`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25657573631075137`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24615234598951957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24615234598951957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24615234598951957`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2519091151133099`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2519091151133099`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2519091151133099`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2571739940764933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2571739940764933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2571739940764933`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24668786085336783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24668786085336783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "26.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24668786085336783`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25242559785189406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25242559785189406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25242559785189406`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25772129349550277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25772129349550277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25772129349550277`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2471733551885399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2471733551885399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2471733551885399`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25289568210539987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25289568210539987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25289568210539987`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2582217362722559`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2582217362722559`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2582217362722559`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24761289705538858`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24761289705538858`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "27.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24761289705538858`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25332119425026434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25332119425026434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25332119425026434`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2586772028919377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2586772028919377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2586772028919377`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24800825947553876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24800825947553876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "28.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24800825947553876`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2537042541231769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2537042541231769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2537042541231769`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2590898563289232`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2590898563289232`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2590898563289232`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24836151936482884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24836151936482884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24836151936482884`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2540460815530479`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2540460815530479`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2540460815530479`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25946097482245073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25946097482245073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25946097482245073`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2486738388214369`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2486738388214369`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "29.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2486738388214369`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25434918841251936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25434918841251936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25434918841251936`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.25979309627863467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.25979309627863467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25979309627863467`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24894770295572374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24894770295572374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24894770295572374`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.254615021436433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.254615021436433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.254615021436433`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26008770687029864`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26008770687029864`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26008770687029864`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24918451949947154`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24918451949947154`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "30.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24918451949947154`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.254845081950059`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.254845081950059`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.254845081950059`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2603463438051243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2603463438051243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2603463438051243`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24938575395097998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24938575395097998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "31.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24938575395097998`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25504037796058604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25504037796058604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25504037796058604`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26057005817520357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26057005817520357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26057005817520357`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2495523716290419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2495523716290419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2495523716290419`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25520243345905336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25520243345905336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25520243345905336`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26076040481817464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26076040481817464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26076040481817464`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24968586504210308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24968586504210308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "32.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24968586504210308`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25533236430460643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25533236430460643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25533236430460643`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2609185305820485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2609185305820485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2609185305820485`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2497873192455216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2497873192455216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2497873192455216`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2554312137806776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2554312137806776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2554312137806776`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.261045510354574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.261045510354574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.261045510354574`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24985774582215933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24985774582215933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "33.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24985774582215933`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2554999342723821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2554999342723821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2554999342723821`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2611423271714842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2611423271714842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2611423271714842`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24989806637671655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24989806637671655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "34.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24989806637671655`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25553947288240664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25553947288240664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25553947288240664`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26120995755455506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26120995755455506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26120995755455506`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24990919827887847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24990919827887847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24990919827887847`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25554942377471745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25554942377471745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25554942377471745`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2612480559521686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2612480559521686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2612480559521686`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24989067623472438`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24989067623472438`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "35.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24989067623472438`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25553204792856915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25553204792856915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25553204792856915`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2612588721351748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2612588721351748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2612588721351748`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24984477077917974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24984477077917974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24984477077917974`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2554873754670647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2554873754670647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2554873754670647`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26124248036631137`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26124248036631137`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26124248036631137`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2497714681885969`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2497714681885969`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "36.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2497714681885969`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2554159510633286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2554159510633286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2554159510633286`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26119945431894365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26119945431894365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26119945431894365`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24967128382846615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24967128382846615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "37.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24967128382846615`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25531825247843853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25531825247843853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25531825247843853`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2611303005940003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2611303005940003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2611303005940003`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24954466627544686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24954466627544686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24954466627544686`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2551946930453707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2551946930453707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2551946930453707`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26103546130971533`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26103546130971533`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26103546130971533`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24939199969447895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24939199969447895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "38.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24939199969447895`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25504562372467204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25504562372467204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25504562372467204`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26091531626354325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26091531626354325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26091531626354325`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24921360578693166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24921360578693166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24921360578693166`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2548713347502262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2548713347502262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2548713347502262`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26077018468561713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26077018468561713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26077018468561713`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.24900974532716486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.24900974532716486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.03`"}], ",", "39.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.24900974532716486`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.02142782702809648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.02142782702809648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.02142782702809648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.02176575678899757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.02176575678899757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.02176575678899757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.02109358899756884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.02109358899756884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.02109358899756884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.03128290529204494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.03128290529204494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.03128290529204494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.03177763578422278`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.03177763578422278`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.03177763578422278`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.030793593316440042`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.030793593316440042`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.030793593316440042`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.04061963653935648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.04061963653935648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.04061963653935648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.041263734419688676`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.041263734419688676`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.041263734419688676`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.03998260887576226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.03998260887576226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.03998260887576226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.04947418028397216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.04947418028397216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.04947418028397216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.05026067264684195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.05026067264684195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.05026067264684195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.048696337945435514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.048696337945435514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.048696337945435514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.05787955208304953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.05787955208304953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.05787955208304953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.05880189274194298`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.05880189274194298`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.05880189274194298`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.05696737249857386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.05696737249857386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.05696737249857386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.0658659486795997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.0658659486795997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.0658659486795997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.06691798716700277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.06691798716700277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.06691798716700277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.06482551661661758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.06482551661661758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.06482551661661758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.07346103443789069`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.07346103443789069`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.07346103443789069`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.07463698750511326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.07463698750511326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.07463698750511326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.0722980704110702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.0722980704110702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.0722980704110702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.08069019424900427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.08069019424900427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08069019424900427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.08198461966070375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.08198461966070375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08198461966070375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.0794100806249283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.0794100806249283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.0794100806249283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.08757675732029443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.08757675732029443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08757675732029443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.08898452975238688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.08898452975238688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08898452975238688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.08618456231269425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.08618456231269425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08618456231269425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.0941421956211798`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.0941421956211798`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.0941421956211798`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.09565848448489435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.09565848448489435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09565848448489435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.09264269535659722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.09264269535659722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09264269535659722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.1063854827306254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.1063854827306254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1063854827306254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.10810539460641273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.10810539460641273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10810539460641273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.10468462914095668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.10468462914095668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10468462914095668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.11756209351362461`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.11756209351362461`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11756209351362461`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.1194693761670286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.1194693761670286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1194693761670286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.11567595021162423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.11567595021162423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11567595021162423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.1277930956595736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.1277930956595736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1277930956595736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.12987321118692668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.12987321118692668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12987321118692668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.12573602910811815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.12573602910811815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12573602910811815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.13718227591225965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.13718227591225965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13718227591225965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.13942218935101916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.13942218935101916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13942218935101916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.13496716524771213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.13496716524771213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13496716524771213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.14581942814397117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.14581942814397117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14581942814397117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.14820742106733997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.14820742106733997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14820742106733997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.14345785006994602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.14345785006994602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14345785006994602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.15378307323501553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.15378307323501553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15378307323501553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.15630858313419302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.15630858313419302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15630858313419302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.15128546105711035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.15128546105711035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15128546105711035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.1611411260793181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.1611411260793181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1611411260793181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.16379460095123508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.16379460095123508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16379460095123508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.15851691422727948`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.15851691422727948`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15851691422727948`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.16795263328666257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.16795263328666257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16795263328666257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.17072542698718787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.17072542698718787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17072542698718787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.16521036024305877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.16521036024305877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16521036024305877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.17426991951718357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.17426991951718357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17426991951718357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.17715418308685255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.17715418308685255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17715418308685255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.17141733758787492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.17141733758787492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17141733758787492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.1801391158160965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.1801391158160965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1801391158160965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.1831277072381074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.1831277072381074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1831277072381074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.1771832767434044`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.1771832767434044`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1771832767434044`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.188190382725269`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.188190382725269`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.188190382725269`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.19132343409375588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.19132343409375588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19132343409375588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.18509153781069304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.18509153781069304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18509153781069304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.19544269071185144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.19544269071185144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19544269071185144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.19870738955253547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.19870738955253547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19870738955253547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.19221349094777218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.19221349094777218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19221349094777218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.2019959618961053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.2019959618961053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2019959618961053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.20538106373806098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.20538106373806098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20538106373806098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.19864750921374727`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.19864750921374727`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19864750921374727`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.2079353067326712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.2079353067326712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2079353067326712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.21143090528094766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.21143090528094766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21143090528094766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.20447738158429554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.20447738158429554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20447738158429554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.21333263362550772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.21333263362550772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21333263362550772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.21692997027575336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.21692997027575336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21692997027575336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.2097738839615138`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.2097738839615138`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2097738839615138`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.21824982650667987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.21824982650667987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21824982650667987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.22194112601304508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.22194112601304508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22194112601304508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.21459792799670735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.21459792799670735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21459792799670735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2227394304274717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2227394304274717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2227394304274717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.22651776962939998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.22651776962939998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22651776962939998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2190012183287648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2190012183287648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2190012183287648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.22684778462410057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.22684778462410057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22684778462410057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.23070698177599425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.23070698177599425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23070698177599425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.22302936215505897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.22302936215505897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22302936215505897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.23061461595531446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.23061461595531446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23061461595531446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.23454913135775682`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.23454913135775682`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23454913135775682`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.22672145263813193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.22672145263813193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22672145263813193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.23407377952637837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.23407377952637837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23407377952637837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.23807864121104652`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.23807864121104652`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23807864121104652`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.23011078448526343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.23011078448526343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23011078448526343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.23725648940486635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.23725648940486635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23725648940486635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.24132721867974904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.24132721867974904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24132721867974904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.23322808467089584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.23322808467089584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23322808467089584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.24018886505888162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.24018886505888162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24018886505888162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2443214166681661`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2443214166681661`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2443214166681661`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.23609904503850304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.23609904503850304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23609904503850304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.24289479560001498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.24289479560001498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24289479560001498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.24708551020485828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.24708551020485828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24708551020485828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.23874717354785321`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.23874717354785321`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23874717354785321`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.24539508394838055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.24539508394838055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24539508394838055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.24964063906545894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.24964063906545894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24964063906545894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.24119293816251178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.24119293816251178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24119293816251178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2477073335174999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2477073335174999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2477073335174999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2520047145111109`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2520047145111109`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2520047145111109`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2434536435793688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2434536435793688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2434536435793688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.24984864269467227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.24984864269467227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24984864269467227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.254195103598226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.254195103598226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.254195103598226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2455461201439419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2455461201439419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2455461201439419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2518334938373998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2518334938373998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2518334938373998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.25622652767723914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.25622652767723914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25622652767723914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.24748461437171443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.24748461437171443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24748461437171443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.25367454240963005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.25367454240963005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25367454240963005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.25811185871040687`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.25811185871040687`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25811185871040687`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.24928156813705526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.24928156813705526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24928156813705526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.25538362162131495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.25538362162131495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25538362162131495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.25986312804547596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.25986312804547596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25986312804547596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.25094861871129115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.25094861871129115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25094861871129115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.25697162474257984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.25697162474257984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25697162474257984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2614913908312876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2614913908312876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2614913908312876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2524964993191157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2524964993191157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2524964993191157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.25844733781549384`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.25844733781549384`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25844733781549384`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2630056090673704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2630056090673704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2630056090673704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2539338227266155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2539338227266155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2539338227266155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.25981906683749867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.25981906683749867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25981906683749867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2644142276983829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2644142276983829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2644142276983829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2552687576449314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2552687576449314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2552687576449314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.26109514907658365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.26109514907658365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26109514907658365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.26572570982575316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.26572570982575316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26572570982575316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.2565095167133593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.2565095167133593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2565095167133593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.26228245877693607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.26228245877693607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26228245877693607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.26694704663640595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.26694704663640595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26694704663640595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2576628587676459`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2576628587676459`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2576628587676459`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.26338677009578865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.26338677009578865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26338677009578865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.26808412502060486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.26808412502060486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26808412502060486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2587344467252565`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2587344467252565`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2587344467252565`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.26441446793110734`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.26441446793110734`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26441446793110734`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.26914342251082374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.26914342251082374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26914342251082374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2597305736554001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2597305736554001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2597305736554001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2653706389294736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2653706389294736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2653706389294736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2701301154719169`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2701301154719169`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2701301154719169`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26065623763390505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26065623763390505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26065623763390505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.2662601007632407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.2662601007632407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2662601007632407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.2710491025926678`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.2710491025926678`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2710491025926678`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.2615161762371724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.2615161762371724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2615161762371724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.26708726713400505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.26708726713400505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26708726713400505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27190487155044235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27190487155044235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27190487155044235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26231473002176414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26231473002176414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26231473002176414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2678548308729263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2678548308729263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2678548308729263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27270020424422214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27270020424422214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27270020424422214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26305450404475755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26305450404475755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26305450404475755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.26856807610117256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.26856807610117256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26856807610117256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27344042630567444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27344042630567444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27344042630567444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2637407407475125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2637407407475125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2637407407475125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.26922983245379556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.26922983245379556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26922983245379556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27412843234037637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27412843234037637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27412843234037637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26437620574779924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26437620574779924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26437620574779924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.26984319685671265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.26984319685671265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26984319685671265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.27476737293212095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.27476737293212095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27476737293212095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.26496394288144937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.26496394288144937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26496394288144937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2704110112967501`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2704110112967501`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2704110112967501`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27536014107991663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27536014107991663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27536014107991663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26550674355237475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26550674355237475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26550674355237475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2709347247787096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2709347247787096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2709347247787096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2759082526220382`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2759082526220382`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2759082526220382`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26600599103846084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26600599103846084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26600599103846084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.27141815524155094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.27141815524155094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27141815524155094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2764155475773673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2764155475773673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2764155475773673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26646548058601116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26646548058601116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26646548058601116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2718631115967449`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2718631115967449`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2718631115967449`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27688387997329267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27688387997329267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27688387997329267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2668869767580769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2668869767580769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2668869767580769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.27227164666027814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.27227164666027814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27227164666027814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.2773153402044783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.2773153402044783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2773153402044783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.26727249510790296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.26727249510790296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26727249510790296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2726450255517807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2726450255517807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2726450255517807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2777112402036224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2777112402036224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2777112402036224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2676232546540551`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2676232546540551`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2676232546540551`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2729855953091811`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2729855953091811`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2729855953091811`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2780739528572843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2780739528572843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2780739528572843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26794157616569053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26794157616569053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26794157616569053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2732948121930622`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2732948121930622`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2732948121930622`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2784049663803594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2784049663803594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2784049663803594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26822888443039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26822888443039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26822888443039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2735741573924647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2735741573924647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2735741573924647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27870579168067705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27870579168067705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27870579168067705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2684866311046381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2684866311046381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2684866311046381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.27382469688520134`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.27382469688520134`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27382469688520134`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.2789775281523825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.2789775281523825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2789775281523825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.26871584920222125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.26871584920222125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26871584920222125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2740478904069172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2740478904069172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2740478904069172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2792216619330854`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2792216619330854`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2792216619330854`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2689179717633393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2689179717633393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2689179717633393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2742448850208678`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2742448850208678`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2742448850208678`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27943936406289677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27943936406289677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27943936406289677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2690941221466741`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2690941221466741`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2690941221466741`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.27441674859383186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.27441674859383186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27441674859383186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2796317269304523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2796317269304523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2796317269304523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2692453437824425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2692453437824425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2692453437824425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.27456446464382644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.27456446464382644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27456446464382644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2797997611905993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2797997611905993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2797997611905993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2693726006579831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2693726006579831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2693726006579831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.274689005380237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.274689005380237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.274689005380237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.27994445422279973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.27994445422279973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27994445422279973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.2694768353885189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.2694768353885189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2694768353885189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.27479027792721344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.27479027792721344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27479027792721344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.28006575740296197`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.28006575740296197`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28006575740296197`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2695579186144103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2695579186144103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2695579186144103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2748702747768452`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2748702747768452`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2748702747768452`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.28016565907673846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.28016565907673846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28016565907673846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2696178458359347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2696178458359347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2696178458359347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.27492923465791985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.27492923465791985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27492923465791985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.28024442766517105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.28024442766517105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28024442766517105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26965682654134837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26965682654134837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26965682654134837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.27496779522170295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.27496779522170295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27496779522170295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2803027207420718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2803027207420718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2803027207420718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2696754784362879`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2696754784362879`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2696754784362879`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.27498653897995534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.27498653897995534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27498653897995534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.28034114019445416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.28034114019445416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28034114019445416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.2696743646162553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.2696743646162553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2696743646162553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2749859962147215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2749859962147215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2749859962147215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2803602352063685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2803602352063685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2803602352063685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26965399640272203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26965399640272203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26965399640272203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2749666475355014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2749666475355014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2749666475355014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.28036050488767705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.28036050488767705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28036050488767705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26961483582895984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26961483582895984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26961483582895984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2749289261076051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2749289261076051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2749289261076051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.28034240057219495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.28034240057219495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28034240057219495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26955729779879195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26955729779879195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26955729779879195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.0508714793213267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.0508714793213267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.0508714793213267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.05120302759928901`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.05120302759928901`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.05120302759928901`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.05054359826460182`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.05054359826460182`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.05054359826460182`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.06045302056957738`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.06045302056957738`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.06045302056957738`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.060938125902655585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.060938125902655585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.060938125902655585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.05997329574957062`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.05997329574957062`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.05997329574957062`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.06951977515803402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.06951977515803402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.06951977515803402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.07015098335473739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.07015098335473739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.07015098335473739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.06889558509134865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.06889558509134865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.06889558509134865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.07810816929742614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.07810816929742614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.07810816929742614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.07887849560380639`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.07887849560380639`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.07887849560380639`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.07734642640959725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.07734642640959725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.07734642640959725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.08625142945702735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.08625142945702735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08625142945702735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.08715432359545987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.08715432359545987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08715432359545987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.08535861496749776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.08535861496749776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08535861496749776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.09397991596786001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.09397991596786001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09397991596786001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.09500923005145773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.09500923005145773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09500923005145773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.09296211188189256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.09296211188189256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09296211188189256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.10132141664326852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.10132141664326852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10132141664326852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.10247137572737029`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.10247137572737029`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10247137572737029`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.10018433509469277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.10018433509469277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10018433509469277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.10830140579590117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.10830140579590117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10830140579590117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.10956658084386492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.10956658084386492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10956658084386492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.10705041596762983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.10705041596762983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10705041596762983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.11494327323268681`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.11494327323268681`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11494327323268681`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.11631855628943319`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.11631855628943319`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11631855628943319`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.11358342606478657`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.11358342606478657`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11358342606478657`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.12126852714027045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.12126852714027045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12126852714027045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.12274910852309098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.12274910852309098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12274910852309098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.11980457801857422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.11980457801857422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11980457801857422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.13304502906670476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.13304502906670476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13304502906670476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.13472287000948002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.13472287000948002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13472287000948002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.13138606116096535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.13138606116096535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13138606116096535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.14377285284507715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.14377285284507715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14377285284507715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.14563181367491065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.14563181367491065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14563181367491065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.141934818493966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.141934818493966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.141934818493966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.15357280204873164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.15357280204873164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15357280204873164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1555984701608447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1555984701608447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1555984701608447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.15156994399111043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.15156994399111043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15156994399111043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.16254825707347054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.16254825707347054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16254825707347054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.16472773065363536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.16472773065363536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16472773065363536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1603933230811573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1603933230811573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1603933230811573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1707885125564537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1707885125564537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1707885125564537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.17311021072738694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.17311021072738694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17311021072738694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1684929437117333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1684929437117333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1684929437117333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1783715397852241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1783715397852241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1783715397852241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.18082503992615429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.18082503992615429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18082503992615429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1759456315353443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1759456315353443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1759456315353443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.18536467274568694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.18536467274568694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18536467274568694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.18794056235730944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.18794056235730944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18794056235730944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.1828177220866419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.1828177220866419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1828177220866419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.19182634148853225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.19182634148853225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19182634148853225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1945161120007532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1945161120007532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1945161120007532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1891667518696534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1891667518696534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1891667518696534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1978082596402262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1978082596402262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1978082596402262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.20060419647792999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.20060419647792999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20060419647792999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.19504364982774192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.19504364982774192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19504364982774192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.20335595135728957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.20335595135728957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20335595135728957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.20625104419360527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.20625104419360527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20625104419360527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.20049324424754358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.20049324424754358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20049324424754358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.21094966736650436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.21094966736650436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21094966736650436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2139816999102339`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2139816999102339`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2139816999102339`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.207951461002518`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.207951461002518`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.207951461002518`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2177723480262627`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2177723480262627`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2177723480262627`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.22092877807416547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.22092877807416547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22092877807416547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.21465102717788295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.21465102717788295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21465102717788295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.22392209794174087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.22392209794174087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22392209794174087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.22719193549390207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.22719193549390207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22719193549390207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.22068851438444945`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.22068851438444945`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22068851438444945`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.22948230707113662`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.22948230707113662`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22948230707113662`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2328558839796991`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2328558839796991`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2328558839796991`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2261460072368788`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2261460072368788`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2261460072368788`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.23452328840607337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.23452328840607337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23452328840607337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.23799206704861575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.23799206704861575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23799206704861575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.23109270247304484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.23109270247304484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23109270247304484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.23910544083923646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.23910544083923646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23910544083923646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.24266185263287052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.24266185263287052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24266185263287052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.23558804226490399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.23558804226490399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23558804226490399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2432799513899009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2432799513899009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2432799513899009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.24691726342122894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.24691726342122894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24691726342122894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.23968238875354012`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.23968238875354012`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23968238875354012`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.24709187832611954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.24709187832611954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24709187832611954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2508040849540481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2508040849540481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2508040849540481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24342008213547184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24342008213547184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24342008213547184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2505797841474838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2505797841474838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2505797841474838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.25436150788513606`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.25436150788513606`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25436150788513606`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24683906493016314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24683906493016314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24683906493016314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.25377645567930546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.25377645567930546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25377645567930546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.25762287304180764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.25762287304180764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25762287304180764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24997157714705526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24997157714705526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24997157714705526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2567120967548252`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2567120967548252`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2567120967548252`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26061886617064023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26061886617064023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26061886617064023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2528473467410611`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2528473467410611`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2528473467410611`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2594119329747063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2594119329747063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2594119329747063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26337513408417584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26337513408417584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26337513408417584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2554911837615953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2554911837615953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2554911837615953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2618989934911345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2618989934911345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2618989934911345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26591508171076433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26591508171076433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26591508171076433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.25792574623559283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.25792574623559283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25792574623559283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2641933040680235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2641933040680235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2641933040680235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26825906294780155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26825906294780155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26825906294780155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2601707360773542`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2601707360773542`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2601707360773542`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.266311784772107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.266311784772107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.266311784772107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27042429237891213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27042429237891213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27042429237891213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26224278284166264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26224278284166264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26224278284166264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2682708404329072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2682708404329072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2682708404329072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2724274372386582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2724274372386582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2724274372386582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26415803199525817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26415803199525817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26415803199525817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2700843504609798`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2700843504609798`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2700843504609798`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2742826074469974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2742826074469974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2742826074469974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26593013549668815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26593013549668815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26593013549668815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27176442641161036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27176442641161036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27176442641161036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27600212235606963`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27600212235606963`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27600212235606963`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26757099993110106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26757099993110106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26757099993110106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2733223661348808`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2733223661348808`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2733223661348808`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27759747109980376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27759747109980376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27759747109980376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26909173401784037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26909173401784037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26909173401784037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27476859093793016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27476859093793016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27476859093793016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2790792306446236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2790792306446236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2790792306446236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27050260517933733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27050260517933733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27050260517933733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27611144310845454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27611144310845454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27611144310845454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28045591152167804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28045591152167804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28045591152167804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27181179006216966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27181179006216966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27181179006216966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2773588377447952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2773588377447952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2773588377447952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28173556062747795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28173556062747795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28173556062747795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27302707359060235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27302707359060235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27302707359060235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27851869184189076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27851869184189076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27851869184189076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28292621684203456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28292621684203456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28292621684203456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2741562520451075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2741562520451075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2741562520451075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.279597535329016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.279597535329016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.279597535329016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2840345211546949`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2840345211546949`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2840345211546949`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27520574578599183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27520574578599183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27520574578599183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2806008519952576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2806008519952576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2806008519952576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28506606307262045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28506606307262045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28506606307262045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27618093434300467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27618093434300467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27618093434300467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28153468005121046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28153468005121046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28153468005121046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.286026970458637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.286026970458637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.286026970458637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2770877670707357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2770877670707357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2770877670707357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2824038383235537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2824038383235537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2824038383235537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2869221466025544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2869221466025544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2869221466025544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2779309794494845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2779309794494845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2779309794494845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28321288297951297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28321288297951297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28321288297951297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28775622428483716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28775622428483716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28775622428483716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27871505193506535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27871505193506535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27871505193506535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28396598515415616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28396598515415616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28396598515415616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2885334444592567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2885334444592567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2885334444592567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.279444086658474`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.279444086658474`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.279444086658474`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28466570720994294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28466570720994294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28466570720994294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2892564487570184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2892564487570184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2892564487570184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2801205680226575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2801205680226575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2801205680226575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2853170061034173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2853170061034173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2853170061034173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28993023856844524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28993023856844524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28993023856844524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28074940838255846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28074940838255846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28074940838255846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28592256296667773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28592256296667773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28592256296667773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2905575537473825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2905575537473825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2905575537473825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2813332310911214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2813332310911214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2813332310911214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2864852989112232`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2864852989112232`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2864852989112232`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29114136558247633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29114136558247633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29114136558247633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2818749076362671`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2818749076362671`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2818749076362671`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28700789013795747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28700789013795747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28700789013795747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29168439690543385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29168439690543385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29168439690543385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28237706808320545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28237706808320545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28237706808320545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.287491736083422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.287491736083422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.287491736083422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2921881049256746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2921881049256746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2921881049256746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2828410551783112`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2828410551783112`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2828410551783112`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2879403829548243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2879403829548243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2879403829548243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29265606163606817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29265606163606817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29265606163606817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2832703887827964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2832703887827964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2832703887827964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2883555594037341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2883555594037341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2883555594037341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2930900351036421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2930900351036421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2930900351036421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2836667589003848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2836667589003848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2836667589003848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2887392024919346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2887392024919346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2887392024919346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2934919966021425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2934919966021425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2934919966021425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28403206872038417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28403206872038417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28403206872038417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2890925447541193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2890925447541193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2890925447541193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2938632182712743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2938632182712743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2938632182712743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2843675119018659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2843675119018659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2843675119018659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28941775197710284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28941775197710284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28941775197710284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2942058919618863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2942058919618863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2942058919618863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2846752278386637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2846752278386637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2846752278386637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28971622284382303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28971622284382303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28971622284382303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29452144402075836`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29452144402075836`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29452144402075836`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2849565880388436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2849565880388436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2849565880388436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2899893621756139`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2899893621756139`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2899893621756139`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29481130557923824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29481130557923824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29481130557923824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2852129712429028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2852129712429028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2852129712429028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29023821368252495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29023821368252495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29023821368252495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29507654825797286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29507654825797286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29507654825797286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2854453937256924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2854453937256924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2854453937256924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.290464135311916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.290464135311916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.290464135311916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2953185541413132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2953185541413132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2953185541413132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28565518911932436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28565518911932436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28565518911932436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29066823409514275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29066823409514275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29066823409514275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2955384506438333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2955384506438333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2955384506438333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2858434443744455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2858434443744455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2858434443744455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29085153561462485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29085153561462485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29085153561462485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29573728424815887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29573728424815887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29573728424815887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28601116432324486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28601116432324486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28601116432324486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29101499228932276`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29101499228932276`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29101499228932276`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29591602708708176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29591602708708176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29591602708708176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28615928180337546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28615928180337546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28615928180337546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2911595252598582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2911595252598582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2911595252598582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2960756191831862`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2960756191831862`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2960756191831862`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2862886991230595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2862886991230595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2862886991230595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2912851907054357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2912851907054357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2912851907054357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2962161466531942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2962161466531942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2962161466531942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2863994432908853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2863994432908853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2863994432908853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2913937531476216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2913937531476216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2913937531476216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29633937526430904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29633937526430904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29633937526430904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28649327674491626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28649327674491626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28649327674491626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2914855286945018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2914855286945018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2914855286945018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2964456432194275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2964456432194275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2964456432194275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2865704939408118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2865704939408118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2865704939408118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29156115826744455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29156115826744455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29156115826744455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2965356071478335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2965356071478335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2965356071478335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.286631720155529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.286631720155529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.286631720155529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2916212347781812`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2916212347781812`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2916212347781812`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29660987500934255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29660987500934255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29660987500934255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2866775333037354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2866775333037354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2866775333037354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2916663061053685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2916663061053685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2916663061053685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2966690091324676`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2966690091324676`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2966690091324676`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28670846685333473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28670846685333473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28670846685333473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29169687775975434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29169687775975434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29169687775975434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2967135289377918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2967135289377918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2967135289377918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28672501243291826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28672501243291826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28672501243291826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2917134152631061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2917134152631061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2917134152631061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29674391337221173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29674391337221173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29674391337221173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2867276221558144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.03`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2867276221558144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.03`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2867276221558144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.08026308853819672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.08026308853819672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08026308853819672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.08058828269318231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.08058828269318231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08058828269318231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.07994153717257903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.07994153717257903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.07994153717257903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.08954621410570655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.08954621410570655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08954621410570655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.09002174824247379`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.09002174824247379`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09002174824247379`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.08907602264523122`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.08907602264523122`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.08907602264523122`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.09831883397917189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}]
        , ",", "0.09831883397917189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09831883397917189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.09893724142186829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.09893724142186829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.09893724142186829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.0977073928682581`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.0977073928682581`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.0977073928682581`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.10661761070998928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.10661761070998928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10661761070998928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.10737190300521825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.10737190300521825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10737190300521825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.1058718356682359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.1058718356682359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1058718356682359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.11447595203993904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.11447595203993904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11447595203993904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.11535958273917095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.11535958273917095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11535958273917095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.11360232018524304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.11360232018524304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11360232018524304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.12192435308760445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.12192435308760445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12192435308760445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.12293118456759021`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.12293118456759021`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12293118456759021`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.12092893600574103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.12092893600574103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12092893600574103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.12899069723872714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.12899069723872714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12899069723872714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1301149703001594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1301149703001594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1301149703001594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.12787919126431807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.12787919126431807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12787919126431807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.13570052132941288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.13570052132941288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13570052132941288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.13693682733270077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.13693682733270077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13693682733270077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1344782752834237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1344782752834237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1344782752834237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.14207724987815648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.14207724987815648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14207724987815648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.14342050519384414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.14342050519384414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14342050519384414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.14074929048747617`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.14074929048747617`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14074929048747617`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1481424024244017`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1481424024244017`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1481424024244017`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.14958782499394435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.14958782499394435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14958782499394435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.14671345763014415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.14671345763014415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14671345763014415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1594137650754137`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1594137650754137`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1594137650754137`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.16105027708946543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.16105027708946543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16105027708946543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1577959432946985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1577959432946985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1577959432946985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.16965627924885895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.16965627924885895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16965627924885895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.1714678778020215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.1714678778020215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1714678778020215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.16786539736112158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.16786539736112158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16786539736112158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.17899032186978023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.17899032186978023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17899032186978023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.18096274217791766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.18096274217791766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18096274217791766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1770404763664406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1770404763664406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1770404763664406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.18751871861432706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.18751871861432706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18751871861432706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.189639212991995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.189639212991995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.189639212991995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.18542250489888568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.18542250489888568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18542250489888568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.19533012995175297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.19533012995175297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19533012995175297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.19758727463725195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.19758727463725195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19758727463725195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1930988338756071`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1930988338756071`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1930988338756071`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2025018547615157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2025018547615157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2025018547615157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.20488538525528818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.20488538525528818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20488538525528818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.20014561561755825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.20014561561755825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20014561561755825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.20910053402529027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.20910053402529027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20910053402529027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.211601194412332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.211601194412332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.211601194412332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.20662849421639848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.20662849421639848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20662849421639848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2151838801087246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2151838801087246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2151838801087246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.21779331544934688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.21779331544934688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21779331544934688`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2126042914582391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2126042914582391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2126042914582391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2208029028616797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2208029028616797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2208029028616797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.22351354853064073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.22351354853064073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22351354853064073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.21812323617674959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.21812323617674959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21812323617674959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.22600243635222597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.22600243635222597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22600243635222597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.22880742760144873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.22880742760144873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22880742760144873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.22322947091132522`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.22322947091132522`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22322947091132522`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.23310009296489917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.23310009296489917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23310009296489917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.23603507047532807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.23603507047532807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23603507047532807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.23019856748519396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.23019856748519396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23019856748519396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2394562018729447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2394562018729447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2394562018729447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.24250892238697488`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.24250892238697488`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24250892238697488`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.23643820632574344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.23643820632574344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23643820632574344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.24516684801492572`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.24516684801492572`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24516684801492572`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.24832660243524854`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.24832660243524854`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24832660243524854`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.24204295721982924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.24204295721982924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24204295721982924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.25031352312989846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.25031352312989846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25031352312989846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2535709063127534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2535709063127534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2535709063127534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24709302424640647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24709302424640647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24709302424640647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2549647888987512`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2549647888987512`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2549647888987512`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.25831150854041063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.25831150854041063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25831150854041063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.25165587030656483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.25165587030656483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25165587030656483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2591794207426586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2591794207426586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2591794207426586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2626081367663206`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2626081367663206`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2626081367663206`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.25578933069771015`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.25578933069771015`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25578933069771015`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2630071254712237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2630071254712237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2630071254712237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2665113170257236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2665113170257236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2665113170257236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.25954230359223457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.25954230359223457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25954230359223457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2664915709396776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2664915709396776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2664915709396776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2700654295273877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2700654295273877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2700654295273877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2629577534973244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2629577534973244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2629577534973244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.26967005740308714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.26967005740308714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26967005740308714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2733083883045088`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2733083883045088`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2733083883045088`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2660723748761691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2660723748761691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2660723748761691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2725742175407875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2725742175407875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2725742175407875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27627236608815964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27627236608815964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27627236608815964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2689172673804289`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2689172673804289`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2689172673804289`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2752331647269113`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2752331647269113`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2752331647269113`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27898694631210713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27898694631210713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27898694631210713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2715210801949143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2715210801949143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2715210801949143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27767115878253223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27767115878253223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27767115878253223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2814767978218841`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2814767978218841`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2814767978218841`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2739076696196712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2739076696196712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2739076696196712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2799103040560466`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2799103040560466`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2799103040560466`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2837643903334031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2837643903334031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2837643903334031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2760987791545093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2760987791545093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2760987791545093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2819697904730012`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2819697904730012`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2819697904730012`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2858692319095805`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2858692319095805`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2858692319095805`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2781132847350363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2781132847350363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2781132847350363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28386579741101203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28386579741101203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28386579741101203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28780778603946255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28780778603946255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28780778603946255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.279967085514178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.279967085514178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.279967085514178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28561398760203566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28561398760203566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28561398760203566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2895959700853568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2895959700853568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2895959700853568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2816755925374859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2816755925374859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2816755925374859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28722759042965995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28722759042965995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28722759042965995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2912472356993653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2912472356993653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2912472356993653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2832518158679037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2832518158679037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2832518158679037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28871812951266956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28871812951266956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28871812951266956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29277330607977664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29277330607977664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29277330607977664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2847070822711142`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2847070822711142`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2847070822711142`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2900963282279362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2900963282279362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2900963282279362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.294185089116085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.294185089116085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.294185089116085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28605193270584517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28605193270584517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28605193270584517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29137210363167143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29137210363167143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29137210363167143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2954926516774772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2954926516774772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2954926516774772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2872961361111331`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2872961361111331`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2872961361111331`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2925533066614089`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2925533066614089`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2925533066614089`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29670400672982844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29670400672982844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29670400672982844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28844738514458423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28844738514458423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28844738514458423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2936474310461406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2936474310461406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2936474310461406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2978267700900735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2978267700900735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2978267700900735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28951304957594254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28951304957594254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28951304957594254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2946619443778519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2946619443778519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2946619443778519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29886853010136916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29886853010136916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29886853010136916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2905004803035237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2905004803035237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2905004803035237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2956030004639324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2956030004639324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2956030004639324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29983554582058386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29983554582058386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29983554582058386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2914157268071766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2914157268071766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2914157268071766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2964757592878506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2964757592878506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2964757592878506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30073307676141403`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30073307676141403`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30073307676141403`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2922638507454647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2922638507454647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2922638507454647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29728588951071677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29728588951071677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29728588951071677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3015668772608383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3015668772608383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3015668772608383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29305043397788866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29305043397788866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29305043397788866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29803790999912905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29803790999912905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29803790999912905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3023415490903964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3023415490903964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3023415490903964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29377991917504315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29377991917504315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29377991917504315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29873609048275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29873609048275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29873609048275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3030614331005909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3030614331005909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3030614331005909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29445650204296947`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29445650204296947`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29445650204296947`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29938433273445236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29938433273445236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29938433273445236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3037304932143884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3037304932143884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3037304932143884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2950840191649346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2950840191649346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2950840191649346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2999850326155428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2999850326155428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2999850326155428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3043512020011795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3043512020011795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3043512020011795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29566479537731527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29566479537731527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29566479537731527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30054280650356874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30054280650356874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30054280650356874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3049282218257306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3049282218257306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3049282218257306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2962034030117028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2962034030117028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2962034030117028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3010601580616832`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3010601580616832`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3010601580616832`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3054641082091668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3054641082091668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3054641082091668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29670229066589354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29670229066589354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29670229066589354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3015398059914812`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3015398059914812`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3015398059914812`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3059616276204419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3059616276204419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3059616276204419`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29716413326373364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29716413326373364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29716413326373364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30198423702599975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30198423702599975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30198423702599975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30642331043013327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30642331043013327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30642331043013327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2975913685814498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2975913685814498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2975913685814498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30239475935092464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30239475935092464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30239475935092464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3068505153751615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3068505153751615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3068505153751615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29798525863950115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29798525863950115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29798525863950115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3027746450746855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3027746450746855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3027746450746855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30724654263629114`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30724654263629114`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30724654263629114`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2983490465296725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2983490465296725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2983490465296725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3031255029521011`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3031255029521011`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3031255029521011`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3076130410660859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3076130410660859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3076130410660859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29868431102579707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29868431102579707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29868431102579707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3034491350506102`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3034491350506102`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3034491350506102`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30795183750852884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30795183750852884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30795183750852884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2989928157039294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2989928157039294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2989928157039294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30374669620040917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30374669620040917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30374669620040917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3082641242576092`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3082641242576092`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3082641242576092`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2992756841930351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2992756841930351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2992756841930351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3040201645738227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3040201645738227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3040201645738227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3085519055319539`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3085519055319539`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3085519055319539`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29953486834040677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29953486834040677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29953486834040677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3042708457973903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3042708457973903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3042708457973903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30881651177169644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30881651177169644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30881651177169644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29977164939398315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29977164939398315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29977164939398315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3045000398116167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3045000398116167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3045000398116167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30905926696429575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30905926696429575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30905926696429575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2999873041438714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2999873041438714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2999873041438714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3047087267045226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3047087267045226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3047087267045226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30928117555396845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30928117555396845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30928117555396845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3001827867445865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3001827867445865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3001827867445865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30489814562842166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30489814562842166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30489814562842166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30948349932894886`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30948349932894886`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30948349932894886`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3003593156325935`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3003593156325935`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3003593156325935`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.305069328265912`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.305069328265912`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.305069328265912`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3096672881699785`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3096672881699785`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3096672881699785`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30051790390153915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30051790390153915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30051790390153915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30522322557385645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30522322557385645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30522322557385645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3098335117291546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3098335117291546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3098335117291546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30065948397721093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30065948397721093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30065948397721093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3053607216970633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3053607216970633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3053607216970633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30998307168910266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30998307168910266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30998307168910266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3007849226145519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3007849226145519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3007849226145519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3054826652239282`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3054826652239282`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3054826652239282`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31011683346498053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31011683346498053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31011683346498053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30089505166242697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30089505166242697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30089505166242697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.305589171658156`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.305589171658156`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.305589171658156`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3102349359813147`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3102349359813147`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3102349359813147`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3009899638832762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3009899638832762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3009899638832762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30568180496629593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30568180496629593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30568180496629593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3103389480076067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3103389480076067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3103389480076067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3010712177652944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3010712177652944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3010712177652944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3057608946536457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3057608946536457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3057608946536457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3104292167309118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3104292167309118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3104292167309118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3011391255360438`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3011391255360438`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3011391255360438`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30582704384323944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30582704384323944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30582704384323944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3105063587024837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3105063587024837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3105063587024837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3011942769748005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3011942769748005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3011942769748005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3058808129945153`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3058808129945153`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3058808129945153`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3105709471314728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3105709471314728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3105709471314728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3012372198647624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3012372198647624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3012372198647624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3059227227995501`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3059227227995501`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3059227227995501`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31062351483635703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31062351483635703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31062351483635703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3012684628350505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3012684628350505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3012684628350505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3059532567958778`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3059532567958778`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3059532567958778`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31066455690925715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31066455690925715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31066455690925715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3012884779229364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3012884779229364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3012884779229364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.305972863720914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.305972863720914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.305972863720914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31069453311859624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31069453311859624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31069453311859624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30129770288086033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.06`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30129770288086033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.06`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30129770288086033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.10960297678344463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.10960297678344463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10960297678344463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.10992184392076235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.10992184392076235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10992184392076235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.10928772808004546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.10928772808004546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.10928772808004546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.11856305971170926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.11856305971170926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11856305971170926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.11902907601476355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.11902907601476355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11902907601476355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.11810234841292781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.11810234841292781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.11810234841292781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.12701769409894628`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.12701769409894628`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12701769409894628`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.12762338857387695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.12762338857387695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.12762338857387695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1264189144423771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1264189144423771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1264189144423771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.13500374518009164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.13500374518009164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13500374518009164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.13574213358946094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.13574213358946094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13574213358946094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.13427380829379074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.13427380829379074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13427380829379074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1425547692812327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1425547692812327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1425547692812327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.14341931665906138`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.14341931665906138`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14341931665906138`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1417001405556245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1417001405556245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1417001405556245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.14970136469446818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.14970136469446818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14970136469446818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.15068595106655813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.15068595106655813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15068595106655813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.14872809793542002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.14872809793542002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14872809793542002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.156471479905895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.156471479905895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.156471479905895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.157570368933472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.157570368933472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.157570368933472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.15538524855591693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.15538524855591693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15538524855591693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.16289068498387999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.16289068498387999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16289068498387999`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1640984952702181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1640984952702181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1640984952702181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.161696810675619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.161696810675619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.161696810675619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.1689824110646018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.1689824110646018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1689824110646018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.1702940898855685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.1702940898855685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1702940898855685`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.16768588974861143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.16768588974861143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16768588974861143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.17476816214307453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.17476816214307453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17476816214307453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.17617896138295885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.17617896138295885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17617896138295885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.17337368801070263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.17337368801070263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17337368801070263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.18549737020209248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.18549737020209248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18549737020209248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.18709327523891975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.18709327523891975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18709327523891975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.18391997499291096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.18391997499291096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18391997499291096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.1952195194086689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.1952195194086689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1952195194086689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.19698468648125464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.19698468648125464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19698468648125464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.19347486218664373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.19347486218664373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19347486218664373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.20405438615690713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.20405438615690713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20405438615690713`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.20597471886675184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.20597471886675184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20597471886675184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.20215639660037918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.20215639660037918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20215639660037918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.21210408347292034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.21210408347292034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21210408347292034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2141670071767111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2141670071767111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2141670071767111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.21006518568302643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.21006518568302643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21006518568302643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.21945649462780503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.21945649462780503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21945649462780503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.22165076008328174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.22165076008328174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22165076008328174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.21728780178206286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.21728780178206286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21728780178206286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2261881163147168`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2261881163147168`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2261881163147168`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.22850363313506852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.22850363313506852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22850363313506852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2238995955036291`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2238995955036291`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2238995955036291`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.23236477868569708`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.23236477868569708`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23236477868569708`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.23479246230570394`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.23479246230570394`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23479246230570394`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2299654028829034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2299654028829034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2299654028829034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2380433704782906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2380433704782906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2380433704782906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.24057503326206744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.24057503326206744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24057503326206744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2355412261233927`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2355412261233927`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2355412261233927`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.24327410138041522`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.24327410138041522`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24327410138041522`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.24590234132336447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.24590234132336447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24590234132336447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24067649855434362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24067649855434362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24067649855434362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.24810102791362265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.24810102791362265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24810102791362265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.25081913761779373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.25081913761779373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25081913761779373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24541459039860422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24541459039860422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24541459039860422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.25466755736442`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.25466755736442`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25466755736442`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.25750922214076066`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.25750922214076066`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25750922214076066`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.25185897673497937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.25185897673497937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25185897673497937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.26052374423655295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.26052374423655295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26052374423655295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26347704211399386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26347704211399386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26347704211399386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2576047930339748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2576047930339748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2576047930339748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2657634460334539`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2657634460334539`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2657634460334539`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.26881796919058465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.26881796919058465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26881796919058465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26274440143485495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26274440143485495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26274440143485495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2704660747767997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2704660747767997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2704660747767997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27361269973634816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27361269973634816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27361269973634816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2673559456750326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2673559456750326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2673559456750326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2746982823369521`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2746982823369521`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2746982823369521`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27792897937706124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27792897937706124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27792897937706124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27150499770171393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27150499770171393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27150499770171393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27851708092722377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27851708092722377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27851708092722377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28182475454216005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28182475454216005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28182475454216005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.275247647387186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.275247647387186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.275247647387186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28197057434454553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28197057434454553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28197057434454553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28534893090687835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28534893090687835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28534893090687835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27863120702420247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27863120702420247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27863120702420247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28510093107538104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28510093107538104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28510093107538104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28854437349126516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28854437349126516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28854437349126516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2816971573669125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2816971573669125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2816971573669125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28794409228497103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28794409228497103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28794409228497103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.291447622208462`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.291447622208462`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.291447622208462`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.284480848623411`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.284480848623411`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.284480848623411`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29053045177112363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29053045177112363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29053045177112363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29408959652235656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29408959652235656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29408959652235656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28701215577887884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28701215577887884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28701215577887884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29288795467936884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29288795467936884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29288795467936884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2964986995545735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2964986995545735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2964986995545735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2893185720799492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2893185720799492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2893185720799492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2950398256244316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2950398256244316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2950398256244316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2986985514307359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2986985514307359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2986985514307359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2914229308528722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2914229308528722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2914229308528722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29700718256004655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29700718256004655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29700718256004655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3007106254774957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3007106254774957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3007106254774957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29334599960332647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29334599960332647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29334599960332647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2988083222166718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2988083222166718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2988083222166718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3025535270064574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3025535270064574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3025535270064574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29510577197896104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29510577197896104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29510577197896104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3004586327741707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3004586327741707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3004586327741707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30424291665239717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30424291665239717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30424291665239717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2967173658479354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2967173658479354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2967173658479354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30197298887272833`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30197298887272833`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30197298887272833`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3057939162408353`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3057939162408353`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3057939162408353`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2981954107876127`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2981954107876127`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2981954107876127`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30336392769156395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30336392769156395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30336392769156395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3072192762247601`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3072192762247601`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3072192762247601`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2995522336968212`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2995522336968212`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2995522336968212`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30464234326612777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30464234326612777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30464234326612777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3085300844215944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3085300844215944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3085300844215944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3007985415750548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3007985415750548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3007985415750548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3058183522235976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3058183522235976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3058183522235976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3097366326654922`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3097366326654922`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3097366326654922`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30194427308978655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30194427308978655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30194427308978655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30690133869714364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30690133869714364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30690133869714364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3108484499626874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3108484499626874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3108484499626874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3029986712101495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3029986712101495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3029986712101495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3078986210706209`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3078986210706209`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3078986210706209`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31187300810955165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31187300810955165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31187300810955165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30396890135997845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30396890135997845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30396890135997845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3088172468480245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3088172468480245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3088172468480245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3128174742721618`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3128174742721618`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3128174742721618`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3048618950886023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3048618950886023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3048618950886023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30966421008055944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30966421008055944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30966421008055944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3136889560187526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3136889560187526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3136889560187526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3056845332391517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3056845332391517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3056845332391517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3104452629073078`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3104452629073078`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3104452629073078`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3144933061758913`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3144933061758913`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3144933061758913`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3064424686261007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3064424686261007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3064424686261007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3111652154156907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3111652154156907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3111652154156907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3152354290941364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3152354290941364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3152354290941364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30714041841187506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30714041841187506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30714041841187506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3118293460714935`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3118293460714935`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3118293460714935`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3159206865367675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3159206865367675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3159206865367675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30778357851532123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30778357851532123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30778357851532123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31244185695774057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31244185695774057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31244185695774057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.316553356308663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.316553356308663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.316553356308663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3083760763102593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3083760763102593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3083760763102593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3130067071446107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3130067071446107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3130067071446107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31713746658782493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31713746658782493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31713746658782493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30892180258398844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30892180258398844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30892180258398844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3135275104124136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3135275104124136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3135275104124136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3176766939947801`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3176766939947801`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3176766939947801`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30942430901962215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30942430901962215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30942430901962215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31400646946119337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31400646946119337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31400646946119337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.318173306862637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.318173306862637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.318173306862637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30988573392011337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30988573392011337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30988573392011337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3144478563160599`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3144478563160599`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3144478563160599`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3186316235496593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3186316235496593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3186316235496593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31031030282197053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31031030282197053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31031030282197053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3148539721664951`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3148539721664951`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3148539721664951`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3190539951223748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3190539951223748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3190539951223748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31070026789346494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31070026789346494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31070026789346494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.315227317605043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.315227317605043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.315227317605043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3194429666484308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3194429666484308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3194429666484308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3110580857617003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3110580857617003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3110580857617003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.315570173511427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.315570173511427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.315570173511427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31980086020486204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31980086020486204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31980086020486204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.311385996572924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.311385996572924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.311385996572924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31588373096158306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31588373096158306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31588373096158306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32012891211848465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32012891211848465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32012891211848465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3116851471573309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3116851471573309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3116851471573309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31617098615572337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31617098615572337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31617098615572337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32043014802921244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32043014802921244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32043014802921244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3119585038212131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3119585038212131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3119585038212131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31643341613130077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31643341613130077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31643341613130077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3207060771311291`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3207060771311291`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3207060771311291`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31220751211694103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31220751211694103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31220751211694103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31667265842937603`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31667265842937603`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31667265842937603`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3209583666644237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3209583666644237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3209583666644237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3124337802083767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3124337802083767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3124337802083767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31688977059992673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31688977059992673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31688977059992673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32118810510878465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32118810510878465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32118810510878465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3126383353685665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3126383353685665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3126383353685665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3170865406078907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3170865406078907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3170865406078907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3213971060675782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3213971060675782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3213971060675782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31282293973344333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31282293973344333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31282293973344333`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31726416067129687`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31726416067129687`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31726416067129687`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3215865843984097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3215865843984097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3215865843984097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31298876329980085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31298876329980085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31298876329980085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31742381011064824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31742381011064824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31742381011064824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32175774168213644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32175774168213644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32175774168213644`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31313696335954605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31313696335954605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31313696335954605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3175663822906444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3175663822906444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3175663822906444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.321911493054597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.321911493054597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.321911493054597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31326841192449284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31326841192449284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31326841192449284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31769298915853045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31769298915853045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31769298915853045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32204897180830877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32204897180830877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32204897180830877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31338419955279573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31338419955279573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31338419955279573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31780456821223485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31780456821223485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31780456821223485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32217113205541936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32217113205541936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32217113205541936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3134852473924043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3134852473924043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3134852473924043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31790197891312244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31790197891312244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31790197891312244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3222788456528941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3222788456528941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3222788456528941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3135723979912557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3135723979912557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3135723979912557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3179860199183351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3179860199183351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3179860199183351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3223729355862436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3223729355862436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3223729355862436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31364643418579613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31364643418579613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31364643418579613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3180574530100797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3180574530100797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3180574530100797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32245417515170544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32245417515170544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32245417515170544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31370810252658016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31370810252658016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31370810252658016`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3181164059632247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3181164059632247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3181164059632247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3225227112713745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3225227112713745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3225227112713745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3137575122243586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3137575122243586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3137575122243586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31816426087957994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31816426087957994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31816426087957994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32257993300875865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32257993300875865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32257993300875865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3137960378714053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3137960378714053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3137960378714053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3182013270322266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3182013270322266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3182013270322266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32262616443779235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32262616443779235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32262616443779235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31382397429440195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31382397429440195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31382397429440195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3182281496076193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3182281496076193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3182281496076193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3226619626727235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3226619626727235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3226619626727235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3138418548408373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3138418548408373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3138418548408373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31824523577104047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31824523577104047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31824523577104047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3226878461439076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3226878461439076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3226878461439076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3138501754908981`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3138501754908981`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3138501754908981`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31825305741120286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31825305741120286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31825305741120286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32270429739336576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32270429739336576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32270429739336576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31384939755181035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31384939755181035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31384939755181035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31825205362379555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31825205362379555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31825205362379555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3227117656055344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3227117656055344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3227117656055344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31383995009482824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31383995009482824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31383995009482824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3182426329581923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3182426329581923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3182426329581923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32271066889782696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32271066889782696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32271066889782696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3138222321586766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.09`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3138222321586766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.09`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3138222321586766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.13889146125541374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.13889146125541374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13889146125541374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.13920402822950706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.13920402822950706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13920402822950706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.13858248843537585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.13858248843537585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.13858248843537585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1475041219824198`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1475041219824198`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1475041219824198`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.14796067322470793`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.14796067322470793`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14796067322470793`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.14705283823521684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.14705283823521684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.14705283823521684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.15561722152903898`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.15561722152903898`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.15561722152903898`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1562102897017411`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1562102897017411`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1562102897017411`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1550310169424877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1550310169424877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1550310169424877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.16326779064700245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.16326779064700245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16326779064700245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.16399040341785667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.16399040341785667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16399040341785667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.16255356409755847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.16255356409755847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16255356409755847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.17048949832297133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.17048949832297133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17048949832297133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.17133513960463004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.17133513960463004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17133513960463004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.16965369610435915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.16965369610435915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16965369610435915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1773130114270879`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1773130114270879`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1773130114270879`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1782755859938582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1782755859938582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1782755859938582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1763616624901265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1763616624901265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1763616624901265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.18376631032740595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.18376631032740595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18376631032740595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.18484011150411855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.18484011150411855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18484011150411855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.18270505844103765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.18270505844103765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18270505844103765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.18987496650409488`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.18987496650409488`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18987496650409488`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1910546466467261`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1910546466467261`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1910546466467261`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1887090996216355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1887090996216355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1887090996216355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.19566238728810398`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.19566238728810398`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19566238728810398`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.19694293079980985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.19694293079980985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19694293079980985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.19439686437779835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.19439686437779835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19439686437779835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.20115003208826635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.20115003208826635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20115003208826635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2025267307373009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2025267307373009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2025267307373009`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1997895076637242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1997895076637242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1997895076637242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.21130135752693352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.21130135752693352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21130135752693352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.21285735822514096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.21285735822514096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21285735822514096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.20976368860238112`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.20976368860238112`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20976368860238112`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.22046949046033615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.22046949046033615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22046949046033615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.22218912925967388`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.22218912925967388`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22218912925967388`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.21877015763542904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.21877015763542904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21877015763542904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.22877342089023747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.22877342089023747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22877342089023747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.23064278853125764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.23064278853125764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23064278853125764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2269261682769958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2269261682769958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2269261682769958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.23631438117272224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.23631438117272224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23631438117272224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2383210930698066`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2383210930698066`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2383210930698066`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2343314445358953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2343314445358953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2343314445358953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.24317932578409646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.24317932578409646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24317932578409646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2453123226498164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2453123226498164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2453123226498164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2410716301565994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2410716301565994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2410716301565994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.24944381209222977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.24944381209222977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24944381209222977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2516931916205624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2516931916205624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2516931916205624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24722113834316267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24722113834316267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24722113834316267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2551727354687589`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2551727354687589`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2551727354687589`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.25752959713765194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.25752959713765194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25752959713765194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.25284387438568345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.25284387438568345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25284387438568345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2604220498776532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2604220498776532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2604220498776532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26287838491345616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26287838491345616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26287838491345616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.25799491088260346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.25799491088260346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25799491088260346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.26524106400941855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.26524106400941855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26524106400941855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2677896435498481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2677896435498481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2677896435498481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2627227858497861`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2627227858497861`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2627227858497861`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2696729656072525`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2696729656072525`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2696729656072525`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2723072491977574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2723072491977574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2723072491977574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26707000688136234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26707000688136234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26707000688136234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27567645035912264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27567645035912264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27567645035912264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.27842833920865706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.27842833920865706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27842833920865706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2729572841187153`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2729572841187153`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2729572841187153`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2810026324267959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2810026324267959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2810026324267959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2838605431595579`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2838605431595579`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2838605431595579`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2781786962225781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2781786962225781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2781786962225781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.28574292729891826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.28574292729891826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28574292729891826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.28869676863872085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.28869676863872085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28869676863872085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2828241851278332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2828241851278332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2828241851278332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2899744807881983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2899744807881983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2899744807881983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2930154244333457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2930154244333457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2930154244333457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28696964948621373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28696964948621373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28696964948621373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2937618725851524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2937618725851524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2937618725851524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2968821635189335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2968821635189335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2968821635189335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2906786093677831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2906786093677831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2906786093677831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2971602093784857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2971602093784857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2971602093784857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30035300727144104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30035300727144104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30035300727144104`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29400526808289906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29400526808289906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29400526808289906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.300215866918563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.300215866918563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.300215866918563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30347511555824475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30347511555824475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30347511555824475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2969952282598508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2969952282598508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2969952282598508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3029694047128061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3029694047128061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3029694047128061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30628972678182825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30628972678182825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30628972678182825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29968837764434053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29968837764434053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29968837764434053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3054553070708258`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3054553070708258`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3054553070708258`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30883190917023484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30883190917023484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30883190917023484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3021186258566166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3021186258566166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3021186258566166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30770264401902647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30770264401902647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30770264401902647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3111312429877612`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3111312429877612`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3111312429877612`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30431453905962463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30431453905962463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30431453905962463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30973811539198837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30973811539198837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30973811539198837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3132148726936624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3132148726936624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3132148726936624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30630237609329536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30630237609329536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30630237609329536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31158384176675546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31158384176675546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31158384176675546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3151053027834021`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3151053027834021`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3151053027834021`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3081038809974559`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3081038809974559`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3081038809974559`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.313259893460504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.313259893460504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.313259893460504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3168229468582842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3168229468582842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3168229468582842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3097387843060769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3097387843060769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3097387843060769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3147836205735803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3147836205735803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3147836205735803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3183854524353435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3183854524353435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3183854524353435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31122414257647846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31122414257647846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31122414257647846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31616956839958055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31616956839958055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31616956839958055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31980762826272185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31980762826272185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31980762826272185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3125742412890143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3125742412890143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3125742412890143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31743178003282996`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31743178003282996`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31743178003282996`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3211037553843667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3211037553843667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3211037553843667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.313802888330524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.313802888330524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.313802888330524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31858205855799526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31858205855799526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31858205855799526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3222858425509148`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3222858425509148`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3222858425509148`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3149216838502884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3149216838502884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3149216838502884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31963063559589844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31963063559589844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31963063559589844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32336430489002327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32336430489002327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32336430489002327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3159406784875527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3159406784875527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3159406784875527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3205869836567386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3205869836567386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3205869836567386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3243487854688399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3243487854688399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3243487854688399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3168691761575803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3168691761575803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3168691761575803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.321459929594813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.321459929594813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.321459929594813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3252482493446106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3252482493446106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3252482493446106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3177158670447966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3177158670447966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3177158670447966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3222562218169906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3222562218169906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3222562218169906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32606959094542826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32606959094542826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32606959094542826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.318487355897028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.318487355897028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.318487355897028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32298243907614493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32298243907614493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32298243907614493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3268195030265891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3268195030265891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3268195030265891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31919010888448257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31919010888448257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31919010888448257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32364508034151884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32364508034151884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32364508034151884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.327504593511521`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.327504593511521`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.327504593511521`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31983051707378995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31983051707378995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31983051707378995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3242494736059191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3242494736059191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3242494736059191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32813028610251216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32813028610251216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32813028610251216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3204138140555237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3204138140555237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3204138140555237`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32480005645724186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32480005645724186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32480005645724186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3287011074800358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3287011074800358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3287011074800358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.320944349612224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.320944349612224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.320944349612224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.325301702138903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.325301702138903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.325301702138903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32922201067303536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32922201067303536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32922201067303536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3214269179357335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3214269179357335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3214269179357335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32575827468302765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32575827468302765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32575827468302765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3296969313819953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3296969313819953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3296969313819953`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3218653123663684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3218653123663684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3218653123663684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32617340814100054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32617340814100054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32617340814100054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33012956919061576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33012956919061576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33012956919061576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3222631022267302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3222631022267302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3222631022267302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32655041252538425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32655041252538425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32655041252538425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3305232936512878`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3305232936512878`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3305232936512878`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32262353871803573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32262353871803573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32262353871803573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3268912772819821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3268912772819821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3268912772819821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3308801510094881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3308801510094881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3308801510094881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3229485521303739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3229485521303739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3229485521303739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32719992217087535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32719992217087535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32719992217087535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3312041127112914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3312041127112914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3312041127112914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32324201619988885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32324201619988885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32324201619988885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3274784318337548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3274784318337548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3274784318337548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3314973070970342`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3314973070970342`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3314973070970342`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3235059700874973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3235059700874973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3235059700874973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32772907551024505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32772907551024505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32772907551024505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3317620452463248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3317620452463248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3317620452463248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3237426416200806`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3237426416200806`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3237426416200806`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32795391269839813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32795391269839813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32795391269839813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3320004291289056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3320004291289056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3320004291289056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32395405574999514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32395405574999514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32395405574999514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32815400526613125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32815400526613125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32815400526613125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3322135549529061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3322135549529061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3322135549529061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3241412281673286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3241412281673286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3241412281673286`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32833206998351205`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32833206998351205`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32833206998351205`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33240417208295964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33240417208295964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33240417208295964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32430684830823986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32430684830823986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32430684830823986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.328489432618594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.328489432618594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.328489432618594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33257363569482873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33257363569482873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33257363569482873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32445221317342354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32445221317342354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32445221317342354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.328627562610125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.328627562610125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.328627562610125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33272344299141987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33272344299141987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33272344299141987`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32457876475728914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32457876475728914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32457876475728914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32874740036093786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32874740036093786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32874740036093786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33285456224487403`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33285456224487403`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33285456224487403`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3246874125562276`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3246874125562276`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3246874125562276`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32885054225894844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32885054225894844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32885054225894844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33296861471473316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33296861471473316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33296861471473316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3247797343602381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3247797343602381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3247797343602381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32893805396773956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32893805396773956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32893805396773956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33306668683227797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33306668683227797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33306668683227797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3248567725412975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3248567725412975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3248567725412975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32901098428454595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32901098428454595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32901098428454595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33314984804217773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33314984804217773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33314984804217773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3249195554643176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3249195554643176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3249195554643176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3290701252898896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3290701252898896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3290701252898896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33321891007913595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33321891007913595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33321891007913595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3249688559324717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3249688559324717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3249688559324717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32911645681131035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32911645681131035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32911645681131035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33327487283370255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33327487283370255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33327487283370255`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3250056336929288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3250056336929288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3250056336929288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3291508109107871`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3291508109107871`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3291508109107871`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.333318583621082`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.333318583621082`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.333318583621082`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3250307057849578`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3250307057849578`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3250307057849578`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32917394562671476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32917394562671476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32917394562671476`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3333508161711648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3333508161711648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3333508161711648`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3250448147103077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3250448147103077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3250448147103077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3291865641519796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3291865641519796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3291865641519796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33337228831902344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33337228831902344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33337228831902344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32504864916078197`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32504864916078197`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32504864916078197`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3291893334710515`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3291893334710515`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3291893334710515`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33338368111167166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33338368111167166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33338368111167166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3250428621657508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3250428621657508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3250428621657508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32918236499015124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32918236499015124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32918236499015124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33338512208309123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33338512208309123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33338512208309123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32502754953804686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32502754953804686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32502754953804686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3291668723829777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3291668723829777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3291668723829777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3333778330394013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3333778330394013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3333778330394013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32500391634624853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32500391634624853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32500391634624853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32914312495870707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32914312495870707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32914312495870707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33336209601869005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33336209601869005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33336209601869005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32497221950072364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32497221950072364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32497221950072364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3291115989975345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3291115989975345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3291115989975345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3333383980663593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3333383980663593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3333383980663593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3249329246099672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3249329246099672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3249329246099672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32907273713575735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32907273713575735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32907273713575735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33330719195034014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33330719195034014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33330719195034014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32488646426360385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32488646426360385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32488646426360385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32902695091859924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32902695091859924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32902695091859924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3332688987613852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3332688987613852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3332688987613852`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3248332405383039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3248332405383039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3248332405383039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3289746231119213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3289746231119213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3289746231119213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3332239102685473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3332239102685473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3332239102685473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32477362726625103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32477362726625103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32477362726625103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3289161097959343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3289161097959343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3289161097959343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33317259105334757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33317259105334757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33317259105334757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32470797208886626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.12`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32470797208886626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.12`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32470797208886626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.16812885430280375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.16812885430280375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16812885430280375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.16843514772097895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.16843514772097895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16843514772097895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.16782613083358458`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.16782613083358458`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.16782613083358458`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.17636995643847417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.17636995643847417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.17636995643847417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1768170948136239`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1768170948136239`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1768170948136239`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1759280482101562`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1759280482101562`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1759280482101562`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.1841182674774575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.1841182674774575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1841182674774575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.18469879491491625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.18469879491491625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.18469879491491625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1835445526716102`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1835445526716102`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1835445526716102`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.19141094281616053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.19141094281616053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19141094281616053`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.19211790635889178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.19211790635889178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19211790635889178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.19071230061612596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.19071230061612596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19071230061612596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.19828172476947356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.19828172476947356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19828172476947356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.1991086343564691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.1991086343564691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1991086343564691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.19746457525076663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.19746457525076663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19746457525076663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.20476131105554654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.20476131105554654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20476131105554654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2057021030342341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2057021030342341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2057021030342341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.20383165151297417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.20383165151297417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20383165151297417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.21087767782401629`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.21087767782401629`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21087767782401629`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2119266816871595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2119266816871595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2119266816871595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.20984111586959828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.20984111586959828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20984111586959828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.21665636349688452`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.21665636349688452`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21665636349688452`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.21780827154272026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.21780827154272026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21780827154272026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.21551814723327162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.21551814723327162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21551814723327162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.22212071874115702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.22212071874115702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22212071874115702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2233705583824782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2233705583824782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2233705583824782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.22088576428739262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.22088576428739262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22088576428739262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2272921270982428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2272921270982428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2272921270982428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2286352355714536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2286352355714536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2286352355714536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.22596504371871595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.22596504371871595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22596504371871595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.23683108006647363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.23683108006647363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23683108006647363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.23834786045784895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.23834786045784895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23834786045784895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2353324557012027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2353324557012027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2353324557012027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.24541288951255993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.24541288951255993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24541288951255993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.24708787676125263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.24708787676125263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24708787676125263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.24375800724244887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.24375800724244887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24375800724244887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.25315556072323747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.25315556072323747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25315556072323747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.25497504978468344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.25497504978468344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25497504978468344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.25135796201895827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.25135796201895827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25135796201895827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.26015926688990904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.26015926688990904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26015926688990904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2621110785090818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2621110785090818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2621110785090818`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2582309838903823`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2582309838903823`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2582309838903823`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.26650987320951913`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.26650987320951913`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26650987320951913`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26858315169691666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26858315169691666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26858315169691666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2644616291279359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2644616291279359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2644616291279359`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.27228185297342467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.27228185297342467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27228185297342467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2744668962451723`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2744668962451723`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2744668962451723`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27012323026998597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27012323026998597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27012323026998597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.277539036452875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.277539036452875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.277539036452875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27982713886906635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27982713886906635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27982713886906635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.27527863283288345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.27527863283288345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27527863283288345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.282336326259647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.282336326259647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.282336326259647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2847196675906562`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2847196675906562`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2847196675906562`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2799818643781683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2799818643781683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2799818643781683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2867220246016683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2867220246016683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2867220246016683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28919355775897976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28919355775897976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28919355775897976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.284280463164906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.284280463164906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.284280463164906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29073835525003183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29073835525003183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29073835525003183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29329171477819527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29329171477819527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29329171477819527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2882159798945334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2882159798945334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2882159798945334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29614976480489696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29614976480489696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29614976480489696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29881522350608775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29881522350608775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29881522350608775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29351667389554675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29351667389554675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29351667389554675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.300918832918485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.300918832918485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.300918832918485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3036851595618175`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3036851595618175`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3036851595618175`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29818611502052794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29818611502052794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29818611502052794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3051343115471891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3051343115471891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3051343115471891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3079917418803707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3079917418803707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3079917418803707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3023116063444334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3023116063444334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3023116063444334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3088708871726475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3088708871726475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3088708871726475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31181089799302647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31181089799302647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31181089799302647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30596661058420965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30596661058420965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30596661058420965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3121909013695692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3121909013695692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3121909013695692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3152060196934019`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3152060196934019`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3152060196934019`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3092124305261246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3092124305261246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3092124305261246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31514740914921324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31514740914921324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31514740914921324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3182310567783776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3182310567783776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3182310567783776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31210123841719395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31210123841719395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31210123841719395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.317784930960415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.317784930960415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.317784930960415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3209312939398135`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3209312939398135`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3209312939398135`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.314676800395917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.314676800395917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.314676800395917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32014230511323655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32014230511323655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32014230511323655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32334623160437026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32334623160437026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32334623160437026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31697730104357247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31697730104357247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31697730104357247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3222524611522318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3222524611522318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3222524611522318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32550936585832074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32550936585832074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32550936585832074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3190351107618728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3190351107618728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3190351107618728`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32414305813694144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32414305813694144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32414305813694144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3274488510448878`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3274488510448878`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3274488510448878`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32087739983389907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32087739983389907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32087739983389907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3258394737070843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3258394737070843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3258394737070843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.32919049563618663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.32919049563618663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32919049563618663`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3225291204379429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3225291204379429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3225291204379429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32736265520675195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32736265520675195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32736265520675195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33075561783530233`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33075561783530233`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33075561783530233`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3240108540844194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3240108540844194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3240108540844194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3287315651184962`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3287315651184962`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3287315651184962`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33216351172271225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33216351172271225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33216351172271225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3253412357740754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3253412357740754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3253412357740754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.329962551335373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.329962551335373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.329962551335373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3334308118047579`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3334308118047579`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3334308118047579`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3265363305325493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3265363305325493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3265363305325493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3310692672004181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3310692672004181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3310692672004181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33457142441301885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33457142441301885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33457142441301885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3276095422396202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3276095422396202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3276095422396202`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33206488120451566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33206488120451566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33206488120451566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33559874712621063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33559874712621063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33559874712621063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32857381295104054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32857381295104054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32857381295104054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3329604229494733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3329604229494733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3329604229494733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33652400672705457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33652400672705457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33652400672705457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32943997772422967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32943997772422967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32943997772422967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.333765422855345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.333765422855345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.333765422855345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3373569090914149`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3373569090914149`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3373569090914149`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3302173939641659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3302173939641659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3302173939641659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3344886801725548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3344886801725548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3344886801725548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3381064168136242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3381064168136242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3381064168136242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3309146994888032`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3309146994888032`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3309146994888032`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33513843812573957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33513843812573957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33513843812573957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33878090541175643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33878090541175643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33878090541175643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33154000670377115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33154000670377115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33154000670377115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33572084008279424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33572084008279424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33572084008279424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3393866542647536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3393866542647536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3393866542647536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3320993226336379`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3320993226336379`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3320993226336379`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3362419743093508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3362419743093508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3362419743093508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33992986404185055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33992986404185055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33992986404185055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33259862844509747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33259862844509747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33259862844509747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3367078218310993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3367078218310993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3367078218310993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34041662080109925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34041662080109925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34041662080109925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3330438046001048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3330438046001048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3330438046001048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.337123269567574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.337123269567574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.337123269567574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3408518980647263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3408518980647263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3408518980647263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3334396444251561`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3334396444251561`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3334396444251561`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3374923598356473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3374923598356473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3374923598356473`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3412398239681591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3412398239681591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3412398239681591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3337901092180472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3337901092180472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3337901092180472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33781954585685264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33781954585685264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33781954585685264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3415849277937274`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3415849277937274`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3415849277937274`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3340995736675748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3340995736675748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3340995736675748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3381083366661914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3381083366661914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3381083366661914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3418907862156036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3418907862156036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3418907862156036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3343714853442274`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3343714853442274`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3343714853442274`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3383620264037596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3383620264037596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3383620264037596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3421607552904546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3421607552904546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3421607552904546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33460907494623543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33460907494623543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33460907494623543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3385836074524179`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3385836074524179`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3385836074524179`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3423978835899444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3423978835899444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3423978835899444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33481527934429706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33481527934429706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33481527934429706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3387748376215026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3387748376215026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3387748376215026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34260398448529744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34260398448529744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34260398448529744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33499180192379513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33499180192379513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33499180192379513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33893927944116753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33893927944116753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33893927944116753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34278266530540047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34278266530540047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34278266530540047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3351421602838172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3351421602838172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3351421602838172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33907878702130106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33907878702130106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33907878702130106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3429358230897283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3429358230897283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3429358230897283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33526816637439094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33526816637439094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33526816637439094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33919538745291977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33919538745291977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33919538745291977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34306552424994885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34306552424994885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34306552424994885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.335371808429317`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.335371808429317`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.335371808429317`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33929091636891684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33929091636891684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33929091636891684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34317364074501777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34317364074501777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34317364074501777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33545488618041325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33545488618041325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33545488618041325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3393662782488597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3393662782488597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3393662782488597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.343261113918722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.343261113918722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.343261113918722`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33551826814580404`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33551826814580404`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33551826814580404`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33942391530555244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33942391530555244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33942391530555244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3433304154376025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3433304154376025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3433304154376025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33556436671841594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33556436671841594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33556436671841594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3394649903734614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3394649903734614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3394649903734614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3433827350866673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3433827350866673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3433827350866673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3355943183614958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3355943183614958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3355943183614958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33949079651727354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33949079651727354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33949079651727354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3434193918356955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3434193918356955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3434193918356955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33560939052585514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33560939052585514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33560939052585514`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33950214398277484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33950214398277484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33950214398277484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3434412211715659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3434412211715659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3434412211715659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3356103687829843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3356103687829843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3356103687829843`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33950043628178916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33950043628178916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33950043628178916`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34344965045887577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34344965045887577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34344965045887577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3355986326775982`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3355986326775982`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3355986326775982`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33948660287744503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33948660287744503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33948660287744503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3434456282481775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3434456282481775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3434456282481775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3355750929342399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3355750929342399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3355750929342399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3394615548047223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3394615548047223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3394615548047223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3434300847150421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3434300847150421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3434300847150421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33554064165597414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33554064165597414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33554064165597414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3394259724566769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3394259724566769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3394259724566769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34340371809022746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34340371809022746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34340371809022746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3354959417493571`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3354959417493571`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3354959417493571`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3393806999065325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3393806999065325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3393806999065325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34336739122422766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34336739122422766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34336739122422766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33544181852005045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33544181852005045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33544181852005045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3393264560747739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3393264560747739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3393264560747739`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34332183707092045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34332183707092045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34332183707092045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3353789770692781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3353789770692781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3353789770692781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33926389079963354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33926389079963354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33926389079963354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3432677199054288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3432677199054288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3432677199054288`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3353080529505565`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3353080529505565`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3353080529505565`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3391936051112185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3391936051112185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3391936051112185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34320565420703997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34320565420703997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34320565420703997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3352296338841052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3352296338841052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3352296338841052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.339116165901189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.339116165901189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.339116165901189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3431362197765653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3431362197765653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3431362197765653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33514427396554547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33514427396554547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33514427396554547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33903164898637006`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33903164898637006`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33903164898637006`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3430595062572918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3430595062572918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3430595062572918`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33505203566799846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33505203566799846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33505203566799846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3389411092374981`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3389411092374981`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3389411092374981`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3429765771965607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3429765771965607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3429765771965607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3349539647851345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3349539647851345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3349539647851345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33884476307692457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33884476307692457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33884476307692457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34288766012359573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34288766012359573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34288766012359573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3348502669356495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3348502669356495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3348502669356495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.338743011034654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.338743011034654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.338743011034654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34279316533781257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34279316533781257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34279316533781257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3347413329762132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3347413329762132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3347413329762132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.338636224299682`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.338636224299682`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.338636224299682`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3426934732001656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3426934732001656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3426934732001656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3346275250124365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3346275250124365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3346275250124365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.338524747055038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.338524747055038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.338524747055038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3425889365127352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3425889365127352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3425889365127352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33450917869000857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33450917869000857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33450917869000857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33840889859076057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33840889859076057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33840889859076057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3424798826726938`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3424798826726938`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3424798826726938`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3343866052673189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3343866052673189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3343866052673189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3382889752166351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3382889752166351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3382889752166351`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3423666156228323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3423666156228323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3423666156228323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3342600934910115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.15`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3342600934910115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.15`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3342600934910115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.19731546348051873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.19731546348051873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19731546348051873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.19761550970661507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.19761550970661507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.19761550970661507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.1970189630722318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.1970189630722318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.1970189630722318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.20516110966576143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.20516110966576143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20516110966576143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.20559888679821056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.20559888679821056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20559888679821056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.20472852549095738`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.20472852549095738`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.20472852549095738`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2125216686228849`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2125216686228849`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2125216686228849`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.21308973981517595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.21308973981517595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21308973981517595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.21196035938186242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.21196035938186242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21196035938186242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.21943437563180526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.21943437563180526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.21943437563180526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2201258145597767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2201258145597767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2201258145597767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2187511935850691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2187511935850691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2187511935850691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.22593300343456965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.22593300343456965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22593300343456965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.22674135297152703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.22674135297152703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22674135297152703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.22513433555701146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.22513433555701146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22513433555701146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2320482395932617`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2320482395932617`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2320482395932617`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2329674742201615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2329674742201615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2329674742201615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2311400449862767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2311400449862767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2311400449862767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.23780801693533615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.23780801693533615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23780801693533615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.23883250853117857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.23883250853117857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23883250853117857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.23679586085606702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.23679586085606702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23679586085606702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2432378035995241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2432378035995241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2432378035995241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.24436229028897574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.24436229028897574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24436229028897574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24212688843342736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24212688843342736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24212688843342736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.24836085820254555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.24836085820254555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24836085820254555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.24958041596787595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.24958041596787595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24958041596787595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.24715605167455307`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.24715605167455307`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24715605167455307`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.25319845481786424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.25319845481786424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25319845481786424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.25450847161024415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.25450847161024415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25450847161024415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2519043157087825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2519043157087825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2519043157087825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.26209173678427555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.26209173678427555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26209173678427555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26356996296785346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26356996296785346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26356996296785346`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2606314931414595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2606314931414595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2606314931414595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2700562026877475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2700562026877475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2700562026877475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.2716873896730706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.2716873896730706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2716873896730706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.26844492250822394`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.26844492250822394`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26844492250822394`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2772086619614231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2772086619614231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2772086619614231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2789793244407279`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2789793244407279`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2789793244407279`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.27545966855387055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.27545966855387055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27545966855387055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2836480394038619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2836480394038619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2836480394038619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28554621712507117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28554621712507117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28554621712507117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2817731475940909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2817731475940909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2817731475940909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28945894136411077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28945894136411077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28945894136411077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29147399449243744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29147399449243744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29147399449243744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.28746866050545217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.28746866050545217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28746866050545217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2947146046144941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2947146046144941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2947146046144941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29683704124626814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29683704124626814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29683704124626814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2926183083608196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2926183083608196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2926183083608196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.2994776573709673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.2994776573709673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2994776573709673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3016989762599358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3016989762599358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3016989762599358`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.29728374084482423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.29728374084482423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29728374084482423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30380182894718605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30380182894718605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30380182894718605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30611440651334243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30611440651334243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30611440651334243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3015178200640285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3015178200640285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3015178200640285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.30773430473980246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.30773430473980246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30773430473980246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31013128237226206`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31013128237226206`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31013128237226206`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3053669752956895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3053669752956895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3053669752956895`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3113162453976819`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3113162453976819`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3113162453976819`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3137914380887505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3137914380887505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3137914380887505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30887170169448774`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30887170169448774`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30887170169448774`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31610919715770497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31610919715770497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31610919715770497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.31869139395639723`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.31869139395639723`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31869139395639723`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3135590190909143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3135590190909143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3135590190909143`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32029675120962414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32029675120962414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32029675120962414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3229750813254095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3229750813254095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3229750813254095`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3176516703248421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3176516703248421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3176516703248421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.32396476544664354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.32396476544664354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32396476544664354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3267298000059284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3267298000059284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3267298000059284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.321234089406743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.321234089406743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.321234089406743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3271852710647624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3271852710647624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3271852710647624`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.330028796259307`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.330028796259307`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.330028796259307`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3243771077684283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3243771077684283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3243771077684283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3300181980408383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3300181980408383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3300181980408383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33293302791483076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33293302791483076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33293302791483076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3271396406386827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3271396406386827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3271396406386827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3325144010972582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3325144010972582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3325144010972582`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3354942225088103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3354942225088103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3354942225088103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32957168109329305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32957168109329305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32957168109329305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33471641460256174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33471641460256174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33471641460256174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3377556584059755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3377556584059755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3377556584059755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3317150292170911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3317150292170911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3317150292170911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3366612422872853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3366612422872853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3366612422872853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33975498295597184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33975498295597184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33975498295597184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33360605330760607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33360605330760607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33360605330760607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.338380158168887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.338380158168887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.338380158168887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3415240196002059`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3415240196002059`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3415240196002059`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33527548516788863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33527548516788863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33527548516788863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.33989932263215106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.33989932263215106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33989932263215106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34308940802900745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34308940802900745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34308940802900745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33674901221709835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33674901221709835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33674901221709835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3412427133024129`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3412427133024129`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3412427133024129`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3444755425093241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3444755425093241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3444755425093241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3380502006578735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3380502006578735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3380502006578735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3424300343916017`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3424300343916017`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3424300343916017`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3457024847374456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3457024847374456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3457024847374456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33919840209814867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33919840209814867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33919840209814867`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34347907982029463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34347907982029463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34347907982029463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34678834820414356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34678834820414356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34678834820414356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3402110948889888`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3402110948889888`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3402110948889888`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3444051404288381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3444051404288381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3444051404288381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3477486993274267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3477486993274267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3477486993274267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34110329793045324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34110329793045324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34110329793045324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3452209275736111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3452209275736111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3452209275736111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34859648976666235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34859648976666235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34859648976666235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34188748356575627`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34188748356575627`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34188748356575627`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3459386907005325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3459386907005325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3459386907005325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.34934419379105697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.34934419379105697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34934419379105697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34257568572411207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34257568572411207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34257568572411207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3465686489519248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3465686489519248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3465686489519248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.350002215044328`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.350002215044328`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.350002215044328`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3431779348093163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3431779348093163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3431779348093163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34711959406483217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34711959406483217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34711959406483217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3505795137405767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3505795137405767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3505795137405767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3437028563177965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3437028563177965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3437028563177965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3475996207617308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3475996207617308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3475996207617308`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3510843405578859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3510843405578859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3510843405578859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.344158394662402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.344158394662402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.344158394662402`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3480163629597131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3480163629597131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3480163629597131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35152445562865753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35152445562865753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35152445562865753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34455205732613636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34455205732613636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34455205732613636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3483753253435853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3483753253435853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3483753253435853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3519054948680786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3519054948680786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3519054948680786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3448892199987497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3448892199987497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3448892199987497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34868208397055894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34868208397055894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34868208397055894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35223313721249655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35223313721249655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35223313721249655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34517535714211633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34517535714211633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34517535714211633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3489420872519267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3489420872519267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3489420872519267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35251293032162884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35251293032162884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35251293032162884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34541581889843764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34541581889843764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34541581889843764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34915975240151176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34915975240151176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34915975240151176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35274937721429284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35274937721429284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35274937721429284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3456149378710126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3456149378710126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3456149378710126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34933870991162347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34933870991162347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34933870991162347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35294618753269635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35294618753269635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35294618753269635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34577626657662236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34577626657662236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34577626657662236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34948297860250743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34948297860250743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34948297860250743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35310745233520574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35310745233520574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35310745233520574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3459037522797486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3459037522797486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3459037522797486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34959569645024796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34959569645024796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34959569645024796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35323637328441443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35323637328441443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35323637328441443`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3460004701504733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3460004701504733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3460004701504733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3496798035941787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3496798035941787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3496798035941787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3533359488660116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3533359488660116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3533359488660116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34606930270652964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34606930270652964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34606930270652964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34973796177037025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34973796177037025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34973796177037025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35340889370748557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35340889370748557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35340889370748557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3461128594438391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3461128594438391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3461128594438391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34977168044932483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34977168044932483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34977168044932483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35345676846394636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35345676846394636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35345676846394636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34613259973852023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34613259973852023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34613259973852023`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34978415978063726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34978415978063726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34978415978063726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3534828166230245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3534828166230245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3534828166230245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3461316802913428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3461316802913428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3461316802913428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34977701074853096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34977701074853096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34977701074853096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3534886889530032`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3534886889530032`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3534886889530032`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3461116730365111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3461116730365111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3461116730365111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3497520085232445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3497520085232445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3497520085232445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3534761974379089`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3534761974379089`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3534761974379089`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3460743167779921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3460743167779921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3460743167779921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34971075208411906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34971075208411906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34971075208411906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3534469750230249`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3534469750230249`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3534469750230249`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3460211769413506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3460211769413506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3460211769413506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34965398175656753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34965398175656753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34965398175656753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35340179545996847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35340179545996847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35340179545996847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34595296128226677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34595296128226677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34595296128226677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3495838606857771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3495838606857771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3495838606857771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35334285061708437`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35334285061708437`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35334285061708437`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3458718039035177`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3458718039035177`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3458718039035177`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3495013788897486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3495013788897486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3495013788897486`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3532711552157769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3532711552157769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3532711552157769`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34577867066515616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34577867066515616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34577867066515616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3494076458540513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3494076458540513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3494076458540513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35318784284673294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35318784284673294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35318784284673294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3456746472315712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3456746472315712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3456746472315712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3493033311527975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3493033311527975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3493033311527975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3530936059968343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3530936059968343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3530936059968343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3455603807994038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3455603807994038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3455603807994038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3491896434195072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3491896434195072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3491896434195072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3529896759712259`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3529896759712259`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3529896759712259`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34543705725234797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34543705725234797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34543705725234797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34906736813964195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34906736813964195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34906736813964195`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.352876855797218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.352876855797218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.352876855797218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3453054448639766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3453054448639766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3453054448639766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3489372725860675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3489372725860675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3489372725860675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3527559304590458`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3527559304590458`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3527559304590458`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3451662934039152`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3451662934039152`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3451662934039152`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.348799917425937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.348799917425937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.348799917425937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3526274768505155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3526274768505155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3526274768505155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34502014764780803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34502014764780803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34502014764780803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34865600754158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34865600754158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34865600754158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35249221735515074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35249221735515074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35249221735515074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34486769501609155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34486769501609155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34486769501609155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3485061427520243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3485061427520243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3485061427520243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3523507647070591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3523507647070591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3523507647070591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34470952262404964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34470952262404964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34470952262404964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34835085939253957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34835085939253957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34835085939253957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.352203668527064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.352203668527064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.352203668527064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3445461536843691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3445461536843691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3445461536843691`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34819065116508907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34819065116508907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34819065116508907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3520514348827846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3520514348827846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3520514348827846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3443780696880658`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3443780696880658`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3443780696880658`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3480259806892272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3480259806892272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3480259806892272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3518945382579548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3518945382579548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3518945382579548`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3442057215294526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3442057215294526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3442057215294526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3478568750083893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3478568750083893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3478568750083893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35173301772786125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35173301772786125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35173301772786125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34402912468722013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34402912468722013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34402912468722013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3476842358909992`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3476842358909992`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3476842358909992`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3515677839221199`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3515677839221199`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3515677839221199`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3438491717661271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3438491717661271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3438491717661271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3475082179655956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3475082179655956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3475082179655956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35139900130830026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35139900130830026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35139900130830026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34366600788260887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34366600788260887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34366600788260887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3473291411239337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3473291411239337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3473291411239337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35122699218328396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35122699218328396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35122699218328396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3434799441285493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3434799441285493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3434799441285493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34714730024005563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34714730024005563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34714730024005563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35105207065975164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35105207065975164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35105207065975164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3432912671259182`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3432912671259182`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3432912671259182`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3469629672700804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3469629672700804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3469629672700804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3508745116372287`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3508745116372287`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3508745116372287`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3431002410845684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3431002410845684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3431002410845684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3467763931490506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3467763931490506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3467763931490506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35069457333048554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35069457333048554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35069457333048554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3429071096603327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3429071096603327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3429071096603327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34658780950526386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34658780950526386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34658780950526386`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3505124941932133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3505124941932133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3505124941932133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34271209763347094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.18`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34271209763347094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.18`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34271209763347094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2264515916046305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2264515916046305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2264515916046305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.22674541676263363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.22674541676263363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22674541676263363`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.22616128820644354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.22616128820644354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.22616128820644354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.23387811945214795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.23387811945214795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23387811945214795`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.23430658640707772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.23430658640707772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23430658640707772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.23345480842290786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.23345480842290786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.23345480842290786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2408282473827437`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2408282473827437`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2408282473827437`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.24138394576417838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.24138394576417838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24138394576417838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.24027926054301837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.24027926054301837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24027926054301837`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.24733924173730695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.24733924173730695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24733924173730695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.24801527890574007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.24801527890574007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24801527890574007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.24667139740031782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.24667139740031782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.24667139740031782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.25344485906724923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.25344485906724923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.25344485906724923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2542348175068329`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2542348175068329`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2542348175068329`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2526645044556704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2526645044556704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2526645044556704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2591757323736938`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2591757323736938`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2591757323736938`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2600736310052787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2600736310052787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2600736310052787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2582887821115273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2582887821115273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2582887821115273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.26455970894646347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.26455970894646347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26455970894646347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.26555996797968096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.26555996797968096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26555996797968096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26357168001132253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26357168001132253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26357168001132253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2696221465685789`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2696221465685789`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2696221465685789`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2707195555474252`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2707195555474252`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2707195555474252`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.26853819005289686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.26853819005289686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.26853819005289686`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.27438617381429564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.27438617381429564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27438617381429564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.27557586254401567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.27557586254401567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.27557586254401567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.2732111038098107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.2732111038098107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2732111038098107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2788729193032827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2788729193032827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2788729193032827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2801503313770979`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2801503313770979`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2801503313770979`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2776112391917493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2776112391917493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2776112391917493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.28708837832608347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.28708837832608347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28708837832608347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28852869927512614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28852869927512614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28852869927512614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.285665868814694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.285665868814694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.285665868814694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.29440571372573465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.29440571372573465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29440571372573465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.29599392728637136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.29599392728637136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29599392728637136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.29283721157902093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.29283721157902093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29283721157902093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3009403148384773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3009403148384773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3009403148384773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3026631697088405`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3026631697088405`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3026631697088405`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29923891107252487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29923891107252487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29923891107252487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3067896580760759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3067896580760759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3067896580760759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30863542531036336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30863542531036336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30863542531036336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30496693796211366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30496693796211366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30496693796211366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3120369119667998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3120369119667998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3120369119667998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3139951773889697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3139951773889697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3139951773889697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31010316054886344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31010316054886344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31010316054886344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.31675391662309904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.31675391662309904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31675391662309904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3188154086977296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3188154086977296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3188154086977296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31471828938149`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31471828938149`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31471828938149`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3210019551172536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3210019551172536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3210019551172536`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.32315838402117664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.32315838402117664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32315838402117664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3188726373897213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3188726373897213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3188726373897213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3248334554661633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3248334554661633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3248334554661633`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3270774006320455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3270774006320455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3270774006320455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32261777362284166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32261777362284166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32261777362284166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32829437158365454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32829437158365454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32829437158365454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3306191689167988`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3306191689167988`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3306191689167988`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3259989046040966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3259989046040966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3259989046040966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3314246976449877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3314246976449877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3314246976449877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3338243472786303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3338243472786303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3338243472786303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32905536835181126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32905536835181126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32905536835181126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.335575240127646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.335575240127646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.335575240127646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.33807717757344097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.33807717757344097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33807717757344097`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3331049790853834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3331049790853834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3331049790853834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3391593497729416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3391593497729416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3391593497729416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3417530714629576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3417530714629576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3417530714629576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.33659852433113674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.33659852433113674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33659852433113674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.34225975390822305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.34225975390822305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34225975390822305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3449361701906865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3449361701906865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3449361701906865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.33961733526905985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.33961733526905985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33961733526905985`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34494562376173743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34494562376173743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34494562376173743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3476968336682344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3476968336682344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3476968336682344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3422294094854273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3422294094854273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3422294094854273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3472743024922835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3472743024922835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3472743024922835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35009340823382123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35009340823382123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35009340823382123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3444910998183598`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3444910998183598`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3444910998183598`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3492942914041602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3492942914041602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3492942914041602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3521752452748677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3521752452748677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3521752452748677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.34645006842402876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.34645006842402876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34645006842402876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35104600534514013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35104600534514013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35104600534514013`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3539834825339322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3539834825339322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3539834825339322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3481460167528756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3481460167528756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3481460167528756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35256449774248283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35256449774248283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35256449774248283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3555537978268575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3555537978268575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3555537978268575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3496133818370324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3496133818370324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3496133818370324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35387928511110467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35387928511110467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35387928511110467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35691623940852574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35691623940852574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35691623940852574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3508811554833113`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3508811554833113`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3508811554833113`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3550149397488594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3550149397488594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3550149397488594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3580958412405499`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3580958412405499`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3580958412405499`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3519734532741696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3519734532741696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3519734532741696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35599395943966683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35599395943966683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35599395943966683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3591155060426748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3591155060426748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3591155060426748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3529123774315762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3529123774315762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3529123774315762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35683473654741604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35683473654741604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35683473654741604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35999396741013884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35999396741013884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35999396741013884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35371597790113446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35371597790113446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35371597790113446`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35755383440718835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35755383440718835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35755383440718835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3607480966664532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3607480966664532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3607480966664532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35440051758235885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35440051758235885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35440051758235885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3581654315758397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3581654315758397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3581654315758397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36139233663828046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36139233663828046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36139233663828046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35497991339944673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35497991339944673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35497991339944673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3586812470732163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3586812470732163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3586812470732163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3619386380535765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3619386380535765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3619386380535765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3554656559634868`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3554656559634868`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3554656559634868`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3591125722872775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3591125722872775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3591125722872775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3623985029290192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3623985029290192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3623985029290192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3558688285157055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3558688285157055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3558688285157055`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3594687706707585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3594687706707585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3594687706707585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3627814745734959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3627814745734959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3627814745734959`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3561986171010538`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3561986171010538`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3561986171010538`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3597578615327111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3597578615327111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3597578615327111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36309573148871377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36309573148871377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36309573148871377`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3564628840956875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3564628840956875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3564628840956875`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3599872039443257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3599872039443257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3599872039443257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36334878127584586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36334878127584586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36334878127584586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3566688418251022`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3566688418251022`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3566688418251022`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3601637967555026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3601637967555026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3601637967555026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3635477429024892`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3635477429024892`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3635477429024892`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35682337033810796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35682337033810796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35682337033810796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3602924735710829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3602924735710829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3602924735710829`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36369757389113905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36369757389113905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36369757389113905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35693118150754954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35693118150754954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35693118150754954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.36037827690059115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.36037827690059115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36037827690059115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36380341414859024`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36380341414859024`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36380341414859024`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35699722166941067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35699722166941067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35699722166941067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3604261001412302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3604261001412302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3604261001412302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36387025133051853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36387025133051853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36387025133051853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3570262909165061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3570262909165061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3570262909165061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3604398750329299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3604398750329299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3604398750329299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3639020980991026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3639020980991026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3639020980991026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35702224121641174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35702224121641174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35702224121641174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3604227992497344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3604227992497344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3604227992497344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3639022264895155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3639022264895155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3639022264895155`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35698819701135087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35698819701135087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35698819701135087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.36037844266391966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.36037844266391966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36037844266391966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36387427474346395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36387427474346395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36387427474346395`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3569276604731664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3569276604731664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3569276604731664`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.36030955671726805`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.36030955671726805`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36030955671726805`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36382105410965065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36382105410965065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36382105410965065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35684332408417474`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35684332408417474`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35684332408417474`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.36021871386186577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.36021871386186577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36021871386186577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3637451918639532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3637451918639532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3637451918639532`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35673770617405326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35673770617405326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35673770617405326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3601082325812322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3601082325812322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3601082325812322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36364905613260273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36364905613260273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36364905613260273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3566130762144048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3566130762144048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3566130762144048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3599793592212231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3599793592212231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3599793592212231`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3635339403827485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3635339403827485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3635339403827485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35647063447322047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35647063447322047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35647063447322047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35983492487567037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35983492487567037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35983492487567037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3634027173351038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3634027173351038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3634027173351038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35631317033626736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35631317033626736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35631317033626736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3596762859823218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3596762859823218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3596762859823218`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36325678023895264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36325678023895264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36325678023895264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3561420041325119`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3561420041325119`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3561420041325119`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35950495648844766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35950495648844766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35950495648844766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3630976774153689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3630976774153689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3630976774153689`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35595861587265554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35595861587265554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35595861587265554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35932229012821665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35932229012821665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35932229012821665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3629267942763414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3629267942763414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3629267942763414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3557643280186164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3557643280186164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3557643280186164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35912885234372866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35912885234372866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35912885234372866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3627447266099035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3627447266099035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3627447266099035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3555596764826332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3555596764826332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3555596764826332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35892652344480364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35892652344480364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35892652344480364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36255338244313196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36255338244313196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36255338244313196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35534651359414315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35534651359414315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35534651359414315`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3587161122220758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3587161122220758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3587161122220758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36235359322155347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36235359322155347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36235359322155347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3551256260143241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3551256260143241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3551256260143241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35849853793969105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35849853793969105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35849853793969105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3621463006044051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3621463006044051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3621463006044051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35489791090543277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35489791090543277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35489791090543277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35827432125689257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35827432125689257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35827432125689257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36193204610760743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36193204610760743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36193204610760743`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3546638685969116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3546638685969116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3546638685969116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35804447247886706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35804447247886706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35804447247886706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3617118614706421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3617118614706421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3617118614706421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35442448794376596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35442448794376596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35442448794376596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3578096266586481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3578096266586481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3578096266586481`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36148639792139936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36148639792139936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36148639792139936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35418038817823694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35418038817823694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35418038817823694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35757040198152906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35757040198152906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35757040198152906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36125629008153554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36125629008153554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36125629008153554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35393217131227495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35393217131227495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35393217131227495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35732723326636656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35732723326636656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35732723326636656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3610219811719241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3610219811719241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3610219811719241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35368025767268885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35368025767268885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35368025767268885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3570806823311453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3570806823311453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3570806823311453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36078405954099907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36078405954099907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36078405954099907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3534251928566174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3534251928566174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3534251928566174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35683122503615106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35683122503615106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35683122503615106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3605430083495781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3605430083495781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3605430083495781`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35316744099361297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35316744099361297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35316744099361297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35657927409459467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35657927409459467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35657927409459467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3602992580650309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3602992580650309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3602992580650309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35290740835897666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35290740835897666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35290740835897666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35632522078623025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35632522078623025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35632522078623025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3600532019918185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3600532019918185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3600532019918185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35264546578697487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35264546578697487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35264546578697487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3560694155924224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3560694155924224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3560694155924224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3598052055105666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3598052055105666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3598052055105666`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35238195714621434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35238195714621434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35238195714621434`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35581182895725283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35581182895725283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35581182895725283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3595552495724825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3595552495724825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3595552495724825`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35211684283840383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35211684283840383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35211684283840383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3555532100957076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3555532100957076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3555532100957076`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35930409208708225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35930409208708225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35930409208708225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3518508631754776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3518508631754776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3518508631754776`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3552936461224744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3552936461224744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3552936461224744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35905182884018866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35905182884018866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35905182884018866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3515840894859762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3515840894859762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3515840894859762`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3550333723438853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3550333723438853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3550333723438853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3587987032207966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3587987032207966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3587987032207966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3513167617150884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3513167617150884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3513167617150884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.35477260342012196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.35477260342012196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35477260342012196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.358544937451105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.358544937451105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.358544937451105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35104908145797425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35104908145797425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35104908145797425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3545115352135598`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3545115352135598`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3545115352135598`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3582907344736782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3582907344736782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3582907344736782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3507812375810006`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3507812375810006`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3507812375810006`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3542503464531757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3542503464531757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3542503464531757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35803627965139967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35803627965139967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35803627965139967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3505134022571033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3505134022571033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3505134022571033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3539892002339224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3539892002339224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3539892002339224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35778174229944004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35778174229944004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35778174229944004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.350245732432983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.21`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.350245732432983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.21`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.350245732432983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.25553753680647767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.25553753680647767`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25553753680647767`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2558251667840771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2558251667840771`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2558251667840771`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.25525340460306645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.25525340460306645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.25525340460306645`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2625215149215479`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2625215149215479`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2625215149215479`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.26294072221462117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.26294072221462117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26294072221462117`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.2621074266776336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.2621074266776336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2621074266776336`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2690388121751506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2690388121751506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2690388121751506`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2695822201449396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2695822201449396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2695822201449396`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.26850206560494433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.26850206560494433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "0.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.26850206560494433`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}],
         "}"}], ",", "0.27512667292358806`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}],
         "}"}], ",", "0.27512667292358806`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.27512667292358806`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}],
         "}"}], ",", "0.2757874294674435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}],
         "}"}], ",", "0.2757874294674435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2757874294674435`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}],
         "}"}], ",", "0.2744740455675807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}],
         "}"}], ",", "0.2744740455675807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2744740455675807`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2808187870564494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2808187870564494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2808187870564494`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2815905207224266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2815905207224266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2815905207224266`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.28005657995637556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.28005657995637556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.28005657995637556`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.28614568513904226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.28614568513904226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.28614568513904226`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.28702246533940445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.28702246533940445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.28702246533940445`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.28527976241378517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.28527976241378517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.28527976241378517`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.29113508337446986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.29113508337446986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.29113508337446986`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.2921113843481704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.2921113843481704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2921113843481704`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.290170908040159`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.290170908040159`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.290170908040159`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.2958121862934591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.2958121862934591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2958121862934591`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.29688285431649813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.29688285431649813`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.29688285431649813`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.29475485285278247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.29475485285278247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "1.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.29475485285278247`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}],
         "}"}], ",", "0.3001999517508591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}],
         "}"}], ",", "0.3001999517508591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3001999517508591`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}],
         "}"}], ",", "0.3013601754107131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}],
         "}"}], ",", "0.3013601754107131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3013601754107131`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}],
         "}"}], ",", "0.2990542157173471`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}],
         "}"}], ",", "0.2990542157173471`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.2990542157173471`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.30431932448039295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.30431932448039295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.30431932448039295`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3055646076401046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3055646076401046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3055646076401046`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.303089629222877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.303089629222877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.303089629222877`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.311825912494262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.311825912494262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.311825912494262`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.31322896001831024`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.31322896001831024`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.31322896001831024`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3104405072680141`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3104405072680141`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "2.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3104405072680141`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}],
         "}"}], ",", "0.3184675120685497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}],
         "}"}], ",", "0.3184675120685497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3184675120685497`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}],
         "}"}], ",", "0.32001355558852984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}],
         "}"}], ",", "0.32001355558852984`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.32001355558852984`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}],
         "}"}], ",", "0.31694098725528247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}],
         "}"}], ",", "0.31694098725528247`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.31694098725528247`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.324357855133122`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.324357855133122`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.324357855133122`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3260338897273733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3260338897273733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3260338897273733`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3227030569229881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3227030569229881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3227030569229881`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3295927584239483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3295927584239483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3295927584239483`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.33138729710144477`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.33138729710144477`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.33138729710144477`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.32782103172185084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.32782103172185084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "3.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.32782103172185084`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.33425376519361366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.33425376519361366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.33425376519361366`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.33615662931117674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.33615662931117674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.33615662931117674`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3323751613356141`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3323751613356141`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3323751613356141`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3384111505481803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3384111505481803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3384111505481803`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.34041329583399393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.34041329583399393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.34041329583399393`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3364345993847449`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3364345993847449`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "4.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3364345993847449`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}],
         "}"}], ",", "0.3421247026636282`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}],
         "}"}], ",", "0.3421247026636282`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3421247026636282`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}],
         "}"}], ",", "0.34421805741512523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}],
         "}"}], ",", "0.34421805741512523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.34421805741512523`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}],
         "}"}], ",", "0.34005817306993186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}],
         "}"}], ",", "0.34005817306993186`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.34005817306993186`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.34544541531366757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.34544541531366757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.34544541531366757`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.34762276729598784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.34762276729598784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.34762276729598784`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.34329602693860295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.34329602693860295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.34329602693860295`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3484178913016698`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3484178913016698`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3484178913016698`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.350672774895893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.350672774895893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.350672774895893`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.34619202619653533`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.34619202619653533`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "5.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.34619202619653533`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.35108085130538125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.35108085130538125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.35108085130538125`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.35340745526161116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.35340745526161116`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.35340745526161116`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3487842451513632`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3487842451513632`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3487842451513632`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.35456726638857106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.35456726638857106`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.35456726638857106`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3569917927024098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3569917927024098`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3569917927024098`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3521740805265995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3521740805265995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "6.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3521740805265995`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3575282553361838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3575282553361838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3575282553361838`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3600405712714265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3600405712714265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3600405712714265`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.35504848916286325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.35504848916286325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "7.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.35504848916286325`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}],
         "}"}], ",", "0.3600431709356702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}],
         "}"}], ",", "0.3600431709356702`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3600431709356702`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}],
         "}"}], ",", "0.3626345278725297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}],
         "}"}], ",", "0.3626345278725297`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3626345278725297`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}],
         "}"}], ",", "0.3574854572318692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}],
         "}"}], ",", "0.3574854572318692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3574854572318692`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3621781153753193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3621781153753193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3621781153753193`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3648409255294139`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3648409255294139`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3648409255294139`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3595499408696436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3595499408696436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "8.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3595499408696436`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.363987664620694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.363987664620694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.363987664620694`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36671531753469844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36671531753469844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36671531753469844`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36129555133198726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36129555133198726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36129555133198726`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36551781054702787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36551781054702787`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36551781054702787`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36830452216388654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36830452216388654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36830452216388654`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3627674648049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3627674648049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "9.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3627674648049`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3668067126051966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3668067126051966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3668067126051966`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36964739861837065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36964739861837065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36964739861837065`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36400314897592817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36400314897592817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "10.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36400314897592817`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36788735463286903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36788735463286903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36788735463286903`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3707775384523352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3707775384523352`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3707775384523352`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36503499148402746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36503499148402746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36503499148402746`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3687873944308421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3687873944308421`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3687873944308421`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37172311005417324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37172311005417324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37172311005417324`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36589014275089893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36589014275089893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "11.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36589014275089893`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.369529724633216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.369529724633216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.369529724633216`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37250745301946975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37250745301946975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37250745301946975`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.366591055654914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.366591055654914`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.366591055654914`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37013528654992467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37013528654992467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37013528654992467`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.373151895692982`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.373151895692982`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.373151895692982`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36715828939791084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36715828939791084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "12.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36715828939791084`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3706210858910586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3706210858910586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3706210858910586`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37367377371192173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37367377371192173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37367377371192173`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36760852435302543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36760852435302543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "13.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36760852435302543`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3710023953618272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3710023953618272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3710023953618272`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3740886544618608`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3740886544618608`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3740886544618608`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36795674230749204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36795674230749204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36795674230749204`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37129222597133754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37129222597133754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37129222597133754`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37440980182164835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37440980182164835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37440980182164835`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3682157047995467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3682157047995467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "14.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3682157047995467`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.371501254478618`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.371501254478618`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.371501254478618`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37464811353679983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37464811353679983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37464811353679983`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36839587079686376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36839587079686376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36839587079686376`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37163976947228894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37163976947228894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37163976947228894`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37481407940822253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37481407940822253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37481407940822253`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3685073300865904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3685073300865904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "15.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3685073300865904`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37171624204304393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37171624204304393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37171624204304393`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3749163416704275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3749163416704275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3749163416704275`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3685583849838753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3685583849838753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "16.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3685583849838753`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37173788229747784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37173788229747784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37173788229747784`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37496226152329226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37496226152329226`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37496226152329226`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3685560966855302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3685560966855302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3685560966855302`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37171128249543417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37171128249543417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37171128249543417`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3749585723291431`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3749585723291431`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3749585723291431`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3685069180850027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3685069180850027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "17.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3685069180850027`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3716427805999936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3716427805999936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3716427805999936`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3749117260631888`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3749117260631888`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3749117260631888`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36841707438908217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36841707438908217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36841707438908217`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3715365076337374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3715365076337374`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3715365076337374`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37482597046957494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37482597046957494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37482597046957494`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3682905820420188`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3682905820420188`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "18.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3682905820420188`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37139695171499043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37139695171499043`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37139695171499043`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3747058856622635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3747058856622635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3747058856622635`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36813183833421376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36813183833421376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "19.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36813183833421376`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37122843102898856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37122843102898856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37122843102898856`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37455587908853133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37455587908853133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37455587908853133`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3679450731231842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3679450731231842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3679450731231842`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3710343724301254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3710343724301254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3710343724301254`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3743794537291151`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3743794537291151`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3743794537291151`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.367733638247609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.367733638247609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "20.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.367733638247609`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3708175226809142`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3708175226809142`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3708175226809142`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3741794260562523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3741794260562523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3741794260562523`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3675002118491455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3675002118491455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3675002118491455`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.37058098757223107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.37058098757223107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37058098757223107`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37395896637263615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37395896637263615`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37395896637263615`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36724783586759974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36724783586759974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "21.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36724783586759974`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3703271171704621`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3703271171704621`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3703271171704621`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3737204807757451`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3737204807757451`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3737204807757451`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36697880515843156`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36697880515843156`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "22.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36697880515843156`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3700581028828409`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3700581028828409`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3700581028828409`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3734662120583828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3734662120583828`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3734662120583828`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36669526042757933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36669526042757933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36669526042757933`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36977590766256224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36977590766256224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36977590766256224`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3731981696540695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3731981696540695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3731981696540695`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3663991187657048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3663991187657048`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "23.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3663991187657048`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36948150271365054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36948150271365054`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36948150271365054`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37291736811846826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37291736811846826`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37291736811846826`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3660913090292897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3660913090292897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3660913090292897`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36917734057466584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36917734057466584`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36917734057466584`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3726262997663056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3726262997663056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3726262997663056`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36577424394235863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36577424394235863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "24.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36577424394235863`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3688645132462211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3688645132462211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3688645132462211`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37232609063270355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37232609063270355`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37232609063270355`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36544898215929356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36544898215929356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "25.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36544898215929356`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36854426454205724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36854426454205724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36854426454205724`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37201801658722045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37201801658722045`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37201801658722045`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3651167358885028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3651167358885028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3651167358885028`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3682176946836092`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3682176946836092`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3682176946836092`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37170320738257384`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37170320738257384`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37170320738257384`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36477857625243504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36477857625243504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "26.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36477857625243504`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36788518679509047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36788518679509047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36788518679509047`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.37138207378875454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.37138207378875454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.37138207378875454`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3644348595523568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3644348595523568`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3644348595523568`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36754833122302133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36754833122302133`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36754833122302133`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3710562274979618`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3710562274979618`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3710562274979618`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3640871493683456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3640871493683456`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "27.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3640871493683456`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36720774882931484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36720774882931484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36720774882931484`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3707263181164034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3707263181164034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3707263181164034`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36373604622588335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36373604622588335`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "28.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36373604622588335`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36686415793682803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36686415793682803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36686415793682803`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.370393085687407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.370393085687407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.370393085687407`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36338225246570494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36338225246570494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36338225246570494`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36651793176795233`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36651793176795233`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36651793176795233`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3700569152406077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3700569152406077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3700569152406077`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36302611575088484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36302611575088484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "29.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36302611575088484`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3661698734984874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3661698734984874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3661698734984874`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36971863307303693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36971863307303693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36971863307303693`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3626684223264328`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3626684223264328`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3626684223264328`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3658204624376427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3658204624376427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3658204624376427`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3693787333073203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3693787333073203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3693787333073203`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36230963201833977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36230963201833977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "30.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36230963201833977`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36547016267451177`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36547016267451177`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36547016267451177`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36903769511404827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36903769511404827`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36903769511404827`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36195020222382185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36195020222382185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "31.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36195020222382185`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36511927888527873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36511927888527873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36511927888527873`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36869583664441`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36869583664441`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36869583664441`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3615904208968734`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3615904208968734`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3615904208968734`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3647682247270997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3647682247270997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3647682247270997`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3683535865538727`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3683535865538727`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3683535865538727`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3612306867697529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3612306867697529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "32.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3612306867697529`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36441734780126467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36441734780126467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36441734780126467`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3680113033631919`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3680113033631919`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3680113033631919`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36087133671209354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36087133671209354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36087133671209354`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36406694428492997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36406694428492997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36406694428492997`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3676692944418001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3676692944418001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3676692944418001`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3605126558607716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3605126558607716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "33.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3605126558607716`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36371728055919544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36371728055919544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36371728055919544`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36732783656203977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36732783656203977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36732783656203977`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.36015490034622544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.36015490034622544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "34.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36015490034622544`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3633685993498576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3633685993498576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3633685993498576`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3669871823748861`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3669871823748861`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3669871823748861`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3597983030960614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3597983030960614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3597983030960614`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3630208126691596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3630208126691596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3630208126691596`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3666472531988482`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3666472531988482`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3666472531988482`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3594427671814216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3594427671814216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "35.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3594427671814216`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36267451097530007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36267451097530007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36267451097530007`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36630864800746527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36630864800746527`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36630864800746527`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.35908887443726223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.35908887443726223`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.35908887443726223`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36232971157334976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36232971157334976`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36232971157334976`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3659713918118833`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3659713918118833`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3659713918118833`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3587366346525489`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3587366346525489`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "36.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3587366346525489`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3619865619102636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}
         ], "}"}], ",", "0.3619865619102636`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3619865619102636`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36563563962641626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36563563962641626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36563563962641626`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.35838618799886424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.35838618799886424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "37.4`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.35838618799886424`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3616451933105797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3616451933105797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3616451933105797`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3653015281253915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3653015281253915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3653015281253915`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3580376589333278`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3580376589333278`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3580376589333278`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36130572238965775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36130572238965775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36130572238965775`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36496918239763554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36496918239763554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36496918239763554`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.35769115775042654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.35769115775042654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "38.6`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.35769115775042654`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.36096825271535693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.36096825271535693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36096825271535693`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.36463871127139175`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.36463871127139175`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.36463871127139175`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.3573467819726148`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.3573467819726148`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.2`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3573467819726148`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.94018`", ",", 
         "1.1666`"}], "}"}], ",", "0.3606328759875005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.94018`", ",", 
         "1.1711`"}], "}"}], ",", "0.3606328759875005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.94018`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3606328759875005`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.94368`", ",", 
         "1.1666`"}], "}"}], ",", "0.3643102125637735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.94368`", ",", 
         "1.1711`"}], "}"}], ",", "0.3643102125637735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.94368`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.3643102125637735`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.93668`", ",", 
         "1.1666`"}], "}"}], ",", "0.357004617596619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.93668`", ",", 
         "1.1711`"}], "}"}], ",", "0.357004617596619`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.24000000000000002`", ",", "39.8`", ",", "0.93668`", ",", 
         "1.1621000000000001`"}], "}"}], ",", "0.357004617596619`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2845735925873635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2845735925873635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2845735925873635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.28485505303935194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.28485505303935194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.28485505303935194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2842956059955271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2842956059955271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2842956059955271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.29109181666595724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.29109181666595724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29109181666595724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.2915018142727751`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.2915018142727751`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2915018142727751`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.2906869013854285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.2906869013854285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2906869013854285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.2971541576749495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.2971541576749495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.2971541576749495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.29768535661738754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.29768535661738754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29768535661738754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.29662957025411424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.29662957025411424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.29662957025411424`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.30279778056603196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.30279778056603196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30279778056603196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3034433759369506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3034433759369506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3034433759369506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3021602511402084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3021602511402084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3021602511402084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3080562541189268`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3080562541189268`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3080562541189268`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.30880992676882507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.30880992676882507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30880992676882507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.30731203133443846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.30731203133443846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.30731203133443846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3129599548565105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3129599548565105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3129599548565105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3138158305446869`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3138158305446869`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3138158305446869`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3121148464899191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3121148464899191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3121148464899191`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3175364193344712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3175364193344712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3175364193344712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.318489031707299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.318489031707299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.318489031707299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.31659582908217526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.31659582908217526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31659582908217526`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.32181065273196885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.32181065273196885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32181065273196885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3228549098623357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3228549098623357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3228549098623357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32077961346109146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32077961346109146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32077961346109146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.32580539878544157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.32580539878544157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32580539878544157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3269365527352445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3269365527352445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3269365527352445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3246886027518942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3246886027518942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3246886027518942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3295413774511425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3295413774511425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3295413774511425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3307549966870715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3307549966870715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3307549966870715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.32834320368292735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.32834320368292735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32834320368292735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3363091094752067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3363091094752067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3363091094752067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.337675499787381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.337675499787381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.337675499787381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3349601943937429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3349601943937429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3349601943937429`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3422475007752552`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3422475007752552`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3422475007752552`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3437521550206659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3437521550206659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3437521550206659`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.34076217520192253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.34076217520192253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34076217520192253`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.34746837516826545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.34746837516826545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34746837516826545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3490985465036597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3490985465036597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3490985465036597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3458592286818759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3458592286818759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3458592286818759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3520656678611503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3520656678611503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3520656678611503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3538101209612375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3538101209612375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3538101209612375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35034379535330595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35034379535330595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35034379535330595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3561190995851242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3561190995851242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3561190995851242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.35796789904800214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.35796789904800214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35796789904800214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.35429431082559454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.35429431082559454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35429431082559454`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3596972051095162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3596972051095162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3596972051095162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36164154048917757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36164154048917757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36164154048917757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3577781977885502`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3577781977885502`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3577781977885502`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3628581215928531`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3628581215928531`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3628581215928531`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.36489014448404455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.36489014448404455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36489014448404455`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3608526429070928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3608526429070928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3608526429070928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3656512701316001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3656512701316001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3656512701316001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.36776398070281824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.36776398070281824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36776398070281824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.36356622889217294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.36356622889217294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36356622889217294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3681197784749692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3681197784749692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3681197784749692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3703069126815264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3703069126815264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3703069126815264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3659613566562922`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3659613566562922`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3659613566562922`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37030098299475084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37030098299475084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37030098299475084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3725569204570348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3725569204570348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3725569204570348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.36807472682960646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.36807472682960646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36807472682960646`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3731036060444667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3731036060444667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3731036060444667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3754534253089706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3754534253089706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3754534253089706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37078479761264643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37078479761264643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37078479761264643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37542385665332345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37542385665332345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37542385665332345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3778577971927003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3778577971927003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3778577971927003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37302212589169725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37302212589169725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37302212589169725`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3773374627033736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3773374627033736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3773374627033736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3798471166439838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3798471166439838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3798471166439838`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3748611041280943`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3748611041280943`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3748611041280943`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37890724339479065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37890724339479065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37890724339479065`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3814853336654399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3814853336654399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3814853336654399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37636343438797965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37636343438797965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37636343438797965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3801848220902254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3801848220902254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3801848220902254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38282502419552517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38282502419552517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38282502419552517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3775798023240759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3775798023240759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3775798023240759`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38121352392943814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38121352392943814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38121352392943814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3839103131453729`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3839103131453729`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3839103131453729`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.378552741322004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.378552741322004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.378552741322004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38202911418758534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38202911418758534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38202911418758534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3847776449258704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3847776449258704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3847776449258704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3793173474068031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3793173474068031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3793173474068031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3826623911012855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3826623911012855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3826623911012855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3854584018536327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3854584018536327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3854584018536327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37990384234843216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37990384234843216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37990384234843216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38313904475324834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38313904475324834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38313904475324834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38597876893548777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38597876893548777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38597876893548777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3803374279774933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3803374279774933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3803374279774933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3834801988936239`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3834801988936239`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3834801988936239`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38636029887624085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38636029887624085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38636029887624085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3806388049473263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3806388049473263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3806388049473263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38370515713386144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38370515713386144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38370515713386144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38662266711486876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38662266711486876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38662266711486876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3808269098368464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3808269098368464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3808269098368464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38382946948911656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38382946948911656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38382946948911656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3867817395886523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3867817395886523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3867817395886523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3809169811974008`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3809169811974008`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3809169811974008`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3838670553339262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3838670553339262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3838670553339262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3868517177033647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3868517177033647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3868517177033647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38092266003183645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38092266003183645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38092266003183645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3838297028667746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3838297028667746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3838297028667746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38684463106943684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38684463106943684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38684463106943684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3808554964251008`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3808554964251008`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3808554964251008`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38372699729893367`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38372699729893367`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38372699729893367`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38677027518472423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38677027518472423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38677027518472423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38072486839888986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38072486839888986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38072486839888986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3835681811565537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3835681811565537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3835681811565537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38663808434159924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38663808434159924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38663808434159924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38053982905973704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38053982905973704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38053982905973704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38336079411895807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38336079411895807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38336079411895807`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38645576069102927`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38645576069102927`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38645576069102927`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38030775790957616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38030775790957616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38030775790957616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38311120228913925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38311120228913925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38311120228913925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38622981341181667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38622981341181667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38622981341181667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38003488008819925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38003488008819925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38003488008819925`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3828251999341654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3828251999341654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3828251999341654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3859661704972154`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3859661704972154`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3859661704972154`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3797268578296046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3797268578296046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3797268578296046`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3825084385558194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3825084385558194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3825084385558194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38567059140177495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38567059140177495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38567059140177495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3793892358829262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3793892358829262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3793892358829262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38216431590538796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38216431590538796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38216431590538796`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3853465835611416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3853465835611416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3853465835611416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3790253044225003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3790253044225003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3790253044225003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3817967459526294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3817967459526294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3817967459526294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3849981476597942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3849981476597942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3849981476597942`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3786388918194345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3786388918194345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3786388918194345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3814094507994298`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3814094507994298`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3814094507994298`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38462909010800134`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38462909010800134`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38462909010800134`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37823363678786287`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37823363678786287`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37823363678786287`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.381005333674783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.381005333674783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.381005333674783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38424238559392326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38424238559392326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38424238559392326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3778123721756336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3778123721756336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3778123721756336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3805866739298784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3805866739298784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3805866739298784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3838403787018211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3838403787018211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3838403787018211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37737731315681194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37737731315681194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37737731315681194`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3801560971745151`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3801560971745151`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3801560971745151`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3834257557558018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3834257557558018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3834257557558018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3769310252902362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3769310252902362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3769310252902362`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37971553809020187`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37971553809020187`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37971553809020187`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3830005038461334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3830005038461334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3830005038461334`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3764753916551917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3764753916551917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3764753916551917`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3792667940654614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3792667940654614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3792667940654614`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3825664684526816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3825664684526816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3825664684526816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37601216223639117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37601216223639117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37601216223639117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37881146062971227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37881146062971227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37881146062971227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3821252885830343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3821252885830343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3821252885830343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3755428897213036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3755428897213036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3755428897213036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3783502256749296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3783502256749296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3783502256749296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38167769206581265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38167769206581265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38167769206581265`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37506822307246956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37506822307246956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37506822307246956`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37788514957783703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37788514957783703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37788514957783703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3812257719323475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3812257719323475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3812257719323475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37459018479345707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37459018479345707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37459018479345707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3774170484051215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3774170484051215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3774170484051215`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38077038704629107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38077038704629107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38077038704629107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3741095638554934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3741095638554934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3741095638554934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3769468928671051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3769468928671051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3769468928671051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3803125289849124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3803125289849124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3803125289849124`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37362729608185236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37362729608185236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37362729608185236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3764755191859872`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3764755191859872`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3764755191859872`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37985306372313504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37985306372313504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37985306372313504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37314418934813964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37314418934813964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37314418934813964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37600312487132304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37600312487132304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37600312487132304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37939221383131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37939221383131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37939221383131`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37266042277711475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37266042277711475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37266042277711475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37553099825204445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37553099825204445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37553099825204445`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37893129280252835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37893129280252835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37893129280252835`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3721772568363314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3721772568363314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3721772568363314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37505956725120915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37505956725120915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37505956725120915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37847074762276695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37847074762276695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37847074762276695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37169510085031193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37169510085031193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37169510085031193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37458935217095096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37458935217095096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37458935217095096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3780111177808284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3780111177808284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3780111177808284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37121445620677596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37121445620677596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37121445620677596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3741205620812799`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3741205620812799`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3741205620812799`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3775526296473189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3775526296473189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3775526296473189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37073551512737757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37073551512737757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37073551512737757`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3736537904202264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3736537904202264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3736537904202264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37709589537291593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37709589537291593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37709589537291593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37025885235445977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37025885235445977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37025885235445977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37318935689310423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37318935689310423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37318935689310423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3766412483180529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3766412483180529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3766412483180529`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3697847742225758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3697847742225758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3697847742225758`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3727275669499697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3727275669499697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3727275669499697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37618900784520387`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37618900784520387`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37618900784520387`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3693135724717603`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3693135724717603`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3693135724717603`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37226859329865747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37226859329865747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37226859329865747`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3757393590173467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3757393590173467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3757393590173467`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.36884540775447566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.36884540775447566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36884540775447566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37181269495096464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37181269495096464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37181269495096464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3752925747639503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3752925747639503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3752925747639503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.36838052536956256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.36838052536956256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36838052536956256`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3713600880181228`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3713600880181228`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3713600880181228`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3748488813192679`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3748488813192679`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3748488813192679`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3679191315209921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3679191315209921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3679191315209921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37091094298476934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37091094298476934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37091094298476934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3744084597174518`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3744084597174518`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3744084597174518`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3674613864784165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3674613864784165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3674613864784165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37046540712011894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37046540712011894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37046540712011894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3739714642224271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3739714642224271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3739714642224271`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3670074281196178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3670074281196178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3670074281196178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37002360759880165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37002360759880165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37002360759880165`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3735380344075731`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3735380344075731`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3735380344075731`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.366557374517241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.366557374517241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.366557374517241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.36958540340027896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.36958540340027896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36958540340027896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3731080370387588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3731080370387588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3731080370387588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3661110764287227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3661110764287227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3661110764287227`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3691512087817324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3691512087817324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3691512087817324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3726818934771003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3726818934771003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3726818934771003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3656689425727399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3656689425727399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3656689425727399`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3687209763769978`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3687209763769978`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3687209763769978`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3722595634838545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3722595634838545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3722595634838545`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3652309153070893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3652309153070893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3652309153070893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3682947621206081`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3682947621206081`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3682947621206081`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37184110929208497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37184110929208497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37184110929208497`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3647970448749941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3647970448749941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3647970448749941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3678726135085967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3678726135085967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3678726135085967`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37142658231454123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37142658231454123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37142658231454123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.36436736833267225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.36436736833267225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36436736833267225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3674545541941345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3674545541941345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3674545541941345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3710160232335974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3710160232335974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3710160232335974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.363941917143626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.363941917143626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.363941917143626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3670406223323272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3670406223323272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3670406223323272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37060946318509763`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37060946318509763`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37060946318509763`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3635207106313716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3635207106313716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3635207106313716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3666308310267146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3666308310267146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3666308310267146`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37020692487965756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37020692487965756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37020692487965756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3631037618530479`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.27`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3631037618530479`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.27`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3631037618530479`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.31356004786461183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.31356004786461183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31356004786461183`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.31383536421681857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.31383536421681857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31383536421681857`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3132881815293391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3132881815293391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3132881815293391`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3195895368846266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3195895368846266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3195895368846266`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.31999037425157356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.31999037425157356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.31999037425157356`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3191937452730519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3191937452730519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3191937452730519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.32517506506388894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.32517506506388894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32517506506388894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.32569413536812397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.32569413536812397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32569413536812397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.324662556664174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.324662556664174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.324662556664174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.33035365605005573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.33035365605005573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33035365605005573`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.33098420805218365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.33098420805218365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33098420805218365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.32973110714579523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.32973110714579523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.32973110714579523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.335158698948325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.335158698948325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.335158698948325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3358944718274068`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3358944718274068`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3358944718274068`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.33443229978684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.33443229978684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33443229978684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.33962036097949866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.33962036097949866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.33962036097949866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3404555424171196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3404555424171196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3404555424171196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3387958574398692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3387958574398692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3387958574398692`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.34376594703434715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.34376594703434715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34376594703434715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3446951353291373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3446951353291373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3446951353291373`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3428486782711208`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3428486782711208`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3428486782711208`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.34762021378893243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.34762021378893243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34762021378893243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3486383835845001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3486383835845001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3486383835845001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.34661514627081613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.34661514627081613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.34661514627081613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.35120564475814375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.35120564475814375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35120564475814375`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.35230811601049655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.35230811601049655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35230811601049655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.35011740307701894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.35011740307701894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35011740307701894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3545426916935058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3545426916935058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3545426916935058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.355725101544003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.355725101544003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.355725101544003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3533755864785848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3533755864785848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3533755864785848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.36054260683276845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.36054260683276845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36054260683276845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.36187294045882695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.36187294045882695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36187294045882695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.35922958357851803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.35922958357851803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.35922958357851803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.36575140374869897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.36575140374869897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36575140374869897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.3672154277726414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.3672154277726414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3672154277726414`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.3643065209685842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.3643065209685842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3643065209685842`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3702787342297755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3702787342297755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3702787342297755`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.37186397025162343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.37186397025162343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37186397025162343`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3687143146412484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3687143146412484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3687143146412484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.37421641915416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.37421641915416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37421641915416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.375911891983204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.375911891983204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.375911891983204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3725432991559067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3725432991559067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3725432991559067`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.37764215075459695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.37764215075459695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37764215075459695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3794381750442179`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3794381750442179`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3794381750442179`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3758698917151205`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3758698917151205`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3758698917151205`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.38062254052312167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.38062254052312167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38062254052312167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.38251054500546844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.38251054500546844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38251054500546844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3787596025901189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3787596025901189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3787596025901189`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.3832139124410555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.3832139124410555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3832139124410555`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.3851862761221804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.3851862761221804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3851862761221804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.3812678169823063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.3812678169823063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3812678169823063`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3854639713723078`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3854639713723078`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3854639713723078`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.38751390986827877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.38751390986827877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38751390986827877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3834414132753451`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3834414132753451`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3834414132753451`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.38741424184285345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.38741424184285345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38741424184285345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.38953569479520933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.38953569479520933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38953569479520933`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3853212008477117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3853212008477117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3853212008477117`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3891005616090873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3891005616090873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3891005616090873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3912881008178696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3912881008178696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3912881008178696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3869423931426422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3869423931426422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3869423931426422`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.39120161744422105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.39120161744422105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39120161744422105`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.39347929903691164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.39347929903691164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39347929903691164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3889546233413483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3889546233413483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3889546233413483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.39286539317885616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.39286539317885616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39286539317885616`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.39522382818109025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.39522382818109025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39522382818109025`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3905388349613814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3905388349613814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3905388349613814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}], 
       ",", "0.3941637362702705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}], 
       ",", "0.3941637362702705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3941637362702705`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}], 
       ",", "0.39659485550251034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}], 
       ",", "0.39659485550251034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39659485550251034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}], 
       ",", "0.3917655710592949`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}], 
       ",", "0.3917655710592949`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3917655710592949`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.39515596411640697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.39515596411640697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39515596411640697`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3976527995651661`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3976527995651661`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3976527995651661`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3926930637166508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3926930637166508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3926930637166508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.39589056265623745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.39589056265623745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39589056265623745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3984470688210742`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3984470688210742`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3984470688210742`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.39336888796061487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.39336888796061487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39336888796061487`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3964080258363516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3964080258363516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3964080258363516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3990189337550214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3990189337550214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3990189337550214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3938327714582869`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3938327714582869`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3938327714582869`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3967415868253724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3967415868253724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3967415868253724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3994022829466163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3994022829466163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3994022829466163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39411730083585444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39411730083585444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39411730083585444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.39691973617429305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.39691973617429305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39691973617429305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3996261701962911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3996261701962911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3996261701962911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.39425041083109524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.39425041083109524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39425041083109524`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3969660934517602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3969660934517602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3969660934517602`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3997146911114069`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3997146911114069`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3997146911114069`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39425525148044027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39425525148044027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39425525148044027`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3968999214724482`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3968999214724482`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3968999214724482`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39968752017568804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39968752017568804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39968752017568804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3941506796386324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3941506796386324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3941506796386324`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39673880574508874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39673880574508874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39673880574508874`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3995625993656178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3995625993656178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3995625993656178`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3939539290176901`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3939539290176901`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3939539290176901`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3964967701545596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3964967701545596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3964967701545596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3993542544332606`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3993542544332606`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3993542544332606`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39367872596795656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39367872596795656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39367872596795656`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3961863186661275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3961863186661275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3961863186661275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3990752586844184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3990752586844184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3990752586844184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.39333730867773625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.39333730867773625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39333730867773625`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39581796172639166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39581796172639166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39581796172639166`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39873635253389655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39873635253389655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39873635253389655`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3929399608298855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3929399608298855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3929399608298855`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39540014498699216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39540014498699216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39540014498699216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.398346181304569`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.398346181304569`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.398346181304569`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3924949314087079`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3924949314087079`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3924949314087079`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3949410212051371`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3949410212051371`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3949410212051371`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3979130801047552`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3979130801047552`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3979130801047552`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39201019310932717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39201019310932717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39201019310932717`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3944471603081905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3944471603081905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3944471603081905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3974437727592877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3974437727592877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3974437727592877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3914921641875563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3914921641875563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3914921641875563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.39392405085352883`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.39392405085352883`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39392405085352883`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3969438830191469`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3969438830191469`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3969438830191469`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.39094620005405345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.39094620005405345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39094620005405345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39337665790602905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39337665790602905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39337665790602905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39641850239579896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39641850239579896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39641850239579896`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39037714098274834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39037714098274834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39037714098274834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3928099214989309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3928099214989309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3928099214989309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3958726729140653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3958726729140653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3958726729140653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38978982616547836`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38978982616547836`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38978982616547836`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.392226476196214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.392226476196214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.392226476196214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3953091319889348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3953091319889348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3953091319889348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38918678939489504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38918678939489504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38918678939489504`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3916296437272028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3916296437272028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3916296437272028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39473128294949145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39473128294949145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39473128294949145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38857127187288754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38857127187288754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38857127187288754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.39102252829177575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.39102252829177575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39102252829177575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.39414230944579853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.39414230944579853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39414230944579853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.38794629926875535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.38794629926875535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38794629926875535`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3904074916775946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3904074916775946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3904074916775946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3935446402447994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3935446402447994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3935446402447994`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3873141674540494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3873141674540494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3873141674540494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38978633146351566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38978633146351566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38978633146351566`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39294013392807714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39294013392807714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39294013392807714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38667661405425163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38667661405425163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38667661405425163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38916117569246433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38916117569246433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38916117569246433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39233097240982745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39233097240982745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39233097240982745`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38603571074989707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38603571074989707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38603571074989707`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3885335308114099`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3885335308114099`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3885335308114099`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3917187153892111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3917187153892111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3917187153892111`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3853929157729125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3853929157729125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3853929157729125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3879047833027174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3879047833027174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3879047833027174`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3911047966151014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3911047966151014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3911047966151014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.38474957578547775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.38474957578547775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38474957578547775`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38727615624244244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38727615624244244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38727615624244244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3904904730804986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3904904730804986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3904904730804986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.384106863966671`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.384106863966671`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.384106863966671`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38664804795188107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38664804795188107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38664804795188107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3898761824595309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3898761824595309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3898761824595309`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38346515099163936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38346515099163936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38346515099163936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38602210722471353`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38602210722471353`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38602210722471353`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38926360931704257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38926360931704257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38926360931704257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3828260476802262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3828260476802262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3828260476802262`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3853988760942851`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3853988760942851`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3853988760942851`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3886533246665426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3886533246665426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3886533246665426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3821900677031302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3821900677031302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3821900677031302`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.38477903280270803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.38477903280270803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38477903280270803`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.388046034404049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.388046034404049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.388046034404049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3815578620609385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3815578620609385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3815578620609385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38416314652626865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38416314652626865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38416314652626865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38744233312753684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38744233312753684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38744233312753684`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38092997489429037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38092997489429037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38092997489429037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3835512313718859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3835512313718859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3835512313718859`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.386842257780199`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.386842257780199`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.386842257780199`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38030639815708056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38030639815708056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38030639815708056`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3829442558296774`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3829442558296774`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3829442558296774`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38624680059779026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38624680059779026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38624680059779026`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3796880764765248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3796880764765248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3796880764765248`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3823424525532136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3823424525532136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3823424525532136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3856562117924893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3856562117924893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3856562117924893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3790752253896665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3790752253896665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3790752253896665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.38174613383393563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.38174613383393563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38174613383393563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.38507082141634136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.38507082141634136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38507082141634136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3784681396988815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3784681396988815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3784681396988815`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38115535316234567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38115535316234567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38115535316234567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3844906989700007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3844906989700007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3844906989700007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3778668574734714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3778668574734714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3778668574734714`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38057047859468696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38057047859468696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38057047859468696`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3839162299151946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3839162299151946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3839162299151946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3772717294577477`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3772717294577477`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3772717294577477`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3799916681081694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3799916681081694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3799916681081694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38334758521877543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38334758521877543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38334758521877543`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37668290111810576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37668290111810576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37668290111810576`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37941906430314426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37941906430314426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37941906430314426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38278491697670397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38278491697670397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38278491697670397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3761005024008564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3761005024008564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3761005024008564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3788527091453834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3788527091453834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3788527091453834`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3822282829867554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3822282829867554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3822282829867554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.37552456393370814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.37552456393370814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37552456393370814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3782926958395609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3782926958395609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3782926958395609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38167779367065746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38167779367065746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38167779367065746`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3749551688539756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3749551688539756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3749551688539756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.377739109992038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.377739109992038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.377739109992038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3811335261814943`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3811335261814943`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3811335261814943`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3743923903924498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3743923903924498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3743923903924498`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3771919931015457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3771919931015457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3771919931015457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3805955469922923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3805955469922923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3805955469922923`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3738362592194074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3738362592194074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3738362592194074`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3766513651760741`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3766513651760741`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3766513651760741`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38006388456309786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38006388456309786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38006388456309786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37328679331236886`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37328679331236886`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37328679331236886`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.37611723873750336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.37611723873750336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37611723873750336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.37953855437707557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.37953855437707557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37953855437707557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.37274399147201726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.37274399147201726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37274399147201726`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3755894306475954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3755894306475954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3755894306475954`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37901938276857033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37901938276857033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37901938276857033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37220766638760944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37220766638760944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37220766638760944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3750681590199162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3750681590199162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3750681590199162`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37850659530314185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37850659530314185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37850659530314185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3716780227587058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3716780227587058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3716780227587058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3745533106897924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3745533106897924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3745533106897924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37800008525098505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37800008525098505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37800008525098505`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37115494756143946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37115494756143946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37115494756143946`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3740448491978426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3740448491978426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3740448491978426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3774998224144889`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3774998224144889`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3774998224144889`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3706383960216977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3706383960216977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3706383960216977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3735427311362228`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3735427311362228`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3735427311362228`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3770057695951241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3770057695951241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3770057695951241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3701283189845243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3701283189845243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3701283189845243`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3730469071096396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3730469071096396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3730469071096396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37651788257290425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37651788257290425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37651788257290425`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.36962466171471847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.36962466171471847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.36962466171471847`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37255732270303754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37255732270303754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37255732270303754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3760361107523551`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3760361107523551`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3760361107523551`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3691273647718176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3691273647718176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3691273647718176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37207391956017416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37207391956017416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37207391956017416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37556040148067904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37556040148067904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37556040148067904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3686363648399515`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.3`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3686363648399515`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3686363648399515`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37138529001139814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37138529001139814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37138529001139814`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37164839353982604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37164839353982604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37164839353982604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37112558902291587`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37112558902291587`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37112558902291587`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.37636924016174517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.37636924016174517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37636924016174517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.37675190330411884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.37675190330411884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37675190330411884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3759915500815523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3759915500815523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3759915500815523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38093662423365376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38093662423365376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38093662423365376`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38143167454420607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38143167454420607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38143167454420607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38044803736355187`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "0.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38044803736355187`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "0.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38044803736355187`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.3851239786145073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.3851239786145073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3851239786145073`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.3857247908765332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.3857247908765332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3857247908765332`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.3845310449220417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.3845310449220417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3845310449220417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.388964140556244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.388964140556244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.388964140556244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38966458789587316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38966458789587316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38966458789587316`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3882729162687366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3882729162687366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3882729162687366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3924866776956254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3924866776956254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3924866776956254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39328108759446245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39328108759446245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39328108759446245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39170276900388945`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39170276900388945`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39170276900388945`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39571826136241844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39571826136241844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39571826136241844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39660137604028883`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39660137604028883`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39660137604028883`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3948468637654158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3948468637654158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3948468637654158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3986829918299058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3986829918299058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3986829918299058`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3996499325272378`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3996499325272378`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3996499325272378`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3977289255923793`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "1.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3977289255923793`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "1.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3977289255923793`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.40140268236967236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.40140268236967236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40140268236967236`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.40244891711143926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.40244891711143926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40244891711143926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.40037042451171556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.40037042451171556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40037042451171556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.403897107901245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.403897107901245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.403897107901245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4050184223712193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4050184223712193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4050184223712193`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.40279082109143277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.40279082109143277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40279082109143277`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.40827841824260597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.40827841824260597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40827841824260597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.40953838064208387`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.40953838064208387`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40953838064208387`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.40703544262613794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "2.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.40703544262613794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "2.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40703544262613794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.41195299450915107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.41195299450915107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41195299450915107`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.4133379524138034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.4133379524138034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4133379524138034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.4105868106073354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.4105868106073354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4105868106073354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4150253001322075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4150253001322075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4150253001322075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4165233389478312`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4165233389478312`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4165233389478312`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4135476700258033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4135476700258033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4135476700258033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4175821864097483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4175821864097483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4175821864097483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4191828725121163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4191828725121163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4191828725121163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41600340818472475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "3.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41600340818472475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "3.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41600340818472475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4196966357940909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4196966357940909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "4.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4196966357940909`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4213908003889061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4213908003889061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "4.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4213908003889061`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41802575751638654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41802575751638654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "4.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41802575751638654`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4214308360099733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4214308360099733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "4.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4214308360099733`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4232103983917911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4232103983917911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "4.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4232103983917911`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4196758304547011`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "4.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4196758304547011`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "4.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4196758304547011`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.4228369749676453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.4228369749676453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4228369749676453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.42469477761460744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.42469477761460744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42469477761460744`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.4210049030976244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.4210049030976244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4210049030976244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4239588746775349`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4239588746775349`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4239588746775349`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42588856964511035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42588856964511035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42588856964511035`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4220559982747506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4220559982747506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4220559982747506`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42483445356296695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42483445356296695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42483445356296695`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4268303908647716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4268303908647716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4268303908647716`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4228663439679941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "5.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4228663439679941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "5.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4228663439679941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42549619613511075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42549619613511075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "6.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42549619613511075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4275533326614904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4275533326614904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "6.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4275533326614904`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.42346782670511285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.42346782670511285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "6.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42346782670511285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4261476123892407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4261476123892407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "6.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4261476123892407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4282882301986583`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4282882301986583`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "6.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4282882301986583`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4240370538637583`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "6.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4240370538637583`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "6.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4240370538637583`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "7.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4264579689868483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "7.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4264579689868483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "7.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4264579689868483`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "7.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4286734148596132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "7.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4286734148596132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "7.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4286734148596132`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "7.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.42427375157259417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "7.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.42427375157259417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "7.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42427375157259417`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.`", ",", "0.94018`", ",", "1.1666`"}], "}"}],
        ",", "0.42649056309615635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.`", ",", "0.94018`", ",", "1.1711`"}], "}"}],
        ",", "0.42649056309615635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "8.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42649056309615635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.`", ",", "0.94368`", ",", "1.1666`"}], "}"}],
        ",", "0.42877343340216556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.`", ",", "0.94368`", ",", "1.1711`"}], "}"}],
        ",", "0.42877343340216556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "8.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42877343340216556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.`", ",", "0.93668`", ",", "1.1666`"}], "}"}],
        ",", "0.4242399838275347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.`", ",", "0.93668`", ",", "1.1711`"}], "}"}],
        ",", "0.4242399838275347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "8.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4242399838275347`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4262970401526203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4262970401526203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "8.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4262970401526203`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42864096862521284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42864096862521284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "8.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42864096862521284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.423986372465184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "8.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.423986372465184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "8.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.423986372465184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42591903761099575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42591903761099575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "9.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42591903761099575`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42831852246398594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42831852246398594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "9.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42831852246398594`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.42355370212845306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.42355370212845306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "9.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42355370212845306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42539090037421323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42539090037421323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "9.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42539090037421323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42784116410024586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42784116410024586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "9.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42784116410024586`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4229756032771533`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "9.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4229756032771533`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "9.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4229756032771533`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "10.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42474037566280903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "10.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42474037566280903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "10.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42474037566280903`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "10.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4272372488468246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "10.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4272372488468246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "10.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4272372488468246`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "10.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.42227922351704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "10.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.42227922351704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "10.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42227922351704`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4239909741224427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4239909741224427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "11.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4239909741224427`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4265308080915597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4265308080915597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "11.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4265308080915597`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.42148755985389885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.42148755985389885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "11.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42148755985389885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42316185890563207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42316185890563207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "11.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42316185890563207`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4257414427603593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4257414427603593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "11.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4257414427603593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4206193435255973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "11.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4206193435255973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "11.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4206193435255973`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42226830028255397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42226830028255397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "12.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42226830028255397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42488480000882856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42488480000882856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "12.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42488480000882856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41968947435249393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41968947435249393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "12.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41968947435249393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.42132420527067077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.42132420527067077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "12.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42132420527067077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42397511245758884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42397511245758884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "12.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42397511245758884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41871153718587983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "12.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41871153718587983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "12.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41871153718587983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "13.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4203403389085503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "13.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4203403389085503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "13.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4203403389085503`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "13.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4230234190652216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "13.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4230234190652216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "13.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4230234190652216`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "13.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41769602757863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "13.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41769602757863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "13.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41769602757863`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4193261882982057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4193261882982057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "14.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4193261882982057`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42203945102681034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42203945102681034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "14.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42203945102681034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41665219193030034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41665219193030034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "14.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41665219193030034`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4182895463092975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4182895463092975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "14.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4182895463092975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4210312085953381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4210312085953381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "14.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4210312085953381`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41558761876188094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "14.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41558761876188094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "14.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41558761876188094`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4172364433883753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4172364433883753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "15.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4172364433883753`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.42000490116053085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.42000490116053085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "15.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.42000490116053085`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41450816240955257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41450816240955257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "15.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41450816240955257`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4161727194469623`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4161727194469623`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "15.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4161727194469623`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.41896653243760135`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.41896653243760135`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "15.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41896653243760135`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41341950117602794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "15.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41341950117602794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "15.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41341950117602794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "16.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.41510289426272934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "16.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.41510289426272934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "16.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41510289426272934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "16.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.41792075947264345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "16.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.41792075947264345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "16.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41792075947264345`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "16.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4123260196813214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "16.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4123260196813214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "16.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4123260196813214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.41403060796679786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.41403060796679786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "17.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41403060796679786`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4168713424610457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4168713424610457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "17.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4168713424610457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41123123993391525`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41123123993391525`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "17.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41123123993391525`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.41295907349666955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.41295907349666955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "17.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41295907349666955`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.41582160669851126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.41582160669851126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "17.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41582160669851126`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.41013826413240007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "17.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.41013826413240007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "17.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41013826413240007`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.41189173677845364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.41189173677845364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "18.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41189173677845364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4147750854330952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4147750854330952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "18.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4147750854330952`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4090504486600303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4090504486600303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "18.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4090504486600303`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4108296160652675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4108296160652675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "18.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4108296160652675`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4137328945322447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4137328945322447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "18.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4137328945322447`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4079687274789369`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "18.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4079687274789369`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "18.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4079687274789369`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "19.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.40977480834900415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "19.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.40977480834900415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "19.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40977480834900415`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "19.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.41269719620653245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "19.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.41269719620653245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "19.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41269719620653245`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "19.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.40689511805117673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "19.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.40689511805117673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "19.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40689511805117673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.40872910937857754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.40872910937857754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "20.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40872910937857754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.41166985819421037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.41166985819421037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "20.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41166985819421037`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4058313544224123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4058313544224123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "20.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4058313544224123`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.40769374909773465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.40769374909773465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "20.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40769374909773465`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.41065216893624934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.41065216893624934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "20.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.41065216893624934`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.40477860683332084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "20.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.40477860683332084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "20.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40477860683332084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4066695288130672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4066695288130672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "21.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4066695288130672`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4096449828159544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4096449828159544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "21.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4096449828159544`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.4037376244649715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.4037376244649715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "21.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4037376244649715`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4056575217629701`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4056575217629701`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "21.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4056575217629701`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.40864942281173344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.40864942281173344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "21.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40864942281173344`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.40270943147203475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "21.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.40270943147203475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "21.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40270943147203475`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "22.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.40465834393713546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "22.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.40465834393713546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "22.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40465834393713546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "22.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.40766614744131885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "22.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.40766614744131885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "22.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40766614744131885`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "22.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.401694602046674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "22.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.401694602046674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "22.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.401694602046674`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4036725374197947`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4036725374197947`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "23.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4036725374197947`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.40669573774191853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.40669573774191853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "23.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40669573774191853`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.40069363994879964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.40069363994879964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "23.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40069363994879964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4027005283757831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4027005283757831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "23.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4027005283757831`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4057386549882028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4057386549882028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "23.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4057386549882028`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3997069368025756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "23.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3997069368025756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "23.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3997069368025756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.40174215805080915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.40174215805080915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "24.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40174215805080915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4047947714852459`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4047947714852459`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "24.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4047947714852459`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39873430361020273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39873430361020273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "24.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39873430361020273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.4007981670566931`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.4007981670566931`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "24.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4007981670566931`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.403864859449785`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.403864859449785`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "24.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.403864859449785`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39777644952924673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "24.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39777644952924673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "24.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39777644952924673`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "25.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3998685392347322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "25.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3998685392347322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "25.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3998685392347322`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "25.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4029489278521709`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "25.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4029489278521709`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "25.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4029489278521709`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "25.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3968333341330965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "25.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3968333341330965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "25.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3968333341330965`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3989533563135677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3989533563135677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "26.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3989533563135677`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.402047082435645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.402047082435645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "26.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.402047082435645`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3959050157996609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3959050157996609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "26.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3959050157996609`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3980526280216605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3980526280216605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "26.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3980526280216605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.4011593516007694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.4011593516007694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "26.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.4011593516007694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3949914816935508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "26.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3949914816935508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "26.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3949914816935508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3971660311907409`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3971660311907409`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "27.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3971660311907409`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.40028543919660936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.40028543919660936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "27.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.40028543919660936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.394092393045022`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.394092393045022`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "27.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.394092393045022`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3962938138799592`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3962938138799592`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "27.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3962938138799592`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3994256027424336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3994256027424336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "27.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3994256027424336`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3932079743126718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "27.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3932079743126718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "27.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3932079743126718`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "28.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.395435820591208`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "28.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.395435820591208`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "28.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.395435820591208`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "28.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39857971158842204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "28.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39857971158842204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "28.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39857971158842204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "28.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.39233805494231433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "28.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.39233805494231433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "28.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39233805494231433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39459193402338577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39459193402338577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "29.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39459193402338577`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39774765971064396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39774765971064396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "29.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39774765971064396`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3914825054109323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3914825054109323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "29.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3914825054109323`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39376191929455856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39376191929455856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "29.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39376191929455856`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.396929226225791`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.396929226225791`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "29.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.396929226225791`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3906410741707304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "29.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3906410741707304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "29.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3906410741707304`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3929456354143213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3929456354143213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "30.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3929456354143213`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3961242848288354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3961242848288354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "30.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3961242848288354`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38981360847305596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38981360847305596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "30.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38981360847305596`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39214291826833547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39214291826833547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "30.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39214291826833547`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39533268249540643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39533268249540643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "30.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39533268249540643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38899993240351766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "30.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38899993240351766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "30.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38899993240351766`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "31.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39135357358122735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "31.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39135357358122735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "31.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39135357358122735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "31.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39455423604964635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "31.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39455423604964635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "31.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39455423604964635`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "31.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3881998408815884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "31.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3881998408815884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "31.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3881998408815884`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.39057740257025036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.39057740257025036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "32.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39057740257025036`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39378875125836993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39378875125836993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "32.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39378875125836993`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38741312012557516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38741312012557516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "32.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38741312012557516`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38981411975724845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38981411975724845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "32.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38981411975724845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3930359705610211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3930359705610211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "32.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3930359705610211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38663949042204765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "32.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38663949042204765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "32.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38663949042204765`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3890635537985906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3890635537985906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "33.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3890635537985906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3922957108293052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3922957108293052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "33.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3922957108293052`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3858787561332613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3858787561332613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "33.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3858787561332613`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3883254753973115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3883254753973115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "33.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3883254753973115`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39156775756609064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39156775756609064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "33.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39156775756609064`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3851306839967494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "33.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3851306839967494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "33.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3851306839967494`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "34.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3875996541692969`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "34.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3875996541692969`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "34.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3875996541692969`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "34.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3908518918372164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "34.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3908518918372164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "34.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3908518918372164`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "34.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38439503923133234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "34.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38439503923133234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "34.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38439503923133234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3868858110282275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3868858110282275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "35.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3868858110282275`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.39014783978592915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.39014783978592915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "35.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.39014783978592915`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3836715362779778`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3836715362779778`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "35.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3836715362779778`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38618386497255003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38618386497255003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "35.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38618386497255003`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3894555241322569`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3894555241322569`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "35.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3894555241322569`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38296008200733145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "35.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38296008200733145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "35.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38296008200733145`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.385493406113365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.385493406113365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "36.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.385493406113365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3887745478820792`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3887745478820792`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "36.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3887745478820792`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3822602659253049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3822602659253049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "36.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3822602659253049`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3848142739692086`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3848142739692086`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "36.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3848142739692086`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3881047500094508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3881047500094508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "36.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3881047500094508`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3815719174770014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "36.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3815719174770014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "36.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3815719174770014`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "37.4`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38414623823882865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "37.4`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38414623823882865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "37.4`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38414623823882865`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "37.4`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.387445906622706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "37.4`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.387445906622706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "37.4`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.387445906622706`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "37.4`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.3808948044741118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "37.4`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.3808948044741118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "37.4`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3808948044741118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38348907436191254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38348907436191254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "38.`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38348907436191254`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3867977974116894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3867977974116894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "38.`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3867977974116894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.38022869451476077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.38022869451476077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "38.`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38022869451476077`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.6`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38284255568717906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.6`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38284255568717906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "38.6`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38284255568717906`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.6`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38616020401237144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.6`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38616020401237144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "38.6`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38616020401237144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.6`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37957335982306173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "38.6`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37957335982306173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "38.6`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37957335982306173`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.2`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.3822064643247958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.2`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.3822064643247958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "39.2`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3822064643247958`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.2`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.3855329112617591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.2`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.3855329112617591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "39.2`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.3855329112617591`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.2`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37892857653914136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.2`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37892857653914136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "39.2`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37892857653914136`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.8`", ",", "0.94018`", ",", "1.1666`"}], 
        "}"}], ",", "0.38158071202612703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.8`", ",", "0.94018`", ",", "1.1711`"}], 
        "}"}], ",", "0.38158071202612703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "39.8`", ",", "0.94018`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38158071202612703`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.8`", ",", "0.94368`", ",", "1.1666`"}], 
        "}"}], ",", "0.38491583365117393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.8`", ",", "0.94368`", ",", "1.1711`"}], 
        "}"}], ",", "0.38491583365117393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "39.8`", ",", "0.94368`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.38491583365117393`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.8`", ",", "0.93668`", ",", "1.1666`"}], 
        "}"}], ",", "0.37829425520854937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.36`", ",", "39.8`", ",", "0.93668`", ",", "1.1711`"}], 
        "}"}], ",", "0.37829425520854937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.36`", ",", "39.8`", ",", "0.93668`", ",", "1.1621000000000001`"}], 
        "}"}], ",", "0.37829425520854937`"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.6346300152018137`*^9, 3.634630049725461*^9}}]
}, Closed]],

Cell["\<\
The table of in the cell above contains the solution of the renormalization \
group equations of the SM (allowing for different boundary conditions for the \
quartic coupling). The solution is interpolated to avoid slow numerical \
integrations.\
\>", "Text",
 CellChangeTimes->{{3.638562584486388*^9, 3.638562630825861*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]atMTint", "=", 
   RowBox[{"Quiet", "@", 
    RowBox[{"Interpolation", "[", "tableint", "]"}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.634630064211915*^9, 3.634630064212655*^9}, {
  3.638562383413023*^9, 3.6385624951936073`*^9}, {3.638562565328855*^9, 
  3.638562565760898*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["High - Scale", "Subsection",
 CellChangeTimes->{{3.6251722918352222`*^9, 3.6251723019525843`*^9}, {
  3.628108731774048*^9, 3.628108731789188*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"positiveQ", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Im", "[", "x", "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{"x", ">", "0"}], ",", "False"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "MhpoleHSS", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MhpoleHSS", "[", 
   RowBox[{
    RowBox[{"mtilde_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ1_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ2_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ3_", "?", "positiveQ"}], ",", 
    RowBox[{"mU1_", "?", "positiveQ"}], ",", 
    RowBox[{"mU2_", "?", "positiveQ"}], ",", 
    RowBox[{"mU3_", "?", "positiveQ"}], ",", 
    RowBox[{"mD1_", "?", "positiveQ"}], ",", 
    RowBox[{"mD2_", "?", "positiveQ"}], ",", 
    RowBox[{"mD3_", "?", "positiveQ"}], ",", 
    RowBox[{"mE1_", "?", "positiveQ"}], ",", 
    RowBox[{"mE2_", "?", "positiveQ"}], ",", 
    RowBox[{"mE3_", "?", "positiveQ"}], ",", 
    RowBox[{"mL1_", "?", "positiveQ"}], ",", 
    RowBox[{"mL2_", "?", "positiveQ"}], ",", 
    RowBox[{"mL3_", "?", "positiveQ"}], ",", 
    RowBox[{"mA_", "?", "positiveQ"}], ",", 
    RowBox[{"Q\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"M1_", "?", "NumericQ"}], ",", 
    RowBox[{"M2_", "?", "NumericQ"}], ",", 
    RowBox[{"M3_", "?", "NumericQ"}], ",", 
    RowBox[{"tan\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"Xt_", "?", "NumericQ"}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tmax", "=", 
       RowBox[{"Rationalize", "[", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox["mtilde", "MT"], "]"}], ",", 
         SuperscriptBox["10", 
          RowBox[{"-", "5"}]]}], "]"}]}], ",", "\[Lambda]mtilde", ",", 
      "\[Lambda]MT"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Lambda]mtilde", "=", 
      RowBox[{
       RowBox[{"\[Lambda]HSS", "[", 
        RowBox[{
        "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
         ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
         "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", 
         ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
         ",", "Xt", ",", "opts"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["g", "1"], "\[Rule]", 
          RowBox[{
           SubscriptBox["g", "1"], "[", "tmax", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "2"], "\[Rule]", 
          RowBox[{
           SubscriptBox["g", "2"], "[", "tmax", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "3"], "\[Rule]", 
          RowBox[{
           SubscriptBox["g", "3"], "[", "tmax", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "t"], "\[Rule]", 
          RowBox[{
           SubscriptBox["g", "t"], "[", "tmax", "]"}]}], ",", 
         RowBox[{"\[Lambda]", "\[Rule]", 
          RowBox[{"\[Lambda]", "[", "tmax", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "\[Tau]"], "\[Rule]", 
          RowBox[{
           SubscriptBox["g", "\[Tau]"], "[", "tmax", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "b"], "\[Rule]", 
          RowBox[{
           SubscriptBox["g", "b"], "[", "tmax", "]"}]}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Lambda]MT", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"\[Lambda]", "[", "0", "]"}]}], "/.", 
        RowBox[{"SMrun", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["g", "1"], ",", 
            SubscriptBox["g", "2"], ",", 
            SubscriptBox["g", "3"], ",", 
            SubscriptBox["g", "t"], ",", "\[Lambda]", ",", 
            SubscriptBox["g", "\[Tau]"], ",", 
            SubscriptBox["g", "b"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["g", "1"], "[", "0", "]"}], "\[Equal]", "g1MT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "2"], "[", "0", "]"}], "\[Equal]", "g2MT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "3"], "[", "0", "]"}], "\[Equal]", "g3MT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "t"], "[", "0", "]"}], "\[Equal]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                 RowBox[{"[", "4", "]"}], "]"}], "\[Equal]", "0"}], ",", 
               "gtMT2l", ",", "gtMT3l"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"\[Lambda]", "[", "tmax", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["1", "2"], "\[Lambda]mtilde"}]}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "b"], "[", "0", "]"}], "\[Equal]", "gbMT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "\[Tau]"], "[", "0", "]"}], "\[Equal]", 
             "g\[Tau]MT"}]}], "}"}], ",", "0", ",", "tmax", ",", 
          "optsSMrun"}], "]"}]}], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Mhpole", "[", "\[Lambda]MT", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6200439004381037`*^9, 3.62004401421668*^9}, {
   3.6200440567762423`*^9, 3.620044111288514*^9}, {3.62004414554535*^9, 
   3.620044220473219*^9}, {3.620119729736141*^9, 3.620119795477969*^9}, {
   3.620119995494102*^9, 3.6201200185884533`*^9}, {3.620120374761421*^9, 
   3.620120411152298*^9}, {3.62012059134039*^9, 3.6201206299114513`*^9}, {
   3.62012391285954*^9, 3.620123934632702*^9}, {3.620124649276807*^9, 
   3.620124650732354*^9}, {3.620125360416038*^9, 3.620125371846684*^9}, {
   3.620125946026581*^9, 3.620125958693842*^9}, {3.620127083161211*^9, 
   3.620127089007598*^9}, 3.6201271888244553`*^9, {3.6201273534852333`*^9, 
   3.620127355552799*^9}, {3.620220028809361*^9, 3.62022002967591*^9}, {
   3.620306586520327*^9, 3.6203065916317797`*^9}, {3.620307023918005*^9, 
   3.6203070240316277`*^9}, {3.620307252514659*^9, 3.620307252631892*^9}, {
   3.621157052357183*^9, 3.621157107669544*^9}, {3.621157222797364*^9, 
   3.621157245308032*^9}, {3.6211935897248383`*^9, 3.621193590582821*^9}, {
   3.6223541483281193`*^9, 3.622354149206575*^9}, {3.622370986780356*^9, 
   3.622370992506105*^9}, {3.622371256164768*^9, 3.6223712568722363`*^9}, 
   3.622783815048378*^9, 3.622789268413698*^9, {3.622890278646159*^9, 
   3.622890280084846*^9}, {3.625167839061376*^9, 3.625167842538499*^9}, {
   3.627070148855397*^9, 3.62707027998076*^9}, {3.6270705069245462`*^9, 
   3.6270705094648237`*^9}, 3.627070579290236*^9, {3.6270706261080523`*^9, 
   3.627070630117609*^9}, {3.62810342848899*^9, 3.628103660632641*^9}, 
   3.628103842556892*^9, 3.62810401110709*^9, 3.628104047338917*^9, {
   3.628108071369974*^9, 3.6281080723317747`*^9}, {3.6281081443531322`*^9, 
   3.628108148941244*^9}, {3.62810824310456*^9, 3.628108248405758*^9}, {
   3.6281082838910646`*^9, 3.628108292083242*^9}, {3.62810832474*^9, 
   3.628108325952907*^9}, {3.628108387323134*^9, 3.628108422828691*^9}, {
   3.628108527409453*^9, 3.62810854327169*^9}, {3.628108611733378*^9, 
   3.62810868076579*^9}, {3.628108982602491*^9, 3.62810901053065*^9}, {
   3.634541282264557*^9, 3.6345412833974257`*^9}, 3.6346740869319353`*^9, 
   3.6346741201977158`*^9, 3.6346741813054237`*^9, {3.6346743719910097`*^9, 
   3.634674374506263*^9}, 3.635517521716629*^9, {3.63557161631813*^9, 
   3.635571629627192*^9}, {3.635571816724773*^9, 3.635571912566331*^9}, 
   3.6356882017362823`*^9, {3.636197850406645*^9, 3.636197861620981*^9}, {
   3.63639373101935*^9, 3.63639374322254*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "MhpoleHSSfast", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solSM2l", "=", 
   RowBox[{"SMrun", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["g", "1"], ",", 
       SubscriptBox["g", "2"], ",", 
       SubscriptBox["g", "3"], ",", 
       SubscriptBox["g", "t"], ",", "\[Lambda]", ",", 
       SubscriptBox["g", "\[Tau]"], ",", 
       SubscriptBox["g", "b"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["g", "1"], "[", "0", "]"}], "\[Equal]", "g1MT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "2"], "[", "0", "]"}], "\[Equal]", "g2MT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "3"], "[", "0", "]"}], "\[Equal]", "g3MT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "t"], "[", "0", "]"}], "\[Equal]", "gtMT2l"}], ",", 
       RowBox[{
        RowBox[{"\[Lambda]", "[", "0", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox["1", "2"], "\[Lambda]MT"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "b"], "[", "0", "]"}], "\[Equal]", "gbMT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "\[Tau]"], "[", "0", "]"}], "\[Equal]", 
        "g\[Tau]MT"}]}], "}"}], ",", "0", ",", "40", ",", "optsSMrun"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solSM3l", "=", 
   RowBox[{"SMrun", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["g", "1"], ",", 
       SubscriptBox["g", "2"], ",", 
       SubscriptBox["g", "3"], ",", 
       SubscriptBox["g", "t"], ",", "\[Lambda]", ",", 
       SubscriptBox["g", "\[Tau]"], ",", 
       SubscriptBox["g", "b"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["g", "1"], "[", "0", "]"}], "\[Equal]", "g1MT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "2"], "[", "0", "]"}], "\[Equal]", "g2MT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "3"], "[", "0", "]"}], "\[Equal]", "g3MT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "t"], "[", "0", "]"}], "\[Equal]", "gtMT3l"}], ",", 
       RowBox[{
        RowBox[{"\[Lambda]", "[", "0", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox["1", "2"], "\[Lambda]MT"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "b"], "[", "0", "]"}], "\[Equal]", "gbMT"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["g", "\[Tau]"], "[", "0", "]"}], "\[Equal]", 
        "g\[Tau]MT"}]}], "}"}], ",", "0", ",", "40", ",", "optsSMrun"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"solutionSMRGEs", "=", 
    RowBox[{"solSM3l", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g1", "\[Rule]", "\"\<g1\>\""}], ",", 
       RowBox[{"g2", "\[Rule]", "\"\<g2\>\""}], ",", 
       RowBox[{"g3", "\[Rule]", "\"\<g3\>\""}], ",", 
       RowBox[{"gt", "\[Rule]", "\"\<gt\>\""}], ",", 
       RowBox[{"\[Lambda]", "\[Rule]", "\"\<\[Lambda]\>\""}], ",", 
       RowBox[{"g\[Tau]", "\[Rule]", "\"\<g\[Tau]\>\""}], ",", 
       RowBox[{"gb", "->", "\"\<gb\>\""}]}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "This", " ", "solution", " ", "is", " ", "an", " ", "external", " ", 
    "variable", " ", "for", " ", 
    RowBox[{"convenience", "."}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MhpoleHSSfast", "[", 
   RowBox[{
    RowBox[{"mtilde_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ1_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ2_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ3_", "?", "positiveQ"}], ",", 
    RowBox[{"mU1_", "?", "positiveQ"}], ",", 
    RowBox[{"mU2_", "?", "positiveQ"}], ",", 
    RowBox[{"mU3_", "?", "positiveQ"}], ",", 
    RowBox[{"mD1_", "?", "positiveQ"}], ",", 
    RowBox[{"mD2_", "?", "positiveQ"}], ",", 
    RowBox[{"mD3_", "?", "positiveQ"}], ",", 
    RowBox[{"mE1_", "?", "positiveQ"}], ",", 
    RowBox[{"mE2_", "?", "positiveQ"}], ",", 
    RowBox[{"mE3_", "?", "positiveQ"}], ",", 
    RowBox[{"mL1_", "?", "positiveQ"}], ",", 
    RowBox[{"mL2_", "?", "positiveQ"}], ",", 
    RowBox[{"mL3_", "?", "positiveQ"}], ",", 
    RowBox[{"mA_", "?", "positiveQ"}], ",", 
    RowBox[{"Q\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"M1_", "?", "NumericQ"}], ",", 
    RowBox[{"M2_", "?", "NumericQ"}], ",", 
    RowBox[{"M3_", "?", "NumericQ"}], ",", 
    RowBox[{"tan\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"Xt_", "?", "NumericQ"}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Lambda]mtilde", ",", "evaluate", ",", "tmtilde", ",", 
      "\[Lambda]\[Lambda]"}], "}"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"tmtilde", "=", 
       RowBox[{"Log", "[", 
        FractionBox["mtilde", "MT"], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"evaluate", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Lambda]\[Lambda]", "\[Rule]", 
           RowBox[{"\[Lambda]", "[", "tmtilde", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["g", "t"], "\[Rule]", 
           RowBox[{"gt", "[", "tmtilde", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["g", "3"], "\[Rule]", 
           RowBox[{"g3", "[", "tmtilde", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["g", "2"], "\[Rule]", 
           RowBox[{"g2", "[", "tmtilde", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["g", "1"], "\[Rule]", 
           RowBox[{"g1", "[", "tmtilde", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["g", "b"], "\[Rule]", 
           RowBox[{"gb", "[", "tmtilde", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["g", "\[Tau]"], "\[Rule]", 
           RowBox[{"g\[Tau]", "[", "tmtilde", "]"}]}]}], "}"}], "/.", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
            RowBox[{"[", "4", "]"}], "]"}], "\[Equal]", "0"}], ",", "solSM2l",
           ",", "solSM3l"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"\[Lambda]mtilde", "=", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Lambda]HSS", "[", 
           RowBox[{
           "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
            "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1",
             ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
            "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
            "tan\[Beta]", ",", "Xt", ",", "opts"}], "]"}], "/.", "evaluate"}],
          "/.", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]\[Lambda]", "\[Rule]", "\[Lambda]"}], "}"}]}], 
        ")"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Mhpole", "[", 
       RowBox[{"Quiet", "@", 
        RowBox[{"\[Lambda]atMTint", "[", 
         RowBox[{"\[Lambda]mtilde", ",", "tmtilde", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
              RowBox[{"[", "4", "]"}], "]"}], "\[Equal]", "0"}], ",", 
            "gtMT2l", ",", "gtMT3l"}], "]"}], ",", "g3MT"}], "]"}]}], "]"}]}],
      ")"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6200439004381037`*^9, 3.62004401421668*^9}, {
   3.6200440567762423`*^9, 3.620044111288514*^9}, {3.62004414554535*^9, 
   3.620044220473219*^9}, {3.620119729736141*^9, 3.620119795477969*^9}, {
   3.620119995494102*^9, 3.6201200185884533`*^9}, {3.620120374761421*^9, 
   3.620120411152298*^9}, {3.62012059134039*^9, 3.6201206299114513`*^9}, {
   3.62012391285954*^9, 3.620123934632702*^9}, {3.620124649276807*^9, 
   3.620124650732354*^9}, {3.620125360416038*^9, 3.620125371846684*^9}, {
   3.620125946026581*^9, 3.620125958693842*^9}, {3.620127083161211*^9, 
   3.620127089007598*^9}, 3.6201271888244553`*^9, {3.6201273534852333`*^9, 
   3.620127355552799*^9}, {3.620220028809361*^9, 3.62022002967591*^9}, {
   3.620306586520327*^9, 3.6203065916317797`*^9}, {3.620307023918005*^9, 
   3.6203070240316277`*^9}, {3.620307252514659*^9, 3.620307252631892*^9}, {
   3.621157052357183*^9, 3.621157107669544*^9}, {3.621157222797364*^9, 
   3.621157245308032*^9}, {3.6211935897248383`*^9, 3.621193590582821*^9}, {
   3.621520586832548*^9, 3.6215205906136847`*^9}, {3.6215206760725813`*^9, 
   3.62152070636677*^9}, {3.62152085311343*^9, 3.621520858656086*^9}, {
   3.6215209109659443`*^9, 3.621520952739449*^9}, {3.621521137587742*^9, 
   3.621521148995653*^9}, {3.62152130564041*^9, 3.621521309623974*^9}, {
   3.6215214207634563`*^9, 3.621521420940029*^9}, {3.62152148614958*^9, 
   3.621521486401306*^9}, 3.62152156236625*^9, {3.621521856048818*^9, 
   3.621521864967599*^9}, {3.621521897842627*^9, 3.621521950777298*^9}, {
   3.621522745986074*^9, 3.6215227889371853`*^9}, {3.621522824205729*^9, 
   3.621522902407538*^9}, {3.6216613767899218`*^9, 3.621661379166711*^9}, {
   3.6216617976525803`*^9, 3.6216618054931393`*^9}, {3.622176882224999*^9, 
   3.622176916832407*^9}, {3.622354230999218*^9, 3.622354264027398*^9}, {
   3.622370968749147*^9, 3.6223709815104523`*^9}, {3.622371079357951*^9, 
   3.62237109262851*^9}, {3.622371585883605*^9, 3.6223716050995007`*^9}, {
   3.622448205124176*^9, 3.622448212127945*^9}, {3.622783472730138*^9, 
   3.622783478827718*^9}, {3.622784004698971*^9, 3.62278400784019*^9}, {
   3.62278469730939*^9, 3.622784701484828*^9}, {3.622883940292934*^9, 
   3.622883950132716*^9}, 3.6228841034593277`*^9, 3.6228841429689074`*^9, {
   3.622884507851056*^9, 3.6228845859707117`*^9}, {3.622884648367023*^9, 
   3.622884659071587*^9}, {3.622885663356473*^9, 3.622885666490945*^9}, {
   3.622885697256632*^9, 3.62288570950738*^9}, 3.62288581558117*^9, {
   3.622886298933775*^9, 3.622886317489414*^9}, 3.62288794695895*^9, {
   3.62288838486686*^9, 3.622888386546103*^9}, {3.6228885892388353`*^9, 
   3.622888593031371*^9}, {3.6228889397624598`*^9, 3.622888941891099*^9}, {
   3.6228890832031603`*^9, 3.622889083594805*^9}, 3.622889776534156*^9, {
   3.622890490803631*^9, 3.622890500986258*^9}, {3.622890563114365*^9, 
   3.6228905828498707`*^9}, {3.6228906243790083`*^9, 3.622890634506732*^9}, {
   3.625168494704246*^9, 3.625168500051457*^9}, {3.625171274817027*^9, 
   3.625171276108211*^9}, {3.625172330172715*^9, 3.6251723306635313`*^9}, {
   3.625173700295948*^9, 3.62517370588754*^9}, {3.626446614620759*^9, 
   3.6264466267086353`*^9}, {3.626447313290813*^9, 3.6264473177122602`*^9}, {
   3.6270706340375032`*^9, 3.627070723382229*^9}, 3.627070778980907*^9, {
   3.627070893114724*^9, 3.627070907013871*^9}, {3.6278843087727413`*^9, 
   3.627884317179058*^9}, 3.628104169111478*^9, {3.628108697169813*^9, 
   3.628108719015168*^9}, {3.628109028483128*^9, 3.628109044495627*^9}, {
   3.634541291979786*^9, 3.634541325557482*^9}, {3.6346740893204603`*^9, 
   3.634674093146641*^9}, {3.634674371997107*^9, 3.6346743745127687`*^9}, 
   3.635517495280038*^9, {3.636197898861512*^9, 3.6361979139867764`*^9}, {
   3.6363675294389057`*^9, 3.636367573539629*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Split", "Subsection",
 CellChangeTimes->{{3.62517230955968*^9, 3.6251723183531322`*^9}}],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "g1SM", ",", "g2SM", ",", "g3SM", ",", "gtSM", ",", "evaluateintmtilde", 
     ",", "evaluateintmsplit", ",", "\[Lambda]Splitmtilde", ",", 
     "gtSplitmsplit", ",", "g1utmtilde", ",", "g2utmtilde", ",", "g1dtmtilde",
      ",", "g2dtmtilde", ",", "\[Lambda]Splitsplit", ",", "tmtilde", ",", 
     "tmsplit", ",", "solsplit", ",", "rules", ",", "\[Lambda]SMtmsplit", ",",
      "\[Lambda]SMMT"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rules", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["g", "1"], "->", "g1"}], ",", 
       RowBox[{
        SubscriptBox["g", "2"], "->", "g2"}], ",", 
       RowBox[{
        SubscriptBox["g", "3"], "->", "g3"}], ",", 
       RowBox[{
        SubscriptBox["g", "t"], "->", "gt"}], ",", 
       RowBox[{
        SubscriptBox["g", "\[Tau]"], "->", "g\[Tau]"}], ",", 
       RowBox[{
        SubscriptBox["g", "b"], "->", "gb"}], ",", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "u"}]], "->", "gtildeu"}], ",", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "u"}]], "->", "gtilde2u"}], ",", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"1", " ", "d"}]], "->", "gtilded"}], ",", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["g", "~"], 
         RowBox[{"2", " ", "d"}]], "->", "gtilde2d"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g1SM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"g1", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g2SM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"g2", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g3SM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"g3", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gtSM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"gt", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"evaluateintmtilde", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Rule]", 
         RowBox[{"#", "[", "tmtilde", "]"}]}], "&"}], "/@", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         SubscriptBox["g", "t"], ",", 
         SubscriptBox["g", "3"], ",", 
         SubscriptBox["g", "2"], ",", 
         SubscriptBox["g", "1"], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", "u"}]], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", "u"}]], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", "d"}]], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", "d"}]], ",", 
         SubscriptBox["g", "b"], ",", 
         SubscriptBox["g", "\[Tau]"]}], "}"}]}], ")"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"evaluateintmsplit", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Rule]", 
         RowBox[{"#", "[", "tmsplit", "]"}]}], "&"}], "/@", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         SubscriptBox["g", "t"], ",", 
         SubscriptBox["g", "3"], ",", 
         SubscriptBox["g", "2"], ",", 
         SubscriptBox["g", "1"], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", "u"}]], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", "u"}]], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"1", "d"}]], ",", 
         SubscriptBox[
          OverscriptBox["g", "~"], 
          RowBox[{"2", "d"}]], ",", 
         SubscriptBox["g", "b"], ",", 
         SubscriptBox["g", "\[Tau]"]}], "}"}]}], ")"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MhpoleSplit", "[", 
      RowBox[{
       RowBox[{"mtilde_", "?", "positiveQ"}], ",", 
       RowBox[{"msplit_", "?", "positiveQ"}], ",", 
       RowBox[{"mQ1_", "?", "positiveQ"}], ",", 
       RowBox[{"mQ2_", "?", "positiveQ"}], ",", 
       RowBox[{"mQ3_", "?", "positiveQ"}], ",", 
       RowBox[{"mU1_", "?", "positiveQ"}], ",", 
       RowBox[{"mU2_", "?", "positiveQ"}], ",", 
       RowBox[{"mU3_", "?", "positiveQ"}], ",", 
       RowBox[{"mD1_", "?", "positiveQ"}], ",", 
       RowBox[{"mD2_", "?", "positiveQ"}], ",", 
       RowBox[{"mD3_", "?", "positiveQ"}], ",", 
       RowBox[{"mE1_", "?", "positiveQ"}], ",", 
       RowBox[{"mE2_", "?", "positiveQ"}], ",", 
       RowBox[{"mE3_", "?", "positiveQ"}], ",", 
       RowBox[{"mL1_", "?", "positiveQ"}], ",", 
       RowBox[{"mL2_", "?", "positiveQ"}], ",", 
       RowBox[{"mL3_", "?", "positiveQ"}], ",", 
       RowBox[{"mA_", "?", "positiveQ"}], ",", 
       RowBox[{"Q\[Mu]_", "?", "NumericQ"}], ",", 
       RowBox[{"M1_", "?", "NumericQ"}], ",", 
       RowBox[{"M2_", "?", "NumericQ"}], ",", 
       RowBox[{"M3_", "?", "NumericQ"}], ",", 
       RowBox[{"tan\[Beta]_", "?", "NumericQ"}], ",", 
       RowBox[{"Xt_", "?", "NumericQ"}]}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "Avoids", " ", "instability", " ", "of", " ", "the", " ", "solution", 
         " ", "for", " ", "small", " ", "running"}], ",", " ", 
        RowBox[{
        "when", " ", "tmtilde", " ", "and", " ", "tmsplit", " ", "are", " ", 
         RowBox[{"close", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tmtilde", "=", 
        RowBox[{"Rationalize", "[", 
         RowBox[{
          RowBox[{"Log", "[", 
           FractionBox["mtilde", "MT"], "]"}], ",", 
          SuperscriptBox["10", 
           RowBox[{"-", "5"}]]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tmsplit", "=", 
        RowBox[{"Rationalize", "[", 
         RowBox[{
          RowBox[{"Log", "[", 
           FractionBox["msplit", "MT"], "]"}], ",", 
          SuperscriptBox["10", 
           RowBox[{"-", "5"}]]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Lambda]Splitmtilde", "=", 
        RowBox[{
         RowBox[{"\[Lambda]Splitscalars", "[", 
          RowBox[{
          "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
           "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", 
           ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
           "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
           "tan\[Beta]", ",", "Xt"}], "]"}], "/.", "evaluateintmtilde"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"gtSplitmsplit", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"gtSplitsplit", "[", 
            RowBox[{
            "msplit", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3"}], "]"}],
            "/.", "evaluateintmsplit"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["g", "t"], "\[Rule]", "gtSM"}], "}"}]}], ")"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"g1utmtilde", "=", 
        RowBox[{
         RowBox[{"g1umtilde", "[", 
          RowBox[{
          "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
           "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", 
           ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
           "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
           "tan\[Beta]", ",", "Xt"}], "]"}], "/.", "evaluateintmtilde"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"g2utmtilde", "=", 
        RowBox[{
         RowBox[{"g2umtilde", "[", 
          RowBox[{
          "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
           "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", 
           ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
           "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
           "tan\[Beta]", ",", "Xt"}], "]"}], "/.", "evaluateintmtilde"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"g1dtmtilde", "=", 
        RowBox[{
         RowBox[{"g1dmtilde", "[", 
          RowBox[{
          "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
           "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", 
           ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
           "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
           "tan\[Beta]", ",", "Xt"}], "]"}], "/.", "evaluateintmtilde"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"g2dtmtilde", "=", 
        RowBox[{
         RowBox[{"g2dmtilde", "[", 
          RowBox[{
          "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
           "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", 
           ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
           "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
           "tan\[Beta]", ",", "Xt"}], "]"}], "/.", "evaluateintmtilde"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"solsplit", "=", 
        RowBox[{"Splitrun", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[Lambda]", ",", 
            SubscriptBox["g", "3"], ",", 
            SubscriptBox["g", "2"], ",", 
            SubscriptBox["g", "1"], ",", 
            SubscriptBox["g", "t"], ",", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "u"}]], ",", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "u"}]], ",", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"1", " ", "d"}]], ",", 
            SubscriptBox[
             OverscriptBox["g", "~"], 
             RowBox[{"2", " ", "d"}]], ",", 
            SubscriptBox["g", "b"], ",", 
            SubscriptBox["g", "\[Tau]"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Lambda]", "[", "tmtilde", "]"}], "\[Equal]", 
             "\[Lambda]Splitmtilde"}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "t"], "[", "tmsplit", "]"}], "\[Equal]", 
             "gtSplitmsplit"}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "3"], "[", "tmsplit", "]"}], "\[Equal]", 
             RowBox[{"g3SM", "[", "tmsplit", "]"}]}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "2"], "[", "tmsplit", "]"}], "\[Equal]", 
             RowBox[{"g2SM", "[", "tmsplit", "]"}]}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "1"], "[", "tmsplit", "]"}], "\[Equal]", 
             RowBox[{"g1SM", "[", "tmsplit", "]"}]}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", "u"}]], "[", "tmtilde", "]"}], "\[Equal]", 
             "g1utmtilde"}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"2", "u"}]], "[", "tmtilde", "]"}], "\[Equal]", 
             "g2utmtilde"}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"1", "d"}]], "[", "tmtilde", "]"}], "\[Equal]", 
             "g1dtmtilde"}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox[
               OverscriptBox["g", "~"], 
               RowBox[{"2", "d"}]], "[", "tmtilde", "]"}], "\[Equal]", 
             "g2dtmtilde"}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "b"], "[", "tmsplit", "]"}], "\[Equal]", 
             "gbMT"}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "\[Tau]"], "[", "tmsplit", "]"}], "\[Equal]", 
             "g\[Tau]MT"}]}], "}"}], ",", "tmsplit", ",", "tmtilde", ",", 
          "optsSplitrun"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Lambda]SMtmsplit", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Lambda]SMsplit", "[", 
             RowBox[{
             "msplit", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
              "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", 
              "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", 
              "mL3", ",", "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", 
              "M3", ",", "tan\[Beta]", ",", "Xt"}], "]"}], "/.", 
            "evaluateintmsplit"}], "/.", "rules"}], ")"}], "/.", 
         "solsplit"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Lambda]SMMT", "=", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"\[Lambda]", "[", "0", "]"}]}], "/.", 
         RowBox[{"SMrun", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["g", "1"], ",", 
             SubscriptBox["g", "2"], ",", 
             SubscriptBox["g", "3"], ",", 
             SubscriptBox["g", "t"], ",", "\[Lambda]", ",", 
             SubscriptBox["g", "\[Tau]"], ",", 
             SubscriptBox["g", "b"]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               SubscriptBox["g", "1"], "[", "0", "]"}], "\[Equal]", "g1MT"}], 
             ",", 
             RowBox[{
              RowBox[{
               SubscriptBox["g", "2"], "[", "0", "]"}], "\[Equal]", "g2MT"}], 
             ",", 
             RowBox[{
              RowBox[{
               SubscriptBox["g", "3"], "[", "0", "]"}], "\[Equal]", "g3MT"}], 
             ",", 
             RowBox[{
              RowBox[{
               SubscriptBox["g", "t"], "[", "0", "]"}], "\[Equal]", 
              "gtMT3l"}], ",", 
             RowBox[{
              RowBox[{"\[Lambda]", "[", "tmsplit", "]"}], "\[Equal]", 
              RowBox[{
               FractionBox["1", "2"], "\[Lambda]SMtmsplit"}]}], ",", 
             RowBox[{
              RowBox[{
               SubscriptBox["g", "b"], "[", "0", "]"}], "\[Equal]", "gbMT"}], 
             ",", 
             RowBox[{
              RowBox[{
               SubscriptBox["g", "\[Tau]"], "[", "0", "]"}], "\[Equal]", 
              "g\[Tau]MT"}]}], "}"}], ",", "0", ",", "tmsplit", ",", 
           "optsSMrun"}], "]"}]}]}], ";", 
       RowBox[{"Mhpole", "[", "\[Lambda]SMMT", "]"}]}], "\[IndentingNewLine]",
       ")"}]}]}]}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620307654964827*^9, 3.6203076557330427`*^9}, {
   3.620307686885787*^9, 3.620307804449539*^9}, {3.620307840908637*^9, 
   3.620307860932596*^9}, {3.620307898383239*^9, 3.620307925196705*^9}, {
   3.6203079653341312`*^9, 3.620308004347045*^9}, {3.6203127176356573`*^9, 
   3.620312748371455*^9}, {3.620312843000086*^9, 3.620312853007763*^9}, {
   3.620312935020341*^9, 3.62031314807484*^9}, {3.620313189367312*^9, 
   3.620313189758264*^9}, {3.620313237536434*^9, 3.620313256190668*^9}, {
   3.620313355675199*^9, 3.620313436158011*^9}, {3.620313675779447*^9, 
   3.620313716983138*^9}, {3.620313811527273*^9, 3.62031382621881*^9}, 
   3.620313879738152*^9, {3.620313962127872*^9, 3.620313969285301*^9}, {
   3.620314014692772*^9, 3.620314027659131*^9}, {3.6203143538727703`*^9, 
   3.620314385077961*^9}, 3.6203206194571743`*^9, {3.620320869961225*^9, 
   3.620320881779951*^9}, {3.6203209293899937`*^9, 3.620320978950663*^9}, {
   3.6203211300427313`*^9, 3.6203211500747967`*^9}, {3.6203212440497723`*^9, 
   3.62032125553367*^9}, {3.620321395619134*^9, 3.62032139623273*^9}, {
   3.620321572520484*^9, 3.620321824751378*^9}, {3.620321860844781*^9, 
   3.620321863332625*^9}, {3.620321894144816*^9, 3.62032189575915*^9}, {
   3.620321950558477*^9, 3.620321951898093*^9}, {3.6203225243518353`*^9, 
   3.6203225283493423`*^9}, {3.620322964821612*^9, 3.620322995547594*^9}, {
   3.620323322946258*^9, 3.620323368843038*^9}, {3.6203234287384033`*^9, 
   3.620323449230133*^9}, {3.620323486548788*^9, 3.620323591409143*^9}, {
   3.620323668781797*^9, 3.6203236722249117`*^9}, {3.6203237705027657`*^9, 
   3.62032381253459*^9}, {3.620323848243391*^9, 3.620323858990075*^9}, {
   3.6203246647061443`*^9, 3.620324672966049*^9}, {3.620324833745476*^9, 
   3.620324868454115*^9}, {3.620324927941304*^9, 3.620324928525095*^9}, {
   3.620325091160356*^9, 3.620325094609602*^9}, {3.620325183264945*^9, 
   3.620325190550756*^9}, {3.620325353017346*^9, 3.62032539953503*^9}, {
   3.6203254369414587`*^9, 3.6203254663461742`*^9}, {3.6203257747603292`*^9, 
   3.620325776347782*^9}, {3.6203266133365803`*^9, 3.620326620406947*^9}, {
   3.620326670444427*^9, 3.620326727611986*^9}, {3.620327065122168*^9, 
   3.620327067994006*^9}, {3.620383707308453*^9, 3.620383749875289*^9}, {
   3.620383809321518*^9, 3.6203838095090113`*^9}, {3.620384514532486*^9, 
   3.620384516644107*^9}, {3.6204582812281027`*^9, 3.620458283224544*^9}, {
   3.6204585111053333`*^9, 3.620458513298601*^9}, {3.6204586351992903`*^9, 
   3.6204586488394327`*^9}, {3.620458679219399*^9, 3.620458681105961*^9}, {
   3.620548573225025*^9, 3.620548575783547*^9}, {3.620550453197349*^9, 
   3.620550457701816*^9}, {3.620550514811223*^9, 3.620550516197401*^9}, {
   3.620550589568631*^9, 3.620550599653009*^9}, {3.620550644658326*^9, 
   3.620550651698957*^9}, {3.6224547050599527`*^9, 3.622454757400074*^9}, {
   3.622454979620558*^9, 3.6224549804069033`*^9}, {3.622455057729727*^9, 
   3.622455068762911*^9}, {3.622789066013948*^9, 3.622789088174221*^9}, 
   3.622789118556143*^9, 3.622789234617255*^9, {3.622890839288056*^9, 
   3.6228908832495403`*^9}, {3.622890960426119*^9, 3.6228909767059517`*^9}, {
   3.622891020461163*^9, 3.622891025634227*^9}, {3.622891109545061*^9, 
   3.622891133438816*^9}, 3.6228912975623293`*^9, {3.622891430798396*^9, 
   3.622891431437358*^9}, {3.6228915702530317`*^9, 3.6228915740149918`*^9}, {
   3.6251748059948874`*^9, 3.6251748113180437`*^9}, {3.625175368359123*^9, 
   3.6251753893969297`*^9}, {3.625175546603277*^9, 3.625175578067911*^9}, {
   3.625175637084237*^9, 3.6251756384194117`*^9}, {3.625205000587425*^9, 
   3.6252050008817177`*^9}, {3.625205126270165*^9, 3.6252051738682823`*^9}, {
   3.6252053038761044`*^9, 3.62520537069044*^9}, {3.625205409914897*^9, 
   3.625205420220603*^9}, {3.6252055472984543`*^9, 3.625205562342833*^9}, {
   3.625248685425153*^9, 3.625248790576439*^9}, {3.625248822725107*^9, 
   3.625248824770687*^9}, {3.625248954534272*^9, 3.6252489550841513`*^9}, {
   3.6252566348064623`*^9, 3.625256660165593*^9}, {3.627109900249579*^9, 
   3.6271099072955914`*^9}, {3.627109953722624*^9, 3.627109955067009*^9}, {
   3.6281090631871357`*^9, 3.628109071655376*^9}, {3.628109103548332*^9, 
   3.6281091472045097`*^9}, {3.628150877510447*^9, 3.628150925495509*^9}, {
   3.628151011718484*^9, 3.6281510946655912`*^9}, 3.628151426387137*^9, {
   3.628151563744521*^9, 3.6281515990799303`*^9}, {3.628151654455986*^9, 
   3.628151721747993*^9}, {3.634541411692401*^9, 3.634541431200225*^9}, {
   3.634541507228382*^9, 3.634541533280726*^9}, {3.634541610875897*^9, 
   3.6345416160768557`*^9}, {3.63639360080098*^9, 3.63639360536399*^9}, {
   3.636393636729019*^9, 3.636393674764339*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["MHiggs Function", "Subsection",
 CellChangeTimes->{{3.634638225650672*^9, 3.6346382378806343`*^9}, {
  3.634674732429229*^9, 3.634674736572421*^9}, {3.63467486755651*^9, 
  3.634674870732809*^9}}],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection",
 CellChangeTimes->{{3.6367059443445253`*^9, 3.6367059545495577`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "It", " ", "returns", " ", "a", " ", "list", " ", "to", " ", "be", " ", 
    "used", " ", "as", " ", "the", " ", "argument", " ", "for", " ", 
    "function", " ", "which", " ", "computes", " ", "the", " ", "Higgs", " ", 
    
    RowBox[{"mass", "."}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"getList", "[", "x_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "list", "}"}], ",", 
     RowBox[{
      RowBox[{"Switch", "[", 
       RowBox[{
        RowBox[{"Length", "[", "x", "]"}], ",", "2", ",", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"tan\[Beta]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"m0", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"list", "=", 
           RowBox[{"{", 
            RowBox[{
            "tan\[Beta]", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", 
             "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",",
              "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", 
             ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0"}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "3", ",", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"tan\[Beta]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"m0", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ",", 
            RowBox[{"At", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"list", "=", 
           RowBox[{"{", 
            RowBox[{
            "tan\[Beta]", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", 
             "At", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",",
              "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", 
             ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0"}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "4", ",", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"tan\[Beta]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"m0", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ",", 
            RowBox[{"At", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ",", 
            RowBox[{"m12", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"list", "=", 
           RowBox[{"{", 
            RowBox[{
            "tan\[Beta]", ",", "m12", ",", "m12", ",", "m12", ",", "m12", ",",
              "At", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", 
             ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0",
              ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0"}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "5", ",", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"tan\[Beta]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"m0", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ",", 
            RowBox[{"At", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ",", 
            RowBox[{"m12", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], ",", 
            RowBox[{"\[Mu]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
          RowBox[{"list", "=", 
           RowBox[{"{", 
            RowBox[{
            "tan\[Beta]", ",", "m12", ",", "m12", ",", "m12", ",", "\[Mu]", 
             ",", "At", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0",
              ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", 
             "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0"}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "6", ",", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"tan\[Beta]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"mQ3", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ",", 
            RowBox[{"mU3", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ",", 
            RowBox[{"At", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], ",", 
            RowBox[{"m12", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "5", "]"}], "]"}]}], ",", 
            RowBox[{"\[Mu]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "6", "]"}], "]"}]}], ",", 
            RowBox[{"m0", "=", 
             SqrtBox[
              RowBox[{
               RowBox[{"x", "[", 
                RowBox[{"[", "2", "]"}], "]"}], 
               RowBox[{"x", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}]]}]}], "}"}], ",", 
          RowBox[{"list", "=", 
           RowBox[{"{", 
            RowBox[{
            "tan\[Beta]", ",", "m12", ",", "m12", ",", "m12", ",", "\[Mu]", 
             ",", "At", ",", "mQ3", ",", "mU3", ",", "m0", ",", "m0", ",", 
             "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",",
              "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0"}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "8", ",", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"tan\[Beta]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"mQ3", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ",", 
            RowBox[{"mU3", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ",", 
            RowBox[{"At", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], ",", 
            RowBox[{"M1", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "5", "]"}], "]"}]}], ",", 
            RowBox[{"M2", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "6", "]"}], "]"}]}], ",", 
            RowBox[{"M3", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "7", "]"}], "]"}]}], ",", 
            RowBox[{"\[Mu]", "=", 
             RowBox[{"x", "[", 
              RowBox[{"[", "8", "]"}], "]"}]}], ",", 
            RowBox[{"m0", "=", 
             SqrtBox[
              RowBox[{
               RowBox[{"x", "[", 
                RowBox[{"[", "2", "]"}], "]"}], 
               RowBox[{"x", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}]]}]}], "}"}], ",", 
          RowBox[{"list", "=", 
           RowBox[{"{", 
            RowBox[{
            "tan\[Beta]", ",", "M1", ",", "M2", ",", "M3", ",", "\[Mu]", ",", 
             "At", ",", "mQ3", ",", "mU3", ",", "m0", ",", "m0", ",", "m0", 
             ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0",
              ",", "m0", ",", "m0", ",", "m0", ",", "m0", ",", "m0"}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "22", ",", 
        RowBox[{"list", "=", "x"}], ",", "\[IndentingNewLine]", "_", ",", 
        RowBox[{"list", "=", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "22"}], "}"}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", "list"}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.635855191964452*^9, 3.635855225212082*^9}, {
   3.6358552749720087`*^9, 3.635855291495501*^9}, {3.635855656673271*^9, 
   3.635855704905004*^9}, {3.635855823391842*^9, 3.6358558572216673`*^9}, {
   3.635855905347034*^9, 3.6358560155297117`*^9}, {3.635856094303296*^9, 
   3.635856106079434*^9}, {3.6358657747092543`*^9, 3.635865789343143*^9}, {
   3.6358658502382107`*^9, 3.635865872973936*^9}, 3.635865905077634*^9, {
   3.635865944013034*^9, 3.6358661083127527`*^9}, {3.635866181145009*^9, 
   3.635866190947218*^9}, {3.635971703046588*^9, 3.635971727333641*^9}, {
   3.6359717693392553`*^9, 3.63597186339887*^9}, {3.635971922569673*^9, 
   3.6359719624433107`*^9}, {3.635971997350934*^9, 3.635972222854707*^9}, {
   3.6359722884806004`*^9, 3.635972312867818*^9}, {3.6359723776645403`*^9, 
   3.635972588604334*^9}, {3.635972824633541*^9, 3.635972826787705*^9}, {
   3.636012049262809*^9, 3.6360120815763617`*^9}, {3.636013215439248*^9, 
   3.6360132816054087`*^9}, {3.636013357489786*^9, 3.6360133879193077`*^9}, {
   3.6360134661637363`*^9, 3.636013505231924*^9}, 3.6360141098192453`*^9, {
   3.6362060120939207`*^9, 3.636206012957942*^9}, {3.636364692294653*^9, 
   3.636364697343094*^9}, {3.636364731037129*^9, 3.6363648092464437`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gtMSSM", "[", 
   RowBox[{"Q_", ",", "tan\[Beta]_"}], "]"}], ":=", 
  RowBox[{"(", 
   FractionBox[
    RowBox[{
     RowBox[{"gt", "[", 
      RowBox[{"Log", "[", 
       FractionBox["Q", "MT"], "]"}], "]"}], "/.", "solSM3l"}], 
    RowBox[{"Sin", "[", 
     RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}], "]"}]], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gbMSSM", "[", 
   RowBox[{
   "Q_", ",", "mQ3_", ",", "mU3_", ",", "mD3_", ",", "M3_", ",", "\[Mu]_", 
    ",", "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gbDRbar", ",", "tRG", ",", "evaluate"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tRG", "=", 
      RowBox[{"Log", "[", 
       FractionBox["Q", "MT"], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"evaluate", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["g", "t"], "\[Rule]", 
          RowBox[{"gt", "[", "tRG", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "3"], "\[Rule]", 
          RowBox[{"g3", "[", "tRG", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "b"], "\[Rule]", 
          RowBox[{"gb", "[", "tRG", "]"}]}]}], "}"}], "/.", "solSM3l"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"gbDRbar", "=", 
      RowBox[{
       RowBox[{"gbDR", "[", 
        RowBox[{
        "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", "\[Mu]", ",", 
         "tan\[Beta]", ",", "Xt"}], "]"}], "/.", "evaluate"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"testgbDR", "[", 
   RowBox[{
   "Q_", ",", "mQ3_", ",", "mU3_", ",", "mD3_", ",", "M3_", ",", "\[Mu]_", 
    ",", "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gbDRbar", "=", 
      RowBox[{"gbMSSM", "[", 
       RowBox[{
       "Q", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", "\[Mu]", ",", 
        "tan\[Beta]", ",", "Xt"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{"4", "<", 
       RowBox[{"Abs", "@", "gbDRbar"}], "<", 
       RowBox[{"4", "\[Pi]"}]}], ",", 
      RowBox[{"Message", "[", 
       RowBox[{"MHiggs", "::", "bottomYukawa"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Abs", "@", "gbDRbar"}], "\[GreaterEqual]", 
       RowBox[{"4", "\[Pi]"}]}], ",", 
      RowBox[{
       RowBox[{"Message", "[", 
        RowBox[{"MHiggs", "::", "bottomYukawa"}], "]"}], ";", "True"}]}], 
     "]"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.636364823609317*^9, 3.636364823960367*^9}, {
   3.636364862168602*^9, 3.636364864704912*^9}, {3.636365009440282*^9, 
   3.636365211159444*^9}, {3.636365312261993*^9, 3.636365374884058*^9}, {
   3.636365405159171*^9, 3.636365454619546*^9}, {3.636365616704748*^9, 
   3.636365624774589*^9}, {3.636366030851445*^9, 3.636366033275737*^9}, {
   3.636380038717289*^9, 3.636380049538726*^9}, {3.6364639204942408`*^9, 
   3.6364639215214376`*^9}, {3.6364639576186247`*^9, 3.636463958678329*^9}, {
   3.636706918241069*^9, 3.636706921860998*^9}, 3.63670695724924*^9, {
   3.6380036250873823`*^9, 3.638003690769953*^9}, {3.638003785279406*^9, 
   3.6380038982677307`*^9}, {3.63800418624159*^9, 3.638004188897745*^9}, {
   3.638040837110599*^9, 3.6380408794649067`*^9}, {3.6380409690643663`*^9, 
   3.638040976631633*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gtauMSSM", "[", 
   RowBox[{
   "Q_", ",", "mL3_", ",", "mE3_", ",", "M2_", ",", "M1_", ",", "\[Mu]_", ",",
     "tan\[Beta]_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gtauDRbar", ",", "tRG", ",", "evaluate"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tRG", "=", 
      RowBox[{"Log", "[", 
       FractionBox["Q", "MT"], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"evaluate", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["g", "1"], "\[Rule]", 
          RowBox[{"g1", "[", "tRG", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "2"], "\[Rule]", 
          RowBox[{"g2", "[", "tRG", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["g", "\[Tau]"], "\[Rule]", 
          RowBox[{"g\[Tau]", "[", "tRG", "]"}]}]}], "}"}], "/.", 
       "solSM3l"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"gtauDRbar", "=", 
      RowBox[{
       RowBox[{"gtauDR", "[", 
        RowBox[{
        "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", "\[Mu]", ",", 
         "tan\[Beta]"}], "]"}], "/.", "evaluate"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"testgtauDR", "[", 
   RowBox[{
   "Q_", ",", "mL3_", ",", "mE3_", ",", "M2_", ",", "M1_", ",", "\[Mu]_", ",",
     "tan\[Beta]_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gtauDRbar", "=", 
      RowBox[{"gtauMSSM", "[", 
       RowBox[{
       "Q", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", "\[Mu]", ",", 
        "tan\[Beta]"}], "]"}]}], "}"}], ",", 
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{"4", "<", 
       RowBox[{"Abs", "@", "gtauDRbar"}], "<", 
       RowBox[{"4", "\[Pi]"}]}], ",", 
      RowBox[{"Message", "[", 
       RowBox[{"MHiggs", "::", "tauYukawa"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Abs", "@", "gtauDRbar"}], "\[GreaterEqual]", 
       RowBox[{"4", "\[Pi]"}]}], ",", 
      RowBox[{
       RowBox[{"Message", "[", 
        RowBox[{"MHiggs", "::", "tauYukawa"}], "]"}], ";", "True"}]}], 
     "]"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.636364823609317*^9, 3.636364823960367*^9}, {
   3.636364862168602*^9, 3.636364864704912*^9}, {3.636365009440282*^9, 
   3.636365211159444*^9}, {3.636365312261993*^9, 3.636365374884058*^9}, {
   3.636365405159171*^9, 3.636365454619546*^9}, {3.636365616704748*^9, 
   3.636365624774589*^9}, {3.636366030851445*^9, 3.636366033275737*^9}, {
   3.636380038717289*^9, 3.636380049538726*^9}, {3.6364639204942408`*^9, 
   3.6364639215214376`*^9}, {3.6364639576186247`*^9, 3.636463958678329*^9}, {
   3.636705976839645*^9, 3.636705980014183*^9}, {3.636706011958301*^9, 
   3.63670602305475*^9}, {3.63670605898319*^9, 3.636706182877327*^9}, {
   3.636706235109425*^9, 3.636706236469289*^9}, {3.636706715721614*^9, 
   3.6367067611371202`*^9}, {3.636706837889572*^9, 3.636706845257407*^9}, {
   3.636706911273897*^9, 3.636706916020358*^9}, 3.636706954849078*^9, {
   3.6367076146450987`*^9, 3.6367076506840467`*^9}, {3.6380039275169353`*^9, 
   3.638003934028307*^9}, {3.6380040015505667`*^9, 3.6380041053378363`*^9}, {
   3.638004171504774*^9, 3.63800417480101*^9}, {3.6380042117696953`*^9, 
   3.638004214065734*^9}, {3.638042132948146*^9, 3.638042140324394*^9}, {
   3.638091145354388*^9, 3.638091145585683*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Function", "Subsubsection",
 CellChangeTimes->{{3.6367059609867077`*^9, 3.636705967002927*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numericListQ", "[", "list_", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Not", "@", 
        RowBox[{"ListQ", "[", "list", "]"}]}], ",", 
       RowBox[{"Return", "[", "False", "]"}]}], "]"}], ";", 
     RowBox[{"And", "@@", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"NumericQ", "[", "element", "]"}], ",", "True", ",", 
          "False"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"element", ",", "list"}], "}"}]}], "]"}]}]}], ")"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "ensure", " ", "a", " ", "numeric", " ", "list", " ", "as", " ", "a", " ", 
    "variable", " ", "for", " ", "MHiggs"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cond", "[", "m_", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"NumericQ", "[", "m", "]"}], "&&", 
     RowBox[{
      RowBox[{"Im", "[", "m", "]"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"Abs", "[", "m", "]"}], ">", "175"}]}], ")"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{"condition", " ", "for", " ", "the", " ", "soft", " ", "masses"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Options", "[", "MHiggs", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"numerical", "\[Rule]", "False"}], ",", 
     RowBox[{"split", "\[Rule]", "False"}], ",", 
     RowBox[{"Rscale", "\[Rule]", "0"}], ",", 
     RowBox[{"RscaleSplit", "\[Rule]", "0"}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MHiggs", "[", 
   RowBox[{
    RowBox[{"shortList_", "?", "numericListQ"}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tan\[Beta]", ",", "M1", ",", "M2", ",", "M3", ",", "\[Mu]", ",", "At", 
      ",", "mQ3", ",", "mU3", ",", "mD3", ",", "mQ2", ",", "mU2", ",", "mD2", 
      ",", "mQ1", ",", "mU1", ",", "mD1", ",", "mL3", ",", "mE3", ",", "mL2", 
      ",", "mE2", ",", "mL1", ",", "mE1", ",", "mA", ",", "Xt", ",", "mtilde",
       ",", "msplit", ",", "mh"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "tan\[Beta]", ",", "M1", ",", "M2", ",", "M3", ",", "\[Mu]", ",", "At",
         ",", "mQ3", ",", "mU3", ",", "mD3", ",", "mQ2", ",", "mU2", ",", 
        "mD2", ",", "mQ1", ",", "mU1", ",", "mD1", ",", "mL3", ",", "mE3", 
        ",", "mL2", ",", "mE2", ",", "mL1", ",", "mE1", ",", "mA"}], "}"}], 
      "=", 
      RowBox[{"getList", "[", "shortList", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Xt", "=", 
      RowBox[{"At", "-", 
       RowBox[{"\[Mu]", " ", "/", "tan\[Beta]"}]}]}], ";", 
     RowBox[{"msplit", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", "RscaleSplit", "]"}], "<", "200"}], ",", 
        
        RowBox[{"Max", "[", 
         RowBox[{"\[Mu]", ",", "M2"}], "]"}], ",", 
        RowBox[{"OptionValue", "[", "RscaleSplit", "]"}]}], "]"}]}], ";", 
     RowBox[{"mtilde", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", "Rscale", "]"}], "<", "200"}], ",", 
        SqrtBox[
         RowBox[{"mQ3", " ", "mU3"}]], ",", 
        RowBox[{"OptionValue", "[", "Rscale", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"NumericQ", "[", "tan\[Beta]", "]"}], "&&", 
        RowBox[{"tan\[Beta]", "\[GreaterEqual]", "1"}], "&&", 
        RowBox[{"cond", "[", "M1", "]"}], "&&", 
        RowBox[{"cond", "[", "M2", "]"}], "&&", 
        RowBox[{"cond", "[", "M3", "]"}], "&&", 
        RowBox[{"cond", "[", "\[Mu]", "]"}], "&&", 
        RowBox[{
         RowBox[{"Im", "[", "At", "]"}], "\[Equal]", "0"}], "&&", 
        RowBox[{"NumericQ", "[", "At", "]"}], "&&", 
        RowBox[{"cond", "[", "mQ3", "]"}], "&&", 
        RowBox[{"cond", "[", "mU3", "]"}], "&&", 
        RowBox[{"cond", "[", "mD3", "]"}], "&&", 
        RowBox[{"cond", "[", "mQ2", "]"}], "&&", 
        RowBox[{"cond", "[", "mU2", "]"}], "&&", 
        RowBox[{"cond", "[", "mD2", "]"}], "&&", 
        RowBox[{"cond", "[", "mQ1", "]"}], "&&", 
        RowBox[{"cond", "[", "mU1", "]"}], "&&", 
        RowBox[{"cond", "[", "mD1", "]"}], "&&", 
        RowBox[{"cond", "[", "mL3", "]"}], "&&", 
        RowBox[{"cond", "[", "mE3", "]"}], "&&", 
        RowBox[{"cond", "[", "mL2", "]"}], "&&", 
        RowBox[{"cond", "[", "mE2", "]"}], "&&", 
        RowBox[{"cond", "[", "mL1", "]"}], "&&", 
        RowBox[{"cond", "[", "mE1", "]"}], "&&", 
        RowBox[{"cond", "[", "mA", "]"}]}], ",", "1", ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"MHiggs", "::", "variables"}], "]"}], ";", 
        RowBox[{"Return", "[", "0", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{
          FractionBox["1", "10"], "\[LessEqual]", 
          FractionBox["mtilde", 
           SqrtBox[
            RowBox[{"mQ3", " ", "mU3"}]]], "\[LessEqual]", "10"}], "]"}], "||", 
        RowBox[{"0", "<", 
         RowBox[{"OptionValue", "[", "Rscale", "]"}], "<", "200"}]}], ",", 
       RowBox[{"Message", "[", 
        RowBox[{"MHiggs", "::", "warning"}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"testgbDR", "[", 
        RowBox[{
        "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", "\[Mu]",
          ",", "tan\[Beta]", ",", "Xt"}], "]"}], ",", 
       RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"testgtauDR", "[", 
        RowBox[{
        "mtilde", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", "\[Mu]", 
         ",", "tan\[Beta]"}], "]"}], ",", 
       RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Which", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{"OptionValue", "@", "split"}], "]"}], "&&", " ", 
        RowBox[{"Not", "[", 
         RowBox[{"OptionValue", "@", "numerical"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"mh", "=", 
        RowBox[{"MhpoleHSSfast", "[", 
         RowBox[{
         "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2",
           ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
          "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", 
          ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
          ",", "Xt", ",", 
          RowBox[{"FilterRules", "[", 
           RowBox[{
            RowBox[{"{", "opts", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"hiOrd", ",", "scheme"}], "}"}]}], "]"}]}], "]"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{"OptionValue", "@", "split"}], "]"}], "&&", 
        RowBox[{"OptionValue", "@", "numerical"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"mh", "=", 
        RowBox[{"MhpoleHSS", "[", 
         RowBox[{
         "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2",
           ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
          "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", 
          ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
          ",", "Xt", ",", 
          RowBox[{"FilterRules", "[", 
           RowBox[{
            RowBox[{"{", "opts", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"hiOrd", ",", "scheme"}], "}"}]}], "]"}]}], "]"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"OptionValue", "@", "split"}], "&&", 
        RowBox[{"(", 
         RowBox[{"msplit", "<", "mtilde"}], ")"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"mh", "=", 
        RowBox[{"MhpoleSplit", "[", 
         RowBox[{
         "mtilde", ",", "msplit", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", 
          "mU1", ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", 
          ",", "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", 
          "mL3", ",", "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", 
          ",", "tan\[Beta]", ",", "Xt"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"OptionValue", "@", "split"}], "&&", 
        RowBox[{"(", 
         RowBox[{"msplit", ">=", "mtilde"}], ")"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{"MHiggs", "::", "warningsplit"}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mh", "=", 
          RowBox[{"MhpoleHSSfast", "[", 
           RowBox[{
           "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
            "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1",
             ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
            "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
            "tan\[Beta]", ",", "Xt", ",", 
            RowBox[{"FilterRules", "[", 
             RowBox[{
              RowBox[{"{", "opts", "}"}], ",", 
              RowBox[{"{", "hiOrd", "}"}]}], "]"}]}], "]"}]}]}], ")"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Im", "[", "mh", "]"}], "\[Equal]", "0"}], ",", "mh", ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"MHiggs", "::", "negative"}], "]"}], 
        RowBox[{"(*", 
         RowBox[{";", 
          RowBox[{"Print", "[", "mh", "]"}]}], "*)"}], ";", "0"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.634638251655447*^9, 3.634638311863864*^9}, {
   3.634638355359291*^9, 3.634638360538971*^9}, {3.634638452778713*^9, 
   3.6346384570552588`*^9}, {3.63463858485856*^9, 3.63463868124089*^9}, {
   3.634638834658*^9, 3.634639024200336*^9}, {3.634639061760597*^9, 
   3.634639105097885*^9}, {3.634639397280755*^9, 3.6346394001114798`*^9}, {
   3.634639492742152*^9, 3.634639505974339*^9}, {3.634639537750573*^9, 
   3.63463957305501*^9}, {3.6346398098448057`*^9, 3.634639820708787*^9}, {
   3.634639981356032*^9, 3.634639997108485*^9}, {3.634640259953167*^9, 
   3.634640272681753*^9}, {3.634640360641231*^9, 3.6346404068491488`*^9}, {
   3.634640437433321*^9, 3.634640447736899*^9}, {3.634640480913096*^9, 
   3.634640481954729*^9}, {3.634640854806884*^9, 3.6346410402782183`*^9}, 
   3.634643864344404*^9, {3.634644189153885*^9, 3.634644189829077*^9}, 
   3.6346442454705553`*^9, {3.634650805941247*^9, 3.6346508367341337`*^9}, {
   3.634650975043668*^9, 3.634651016180388*^9}, {3.6346510876753807`*^9, 
   3.634651090087926*^9}, {3.63465115929142*^9, 3.634651162539447*^9}, {
   3.6346512090177317`*^9, 3.634651210864401*^9}, {3.634651290019767*^9, 
   3.634651290182136*^9}, {3.6346513679946947`*^9, 3.634651418403027*^9}, {
   3.634674095704072*^9, 3.634674102792953*^9}, {3.634674372003586*^9, 
   3.6346743745220413`*^9}, {3.634674755985002*^9, 3.6346748262875957`*^9}, {
   3.6346748742904663`*^9, 3.6346748885153933`*^9}, 3.634674939633971*^9, {
   3.634674970929063*^9, 3.634675074841545*^9}, {3.634675107016081*^9, 
   3.634675111785111*^9}, {3.634675210447596*^9, 3.634675218176543*^9}, {
   3.635517553333527*^9, 3.635517556704378*^9}, {3.6355179480989017`*^9, 
   3.6355179498680487`*^9}, {3.6355181215957003`*^9, 3.635518123003985*^9}, {
   3.6356843240777493`*^9, 3.635684338245636*^9}, {3.6356845481556664`*^9, 
   3.635684700857967*^9}, 3.635684799275329*^9, 3.635685200507639*^9, {
   3.635687625544167*^9, 3.63568794979629*^9}, {3.635688008473654*^9, 
   3.635688116607976*^9}, {3.635688164041767*^9, 3.635688166799481*^9}, {
   3.6356884519285793`*^9, 3.6356884529196253`*^9}, {3.635688504344571*^9, 
   3.635688506423699*^9}, {3.635689268993642*^9, 3.635689354729046*^9}, {
   3.63568940335273*^9, 3.635689429183928*^9}, {3.635689543031486*^9, 
   3.6356896235641212`*^9}, {3.6357087285680532`*^9, 
   3.6357087297752523`*^9}, {3.635710331983213*^9, 3.6357103558568697`*^9}, {
   3.636012124088531*^9, 3.636012127605102*^9}, {3.636012160860321*^9, 
   3.636012168387995*^9}, {3.6360122070689697`*^9, 3.636012315696607*^9}, 
   3.636012363493806*^9, {3.636012398946203*^9, 3.636012414574625*^9}, {
   3.636012453731823*^9, 3.636012509591187*^9}, {3.636012547288004*^9, 
   3.636012711645401*^9}, {3.6360127498871*^9, 3.636012839176407*^9}, {
   3.636013626686816*^9, 3.636013636383046*^9}, {3.6360138536553802`*^9, 
   3.636013901223233*^9}, {3.636013973062559*^9, 3.636013975386511*^9}, {
   3.636014038896825*^9, 3.636014047929541*^9}, {3.636018088077421*^9, 
   3.6360180899546337`*^9}, {3.636022229338591*^9, 3.636022236686511*^9}, {
   3.6360227438502073`*^9, 3.6360227519301977`*^9}, {3.636022783618552*^9, 
   3.636022790711563*^9}, {3.636023248420796*^9, 3.636023357779853*^9}, {
   3.6361979507508507`*^9, 3.636197956022398*^9}, {3.636197986357379*^9, 
   3.6361979911601152`*^9}, {3.636364617698689*^9, 3.636364620777339*^9}, {
   3.636364659393458*^9, 3.6363646636955853`*^9}, {3.636365854512487*^9, 
   3.636365857944618*^9}, {3.636372397544793*^9, 3.636372401979257*^9}, {
   3.6363737465846643`*^9, 3.636373789336685*^9}, 3.636373877529092*^9, {
   3.636373959968219*^9, 3.636373962270363*^9}, {3.6364639671516247`*^9, 
   3.636463975566579*^9}, {3.6367075870986137`*^9, 3.6367075973307734`*^9}, {
   3.638004226663595*^9, 3.6380042365443296`*^9}, 3.638091207944927*^9, {
   3.638207791035928*^9, 3.6382077966601267`*^9}, 3.6385350262992477`*^9, 
   3.638605935370508*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theoretical uncertainties", "Section",
 CellChangeTimes->{{3.6271343796043262`*^9, 3.627134386515895*^9}, {
  3.6386217046667967`*^9, 3.6386217090348797`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "EFT: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["v", "2"], "/", 
     SubsuperscriptBox["m", 
      StyleBox["SUSY",
       FontSize->12], "2"]}], "-"}], TraditionalForm]]],
 "suppressed corrections"
}], "Subsection",
 CellChangeTimes->{{3.6277298148840313`*^9, 3.627729864567634*^9}, {
  3.627729897007782*^9, 3.6277299153818398`*^9}, {3.6277347988334293`*^9, 
  3.627734810227992*^9}, {3.638606228989068*^9, 3.6386062951964703`*^9}, {
  3.638621906413866*^9, 3.638621910455669*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MhpoleHSSmom", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Lambda]mtilde", ",", "evaluate", ",", "tmtilde", ",", 
      "\[Lambda]\[Lambda]"}], "}"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"tmtilde", "=", 
        RowBox[{"Log", "[", 
         FractionBox["mtilde", "MT"], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"evaluate", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Lambda]\[Lambda]", "\[Rule]", 
             RowBox[{"\[Lambda]", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "t"], "\[Rule]", 
             RowBox[{"gt", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "3"], "\[Rule]", 
             RowBox[{"g3", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "2"], "\[Rule]", 
             RowBox[{"g2", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "1"], "\[Rule]", 
             RowBox[{"g1", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "b"], "\[Rule]", 
             RowBox[{"gb", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "\[Tau]"], "\[Rule]", 
             RowBox[{"g\[Tau]", "[", "tmtilde", "]"}]}]}], "}"}], "/.", 
          "solSM3l"}], "/.", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]\[Lambda]", "\[Rule]", "\[Lambda]"}], "}"}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"\[Lambda]mtilde", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Lambda]HSS", "[", 
           RowBox[{
           "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
            "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1",
             ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
            "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
            "tan\[Beta]", ",", "Xt", ",", 
            RowBox[{"hiOrd", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
            RowBox[{"suppressedCorrections", "\[Rule]", "True"}]}], "]"}], 
          ")"}], "/.", "evaluate"}]}]}], ")"}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Lambda]MT", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"\[Lambda]", "[", "0", "]"}]}], "/.", 
        RowBox[{"SMrun", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["g", "1"], ",", 
            SubscriptBox["g", "2"], ",", 
            SubscriptBox["g", "3"], ",", 
            SubscriptBox["g", "t"], ",", "\[Lambda]", ",", 
            SubscriptBox["g", "\[Tau]"], ",", 
            SubscriptBox["g", "b"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["g", "1"], "[", "0", "]"}], "\[Equal]", "g1MT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "2"], "[", "0", "]"}], "\[Equal]", "g2MT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "3"], "[", "0", "]"}], "\[Equal]", "g3MT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "t"], "[", "0", "]"}], "\[Equal]", "gtMT3l"}],
             ",", 
            RowBox[{
             RowBox[{"\[Lambda]", "[", "tmax", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["1", "2"], "\[Lambda]mtilde"}]}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "b"], "[", "0", "]"}], "\[Equal]", "gbMT"}], 
            ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["g", "\[Tau]"], "[", "0", "]"}], "\[Equal]", 
             "g\[Tau]MT"}]}], "}"}], ",", "0", ",", "tmax", ",", 
          "optsSMrun"}], "]"}]}], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Mhpole", "[", "\[Lambda]MT", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6200439004381037`*^9, 3.62004401421668*^9}, {
   3.6200440567762423`*^9, 3.620044111288514*^9}, {3.62004414554535*^9, 
   3.620044220473219*^9}, {3.620119729736141*^9, 3.620119795477969*^9}, {
   3.620119995494102*^9, 3.6201200185884533`*^9}, {3.620120374761421*^9, 
   3.620120411152298*^9}, {3.62012059134039*^9, 3.6201206299114513`*^9}, {
   3.62012391285954*^9, 3.620123934632702*^9}, {3.620124649276807*^9, 
   3.620124650732354*^9}, {3.620125360416038*^9, 3.620125371846684*^9}, {
   3.620125946026581*^9, 3.620125958693842*^9}, {3.620127083161211*^9, 
   3.620127089007598*^9}, 3.6201271888244553`*^9, {3.6201273534852333`*^9, 
   3.620127355552799*^9}, {3.620220028809361*^9, 3.62022002967591*^9}, {
   3.620306586520327*^9, 3.6203065916317797`*^9}, {3.620307023918005*^9, 
   3.6203070240316277`*^9}, {3.620307252514659*^9, 3.620307252631892*^9}, {
   3.621157052357183*^9, 3.621157107669544*^9}, {3.621157222797364*^9, 
   3.621157245308032*^9}, {3.6211935897248383`*^9, 3.621193590582821*^9}, {
   3.6223541483281193`*^9, 3.622354149206575*^9}, {3.622370986780356*^9, 
   3.622370992506105*^9}, {3.622371256164768*^9, 3.6223712568722363`*^9}, 
   3.622783815048378*^9, 3.622789268413698*^9, {3.622890278646159*^9, 
   3.622890280084846*^9}, {3.625167839061376*^9, 3.625167842538499*^9}, {
   3.627070148855397*^9, 3.62707027998076*^9}, {3.6270705069245462`*^9, 
   3.6270705094648237`*^9}, 3.627070579290236*^9, {3.6270706261080523`*^9, 
   3.627070630117609*^9}, {3.627134079746849*^9, 3.62713416493506*^9}, {
   3.6277297413838387`*^9, 3.6277297575547037`*^9}, {3.627828756802885*^9, 
   3.627828805094492*^9}, {3.62782884464913*^9, 3.6278288576239777`*^9}, {
   3.6346741054890842`*^9, 3.6346741072655163`*^9}, {3.634674372010831*^9, 
   3.6346743745276203`*^9}, {3.634676044065192*^9, 3.63467604512142*^9}, 
   3.638102739125403*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MhpoleHSSmomfast", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Lambda]mtilde", ",", "evaluate", ",", "tmtilde", ",", 
      "\[Lambda]\[Lambda]"}], "}"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"tmtilde", "=", 
        RowBox[{"Log", "[", 
         FractionBox["mtilde", "MT"], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"evaluate", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Lambda]\[Lambda]", "\[Rule]", 
             RowBox[{"\[Lambda]", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "t"], "\[Rule]", 
             RowBox[{"gt", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "3"], "\[Rule]", 
             RowBox[{"g3", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "2"], "\[Rule]", 
             RowBox[{"g2", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "1"], "\[Rule]", 
             RowBox[{"g1", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "b"], "\[Rule]", 
             RowBox[{"gb", "[", "tmtilde", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["g", "\[Tau]"], "\[Rule]", 
             RowBox[{"g\[Tau]", "[", "tmtilde", "]"}]}]}], "}"}], "/.", 
          "solSM3l"}], "/.", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]\[Lambda]", "\[Rule]", "\[Lambda]"}], "}"}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"\[Lambda]mtilde", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Lambda]HSS", "[", 
           RowBox[{
           "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
            "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1",
             ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
            "mA", ",", "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
            "tan\[Beta]", ",", "Xt", ",", 
            RowBox[{"hiOrd", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
            RowBox[{"suppressedCorrections", "\[Rule]", "True"}]}], "]"}], 
          ")"}], "/.", "evaluate"}]}]}], ")"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Mhpole", "[", 
      RowBox[{"Quiet", "@", 
       RowBox[{"\[Lambda]atMTint", "[", 
        RowBox[{
        "\[Lambda]mtilde", ",", "tmtilde", ",", "gtMT3l", ",", "g3MT"}], 
        "]"}]}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6200439004381037`*^9, 3.62004401421668*^9}, {
   3.6200440567762423`*^9, 3.620044111288514*^9}, {3.62004414554535*^9, 
   3.620044220473219*^9}, {3.620119729736141*^9, 3.620119795477969*^9}, {
   3.620119995494102*^9, 3.6201200185884533`*^9}, {3.620120374761421*^9, 
   3.620120411152298*^9}, {3.62012059134039*^9, 3.6201206299114513`*^9}, {
   3.62012391285954*^9, 3.620123934632702*^9}, {3.620124649276807*^9, 
   3.620124650732354*^9}, {3.620125360416038*^9, 3.620125371846684*^9}, {
   3.620125946026581*^9, 3.620125958693842*^9}, {3.620127083161211*^9, 
   3.620127089007598*^9}, 3.6201271888244553`*^9, {3.6201273534852333`*^9, 
   3.620127355552799*^9}, {3.620220028809361*^9, 3.62022002967591*^9}, {
   3.620306586520327*^9, 3.6203065916317797`*^9}, {3.620307023918005*^9, 
   3.6203070240316277`*^9}, {3.620307252514659*^9, 3.620307252631892*^9}, {
   3.621157052357183*^9, 3.621157107669544*^9}, {3.621157222797364*^9, 
   3.621157245308032*^9}, {3.6211935897248383`*^9, 3.621193590582821*^9}, {
   3.621520586832548*^9, 3.6215205906136847`*^9}, {3.6215206760725813`*^9, 
   3.62152070636677*^9}, {3.62152085311343*^9, 3.621520858656086*^9}, {
   3.6215209109659443`*^9, 3.621520952739449*^9}, {3.621521137587742*^9, 
   3.621521148995653*^9}, {3.62152130564041*^9, 3.621521309623974*^9}, {
   3.6215214207634563`*^9, 3.621521420940029*^9}, {3.62152148614958*^9, 
   3.621521486401306*^9}, 3.62152156236625*^9, {3.621521856048818*^9, 
   3.621521864967599*^9}, {3.621521897842627*^9, 3.621521950777298*^9}, {
   3.621522745986074*^9, 3.6215227889371853`*^9}, {3.621522824205729*^9, 
   3.621522902407538*^9}, {3.6216613767899218`*^9, 3.621661379166711*^9}, {
   3.6216617976525803`*^9, 3.6216618054931393`*^9}, {3.622176882224999*^9, 
   3.622176916832407*^9}, {3.622354230999218*^9, 3.622354264027398*^9}, {
   3.622370968749147*^9, 3.6223709815104523`*^9}, {3.622371079357951*^9, 
   3.62237109262851*^9}, {3.622371585883605*^9, 3.6223716050995007`*^9}, {
   3.622448205124176*^9, 3.622448212127945*^9}, {3.622783472730138*^9, 
   3.622783478827718*^9}, {3.622784004698971*^9, 3.62278400784019*^9}, {
   3.62278469730939*^9, 3.622784701484828*^9}, {3.622883940292934*^9, 
   3.622883950132716*^9}, 3.6228841034593277`*^9, 3.6228841429689074`*^9, {
   3.622884507851056*^9, 3.6228845859707117`*^9}, {3.622884648367023*^9, 
   3.622884659071587*^9}, {3.622885663356473*^9, 3.622885666490945*^9}, {
   3.622885697256632*^9, 3.62288570950738*^9}, 3.62288581558117*^9, {
   3.622886298933775*^9, 3.622886317489414*^9}, 3.62288794695895*^9, {
   3.62288838486686*^9, 3.622888386546103*^9}, {3.6228885892388353`*^9, 
   3.622888593031371*^9}, {3.6228889397624598`*^9, 3.622888941891099*^9}, {
   3.6228890832031603`*^9, 3.622889083594805*^9}, 3.622889776534156*^9, {
   3.622890490803631*^9, 3.622890500986258*^9}, {3.622890563114365*^9, 
   3.6228905828498707`*^9}, {3.6228906243790083`*^9, 3.622890634506732*^9}, {
   3.625168494704246*^9, 3.625168500051457*^9}, {3.625171274817027*^9, 
   3.625171276108211*^9}, {3.625172330172715*^9, 3.6251723306635313`*^9}, {
   3.625173700295948*^9, 3.62517370588754*^9}, {3.626446614620759*^9, 
   3.6264466267086353`*^9}, {3.626447313290813*^9, 3.6264473177122602`*^9}, {
   3.6270706340375032`*^9, 3.627070723382229*^9}, 3.627070778980907*^9, {
   3.627070893114724*^9, 3.627070907013871*^9}, {3.6278843087727413`*^9, 
   3.627884317179058*^9}, {3.627884419399662*^9, 3.627884456876903*^9}, {
   3.6278844885564404`*^9, 3.6278845072512903`*^9}, {3.627884551492456*^9, 
   3.6278845524788523`*^9}, {3.62788458456876*^9, 3.627884585579464*^9}, {
   3.6281043068783493`*^9, 3.628104311542111*^9}, {3.634674109203328*^9, 
   3.634674111084433*^9}, {3.6346743720139313`*^9, 3.634674374533431*^9}, {
   3.6346760566328917`*^9, 3.63467610935947*^9}, {3.635846600174013*^9, 
   3.635846631239806*^9}, {3.636266711370366*^9, 3.636266712139296*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSmom", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Abs", "[", 
   RowBox[{
    RowBox[{"MhpoleHSSmom", "[", 
     RowBox[{
     "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
      ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2", 
      ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
      "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
      "Xt"}], "]"}], "-", 
    RowBox[{"MhpoleHSS", "[", 
     RowBox[{
     "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
      ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2", 
      ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
      "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
       ",", 
      RowBox[{"hiOrd", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6278839918160963`*^9, 3.627883993662992*^9}, 
   3.627884126799674*^9, 3.634674113372176*^9, {3.634674372016097*^9, 
   3.634674374537706*^9}, {3.638102786070503*^9, 3.638102786981468*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSmomfast", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "Q\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Abs", "[", 
   RowBox[{
    RowBox[{"MhpoleHSSmomfast", "[", 
     RowBox[{
     "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
      ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2", 
      ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
      "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
      "Xt"}], "]"}], "-", 
    RowBox[{"MhpoleHSSfast", "[", 
     RowBox[{
     "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
      ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2", 
      ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
      "Q\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
       ",", 
      RowBox[{"hiOrd", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}]}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627134470575588*^9, 3.627134551034861*^9}, {
   3.627828522341885*^9, 3.627828558731588*^9}, {3.627828635899735*^9, 
   3.627828638818606*^9}, {3.627828725138694*^9, 3.627828730298897*^9}, {
   3.627828905098318*^9, 3.627828905280657*^9}, {3.6278290222253923`*^9, 
   3.6278290224161997`*^9}, {3.627884026483934*^9, 3.627884031637231*^9}, 
   3.63467411489196*^9, {3.634674372017042*^9, 3.6346743745407*^9}, {
   3.636266733159192*^9, 3.636266733935186*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["SM higher order corrections", "Subsection",
 CellChangeTimes->{{3.6277298148840313`*^9, 3.627729864567634*^9}, {
  3.627729897007782*^9, 3.6277299153818398`*^9}, {3.6277347988334293`*^9, 
  3.627734810227992*^9}, {3.638606581113264*^9, 3.63860659101082*^9}, {
  3.638621916371808*^9, 3.638621918340021*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "\[CapitalDelta]MhpoleHSSSMfast", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSSM", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"MhpoleHSS", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", 
       RowBox[{"hiOrd", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0", ",", "1"}], "}"}]}], ",", "opts"}], 
      "]"}], "-", 
     RowBox[{"MhpoleHSS", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", 
       RowBox[{"hiOrd", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", "opts"}], 
      "]"}]}], "]"}], "+", "0.15"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6277346277674723`*^9, 3.627734690762897*^9}, {
  3.627829229873575*^9, 3.627829242846737*^9}, {3.634674117043105*^9, 
  3.634674132464158*^9}, {3.634674372018079*^9, 3.634674374544471*^9}, {
  3.6362650934275723`*^9, 3.636265097116261*^9}, {3.636265241787093*^9, 
  3.636265255174902*^9}, {3.63626530437537*^9, 3.6362653073541307`*^9}, {
  3.636265377090513*^9, 3.636265384219715*^9}, {3.63626545607407*^9, 
  3.6362654859941473`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "\[CapitalDelta]MhpoleHSSSMfast", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSSMfast", "[", 
   RowBox[{"mtilde_", ",", 
    RowBox[{"mQ1_", "?", "NumericQ"}], ",", "mQ2_", ",", "mQ3_", ",", "mU1_", 
    ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", "mD3_", ",", 
    "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", "mL2_", ",", "mL3_", 
    ",", "mA_", ",", "\[Mu]_", ",", "M1_", ",", "M2_", ",", "M3_", ",", 
    "tan\[Beta]_", ",", "Xt_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"MhpoleHSSfast", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", 
       RowBox[{"hiOrd", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0", ",", "1"}], "}"}]}], ",", "opts"}], 
      "]"}], "-", 
     RowBox[{"MhpoleHSSfast", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", 
       RowBox[{"hiOrd", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", "opts"}], 
      "]"}]}], "]"}], "+", "0.15"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627884631057171*^9, 3.62788464177741*^9}, {
   3.634674119182795*^9, 3.634674136568142*^9}, {3.6346743720196943`*^9, 
   3.634674374548543*^9}, {3.6362647934378977`*^9, 3.636264795390411*^9}, {
   3.636265004164653*^9, 3.636265005980968*^9}, {3.636265070739752*^9, 
   3.636265097976602*^9}, {3.636265260803458*^9, 3.636265298058297*^9}, 
   3.636265332506966*^9, {3.6362653861473846`*^9, 3.636265388251445*^9}, {
   3.636265483033991*^9, 3.63626549099436*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["SUSY: Variation of the renormalization scale", "Subsection",
 CellChangeTimes->{{3.6277347566848288`*^9, 3.62773477739375*^9}, {
  3.6278861048342733`*^9, 3.6278861106413803`*^9}, {3.63862163904125*^9, 
  3.6386216416581087`*^9}, {3.638621871016964*^9, 3.63862187250708*^9}, {
  3.63862192081959*^9, 3.638621924023325*^9}}],

Cell[CellGroupData[{

Cell["Manipulation", "Subsubsection",
 CellChangeTimes->{{3.627822957559412*^9, 3.627822966457753*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Beta]\[Beta]", "[", 
   SubscriptBox[
    OverscriptBox["g", "^"], "t"], "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"4", "\[Pi]"}], ")"}], "2"]], 
   SubscriptBox[
    OverscriptBox["g", "^"], "t"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "^"], "t"], "2"]}], "-", 
     RowBox[{
      FractionBox["16", "3"], 
      SuperscriptBox[
       SubscriptBox["g", "3"], "2"]}], "-", 
     RowBox[{"3", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "2"]}], "-", 
     RowBox[{
      FractionBox["13", "15"], 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]\[Beta]", "[", "\[Mu]", "]"}], ":=", 
  RowBox[{
   FractionBox["\[Mu]", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"4", "\[Pi]"}], ")"}], "2"]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "^"], "t"], "2"]}], "+", 
     RowBox[{"3", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "^"], "b"], "2"]}], "+", 
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["g", "^"], "\[Tau]"], "2"], "-", " ", 
     RowBox[{"3", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "2"]}], "-", " ", 
     RowBox[{
      FractionBox["3", "5"], 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]\[Beta]", "[", 
   SubscriptBox["a", "t"], "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]"}], ")"}], "2"]], 
    SubscriptBox["a", "t"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"18", 
       SuperscriptBox[
        SubscriptBox[
         OverscriptBox["g", "^"], "t"], "2"]}], "-", 
      RowBox[{
       FractionBox["16", "3"], 
       SuperscriptBox[
        SubscriptBox["g", "3"], "2"]}], "-", 
      RowBox[{"3", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"]}], "-", 
      RowBox[{
       FractionBox["13", "15"], 
       SuperscriptBox[
        SubscriptBox["g", "1"], "2"]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]"}], ")"}], "2"]], 
    SubscriptBox[
     OverscriptBox["g", "^"], "t"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["32", "3"], 
       SuperscriptBox[
        SubscriptBox["g", "3"], "2"], 
       SubscriptBox["M", "3"]}], "+", 
      RowBox[{"6", 
       SuperscriptBox[
        SubscriptBox["g", "2"], "2"], 
       SubscriptBox["M", "2"]}], "+", 
      RowBox[{
       FractionBox["26", "15"], 
       SuperscriptBox[
        SubscriptBox["g", "1"], "2"], 
       SubscriptBox["M", "1"]}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["XX", "t"], ":=", 
   RowBox[{
    RowBox[{"2", " ", 
     SubsuperscriptBox[
      OverscriptBox["g", "^"], "t", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", 
        SubscriptBox["H", "u"], "2"], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["u", "3"], "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      SubscriptBox["a", "t"], "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["XX", "b"], ":=", 
   RowBox[{
    RowBox[{"2", " ", 
     SubsuperscriptBox[
      OverscriptBox["g", "^"], "b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", 
        SubscriptBox["H", "u"], "2"], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "3"], "2"], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["u", "3"], "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      SubscriptBox["a", "b"], "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["XX", "\[Tau]"], ":=", 
   RowBox[{
    RowBox[{"2", " ", 
     SubsuperscriptBox[
      OverscriptBox["g", "^"], "\[Tau]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", 
        SubscriptBox["H", "u"], "2"], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["L", "3"], "2"], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["e", "3"], "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      SubscriptBox["a", "\[Tau]"], "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["a", "t"], ":=", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["g", "^"], "t"], 
    SubscriptBox["A", "t"]}]}], ";", 
  RowBox[{
   SubscriptBox["a", "b"], ":=", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["g", "^"], "b"], 
    SubscriptBox["A", "b"]}]}], ";", 
  RowBox[{
   SubscriptBox["a", "\[Tau]"], ":=", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["g", "^"], "\[Tau]"], 
    SubscriptBox["A", "\[Tau]"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S", " ", ":=", " ", 
   RowBox[{
    SubsuperscriptBox["m", 
     SubscriptBox["H", "u"], "2"], "-", 
    SubsuperscriptBox["m", 
     SubscriptBox["H", "d"], "2"], "+", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "3"], 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", 
        SubscriptBox["Q", "i"], "2"], "-", 
       SubsuperscriptBox["m", 
        SubscriptBox["L", "i"], "2"], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["m", 
         SubscriptBox["u", "i"], "2"]}], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["d", "i"], "2"], "+", 
       SubsuperscriptBox["m", 
        SubscriptBox["e", "i"], "2"]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Beta]\[Beta]", "[", 
    SubsuperscriptBox["m", 
     SubscriptBox["H", "u"], "2"], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SubscriptBox["XX", "t"]}], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["g", "2", "2"], " ", 
       SubsuperscriptBox["M", "2", "2"]}], "-", 
      RowBox[{
       FractionBox["6", "5"], " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       SubsuperscriptBox["M", "1", "2"]}], "+", " ", 
      FractionBox[
       RowBox[{"3", " ", 
        SubsuperscriptBox["g", "1", "2"], " ", "S"}], "5"]}], ")"}]}]}], ";", 
  
  RowBox[{
   RowBox[{"\[Beta]\[Beta]", "[", 
    SubsuperscriptBox["m", 
     SubscriptBox["H", "d"], "2"], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SubscriptBox["XX", "b"]}], "+", 
      SubscriptBox["XX", "\[Tau]"], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["g", "2", "2"], " ", 
       SubsuperscriptBox["M", "2", "2"]}], "-", 
      RowBox[{
       FractionBox["6", "5"], " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       SubsuperscriptBox["M", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubsuperscriptBox["g", "1", "2"], " ", "S"}], "5"]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Beta]\[Beta]", "[", 
    SubsuperscriptBox["m", 
     SubscriptBox["Q", "3"], "2"], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["XX", "t"], "-", 
      RowBox[{
       FractionBox["32", "3"], " ", 
       SubsuperscriptBox["g", "3", "2"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["g", "2", "2"], " ", 
       SubsuperscriptBox["M", "2", "2"]}], "-", 
      RowBox[{
       FractionBox["2", "15"], " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       SubsuperscriptBox["M", "1", "2"]}], "+", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["g", "1", "2"], " ", "S"}], "5"]}], ")"}]}]}], ";", 
  
  RowBox[{
   RowBox[{"\[Beta]\[Beta]", "[", 
    SubsuperscriptBox["m", 
     SubscriptBox["u", "3"], "2"], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       SubscriptBox["XX", "t"]}], "-", 
      RowBox[{
       FractionBox["32", "3"], " ", 
       SubsuperscriptBox["g", "3", "2"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{
       FractionBox["32", "15"], " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       SubsuperscriptBox["M", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubsuperscriptBox["g", "1", "2"], " ", "S"}], "5"]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Beta]\[Beta]", "[", 
    SubsuperscriptBox["m", 
     SubscriptBox["d", "3"], "2"], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       SubscriptBox["XX", "b"]}], "-", 
      RowBox[{
       FractionBox["32", "3"], " ", 
       SubsuperscriptBox["g", "3", "2"], " ", 
       SubsuperscriptBox["M", "3", "2"]}], "-", 
      RowBox[{
       FractionBox["8", "15"], " ", 
       SubsuperscriptBox["g", "1", "2"], " ", 
       SubsuperscriptBox["M", "1", "2"]}], "+", 
      RowBox[{
       FractionBox["2", "5"], " ", 
       SubsuperscriptBox["g", "1", "2"], " ", "S"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]\[Beta]", "[", 
   SubscriptBox["X", "t"], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Beta]\[Beta]", "[", 
    SubscriptBox["A", "t"], "]"}], "-", 
   FractionBox[
    RowBox[{"\[Beta]\[Beta]", "[", "\[Mu]", "]"}], 
    RowBox[{"Tan", "[", "\[Beta]", "]"}]], "+", 
   RowBox[{
    FractionBox["\[Mu]", 
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"Tan", "[", "\[Beta]", "]"}], "3"]}]], 
    RowBox[{"\[Beta]\[Beta]", "[", 
     SuperscriptBox["tan\[Beta]", "2"], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]\[Beta]", "[", 
   SubscriptBox["A", "t"], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox["1", 
     SubscriptBox[
      OverscriptBox["g", "^"], "t"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Beta]\[Beta]", "[", 
       SubscriptBox["a", "t"], "]"}], "-", 
      RowBox[{
       RowBox[{"\[Beta]\[Beta]", "[", 
        SubscriptBox[
         OverscriptBox["g", "^"], "t"], "]"}], 
       SubscriptBox["A", "t"]}]}], ")"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Gamma]", "2"], ":=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", 
     SuperscriptBox["\[Pi]", "2"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"9", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "2"]}], "+", 
     RowBox[{"3", 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}], "-", 
     RowBox[{"12", 
      SuperscriptBox[
       SubscriptBox[
        OverscriptBox["g", "^"], "t"], "2"]}], "-", 
     RowBox[{"6", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "2"]}], "-", 
     RowBox[{"2", 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Gamma]", "1"], ":=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", 
     SuperscriptBox["\[Pi]", "2"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"9", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "2"]}], "+", 
     RowBox[{"3", 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}], "-", 
     RowBox[{"6", 
      SuperscriptBox[
       SubscriptBox["g", "2"], "2"]}], "-", 
     RowBox[{"2", 
      SuperscriptBox[
       SubscriptBox["g", "1"], "2"]}]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]\[Beta]", "[", 
   SuperscriptBox["tan\[Beta]", "2"], "]"}], ":=", 
  RowBox[{"2", 
   SuperscriptBox[
    RowBox[{"Tan", "[", "\[Beta]", "]"}], "2"], 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Gamma]", "2"], "-", 
     SubscriptBox["\[Gamma]", "1"]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replacements1", ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "\[Rule]", "D"}], ",", 
     RowBox[{"e", "\[Rule]", "E"}], ",", 
     RowBox[{"u", "\[Rule]", "U"}], ",", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["m", 
        SubscriptBox["H", "u"]], "2"], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["mA", "2"], 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Beta]", "]"}], "2"]}], "-", 
       SuperscriptBox["\[Mu]", "2"]}]}], ",", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["m", 
        SubscriptBox["H", "d"]], "2"], "\[Rule]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["mA", "2"], 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Beta]", "]"}], "2"]}], "-", 
       SuperscriptBox["\[Mu]", "2"]}]}], ",", 
     RowBox[{
      SubscriptBox["XX", "\[Tau]"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["A", "t"], "\[Rule]", 
      RowBox[{"Xt", "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"Cot", "[", "\[Beta]", "]"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["A", "b"], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["A", "\[Tau]"], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replacements2", ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["m", 
        SubscriptBox["x_", "y_"]], "2"], "\[RuleDelayed]", 
      SuperscriptBox[
       RowBox[{"Symbol", "[", 
        RowBox[{"\"\<m\>\"", "<>", 
         RowBox[{"ToString", "[", "x", "]"}], "<>", 
         RowBox[{"ToString", "[", "y", "]"}]}], "]"}], "2"]}], ",", 
     RowBox[{
      SubscriptBox["M", "x_"], "\[RuleDelayed]", 
      RowBox[{"Symbol", "[", 
       RowBox[{"\"\<M\>\"", "<>", 
        RowBox[{"ToString", "[", "x", "]"}]}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["X", "t"], "\[Rule]", "Xt"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"ArcTan", "[", "tan\[Beta]", "]"}]}], ",", 
     RowBox[{
      SubscriptBox["g", "1"], "\[Rule]", 
      RowBox[{"g1SM", "[", 
       RowBox[{"Log", "[", 
        FractionBox["mtilde", "MT"], "]"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["g", "2"], "\[Rule]", 
      RowBox[{"g2SM", "[", 
       RowBox[{"Log", "[", 
        FractionBox["mtilde", "MT"], "]"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["g", "3"], "\[Rule]", 
      RowBox[{"g3SM", "[", 
       RowBox[{"Log", "[", 
        FractionBox["mtilde", "MT"], "]"}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["g", "^"], "t"], "\[Rule]", 
      RowBox[{"gtMSSM", "[", 
       RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["g", "^"], "b"], "->", 
      RowBox[{"gbMSSM", "[", 
       RowBox[{
       "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", "\[Mu]", 
        ",", "tan\[Beta]", ",", "Xt"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["g", "^"], "\[Tau]"], "\[Rule]", 
      RowBox[{"gtauMSSM", "[", 
       RowBox[{
       "mtilde", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", "\[Mu]", 
        ",", "tan\[Beta]"}], "]"}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.623570506065742*^9, 3.6235706190063133`*^9}, {
   3.623570661662108*^9, 3.623570665349971*^9}, {3.6235707469337597`*^9, 
   3.623570769678277*^9}, {3.62357145620296*^9, 3.6235714858423643`*^9}, {
   3.623574874477379*^9, 3.623574919206504*^9}, 3.623575666557725*^9, {
   3.6235759118206253`*^9, 3.623576169503047*^9}, {3.623576571422017*^9, 
   3.623576591133855*^9}, {3.623576739021027*^9, 3.62357678478435*^9}, {
   3.623576851251732*^9, 3.623576878826859*^9}, {3.623576943477681*^9, 
   3.6235770355176373`*^9}, {3.623577735623693*^9, 3.6235777864737062`*^9}, {
   3.623579513258267*^9, 3.623579524216441*^9}, {3.627735823950989*^9, 
   3.627735858853792*^9}, {3.6277358945832577`*^9, 3.62773590097355*^9}, {
   3.627736137799953*^9, 3.62773619427773*^9}, {3.6278002461969767`*^9, 
   3.627800307108191*^9}, {3.627800370148155*^9, 3.627800469689794*^9}, {
   3.6278005030823307`*^9, 3.627800504617968*^9}, {3.6278007115294847`*^9, 
   3.627800761530963*^9}, {3.627800797581087*^9, 3.6278008158187313`*^9}, {
   3.627800956297986*^9, 3.627801158864912*^9}, {3.627801209865349*^9, 
   3.6278012423135357`*^9}, {3.627801700199403*^9, 3.627801714013462*^9}, 
   3.627802029660954*^9, {3.627814172269162*^9, 3.6278141742009068`*^9}, {
   3.627814849164611*^9, 3.6278148627081413`*^9}, {3.627814992592711*^9, 
   3.6278150051553297`*^9}, {3.627816948178911*^9, 3.627817086684369*^9}, {
   3.627817481857566*^9, 3.627817522690165*^9}, {3.627817713245708*^9, 
   3.627817715176754*^9}, {3.627817949429847*^9, 3.62781795617409*^9}, {
   3.627818028344873*^9, 3.6278180315280313`*^9}, 3.6278197768703537`*^9, 
   3.6278198072882557`*^9, 3.627820046396559*^9, {3.627820558971903*^9, 
   3.627820559540704*^9}, {3.62782287830796*^9, 3.627822878656699*^9}, {
   3.627825737272793*^9, 3.6278257808154488`*^9}, {3.637938061125621*^9, 
   3.637938069597762*^9}, {3.637938128040621*^9, 3.637938171402048*^9}, {
   3.637938260420535*^9, 3.6379383173644753`*^9}, {3.637938370149568*^9, 
   3.6379383876053762`*^9}, {3.637940053838626*^9, 3.6379400589782267`*^9}, {
   3.637940133287661*^9, 3.637940183665292*^9}, {3.637994737512665*^9, 
   3.6379948343132553`*^9}, {3.637994923095311*^9, 3.637994955326603*^9}, {
   3.637995006725306*^9, 3.6379950298115177`*^9}, {3.6379950979729156`*^9, 
   3.6379951424446383`*^9}, {3.6379952224886103`*^9, 3.637995264457757*^9}, {
   3.637995300817782*^9, 3.6379953580111427`*^9}, {3.637996213813497*^9, 
   3.637996293443372*^9}, {3.637996436867977*^9, 3.637996451360841*^9}, {
   3.6379999508930492`*^9, 3.6379999627157507`*^9}, 3.638001812825713*^9, {
   3.638002915754423*^9, 3.638002924996542*^9}, {3.638003540552355*^9, 
   3.638003546642311*^9}, {3.63804074370811*^9, 3.63804081965053*^9}, {
   3.638040957129609*^9, 3.63804096469559*^9}, 3.6380411062045*^9, 
   3.638041147781807*^9, {3.638041734654127*^9, 3.638041735900879*^9}, {
   3.638041790653694*^9, 3.6380417970947123`*^9}, {3.6380418718726797`*^9, 
   3.638041873032785*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["mQ3", "2"], "+", 
      RowBox[{
       RowBox[{"\[Beta]\[Beta]", "[", 
        SuperscriptBox[
         SubscriptBox["m", 
          SubscriptBox["Q", "3"]], "2"], "]"}], 
       RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["mU3", "2"], "+", 
      RowBox[{
       RowBox[{"\[Beta]\[Beta]", "[", 
        SuperscriptBox[
         SubscriptBox["m", 
          SubscriptBox["u", "3"]], "2"], "]"}], 
       RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["mD3", "2"], "+", 
      RowBox[{
       RowBox[{"\[Beta]\[Beta]", "[", 
        SuperscriptBox[
         SubscriptBox["m", 
          SubscriptBox["d", "3"]], "2"], "]"}], 
       RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
     RowBox[{"\[Mu]", "+", 
      RowBox[{
       RowBox[{"\[Beta]\[Beta]", "[", "\[Mu]", "]"}], 
       RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
     RowBox[{
      SubscriptBox["X", "t"], "+", 
      RowBox[{
       RowBox[{"\[Beta]\[Beta]", "[", 
        SubscriptBox["X", "t"], "]"}], 
       RowBox[{"Log", "[", "n", "]"}]}]}]}], "}"}], "/.", "replacements1"}], "/.",
   "replacements2"}]], "Input",
 CellChangeTimes->{{3.6278258067668743`*^9, 3.627825885807932*^9}, {
  3.637994893713087*^9, 3.637994903479546*^9}, {3.6379963631428623`*^9, 
  3.637996387464511*^9}, {3.6380410149372187`*^9, 3.638041048918027*^9}, {
  3.6380411563725443`*^9, 3.638041156719357*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["mQ3", "2"], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["2", "15"]}], " ", 
         SuperscriptBox["M1", "2"], " ", 
         SuperscriptBox[
          RowBox[{"g1SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mD1", "2"], "+", 
           SuperscriptBox["mD2", "2"], "+", 
           SuperscriptBox["mD3", "2"], "+", 
           SuperscriptBox["mE1", "2"], "+", 
           SuperscriptBox["mE2", "2"], "+", 
           SuperscriptBox["mE3", "2"], "-", 
           SuperscriptBox["mL1", "2"], "-", 
           SuperscriptBox["mL2", "2"], "-", 
           SuperscriptBox["mL3", "2"], "+", 
           SuperscriptBox["mQ1", "2"], "+", 
           SuperscriptBox["mQ2", "2"], "+", 
           SuperscriptBox["mQ3", "2"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU1", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU2", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU3", "2"]}], "+", 
           FractionBox[
            SuperscriptBox["mA", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["mA", "2"], " ", 
             SuperscriptBox["tan\[Beta]", "2"]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"g1SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["M2", "2"], " ", 
         SuperscriptBox[
          RowBox[{"g2SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
        RowBox[{
         FractionBox["32", "3"], " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"g3SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"Xt", "+", 
            FractionBox["\[Mu]", "tan\[Beta]"]}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"gtMSSM", "[", 
           RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mQ3", "2"], "+", 
           SuperscriptBox["mU3", "2"], "+", 
           FractionBox[
            SuperscriptBox["mA", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"gtMSSM", "[", 
           RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "n", "]"}]}]}]}], ",", 
   RowBox[{
    SuperscriptBox["mU3", "2"], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["32", "15"]}], " ", 
         SuperscriptBox["M1", "2"], " ", 
         SuperscriptBox[
          RowBox[{"g1SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
        RowBox[{
         FractionBox["4", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mD1", "2"], "+", 
           SuperscriptBox["mD2", "2"], "+", 
           SuperscriptBox["mD3", "2"], "+", 
           SuperscriptBox["mE1", "2"], "+", 
           SuperscriptBox["mE2", "2"], "+", 
           SuperscriptBox["mE3", "2"], "-", 
           SuperscriptBox["mL1", "2"], "-", 
           SuperscriptBox["mL2", "2"], "-", 
           SuperscriptBox["mL3", "2"], "+", 
           SuperscriptBox["mQ1", "2"], "+", 
           SuperscriptBox["mQ2", "2"], "+", 
           SuperscriptBox["mQ3", "2"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU1", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU2", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU3", "2"]}], "+", 
           FractionBox[
            SuperscriptBox["mA", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["mA", "2"], " ", 
             SuperscriptBox["tan\[Beta]", "2"]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"g1SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
        RowBox[{
         FractionBox["32", "3"], " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"g3SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"Xt", "+", 
               FractionBox["\[Mu]", "tan\[Beta]"]}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"gtMSSM", "[", 
              RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "+", 
              SuperscriptBox["mU3", "2"], "+", 
              FractionBox[
               SuperscriptBox["mA", "2"], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"gtMSSM", "[", 
              RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], 
          ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "n", "]"}]}]}]}], ",", 
   RowBox[{
    SuperscriptBox["mD3", "2"], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["8", "15"]}], " ", 
         SuperscriptBox["M1", "2"], " ", 
         SuperscriptBox[
          RowBox[{"g1SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         FractionBox["2", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mD1", "2"], "+", 
           SuperscriptBox["mD2", "2"], "+", 
           SuperscriptBox["mD3", "2"], "+", 
           SuperscriptBox["mE1", "2"], "+", 
           SuperscriptBox["mE2", "2"], "+", 
           SuperscriptBox["mE3", "2"], "-", 
           SuperscriptBox["mL1", "2"], "-", 
           SuperscriptBox["mL2", "2"], "-", 
           SuperscriptBox["mL3", "2"], "+", 
           SuperscriptBox["mQ1", "2"], "+", 
           SuperscriptBox["mQ2", "2"], "+", 
           SuperscriptBox["mQ3", "2"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU1", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU2", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["mU3", "2"]}], "+", 
           FractionBox[
            SuperscriptBox["mA", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["mA", "2"], " ", 
             SuperscriptBox["tan\[Beta]", "2"]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"g1SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
        RowBox[{
         FractionBox["32", "3"], " ", 
         SuperscriptBox["M3", "2"], " ", 
         SuperscriptBox[
          RowBox[{"g3SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mQ3", "2"], "+", 
           SuperscriptBox["mU3", "2"], "+", 
           FractionBox[
            SuperscriptBox["mA", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"gbMSSM", "[", 
           RowBox[{
           "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", 
            "\[Mu]", ",", "tan\[Beta]", ",", "Xt"}], "]"}], "2"]}]}], ")"}], 
      " ", 
      RowBox[{"Log", "[", "n", "]"}]}]}]}], ",", 
   RowBox[{"\[Mu]", "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["3", "5"]}], " ", 
         SuperscriptBox[
          RowBox[{"g1SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"g2SM", "[", 
           RowBox[{"Log", "[", 
            FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"gbMSSM", "[", 
           RowBox[{
           "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", 
            "\[Mu]", ",", "tan\[Beta]", ",", "Xt"}], "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"gtauMSSM", "[", 
          RowBox[{
          "mtilde", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", 
           "\[Mu]", ",", "tan\[Beta]"}], "]"}], "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"gtMSSM", "[", 
           RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "n", "]"}]}]}]}], ",", 
   RowBox[{"Xt", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", "tan\[Beta]"}]], 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox["3", "5"]}], " ", 
             SuperscriptBox[
              RowBox[{"g1SM", "[", 
               RowBox[{"Log", "[", 
                FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{"g2SM", "[", 
               RowBox[{"Log", "[", 
                FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{"gbMSSM", "[", 
               RowBox[{
               "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", 
                "\[Mu]", ",", "tan\[Beta]", ",", "Xt"}], "]"}], "2"]}], "+", 
            SuperscriptBox[
             RowBox[{"gtauMSSM", "[", 
              RowBox[{
              "mtilde", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", 
               "\[Mu]", ",", "tan\[Beta]"}], "]"}], "2"], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{"gtMSSM", "[", 
               RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], 
           ")"}]}]}]}], "+", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"120", " ", 
          SuperscriptBox["\[Pi]", "2"]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"13", " ", "M1", " ", 
           SuperscriptBox[
            RowBox[{"g1SM", "[", 
             RowBox[{"Log", "[", 
              FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
          RowBox[{"45", " ", "M2", " ", 
           SuperscriptBox[
            RowBox[{"g2SM", "[", 
             RowBox[{"Log", "[", 
              FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
          RowBox[{"80", " ", "M3", " ", 
           SuperscriptBox[
            RowBox[{"g3SM", "[", 
             RowBox[{"Log", "[", 
              FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
          RowBox[{"90", " ", 
           RowBox[{"(", 
            RowBox[{"Xt", "+", 
             FractionBox["\[Mu]", "tan\[Beta]"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"gtMSSM", "[", 
             RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], ")"}]}], 
       "+", 
       RowBox[{
        FractionBox["1", "tan\[Beta]"], 
        RowBox[{"\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"g1SM", "[", 
                RowBox[{"Log", "[", 
                 FractionBox["mtilde", "MT"], "]"}], "]"}], "2"], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"g2SM", "[", 
                 RowBox[{"Log", "[", 
                  FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}]}], 
             RowBox[{"64", " ", 
              SuperscriptBox["\[Pi]", "2"]}]]}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"g1SM", "[", 
               RowBox[{"Log", "[", 
                FractionBox["mtilde", "MT"], "]"}], "]"}], "2"], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{"g2SM", "[", 
                RowBox[{"Log", "[", 
                 FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
             RowBox[{"12", " ", 
              SuperscriptBox[
               RowBox[{"gtMSSM", "[", 
                RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], 
            RowBox[{"64", " ", 
             SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", "n", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6278258412506723`*^9, 3.627825852382668*^9}, 
   3.627825888309849*^9, {3.6379963652178087`*^9, 3.6379963882283487`*^9}, {
   3.638041001834654*^9, 3.638041049701891*^9}, 3.638041109818048*^9, {
   3.638041153662575*^9, 3.638041157446947*^9}, 3.6380417413180933`*^9, {
   3.638041800316886*^9, 3.6380418271262503`*^9}, 3.638041973918648*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"OS", " ", "scheme"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Beta]\[Beta]", "[", "XtOS", "]"}], ":=", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"4", "\[Pi]"}], ")"}], "2"]], "Xt", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", 
        SuperscriptBox[
         SubscriptBox["g", "3"], "2"]}], "-", 
       RowBox[{
        FractionBox["3", "2"], 
        SuperscriptBox[
         SubscriptBox["g", "t"], "2"]}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Xt", "+", 
     RowBox[{
      RowBox[{"\[Beta]\[Beta]", "[", "XtOS", "]"}], 
      RowBox[{"Log", "[", "n", "]"}]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["g", "3"], "\[Rule]", 
       RowBox[{"g3SM", "[", 
        RowBox[{"Log", "[", 
         FractionBox["mtilde", "MT"], "]"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["g", "t"], "->", 
       RowBox[{"gtSM", "[", 
        RowBox[{"Log", "[", 
         FractionBox["mtilde", "MT"], "]"}], "]"}]}]}], "}"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.638087569785364*^9, 3.638087683904365*^9}}],

Cell[BoxData[
 RowBox[{"Xt", "+", 
  FractionBox[
   RowBox[{"Xt", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       SuperscriptBox[
        RowBox[{"g3SM", "[", 
         RowBox[{"Log", "[", 
          FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox[
        RowBox[{"gtSM", "[", 
         RowBox[{"Log", "[", 
          FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}]}], ")"}], " ", 
    RowBox[{"Log", "[", "n", "]"}]}], 
   RowBox[{"16", " ", 
    SuperscriptBox["\[Pi]", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.638087586469493*^9, 3.638087641603653*^9}, 
   3.63808768650835*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Variation of the spectrum", "Subsubsection",
 CellChangeTimes->{{3.627823005663177*^9, 3.627823030201768*^9}, {
  3.627823075978513*^9, 3.6278231841996403`*^9}, {3.6380413169404488`*^9, 
  3.638041326931568*^9}, {3.638606623848144*^9, 3.638606625583047*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"At", " ", "the", " ", "moment", " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["m", 
      SubscriptBox["Q", "3"], "2"], ",", 
     SubsuperscriptBox["m", 
      SubscriptBox["U", "3"], "2"], ",", 
     SuperscriptBox[
      SubscriptBox["m", 
       SubscriptBox["D", "3"]], "2"], ",", "\[Mu]", ",", 
     SubscriptBox["X", "t"]}], ")"}], " ", "are", " ", 
   RowBox[{"varied", "."}]}], TraditionalForm]], "Text",
 CellChangeTimes->{{3.638606638037259*^9, 3.638606644130307*^9}, {
  3.6386214357142267`*^9, 3.638621452883233*^9}}],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"g1SM", ",", "g2SM", ",", "g3SM", ",", "gtSM"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g1SM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"g1", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g2SM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"g2", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"g3SM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"g3", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gtSM", "[", "Qtup_", "]"}], ":=", 
     RowBox[{
      RowBox[{"gt", "[", "Qtup", "]"}], "/.", "solSM3l"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"spectrum", "[", 
      RowBox[{
      "n_", ",", "mtilde_", ",", "mQ1_", ",", "mQ2_", ",", "mQ3_", ",", 
       "mU1_", ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", ",", 
       "mD3_", ",", "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", 
       "mL2_", ",", "mL3_", ",", "mA_", ",", "\[Mu]_", ",", "M1_", ",", "M2_",
        ",", "M3_", ",", "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["mQ3", "2"], "+", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Pi]", "2"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["2", "15"]}], " ", 
            SuperscriptBox["M1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"g1SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            FractionBox["1", "5"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mD1", "2"], "+", 
              SuperscriptBox["mD2", "2"], "+", 
              SuperscriptBox["mD3", "2"], "+", 
              SuperscriptBox["mE1", "2"], "+", 
              SuperscriptBox["mE2", "2"], "+", 
              SuperscriptBox["mE3", "2"], "-", 
              SuperscriptBox["mL1", "2"], "-", 
              SuperscriptBox["mL2", "2"], "-", 
              SuperscriptBox["mL3", "2"], "+", 
              SuperscriptBox["mQ1", "2"], "+", 
              SuperscriptBox["mQ2", "2"], "+", 
              SuperscriptBox["mQ3", "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU1", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU2", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU3", "2"]}], "+", 
              FractionBox[
               SuperscriptBox["mA", "2"], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["mA", "2"], " ", 
                SuperscriptBox["tan\[Beta]", "2"]}], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"g1SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["M2", "2"], " ", 
            SuperscriptBox[
             RowBox[{"g2SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
           RowBox[{
            FractionBox["32", "3"], " ", 
            SuperscriptBox["M3", "2"], " ", 
            SuperscriptBox[
             RowBox[{"g3SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"Xt", "+", 
               FractionBox["\[Mu]", "tan\[Beta]"]}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"gtMSSM", "[", 
              RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "+", 
              SuperscriptBox["mU3", "2"], "+", 
              FractionBox[
               SuperscriptBox["mA", "2"], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"gtMSSM", "[", 
              RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], ")"}], 
         " ", 
         RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
       RowBox[{
        SuperscriptBox["mU3", "2"], "+", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Pi]", "2"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["32", "15"]}], " ", 
            SuperscriptBox["M1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"g1SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
           RowBox[{
            FractionBox["4", "5"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mD1", "2"], "+", 
              SuperscriptBox["mD2", "2"], "+", 
              SuperscriptBox["mD3", "2"], "+", 
              SuperscriptBox["mE1", "2"], "+", 
              SuperscriptBox["mE2", "2"], "+", 
              SuperscriptBox["mE3", "2"], "-", 
              SuperscriptBox["mL1", "2"], "-", 
              SuperscriptBox["mL2", "2"], "-", 
              SuperscriptBox["mL3", "2"], "+", 
              SuperscriptBox["mQ1", "2"], "+", 
              SuperscriptBox["mQ2", "2"], "+", 
              SuperscriptBox["mQ3", "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU1", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU2", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU3", "2"]}], "+", 
              FractionBox[
               SuperscriptBox["mA", "2"], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["mA", "2"], " ", 
                SuperscriptBox["tan\[Beta]", "2"]}], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"g1SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
           RowBox[{
            FractionBox["32", "3"], " ", 
            SuperscriptBox["M3", "2"], " ", 
            SuperscriptBox[
             RowBox[{"g3SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"Xt", "+", 
                  FractionBox["\[Mu]", "tan\[Beta]"]}], ")"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"gtMSSM", "[", 
                 RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["mQ3", "2"], "+", 
                 SuperscriptBox["mU3", "2"], "+", 
                 FractionBox[
                  SuperscriptBox["mA", "2"], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
                 SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"gtMSSM", "[", 
                 RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], 
             ")"}]}]}], ")"}], " ", 
         RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
       RowBox[{
        SuperscriptBox["mD3", "2"], "+", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Pi]", "2"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["8", "15"]}], " ", 
            SuperscriptBox["M1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"g1SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            FractionBox["2", "5"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mD1", "2"], "+", 
              SuperscriptBox["mD2", "2"], "+", 
              SuperscriptBox["mD3", "2"], "+", 
              SuperscriptBox["mE1", "2"], "+", 
              SuperscriptBox["mE2", "2"], "+", 
              SuperscriptBox["mE3", "2"], "-", 
              SuperscriptBox["mL1", "2"], "-", 
              SuperscriptBox["mL2", "2"], "-", 
              SuperscriptBox["mL3", "2"], "+", 
              SuperscriptBox["mQ1", "2"], "+", 
              SuperscriptBox["mQ2", "2"], "+", 
              SuperscriptBox["mQ3", "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU1", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU2", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["mU3", "2"]}], "+", 
              FractionBox[
               SuperscriptBox["mA", "2"], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["mA", "2"], " ", 
                SuperscriptBox["tan\[Beta]", "2"]}], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"g1SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
           RowBox[{
            FractionBox["32", "3"], " ", 
            SuperscriptBox["M3", "2"], " ", 
            SuperscriptBox[
             RowBox[{"g3SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mQ3", "2"], "+", 
              SuperscriptBox["mU3", "2"], "+", 
              FractionBox[
               SuperscriptBox["mA", "2"], 
               RowBox[{"1", "+", 
                SuperscriptBox["tan\[Beta]", "2"]}]], "-", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"gbMSSM", "[", 
              RowBox[{
              "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", 
               "\[Mu]", ",", "tan\[Beta]", ",", "Xt"}], "]"}], "2"]}]}], 
          ")"}], " ", 
         RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
       RowBox[{"\[Mu]", "+", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Pi]", "2"]}]], "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["3", "5"]}], " ", 
            SuperscriptBox[
             RowBox[{"g1SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{"g2SM", "[", 
              RowBox[{"Log", "[", 
               FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{"gbMSSM", "[", 
              RowBox[{
              "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", 
               "\[Mu]", ",", "tan\[Beta]", ",", "Xt"}], "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{"gtauMSSM", "[", 
             RowBox[{
             "mtilde", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", 
              "\[Mu]", ",", "tan\[Beta]"}], "]"}], "2"], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{"gtMSSM", "[", 
              RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], ")"}], 
         " ", 
         RowBox[{"Log", "[", "n", "]"}]}]}], ",", 
       RowBox[{"Xt", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", 
              RowBox[{"16", " ", 
               SuperscriptBox["\[Pi]", "2"], " ", "tan\[Beta]"}]]}], "\[Mu]", 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                FractionBox["3", "5"]}], " ", 
               SuperscriptBox[
                RowBox[{"g1SM", "[", 
                 RowBox[{"Log", "[", 
                  FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"g2SM", "[", 
                 RowBox[{"Log", "[", 
                  FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"gbMSSM", "[", 
                 RowBox[{
                 "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",",
                   "\[Mu]", ",", "tan\[Beta]", ",", "Xt"}], "]"}], "2"]}], 
              "+", 
              SuperscriptBox[
               RowBox[{"gtauMSSM", "[", 
                RowBox[{
                "mtilde", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", 
                 "\[Mu]", ",", "tan\[Beta]"}], "]"}], "2"], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"gtMSSM", "[", 
                 RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], 
             ")"}]}], "+", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"120", " ", 
              SuperscriptBox["\[Pi]", "2"]}]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"13", " ", "M1", " ", 
               SuperscriptBox[
                RowBox[{"g1SM", "[", 
                 RowBox[{"Log", "[", 
                  FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
              RowBox[{"45", " ", "M2", " ", 
               SuperscriptBox[
                RowBox[{"g2SM", "[", 
                 RowBox[{"Log", "[", 
                  FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
              RowBox[{"80", " ", "M3", " ", 
               SuperscriptBox[
                RowBox[{"g3SM", "[", 
                 RowBox[{"Log", "[", 
                  FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "+", 
              RowBox[{"90", " ", 
               RowBox[{"(", 
                RowBox[{"Xt", "+", 
                 FractionBox["\[Mu]", "tan\[Beta]"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"gtMSSM", "[", 
                 RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], 
             ")"}]}], "+", 
           RowBox[{
            FractionBox["1", "tan\[Beta]"], 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"g1SM", "[", 
                    RowBox[{"Log", "[", 
                    FractionBox["mtilde", "MT"], "]"}], "]"}], "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"g2SM", "[", 
                    RowBox[{"Log", "[", 
                    FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}]}], 
                 RowBox[{"64", " ", 
                  SuperscriptBox["\[Pi]", "2"]}]]}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"g1SM", "[", 
                   RowBox[{"Log", "[", 
                    FractionBox["mtilde", "MT"], "]"}], "]"}], "2"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox[
                   RowBox[{"g2SM", "[", 
                    RowBox[{"Log", "[", 
                    FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
                 RowBox[{"12", " ", 
                  SuperscriptBox[
                   RowBox[{"gtMSSM", "[", 
                    RowBox[{"mtilde", ",", "tan\[Beta]"}], "]"}], "2"]}]}], 
                RowBox[{"64", " ", 
                 SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]}]}], ")"}], " ", 
         RowBox[{"Log", "[", "n", "]"}]}]}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"XtOS", "[", 
      RowBox[{"n_", ",", "mtilde_", ",", "Xt_"}], "]"}], ":=", 
     RowBox[{"Xt", "+", 
      FractionBox[
       RowBox[{"Xt", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"g3SM", "[", 
             RowBox[{"Log", "[", 
              FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}], "-", 
          RowBox[{
           FractionBox["3", "2"], " ", 
           SuperscriptBox[
            RowBox[{"gtSM", "[", 
             RowBox[{"Log", "[", 
              FractionBox["mtilde", "MT"], "]"}], "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"Log", "[", "n", "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["\[Pi]", "2"]}]]}]}]}]}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627822045194447*^9, 3.62782215936069*^9}, 
   3.627822237173196*^9, 3.627822316390059*^9, {3.627822622311377*^9, 
   3.6278226474760923`*^9}, {3.627822717137282*^9, 3.627822758308424*^9}, {
   3.6278259855492*^9, 3.627826019595319*^9}, {3.627826060734928*^9, 
   3.627826100123084*^9}, {3.627826640809226*^9, 3.627826641642536*^9}, {
   3.6346758719986267`*^9, 3.634675969289523*^9}, {3.638041221093498*^9, 
   3.638041239585245*^9}, {3.638041271830147*^9, 3.638041274556921*^9}, {
   3.638041761529141*^9, 3.6380417678596897`*^9}, {3.638041814577894*^9, 
   3.638041816619467*^9}, {3.6380419875258617`*^9, 3.6380419888678017`*^9}, {
   3.638087727346834*^9, 3.6380877581053667`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculation", "Subsubsection",
 CellChangeTimes->{{3.6278234466433897`*^9, 3.627823453245495*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "\[CapitalDelta]MhpoleHSSQ", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DR\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSQ", "[", 
   RowBox[{
    RowBox[{"n_", "?", "positiveQ"}], ",", "mtilde_", ",", "mQ1_", ",", 
    "mQ2_", ",", "mQ3_", ",", "mU1_", ",", "mU2_", ",", "mU3_", ",", "mD1_", 
    ",", "mD2_", ",", "mD3_", ",", "mE1_", ",", "mE2_", ",", "mE3_", ",", 
    "mL1_", ",", "mL2_", ",", "mL3_", ",", "mA_", ",", "\[Mu]_", ",", "M1_", 
    ",", "M2_", ",", "M3_", ",", "tan\[Beta]_", ",", "Xt_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"OptionValue", "[", "scheme", "]"}], "\[Equal]", "\"\<OS\>\""}], 
    ",", 
    RowBox[{
     RowBox[{"MhpoleHSS", "[", 
      RowBox[{
       RowBox[{"n", " ", "mtilde"}], ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", 
       "mU1", ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",",
        "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", 
       ",", "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
       "tan\[Beta]", ",", 
       RowBox[{"XtOS", "[", 
        RowBox[{"n", ",", "mtilde", ",", "Xt"}], "]"}], ",", "opts"}], "]"}], 
     "-", 
     RowBox[{"MhpoleHSS", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", "opts"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "mQ32new", ",", "mU32new", ",", "mD32new", ",", "\[Mu]new", ",", 
        "Xtnew"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "mQ32new", ",", "mU32new", ",", "mD32new", ",", "\[Mu]new", ",", 
          "Xtnew"}], "}"}], "=", 
        RowBox[{"spectrum", "[", 
         RowBox[{
         "n", ",", "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", 
          ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", 
          "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", 
          ",", "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
          "tan\[Beta]", ",", "Xt"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           RowBox[{"mQ32new", ">", "0"}], "&&", 
           RowBox[{"mU32new", ">", "0"}], "&&", 
           RowBox[{"mD32new", ">", "0"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{"\[CapitalDelta]MHiggs", "::", "tachyon"}], "]"}], ";", 
          RowBox[{"Return", "[", "125", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"MhpoleHSS", "[", 
         RowBox[{
          RowBox[{"n", " ", "mtilde"}], ",", "mQ1", ",", "mQ2", ",", 
          SqrtBox["mQ32new"], ",", "mU1", ",", "mU2", ",", 
          SqrtBox["mU32new"], ",", "mD1", ",", "mD2", ",", 
          SqrtBox["mD32new"], ",", "mE1", ",", "mE2", ",", "mE3", ",", "mL1", 
          ",", "mL2", ",", "mL3", ",", "mA", ",", "\[Mu]new", ",", "M1", ",", 
          "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xtnew", ",", "opts"}], 
         "]"}], "-", 
        RowBox[{"MhpoleHSS", "[", 
         RowBox[{
         "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2",
           ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
          "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", 
          ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
          ",", "Xt", ",", "opts"}], "]"}]}]}]}], "]"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627823249848041*^9, 3.627823386659664*^9}, {
  3.6278234625951347`*^9, 3.627823464490324*^9}, {3.627823499914138*^9, 
  3.627823652878066*^9}, {3.627828330562728*^9, 3.627828345392874*^9}, {
  3.628109272739287*^9, 3.628109278679018*^9}, {3.6346741192519197`*^9, 
  3.634674140298354*^9}, {3.634674372022147*^9, 3.634674374552629*^9}, {
  3.6358336388317423`*^9, 3.635833639502232*^9}, {3.638041349012046*^9, 
  3.638041462472513*^9}, {3.6380416544309177`*^9, 3.638041664243115*^9}, {
  3.638102900097735*^9, 3.638102933818416*^9}, {3.6381898003901052`*^9, 
  3.6381898367331247`*^9}, {3.638189918753768*^9, 3.638189919188685*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "\[CapitalDelta]MhpoleHSSQfast", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DR\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSQfast", "[", 
   RowBox[{
    RowBox[{"n_", "?", "positiveQ"}], ",", "mtilde_", ",", "mQ1_", ",", 
    "mQ2_", ",", "mQ3_", ",", "mU1_", ",", "mU2_", ",", "mU3_", ",", "mD1_", 
    ",", "mD2_", ",", "mD3_", ",", "mE1_", ",", "mE2_", ",", "mE3_", ",", 
    "mL1_", ",", "mL2_", ",", "mL3_", ",", "mA_", ",", "\[Mu]_", ",", "M1_", 
    ",", "M2_", ",", "M3_", ",", "tan\[Beta]_", ",", "Xt_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"OptionValue", "[", "scheme", "]"}], "\[Equal]", "\"\<OS\>\""}], 
    ",", 
    RowBox[{
     RowBox[{"MhpoleHSSfast", "[", 
      RowBox[{
       RowBox[{"n", " ", "mtilde"}], ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", 
       "mU1", ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",",
        "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", 
       ",", "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
       "tan\[Beta]", ",", 
       RowBox[{"XtOS", "[", 
        RowBox[{"n", ",", "mtilde", ",", "Xt"}], "]"}], ",", "opts"}], "]"}], 
     "-", 
     RowBox[{"MhpoleHSSfast", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", "opts"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "mQ32new", ",", "mU32new", ",", "mD32new", ",", "\[Mu]new", ",", 
        "Xtnew"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "mQ32new", ",", "mU32new", ",", "mD32new", ",", "\[Mu]new", ",", 
          "Xtnew"}], "}"}], "=", 
        RowBox[{"spectrum", "[", 
         RowBox[{
         "n", ",", "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", 
          ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", 
          "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", 
          ",", "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
          "tan\[Beta]", ",", "Xt"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<spectrum\>\"", ",", "\"\<  \>\"", ",", "n", ",", "\"\<  \>\"", 
           ",", 
           SqrtBox["mQ32new"], ",", "\"\<  \>\"", ",", 
           SqrtBox["mU32new"], ",", "\"\<  \>\"", ",", 
           SqrtBox["mD32new"], ",", "\"\<  \>\"", ",", "\[Mu]new", ",", 
           "\"\<  \>\"", ",", "Xtnew"}], "]"}], ";"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           RowBox[{"mQ32new", ">", "0"}], "&&", 
           RowBox[{"mU32new", ">", "0"}], "&&", 
           RowBox[{"mD32new", ">", "0"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{"\[CapitalDelta]MHiggs", "::", "tachyon"}], "]"}], ";", 
          RowBox[{"Return", "[", "125", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"MhpoleHSSfast", "[", 
         RowBox[{
          RowBox[{"n", " ", "mtilde"}], ",", "mQ1", ",", "mQ2", ",", 
          SqrtBox["mQ32new"], ",", "mU1", ",", "mU2", ",", 
          SqrtBox["mU32new"], ",", "mD1", ",", "mD2", ",", 
          SqrtBox["mD32new"], ",", "mE1", ",", "mE2", ",", "mE3", ",", "mL1", 
          ",", "mL2", ",", "mL3", ",", "mA", ",", "\[Mu]new", ",", "M1", ",", 
          "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xtnew", ",", "opts"}], 
         "]"}], "-", 
        RowBox[{"MhpoleHSSfast", "[", 
         RowBox[{
         "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2",
           ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
          "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", 
          ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
          ",", "Xt", ",", "opts"}], "]"}]}]}]}], "]"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627884780797647*^9, 3.627884789549363*^9}, {
   3.6281092819273157`*^9, 3.628109286663362*^9}, {3.6346741192927847`*^9, 
   3.63467414147789*^9}, {3.6346743720235786`*^9, 3.634674374556349*^9}, {
   3.635833635336636*^9, 3.6358336358472424`*^9}, {3.6358387761371593`*^9, 
   3.6358388344730253`*^9}, {3.6358390463752623`*^9, 
   3.6358390730558357`*^9}, {3.635839260926639*^9, 3.635839269509975*^9}, {
   3.6358393172793093`*^9, 3.635839317934099*^9}, {3.6358394400764847`*^9, 
   3.635839444492363*^9}, {3.636204999862319*^9, 3.636205127900756*^9}, {
   3.638041490366747*^9, 3.6380415633901043`*^9}, {3.638041631266369*^9, 
   3.638041676822858*^9}, {3.638088106192815*^9, 3.638088123463315*^9}, {
   3.63818992228397*^9, 3.638189922577347*^9}, {3.638189964483671*^9, 
   3.6381899708598967`*^9}, {3.6381900096378927`*^9, 
   3.6381900156285686`*^9}, {3.6381900552046556`*^9, 3.638190081852572*^9}, {
   3.638190180829275*^9, 3.638190184504776*^9}, 3.63853499799326*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sbottom contribution ", "Subsection",
 CellChangeTimes->{{3.627830245476431*^9, 3.627830256956648*^9}, {
  3.6386215168383904`*^9, 3.638621545240925*^9}, {3.638621575830729*^9, 
  3.638621612248097*^9}, {3.6386218463628902`*^9, 3.6386218693716383`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSbottom", "[", 
   RowBox[{
    RowBox[{"mtilde_", "?", "positiveQ"}], ",", "mQ1_", ",", "mQ2_", ",", 
    "mQ3_", ",", "mU1_", ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", 
    ",", "mD3_", ",", "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", 
    "mL2_", ",", "mL3_", ",", "mA_", ",", "\[Mu]_", ",", "M1_", ",", "M2_", 
    ",", "M3_", ",", "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"tan\[Beta]", "<", "30"}], ",", "0", ",", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"MhpoleHSS", "[", 
       RowBox[{
       "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
        ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
        "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",",
         "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
        "Xt", ",", 
        RowBox[{"hiOrd", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1", ",", "1"}], "}"}]}]}], "]"}], "-", 
      
      RowBox[{"MhpoleHSS", "[", 
       RowBox[{
       "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
        ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
        "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",",
         "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
        "Xt", ",", 
        RowBox[{"hiOrd", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}]}], "]"}]}], 
     "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6278302921092854`*^9, 3.6278303531683207`*^9}, {
   3.6278303981849117`*^9, 3.627830398415976*^9}, {3.62783046519415*^9, 
   3.6278305142315283`*^9}, 3.627830599703917*^9, {3.62788491560366*^9, 
   3.627884916657187*^9}, {3.628109301313451*^9, 3.6281093060489473`*^9}, 
   3.632488846541988*^9, {3.634674119332178*^9, 3.6346741436733427`*^9}, {
   3.6346743720246773`*^9, 3.634674374560626*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]MhpoleHSSbottomfast", "[", 
   RowBox[{
    RowBox[{"mtilde_", "?", "positiveQ"}], ",", "mQ1_", ",", "mQ2_", ",", 
    "mQ3_", ",", "mU1_", ",", "mU2_", ",", "mU3_", ",", "mD1_", ",", "mD2_", 
    ",", "mD3_", ",", "mE1_", ",", "mE2_", ",", "mE3_", ",", "mL1_", ",", 
    "mL2_", ",", "mL3_", ",", "mA_", ",", "\[Mu]_", ",", "M1_", ",", "M2_", 
    ",", "M3_", ",", "tan\[Beta]_", ",", "Xt_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"tan\[Beta]", "<", "30"}], ",", "0", ",", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"MhpoleHSSfast", "[", 
       RowBox[{
       "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
        ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
        "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",",
         "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
        "Xt", ",", 
        RowBox[{"hiOrd", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1", ",", "1"}], "}"}]}]}], "]"}], "-", 
      
      RowBox[{"MhpoleHSSfast", "[", 
       RowBox[{
       "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
        ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
        "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",",
         "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
        "Xt", ",", 
        RowBox[{"hiOrd", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}]}], "]"}]}], 
     "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6278849218824368`*^9, 3.627884927872098*^9}, {
  3.628109310266816*^9, 3.628109312126443*^9}, {3.632488851469475*^9, 
  3.6324888560657587`*^9}, {3.6346741193747187`*^9, 3.6346741447402554`*^9}, {
  3.634674372026437*^9, 3.634674374564365*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Total", "Subsection",
 CellChangeTimes->{{3.627828405597433*^9, 3.6278284159441757`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "MhpoleHSSUnc", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"sources", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MhpoleHSSUnc", "[", 
   RowBox[{
    RowBox[{"mtilde_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ1_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ2_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ3_", "?", "positiveQ"}], ",", 
    RowBox[{"mU1_", "?", "positiveQ"}], ",", 
    RowBox[{"mU2_", "?", "positiveQ"}], ",", 
    RowBox[{"mU3_", "?", "positiveQ"}], ",", 
    RowBox[{"mD1_", "?", "positiveQ"}], ",", 
    RowBox[{"mD2_", "?", "positiveQ"}], ",", 
    RowBox[{"mD3_", "?", "positiveQ"}], ",", 
    RowBox[{"mE1_", "?", "positiveQ"}], ",", 
    RowBox[{"mE2_", "?", "positiveQ"}], ",", 
    RowBox[{"mE3_", "?", "positiveQ"}], ",", 
    RowBox[{"mL1_", "?", "positiveQ"}], ",", 
    RowBox[{"mL2_", "?", "positiveQ"}], ",", 
    RowBox[{"mL3_", "?", "positiveQ"}], ",", 
    RowBox[{"mA_", "?", "positiveQ"}], ",", 
    RowBox[{"\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"M1_", "?", "NumericQ"}], ",", 
    RowBox[{"M2_", "?", "NumericQ"}], ",", 
    RowBox[{"M3_", "?", "NumericQ"}], ",", 
    RowBox[{"tan\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"Xt_", "?", "NumericQ"}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"OptionValue", "[", "sources", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{"\[CapitalDelta]MhpoleHSSSM", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", 
       RowBox[{"FilterRules", "[", 
        RowBox[{
         RowBox[{"{", "opts", "}"}], ",", 
         RowBox[{"{", "scheme", "}"}]}], "]"}]}], "]"}], ",", "0"}], "]"}], 
   "+", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"OptionValue", "[", "sources", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"Abs", "@", 
          RowBox[{"\[CapitalDelta]MhpoleHSSQ", "[", 
           RowBox[{
           "2", ",", "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1",
             ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", 
            "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3",
             ",", "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
            "tan\[Beta]", ",", "Xt", ",", 
            RowBox[{"hiOrd", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "1", ",", "1", ",", 
               "1"}], "}"}]}]}], "]"}]}], ",", 
         RowBox[{"Abs", "@", 
          RowBox[{"\[CapitalDelta]MhpoleHSSQ", "[", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "mtilde", ",", "mQ1", ",", "mQ2", 
            ",", "mQ3", ",", "mU1", ",", "mU2", ",", "mU3", ",", "mD1", ",", 
            "mD2", ",", "mD3", ",", "mE1", ",", "mE2", ",", "mE3", ",", "mL1",
             ",", "mL2", ",", "mL3", ",", "mA", ",", "\[Mu]", ",", "M1", ",", 
            "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt", ",", 
            RowBox[{"hiOrd", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "1", ",", "1", ",", 
               "1"}], "}"}]}]}], "]"}]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"Max", "[", 
            RowBox[{
             RowBox[{"Abs", "@", 
              RowBox[{"\[CapitalDelta]MhpoleHSSQ", "[", 
               RowBox[{
               "2", ",", "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", 
                "mU1", ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", 
                "mD3", ",", "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", 
                "mL2", ",", "mL3", ",", "mA", ",", "\[Mu]", ",", "M1", ",", 
                "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt", ",", 
                RowBox[{"hiOrd", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0", ",", "1", ",", 
                   "1"}], "}"}]}]}], "]"}]}], ",", 
             RowBox[{"Abs", "@", 
              RowBox[{"\[CapitalDelta]MhpoleHSSQ", "[", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", "mtilde", ",", "mQ1", ",", 
                "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", ",", "mU3", ",", 
                "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2", ",", 
                "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
                "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
                ",", "Xt", ",", 
                RowBox[{"hiOrd", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0", ",", "1", ",", 
                   "1"}], "}"}]}]}], "]"}]}]}], "]"}], ",", "0"}], "]"}]}], 
        "   ", "]"}], "\[IndentingNewLine]", "+", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"\[CapitalDelta]MhpoleHSSbottom", "[", 
          RowBox[{
          "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
           "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", 
           ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
           "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
           "tan\[Beta]", ",", "Xt"}], "]"}], ",", "0"}], "]"}]}], ")"}], ",", 
     "0"}], "]"}], "+", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"OptionValue", "[", "sources", "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{"\[CapitalDelta]MhpoleHSSmom", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
       "Xt"}], "]"}], ",", "0"}], "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627828474822207*^9, 3.627828484262487*^9}, 
   3.627828717741989*^9, {3.627829107602788*^9, 3.6278291820688543`*^9}, {
   3.6278292613167143`*^9, 3.627829279495555*^9}, {3.6278293239669247`*^9, 
   3.6278293592491093`*^9}, {3.627829413341833*^9, 3.627829567913763*^9}, {
   3.627829923841546*^9, 3.627830029425899*^9}, {3.627830091906397*^9, 
   3.6278301071254463`*^9}, {3.6278305329839277`*^9, 3.6278305488326263`*^9}, 
   3.6281092328611526`*^9, 3.628152232786797*^9, {3.634647783671929*^9, 
   3.634647954726129*^9}, {3.634648011171277*^9, 3.634648030839099*^9}, 
   3.6346480770223103`*^9, {3.634674119411881*^9, 3.6346741480740128`*^9}, {
   3.634674372029845*^9, 3.634674374575939*^9}, {3.634675511310521*^9, 
   3.634675517495593*^9}, {3.6346755507817297`*^9, 3.634675562178316*^9}, {
   3.634676223729535*^9, 3.6346762288520317`*^9}, {3.634676589728499*^9, 
   3.6346766077936687`*^9}, {3.6347330907092323`*^9, 3.634733099903926*^9}, {
   3.634733302909205*^9, 3.6347333226513233`*^9}, {3.634733889177104*^9, 
   3.634733891287471*^9}, {3.634734069551209*^9, 3.634734070990364*^9}, {
   3.635831890683053*^9, 3.635831895345517*^9}, {3.6358359052552*^9, 
   3.6358359153199177`*^9}, 3.635836026187725*^9, {3.636018210396381*^9, 
   3.6360182472229557`*^9}, {3.6362638379856653`*^9, 3.636263893918373*^9}, {
   3.6362639273136673`*^9, 3.63626396591369*^9}, {3.6362653942718277`*^9, 
   3.6362654150173073`*^9}, {3.636265523190063*^9, 3.636265534077462*^9}, 
   3.636265572085888*^9, 3.636265707510902*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "MhpoleHSSUncfast", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"sources", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DRbar\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MhpoleHSSUncfast", "[", 
   RowBox[{
    RowBox[{"mtilde_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ1_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ2_", "?", "positiveQ"}], ",", 
    RowBox[{"mQ3_", "?", "positiveQ"}], ",", 
    RowBox[{"mU1_", "?", "positiveQ"}], ",", 
    RowBox[{"mU2_", "?", "positiveQ"}], ",", 
    RowBox[{"mU3_", "?", "positiveQ"}], ",", 
    RowBox[{"mD1_", "?", "positiveQ"}], ",", 
    RowBox[{"mD2_", "?", "positiveQ"}], ",", 
    RowBox[{"mD3_", "?", "positiveQ"}], ",", 
    RowBox[{"mE1_", "?", "positiveQ"}], ",", 
    RowBox[{"mE2_", "?", "positiveQ"}], ",", 
    RowBox[{"mE3_", "?", "positiveQ"}], ",", 
    RowBox[{"mL1_", "?", "positiveQ"}], ",", 
    RowBox[{"mL2_", "?", "positiveQ"}], ",", 
    RowBox[{"mL3_", "?", "positiveQ"}], ",", 
    RowBox[{"mA_", "?", "positiveQ"}], ",", 
    RowBox[{"\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"M1_", "?", "NumericQ"}], ",", 
    RowBox[{"M2_", "?", "NumericQ"}], ",", 
    RowBox[{"M3_", "?", "NumericQ"}], ",", 
    RowBox[{"tan\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"Xt_", "?", "NumericQ"}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"OptionValue", "[", "sources", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{"\[CapitalDelta]MhpoleHSSSMfast", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt",
        ",", 
       RowBox[{"FilterRules", "[", 
        RowBox[{
         RowBox[{"{", "opts", "}"}], ",", 
         RowBox[{"{", "scheme", "}"}]}], "]"}]}], "]"}], ",", "0"}], "]"}], 
   "+", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"OptionValue", "[", "sources", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"Abs", "@", 
          RowBox[{"\[CapitalDelta]MhpoleHSSQfast", "[", 
           RowBox[{
           "2", ",", "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1",
             ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", 
            "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3",
             ",", "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
            "tan\[Beta]", ",", "Xt", ",", 
            RowBox[{"hiOrd", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "1", ",", "1", ",", 
               "1"}], "}"}]}], ",", 
            RowBox[{"FilterRules", "[", 
             RowBox[{
              RowBox[{"{", "opts", "}"}], ",", 
              RowBox[{"{", "scheme", "}"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"Abs", "@", 
          RowBox[{"\[CapitalDelta]MhpoleHSSQfast", "[", 
           RowBox[{
            RowBox[{"1", "/", "2"}], ",", "mtilde", ",", "mQ1", ",", "mQ2", 
            ",", "mQ3", ",", "mU1", ",", "mU2", ",", "mU3", ",", "mD1", ",", 
            "mD2", ",", "mD3", ",", "mE1", ",", "mE2", ",", "mE3", ",", "mL1",
             ",", "mL2", ",", "mL3", ",", "mA", ",", "\[Mu]", ",", "M1", ",", 
            "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt", ",", 
            RowBox[{"hiOrd", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "1", ",", "1", ",", 
               "1"}], "}"}]}], ",", 
            RowBox[{"FilterRules", "[", 
             RowBox[{
              RowBox[{"{", "opts", "}"}], ",", 
              RowBox[{"{", "scheme", "}"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"Max", "[", 
            RowBox[{
             RowBox[{"Abs", "@", 
              RowBox[{"\[CapitalDelta]MhpoleHSSQfast", "[", 
               RowBox[{
               "2", ",", "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", 
                "mU1", ",", "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", 
                "mD3", ",", "mE1", ",", "mE2", ",", "mE3", ",", "mL1", ",", 
                "mL2", ",", "mL3", ",", "mA", ",", "\[Mu]", ",", "M1", ",", 
                "M2", ",", "M3", ",", "tan\[Beta]", ",", "Xt", ",", 
                RowBox[{"hiOrd", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0", ",", "1", ",", 
                   "1"}], "}"}]}], ",", 
                RowBox[{"FilterRules", "[", 
                 RowBox[{
                  RowBox[{"{", "opts", "}"}], ",", 
                  RowBox[{"{", "scheme", "}"}]}], "]"}]}], "]"}]}], ",", 
             RowBox[{"Abs", "@", 
              RowBox[{"\[CapitalDelta]MhpoleHSSQfast", "[", 
               RowBox[{
                RowBox[{"1", "/", "2"}], ",", "mtilde", ",", "mQ1", ",", 
                "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", ",", "mU3", ",", 
                "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2", ",", 
                "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
                "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
                ",", "Xt", ",", 
                RowBox[{"hiOrd", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0", ",", "1", ",", 
                   "1"}], "}"}]}], ",", 
                RowBox[{"FilterRules", "[", 
                 RowBox[{
                  RowBox[{"{", "opts", "}"}], ",", 
                  RowBox[{"{", "scheme", "}"}]}], "]"}]}], "]"}]}]}], "]"}], 
           ",", "0"}], "]"}]}], "   ", "]"}], "\[IndentingNewLine]", "+", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"OptionValue", "[", "hiOrd", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"\[CapitalDelta]MhpoleHSSbottomfast", "[", 
          RowBox[{
          "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", 
           "mU2", ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", 
           ",", "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", 
           "mA", ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", 
           "tan\[Beta]", ",", "Xt"}], "]"}], ",", "0"}], "]"}]}], ")"}], ",", 
     "0"}], "]"}], "+", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"OptionValue", "[", "sources", "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{"\[CapitalDelta]MhpoleHSSmomfast", "[", 
      RowBox[{
      "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2", 
       ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", "mE2",
        ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", ",", 
       "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", ",", 
       "Xt"}], "]"}], ",", "0"}], "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.627884990731722*^9, 3.627885005542966*^9}, 
   3.628109240535245*^9, 3.6281522381549883`*^9, {3.634674119426682*^9, 
   3.634674150866642*^9}, {3.634674372039735*^9, 3.634674374587044*^9}, {
   3.63467620939859*^9, 3.634676257321501*^9}, {3.634676288537916*^9, 
   3.6346762966883793`*^9}, 3.634676358720539*^9, {3.6346765361217833`*^9, 
   3.634676566244759*^9}, 3.634733124313388*^9, {3.634733896949504*^9, 
   3.634733898760284*^9}, {3.6347339288171873`*^9, 3.634733929832107*^9}, {
   3.635833569427771*^9, 3.6358335715890017`*^9}, {3.635835696662602*^9, 
   3.635835733846027*^9}, {3.635836519736719*^9, 3.635836531806695*^9}, {
   3.6358365700560293`*^9, 3.6358365723113127`*^9}, {3.6358366027612133`*^9, 
   3.6358367326759357`*^9}, {3.6358371522083683`*^9, 3.635837171679435*^9}, {
   3.635837207378262*^9, 3.635837223279376*^9}, {3.63583727035677*^9, 
   3.6358373477429247`*^9}, {3.6358375227818193`*^9, 3.635837527853704*^9}, {
   3.635837897475601*^9, 3.635837948402104*^9}, {3.635838001190679*^9, 
   3.6358380450208683`*^9}, {3.635838077208804*^9, 3.635838079917006*^9}, {
   3.635838116660152*^9, 3.635838270158486*^9}, 3.635838439807549*^9, {
   3.63583848701516*^9, 3.635838555273922*^9}, {3.636263979257592*^9, 
   3.636264011297594*^9}, {3.636264322695157*^9, 3.636264322910921*^9}, {
   3.636265556567153*^9, 3.6362655992444887`*^9}, {3.636265691763163*^9, 
   3.6362656981798897`*^9}, {3.636266247717392*^9, 3.6362662595438137`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\[CapitalDelta]MHiggs Function", "Subsection",
 CellChangeTimes->{{3.627828405597433*^9, 3.6278284159441757`*^9}, {
  3.634675487211337*^9, 3.634675495846074*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "\[CapitalDelta]MHiggs", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hiOrd", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"sources", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
     RowBox[{"numerical", "\[Rule]", "False"}], ",", 
     RowBox[{"Rscale", "\[Rule]", "0"}], ",", 
     RowBox[{"scheme", "\[Rule]", "\"\<DR\>\""}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]MHiggs", "[", 
    RowBox[{
     RowBox[{"shortList_", "?", "numericListQ"}], ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "tan\[Beta]", ",", "M1", ",", "M2", ",", "M3", ",", "\[Mu]", ",", "At", 
       ",", "mQ3", ",", "mU3", ",", "mD3", ",", "mQ2", ",", "mU2", ",", "mD2",
        ",", "mQ1", ",", "mU1", ",", "mD1", ",", "mL3", ",", "mE3", ",", 
       "mL2", ",", "mE2", ",", "mL1", ",", "mE1", ",", "mA", ",", "Xt", ",", 
       "mtilde", ",", "msplit"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "tan\[Beta]", ",", "M1", ",", "M2", ",", "M3", ",", "\[Mu]", ",", 
         "At", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "mQ2", ",", "mU2", 
         ",", "mD2", ",", "mQ1", ",", "mU1", ",", "mD1", ",", "mL3", ",", 
         "mE3", ",", "mL2", ",", "mE2", ",", "mL1", ",", "mE1", ",", "mA"}], 
        "}"}], "=", 
       RowBox[{"getList", "[", "shortList", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"NumericQ", "[", "tan\[Beta]", "]"}], "&&", 
         RowBox[{"tan\[Beta]", "\[GreaterEqual]", "1"}], "&&", 
         RowBox[{"cond", "[", "M1", "]"}], "&&", 
         RowBox[{"cond", "[", "M2", "]"}], "&&", 
         RowBox[{"cond", "[", "M3", "]"}], "&&", 
         RowBox[{"cond", "[", "\[Mu]", "]"}], "&&", 
         RowBox[{
          RowBox[{"Im", "[", "At", "]"}], "\[Equal]", "0"}], "&&", 
         RowBox[{"NumericQ", "[", "At", "]"}], "&&", 
         RowBox[{"cond", "[", "mQ3", "]"}], "&&", 
         RowBox[{"cond", "[", "mU3", "]"}], "&&", 
         RowBox[{"cond", "[", "mD3", "]"}], "&&", 
         RowBox[{"cond", "[", "mQ2", "]"}], "&&", 
         RowBox[{"cond", "[", "mU2", "]"}], "&&", 
         RowBox[{"cond", "[", "mD2", "]"}], "&&", 
         RowBox[{"cond", "[", "mQ1", "]"}], "&&", 
         RowBox[{"cond", "[", "mU1", "]"}], "&&", 
         RowBox[{"cond", "[", "mD1", "]"}], "&&", 
         RowBox[{"cond", "[", "mL3", "]"}], "&&", 
         RowBox[{"cond", "[", "mE3", "]"}], "&&", 
         RowBox[{"cond", "[", "mL2", "]"}], "&&", 
         RowBox[{"cond", "[", "mE2", "]"}], "&&", 
         RowBox[{"cond", "[", "mL1", "]"}], "&&", 
         RowBox[{"cond", "[", "mE1", "]"}], "&&", 
         RowBox[{"cond", "[", "mA", "]"}]}], ",", "1", ",", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{"MHiggs", "::", "variables"}], "]"}], ";", 
         RowBox[{"Return", "[", "0", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Xt", "=", 
       RowBox[{"At", "-", 
        RowBox[{"\[Mu]", " ", "/", "tan\[Beta]"}]}]}], ";", 
      RowBox[{"mtilde", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"OptionValue", "[", "Rscale", "]"}], "<", "200"}], ",", 
         SqrtBox[
          RowBox[{"mQ3", " ", "mU3"}]], ",", 
         RowBox[{"OptionValue", "[", "Rscale", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           FractionBox["1", "10"], "\[LessEqual]", 
           FractionBox["mtilde", 
            SqrtBox[
             RowBox[{"mQ3", " ", "mU3"}]]], "\[LessEqual]", "10"}], "]"}], "||", 
         RowBox[{"0", "<", 
          RowBox[{"OptionValue", "[", "Rscale", "]"}], "<", "200"}]}], ",", 
        RowBox[{"Message", "[", 
         RowBox[{"MHiggs", "::", "warning"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"testgbDR", "[", 
         RowBox[{
         "mtilde", ",", "mQ3", ",", "mU3", ",", "mD3", ",", "M3", ",", 
          "\[Mu]", ",", "tan\[Beta]", ",", "Xt"}], "]"}], ",", 
        RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"testgtauDR", "[", 
         RowBox[{
         "mtilde", ",", "mL3", ",", "mE3", ",", "M2", ",", "M1", ",", "\[Mu]",
           ",", "tan\[Beta]"}], "]"}], ",", 
        RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{"OptionValue", "@", "numerical"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"MhpoleHSSUncfast", "[", 
         RowBox[{
         "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2",
           ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
          "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", 
          ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
          ",", "Xt", ",", 
          RowBox[{"FilterRules", "[", 
           RowBox[{
            RowBox[{"{", "opts", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"hiOrd", ",", "sources", ",", "scheme"}], "}"}]}], 
           "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"OptionValue", "@", "numerical"}], ",", "\[IndentingNewLine]", 
        RowBox[{"MhpoleHSSUnc", "[", 
         RowBox[{
         "mtilde", ",", "mQ1", ",", "mQ2", ",", "mQ3", ",", "mU1", ",", "mU2",
           ",", "mU3", ",", "mD1", ",", "mD2", ",", "mD3", ",", "mE1", ",", 
          "mE2", ",", "mE3", ",", "mL1", ",", "mL2", ",", "mL3", ",", "mA", 
          ",", "\[Mu]", ",", "M1", ",", "M2", ",", "M3", ",", "tan\[Beta]", 
          ",", "Xt", ",", 
          RowBox[{"FilterRules", "[", 
           RowBox[{
            RowBox[{"{", "opts", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"hiOrd", ",", "sources"}], "}"}]}], "]"}]}], "]"}]}], 
       "]"}]}]}], "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6346767813041763`*^9, 3.6346768031652927`*^9}, {
   3.6346770379976397`*^9, 3.63467703892164*^9}, {3.634677078437952*^9, 
   3.634677185713228*^9}, {3.634677621266511*^9, 3.6346776326657467`*^9}, 
   3.634677688500719*^9, {3.634677742221809*^9, 3.6346777805748167`*^9}, {
   3.634677899929187*^9, 3.634677901599723*^9}, {3.634678015353879*^9, 
   3.6346780291771317`*^9}, {3.634678227142076*^9, 3.634678241996304*^9}, {
   3.6346782914201*^9, 3.634678291591934*^9}, {3.6347331063052597`*^9, 
   3.634733112863716*^9}, 3.6347339102623653`*^9, {3.634734180575919*^9, 
   3.6347341978797827`*^9}, {3.635517972080969*^9, 3.635517975346345*^9}, {
   3.635684752013975*^9, 3.635684763710784*^9}, {3.635684813838306*^9, 
   3.635684814021695*^9}, 3.635685214466978*^9, {3.6356886528262367`*^9, 
   3.635688706899609*^9}, {3.635689891359618*^9, 3.635689901395697*^9}, {
   3.6356899391461163`*^9, 3.635689939562356*^9}, {3.635690034205976*^9, 
   3.635690042217414*^9}, {3.635710377002761*^9, 3.6357103992746487`*^9}, 
   3.6360181568408527`*^9, 3.6360222595777283`*^9, {3.636022706706236*^9, 
   3.636022729053856*^9}, {3.6362051530925417`*^9, 3.636205156975816*^9}, {
   3.6362054034535418`*^9, 3.6362054044918327`*^9}, {3.6363660631727457`*^9, 
   3.636366063502469*^9}, {3.636369991770266*^9, 3.636370002600855*^9}, 
   3.6363738030185347`*^9, 3.638046030746866*^9, {3.638091125295664*^9, 
   3.638091125886333*^9}, {3.6380911680149527`*^9, 3.6380911828286552`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"End", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6201234281919928`*^9, 3.620123429316704*^9}, {
  3.620123563531782*^9, 3.6201235672133293`*^9}}],

Cell[BoxData["\<\"Private`\"\>"], "Output",
 CellChangeTimes->{
  3.6201325729826612`*^9, 3.620132610478942*^9, {3.62013265197954*^9, 
   3.620132669704795*^9}, 3.620132704111268*^9, 3.620219988823629*^9, 
   3.620221964771206*^9, 3.620222643869029*^9, 3.620222674438089*^9, 
   3.6202258142778997`*^9, 3.620306605791069*^9, 3.6203070318098173`*^9, 
   3.620307145161228*^9, 3.620307351646105*^9, 3.6203103968093557`*^9, 
   3.620310722538348*^9, 3.620310822295237*^9, 3.620310964734676*^9, 
   3.62031110670183*^9, 3.6203111707962*^9, 3.620311608905447*^9, 
   3.6203119924094152`*^9, {3.620312082377084*^9, 3.6203120993773947`*^9}, 
   3.6203122205832233`*^9, 3.620312554395784*^9, 3.620313737424383*^9, 
   3.620320214748713*^9, 3.620322761995248*^9, 3.6203230927403*^9, 
   3.620326524121333*^9, 3.6203836189210777`*^9, 3.620384488539975*^9, 
   3.620456429660733*^9, 3.6204564834677267`*^9, 3.6204566912173767`*^9, 
   3.6205491611963387`*^9, 3.620550414877236*^9, {3.620550463952883*^9, 
   3.620550493944912*^9}, 3.62115728304862*^9, {3.6211573712298527`*^9, 
   3.6211573833382*^9}, 3.621520727970949*^9, 3.621521223508548*^9, 
   3.621521261503654*^9, 3.621521451489984*^9, 3.621661290450468*^9, {
   3.622176378267982*^9, 3.62217639597119*^9}, 3.622176997147451*^9, 
   3.622351156468664*^9, 3.6223541818105173`*^9, {3.62235460466783*^9, 
   3.622354631563876*^9}, 3.62236863488165*^9, 3.622368669812174*^9, 
   3.622368908072741*^9, 3.622369372903404*^9, {3.6223710129365873`*^9, 
   3.6223710421902523`*^9}, 3.622371102047926*^9, {3.622371291574541*^9, 
   3.6223713262058077`*^9}, 3.622371673021332*^9, {3.6223748867032022`*^9, 
   3.622374914351708*^9}, 3.62237530258739*^9, 3.622375359504417*^9, {
   3.622436391111657*^9, 3.622436417219726*^9}, 3.622453769726418*^9, {
   3.622454770725689*^9, 3.622454782607067*^9}, 3.622454994849079*^9, {
   3.6224550866454887`*^9, 3.622455098965941*^9}, 3.622783191157395*^9, 
   3.622783260190136*^9, 3.622783955543022*^9, {3.6228841568220577`*^9, 
   3.622884166865081*^9}, 3.622884416826653*^9, {3.6228845799482307`*^9, 
   3.622884589225993*^9}, 3.622884622349723*^9, 3.6228846629883633`*^9, 
   3.6228850534624767`*^9, 3.622885543564363*^9, 3.622885673243058*^9, 
   3.622885714066555*^9, 3.6228861999048634`*^9, {3.622886233899726*^9, 
   3.6228862578174143`*^9}, 3.6228863230540943`*^9, 3.6228864648665733`*^9, 
   3.622886628987112*^9, 3.622886728413083*^9, 3.622886869906343*^9, {
   3.622886918210375*^9, 3.6228869325349283`*^9}, {3.6228871293521013`*^9, 
   3.622887154337371*^9}, {3.622887356643589*^9, 3.6228873821892138`*^9}, {
   3.62288747485393*^9, 3.622887495571229*^9}, 3.62288795434719*^9, 
   3.622887994194932*^9, 3.6228880388213997`*^9, 3.622888211835837*^9, 
   3.622888333103518*^9, {3.622888392124147*^9, 3.622888398601953*^9}, 
   3.622888471663018*^9, 3.622888661367237*^9, 3.622888726728368*^9, 
   3.622888836054146*^9, 3.6228888822113867`*^9, 3.62288894452523*^9, 
   3.622888981026752*^9, 3.622889070133569*^9, {3.622889844350361*^9, 
   3.622889850314362*^9}, {3.622890241303672*^9, 3.622890258552477*^9}, 
   3.622890293259968*^9, 3.622890586998657*^9, 3.6228906422034187`*^9, {
   3.622890714746365*^9, 3.62289073626262*^9}, 3.6228909273167057`*^9, 
   3.622890981078726*^9, 3.622891136537505*^9, 3.622891436844555*^9, 
   3.622891579936226*^9, 3.6230412743180733`*^9, 3.62516735264364*^9, {
   3.625167709934806*^9, 3.6251677542249193`*^9}, 3.625170736830027*^9, 
   3.625170838884891*^9, 3.625171046100342*^9, 3.625171280112879*^9, 
   3.62517132484759*^9, 3.625171591550131*^9, {3.625172048564661*^9, 
   3.625172059976304*^9}, 3.625172464779025*^9, 3.625172610858254*^9, 
   3.625172782742831*^9, 3.625173189342906*^9, 3.625173243713771*^9, 
   3.625173345341436*^9, 3.625173382955269*^9, 3.625173754266284*^9, 
   3.6251739089724607`*^9, 3.6251740970586843`*^9, 3.625174142266506*^9, 
   3.625174463381171*^9, 3.625174855883586*^9, 3.6251750701992273`*^9, 
   3.625175409262886*^9, 3.625175440043288*^9, 3.625175588958317*^9, 
   3.625175664966189*^9, 3.625204920306685*^9, 3.625205005123322*^9, 
   3.625205045180923*^9, 3.625205177979178*^9, 3.625205423343526*^9, 
   3.625205458597012*^9, 3.625205571552268*^9, 3.6252486313323107`*^9, 
   3.6252487026389*^9, {3.625248747100794*^9, 3.6252487565361643`*^9}, 
   3.625248794870296*^9, 3.625248831722933*^9, 3.625248967137044*^9, {
   3.625256652025585*^9, 3.6252566807639437`*^9}, {3.62525700641567*^9, 
   3.6252570471485662`*^9}, 3.6252582562932253`*^9, 3.627124066230835*^9, 
   3.6271251924764853`*^9, 3.627624080638029*^9, 3.627647112034758*^9, 
   3.6277242698327293`*^9, 3.627726478786192*^9, 3.627802136157423*^9, 
   3.627826166907531*^9, 3.627826273147871*^9, {3.6278263441494093`*^9, 
   3.627826362254578*^9}, 3.627826407576161*^9, 3.627826656008696*^9, 
   3.627882553286066*^9, 3.627882614978907*^9, {3.627882662397181*^9, 
   3.627882673051557*^9}, 3.627884080886569*^9, {3.627884143134207*^9, 
   3.6278841664584084`*^9}, 3.6278841977236547`*^9, 3.627884327273089*^9, {
   3.627884511596616*^9, 3.6278845580116796`*^9}, 3.627884589278726*^9, 
   3.62788465801031*^9, 3.62788480819092*^9, {3.627884862371437*^9, 
   3.627884891832253*^9}, 3.627884946233436*^9, 3.6278850255722303`*^9, {
   3.627885086545937*^9, 3.627885117723001*^9}, {3.627885276325554*^9, 
   3.627885286396514*^9}, 3.62788537617962*^9, 3.628104268775991*^9, 
   3.6281043631549397`*^9, 3.638042051911058*^9, 3.638042281566866*^9, 
   3.638042426798027*^9, 3.638088246364829*^9, 3.638251070261162*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.620123395022778*^9, 3.620123405190298*^9}, {
  3.620123563531909*^9, 3.620123567213441*^9}}]
}, Closed]]
}, Closed]]
}, Closed]]
},
WindowSize->{1360, 718},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.0 for Linux x86 (64-bit) (June 27, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 300, 5, 129, "Title"],
Cell[883, 29, 558, 9, 94, "Text"],
Cell[CellGroupData[{
Cell[1466, 42, 230, 4, 67, "Section"],
Cell[CellGroupData[{
Cell[1721, 50, 171, 3, 72, "Input",
 InitializationCell->True],
Cell[1895, 55, 86, 1, 72, "Output"]
}, Open  ]],
Cell[1996, 59, 1054, 25, 228, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3075, 88, 43630, 781, 8041, "Input",
 InitializationCell->True],
Cell[46708, 871, 581, 9, 235, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47326, 885, 166, 3, 72, "Input",
 InitializationCell->True],
Cell[47495, 890, 85, 1, 72, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47641, 898, 141, 2, 120, "Title"],
Cell[47785, 902, 329, 6, 62, "Text"],
Cell[CellGroupData[{
Cell[48139, 912, 111, 2, 103, "Section"],
Cell[48253, 916, 2336, 53, 650, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[50626, 974, 170, 4, 76, "Section"],
Cell[CellGroupData[{
Cell[50821, 982, 15587, 444, 35283, "Input"],
Cell[66411, 1428, 408, 8, 35283, "Output"],
Cell[66822, 1438, 7925, 237, 35283, "Output"],
Cell[74750, 1677, 4585, 129, 35283, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[79384, 1812, 148, 2, 101, "Section"],
Cell[79535, 1816, 58188, 1597, 7483, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[137760, 3418, 198, 3, 101, "Section"],
Cell[137961, 3423, 5086, 111, 333, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[143096, 3540, 148, 2, 86, "Title"],
Cell[143247, 3544, 470, 8, 62, "Text"],
Cell[CellGroupData[{
Cell[143742, 3556, 108, 2, 103, "Section"],
Cell[143853, 3560, 2831, 70, 668, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[146721, 3635, 197, 3, 101, "Section"],
Cell[146921, 3640, 1138, 34, 383, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[148084, 3678, 240, 7, 137, "Subsubsection"],
Cell[148327, 3687, 3227, 107, 188, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[151591, 3799, 308, 9, 110, "Subsubsection"],
Cell[151902, 3810, 12962, 426, 1483, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[164901, 4241, 335, 9, 110, "Subsubsection"],
Cell[165239, 4252, 4577, 152, 512, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[169853, 4409, 337, 9, 110, "Subsubsection"],
Cell[170193, 4420, 101193, 3191, 7738, "Input",
 InitializationCell->True],
Cell[271389, 7613, 1165, 37, 112, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[272603, 7656, 138, 2, 101, "Section"],
Cell[272744, 7660, 5047, 111, 368, "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[277840, 7777, 197, 3, 86, "Title"],
Cell[278040, 7782, 624, 10, 40, "Text"],
Cell[CellGroupData[{
Cell[278689, 7796, 111, 2, 67, "Section"],
Cell[278803, 7800, 12874, 222, 2306, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[291714, 8027, 152, 2, 65, "Section"],
Cell[CellGroupData[{
Cell[291891, 8033, 98, 1, 58, "Subsection"],
Cell[CellGroupData[{
Cell[292014, 8038, 189, 3, 66, "Subsubsection"],
Cell[292206, 8043, 2435, 47, 421, "Input",
 InitializationCell->True],
Cell[294644, 8092, 9734, 285, 1845, "Input",
 InitializationCell->True],
Cell[304381, 8379, 12055, 350, 1088, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[316461, 8733, 1398, 44, 160, "Input"],
Cell[317862, 8779, 8332, 248, 1553, "Output"]
}, Closed]],
Cell[326209, 9030, 10520, 298, 1328, "Input"],
Cell[336732, 9330, 12055, 350, 1088, "Input",
 InitializationCell->True],
Cell[348790, 9682, 18668, 527, 2710, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[367495, 10214, 263, 4, 71, "Subsubsection"],
Cell[367761, 10220, 309, 6, 120, "Text"],
Cell[CellGroupData[{
Cell[368095, 10230, 178, 3, 112, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[368276, 10235, 25379, 738, 3097, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[393670, 10976, 22790, 703, 4203, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[416497, 11684, 346, 5, 71, "Subsubsection"],
Cell[CellGroupData[{
Cell[416868, 11693, 2488, 70, 222, "Input"],
Cell[419359, 11765, 22560, 589, 1553, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[441956, 12359, 2548, 71, 197, "Input"],
Cell[444507, 12432, 20573, 540, 1553, "Output"]
}, Closed]],
Cell[465095, 12975, 23478, 600, 4531, "Input",
 InitializationCell->True],
Cell[488576, 13577, 25067, 599, 4601, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[513680, 14181, 548, 13, 71, "Subsubsection"],
Cell[514231, 14196, 797, 26, 140, "Text"],
Cell[CellGroupData[{
Cell[515053, 14226, 203, 3, 77, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[515259, 14231, 2718, 76, 1553, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[517980, 14309, 507, 13, 1553, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[518490, 14324, 1839, 50, 1553, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[520344, 14377, 7852, 231, 1118, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[528233, 14613, 605, 14, 71, "Subsubsection"],
Cell[528841, 14629, 852, 26, 140, "Text"],
Cell[529696, 14657, 4185, 110, 635, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[533930, 14773, 101, 1, 72, "Subsection"],
Cell[CellGroupData[{
Cell[534056, 14778, 640, 17, 52, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[534699, 14797, 1916, 59, 218, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[536618, 14858, 229738, 6087, 21093, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[766393, 20950, 358, 13, 71, "Subsubsection"],
Cell[766754, 20965, 816, 24, 137, "Text"],
Cell[767573, 20991, 11126, 244, 1196, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[778724, 21239, 236, 5, 72, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[778963, 21246, 3780, 93, 578, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[782746, 21341, 2569, 70, 766, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[785352, 21416, 442, 10, 103, "Input"],
Cell[785797, 21428, 1831, 61, 1553, "Output"]
}, Closed]],
Cell[787643, 21492, 2341, 69, 446, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[790009, 21565, 2432, 73, 197, "Input"],
Cell[792444, 21640, 165805, 4675, 1553, "Output"]
}, Closed]],
Cell[958264, 26318, 170684, 4680, 20395, "Input",
 InitializationCell->True],
Cell[1128951, 31000, 167, 3, 72, "Input"],
Cell[1129121, 31005, 11512, 262, 1143, "Input",
 InitializationCell->True],
Cell[1140636, 31269, 30125, 716, 3957, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1170798, 31990, 427, 13, 78, "Subsubsection"],
Cell[1171228, 32005, 833, 25, 137, "Text"],
Cell[CellGroupData[{
Cell[1172086, 32034, 201, 3, 77, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1172290, 32039, 11316, 308, 1553, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1183609, 32349, 13364, 387, 1553, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[1196988, 32739, 28661, 743, 4432, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1225698, 33488, 153, 2, 72, "Subsection"],
Cell[1225854, 33492, 6376, 138, 1057, "Input",
 InitializationCell->True],
Cell[1232233, 33632, 8163, 199, 783, "Input",
 InitializationCell->True],
Cell[1240399, 33833, 11316, 309, 1168, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1251776, 34149, 92, 1, 150, "Title"],
Cell[1251871, 34152, 264, 5, 83, "Text"],
Cell[CellGroupData[{
Cell[1252160, 34161, 261, 3, 103, "Section"],
Cell[1252424, 34166, 379, 9, 115, "Input",
 InitializationCell->True],
Cell[1252806, 34177, 3136, 68, 402, "Input",
 InitializationCell->True],
Cell[1255945, 34247, 6926, 164, 817, "Input",
 InitializationCell->True],
Cell[1262874, 34413, 2223, 57, 270, "Input",
 InitializationCell->True],
Cell[1265100, 34472, 552, 14, 68, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1265689, 34491, 168, 2, 81, "Section"],
Cell[CellGroupData[{
Cell[1265882, 34497, 174, 2, 72, "Subsection"],
Cell[1266059, 34501, 596, 14, 80, "Input"],
Cell[CellGroupData[{
Cell[1266680, 34519, 422, 6, 75, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1267105, 34527, 1764400, 48806, 339243, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True]
}, Closed]],
Cell[3031520, 83336, 335, 6, 77, "Text"],
Cell[3031858, 83344, 352, 8, 47, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3032247, 83357, 153, 2, 58, "Subsection"],
Cell[3032403, 83361, 8280, 185, 1312, "Input",
 InitializationCell->True],
Cell[3040686, 83548, 11584, 255, 1675, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3052307, 83808, 94, 1, 58, "Subsection"],
Cell[3052404, 83811, 19624, 433, 3212, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3072065, 84249, 202, 3, 58, "Subsection"],
Cell[CellGroupData[{
Cell[3072292, 84256, 100, 1, 57, "Subsubsection"],
Cell[3072395, 84259, 9464, 213, 1406, "Input",
 InitializationCell->True],
Cell[3081862, 84474, 3496, 88, 788, "Input",
 InitializationCell->True],
Cell[3085361, 84564, 3493, 81, 627, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3088891, 84650, 101, 1, 46, "Subsubsection"],
Cell[3088995, 84653, 14187, 302, 2103, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3103243, 84962, 165, 2, 81, "Section"],
Cell[CellGroupData[{
Cell[3103433, 84968, 533, 15, 77, "Subsection"],
Cell[3103969, 84985, 6448, 139, 1195, "Input",
 InitializationCell->True],
Cell[3110420, 85126, 6932, 124, 815, "Input",
 InitializationCell->True],
Cell[3117355, 85252, 1692, 34, 400, "Input",
 InitializationCell->True],
Cell[3119050, 85288, 1973, 38, 400, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3121060, 85331, 313, 4, 58, "Subsection"],
Cell[3121376, 85337, 2348, 49, 460, "Input",
 InitializationCell->True],
Cell[3123727, 85388, 2386, 49, 460, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3126150, 85442, 329, 4, 58, "Subsection"],
Cell[CellGroupData[{
Cell[3126504, 85450, 103, 1, 57, "Subsubsection"],
Cell[3126610, 85453, 18568, 550, 2906, "Input"],
Cell[CellGroupData[{
Cell[3145203, 86007, 1511, 43, 168, "Input"],
Cell[3146717, 86052, 14964, 400, 1553, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3161718, 86457, 1212, 39, 346, "Input"],
Cell[3162933, 86498, 692, 21, 1553, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3163674, 86525, 264, 3, 46, "Subsubsection"],
Cell[3163941, 86530, 578, 15, 61, "Text"],
Cell[3164522, 86547, 18616, 462, 2485, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3183175, 87014, 104, 1, 46, "Subsubsection"],
Cell[3183282, 87017, 4864, 101, 646, "Input",
 InitializationCell->True],
Cell[3188149, 87120, 5695, 117, 697, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3193893, 87243, 259, 3, 58, "Subsection"],
Cell[3194155, 87248, 2094, 42, 236, "Input",
 InitializationCell->True],
Cell[3196252, 87292, 1955, 40, 236, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3198244, 87337, 95, 1, 58, "Subsection"],
Cell[3198342, 87340, 9159, 190, 705, "Input",
 InitializationCell->True],
Cell[3207504, 87532, 9852, 205, 798, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3217393, 87742, 169, 2, 58, "Subsection"],
Cell[3217565, 87746, 7966, 170, 815, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3225556, 87920, 197, 4, 47, "Input",
 InitializationCell->True],
Cell[3225756, 87926, 5529, 77, 47, "Output"]
}, Open  ]],
Cell[3231300, 88006, 200, 4, 47, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
